@@ -11,10 +11,6 @@
 ; WARNING - YOU SHOULD NOT EDIT THIS FILE DIRECTLY - Edit config.ini.php instead.
 ;--------
 
-[superuser]
-login			= 
-password		=
-
 [database]
 host			=
 username		=
@@ -36,7 +32,11 @@ dbname			= piwik_tests
 tables_prefix	= piwiktests_
 port			= 3306
 adapter 		= PDO_MYSQL
- 
+
+[superuser]
+login			= 
+password		=
+
 [Debug]
 ; if set to 1, the archiving process will always be triggered, even if the archive has already been computed
 ; this is useful when making changes to the archiving code so we can force the archiving process
@@ -96,7 +96,7 @@ action_category_level_limit = 10
 autocomplete_min_sites = 5
 
 ; maximum number of websites showed in search results in autocompleter
-site_selector_max_sites = 10
+site_selector_max_sites = 15
 
 ; if set to 1, shows sparklines (evolution graph) in 'All Websites' report (MultiSites plugin)
 show_multisites_sparklines = 1
@@ -147,6 +147,11 @@ enable_browser_archiving_triggering = 1
 ; At the moment, this is not needed in core but it can be handy for plugins
 enable_archive_parents_of_datatable = 0
 
+; By default Piwik runs OPTIMIZE TABLE SQL queries to free spaces after deleting some data.
+; If your Piwik tracks millions of pages, the OPTIMIZE TABLE queries might run for hours (seen in "SHOW FULL PROCESSLIST \g")
+; so you can disable these special queries here:
+enable_sql_optimize_queries = 1
+
 ; MySQL minimum required version
 ; note: timezone support added in 4.1.3
 minimum_mysql_version = 4.1
@@ -199,6 +204,10 @@ login_password_recovery_email_address = "password-recovery@{DOMAIN}"
 ; name that appears as a Sender in the password recovery email
 login_password_recovery_email_name = Piwik
 
+; By default when user logs out he is redirected to Piwik "homepage" usually the Login form.
+; Uncomment the next line to set a URL to redirect the user to after he logs out of Piwik.
+; login_logout_url = http://...
+
 ; Set to 1 to disable the framebuster on standard Non-widgets pages (a click-jacking countermeasure).
 ; Default is 0 (i.e., bust frames on all non Widget pages such as Login, API, Widgets, Email reports, etc.).
 enable_framed_pages = 0
@@ -234,6 +243,11 @@ datatable_archiving_maximum_rows_subtable_actions = 100
 ; maximum number of rows for other tables (Providers, User settings configurations)
 datatable_archiving_maximum_rows_standard = 500
 
+; maximum number of rows to fetch from the database when archiving. if set to 0, no limit is used.
+; this can be used to speed up the archiving process, but is only useful if you're site has a large
+; amount of actions, referrers or custom variable name/value pairs.
+archiving_ranking_query_row_limit = 50000
+
 ; by default, the real time Live! widget will update every 5 seconds and refresh with new visits/actions/etc.
 ; you can change the timeout so the widget refreshes more often, or not as frequently
 live_widget_refresh_after_seconds = 5
@@ -247,8 +261,8 @@ multisites_refresh_after_seconds = 300
 use_ajax_cdn = 0
 
 ; required AJAX library versions
-jquery_version = 1.7.1
-jqueryui_version = 1.8.16
+jquery_version = 1.7.2
+jqueryui_version = 1.8.22
 swfobject_version = 2.2
 
 ; Set to 1 if you're using https on your Piwik server and Piwik can't detect it,
@@ -281,6 +295,10 @@ assume_secure_protocol = 0
 ;proxy_ips[] = 199.27.128.0/21
 ;proxy_ips[] = 173.245.48.0/20
 
+; Whether to enable trusted host checking. This can be disabled if you're running Piwik
+; on several URLs and do not wish to constantly edit the trusted host list.
+enable_trusted_host_check = 1
+
 ; List of trusted hosts (eg domain or subdomain names) when generating absolute URLs.
 ;
 ; Examples:
@@ -289,7 +307,7 @@ assume_secure_protocol = 0
 
 ; The release server is an essential part of the Piwik infrastructure/ecosystem
 ; to provide the latest software version.
-latest_version_url = http://piwik.org/latest.zip
+latest_version_url = http://builds.piwik.org/latest.zip
 
 ; The API server is an essential part of the Piwik infrastructure/ecosystem to
 ; provide services to Piwik installations, e.g., getLatestVersion and
@@ -302,6 +320,13 @@ api_service_url = http://api.piwik.org
 ; eg. $period=range&date=previous10 becomes $period=day&date=previous10. Use this setting to override the $period value.
 graphs_default_period_to_plot_when_period_range = day
 
+; The Overlay plugin shows the Top X following pages, Top X downloads and Top X outlinks which followed
+; a view of the current page. The value X can be set here.
+overlay_following_pages_limit = 300
+
+; With this option, you can disable the framed mode of the Overlay plugin. Use it if your website contains a framebuster.
+overlay_disable_framed_mode = 0
+
 [Tracker]
 ; Piwik uses first party cookies by default. If set to 1,
 ; the visit ID cookie will be set on the Piwik server domain as well
@@ -364,6 +389,11 @@ campaign_keyword_var_name	= "pk_kwd,piwik_kwd,utm_term"
 ; maximum length of a Page Title or a Page URL recorded in the log_action.name table
 page_maximum_length = 1024;
 
+; By default, when a request is identified as a "Internal Site Search", the URL will not be recorded. This is for performance reasons
+; (the less unique URLs in Piwik the better). Piwik will track, for each Site Search: "Search Keyword",
+; and optionally the "Search Category" and "Search result count". You can set this to 1 to enable tracking Site Search URLs.
+action_sitesearch_record_url = 0
+
 ; Anonymize a visitor's IP address after testing for "Ip exclude"
 ; This value is the number of octets in IP address to mask; if the AnonymizeIP plugin is deactivated, this value is ignored.
 ; For IPv4 addresses, valid values are 0..4; for IPv6 addresses, valid values are 0..16
@@ -397,6 +427,7 @@ tracking_requests_require_authentication = 1
 delete_logs_enable = 0
 delete_logs_schedule_lowest_interval = 7
 delete_logs_older_than = 180
+enable_auto_database_size_estimate = 1
 
 [branding]
 ; custom logo
@@ -465,6 +496,7 @@ Plugins[] 		= CoreHome
 Plugins[] 		= Proxy
 Plugins[] 		= API
 Plugins[] 		= Widgetize
+Plugins[] 		= Transitions
 Plugins[] 		= LanguagesManager
 Plugins[] 		= Actions
 Plugins[] 		= Dashboard
@@ -482,7 +514,6 @@ Plugins[] 		= VisitorInterest
 Plugins[] 		= ExampleAPI
 Plugins[] 		= ExamplePlugin
 Plugins[]		= ExampleRssWidget
-Plugins[] 		= ExampleFeedburner
 Plugins[] 		= Provider
 Plugins[]		= Feedback
 
@@ -498,6 +529,9 @@ Plugins[]		= CustomVariables
 Plugins[]		= PrivacyManager
 Plugins[]		= ImageGraph
 Plugins[]		= DoNotTrack
+Plugins[]		= Annotations
+Plugins[]		= MobileMessaging
+Plugins[]		= Overlay
 
 [PluginsInstalled]
 PluginsInstalled[] = Login
@@ -510,6 +544,7 @@ PluginsInstalled[] = Installation
 Plugins_Tracker[] = Provider
 Plugins_Tracker[] = Goals
 Plugins_Tracker[] = DoNotTrack
+Plugins_Tracker[] = UserCountry
 
 [APISettings]
 ; Any key/value pair can be added in this section, they will be available via the REST call
@@ -518,5 +553,5 @@ Plugins_Tracker[] = DoNotTrack
 SDK_batch_size = 10
 SDK_interval_value = 30
 
-; NOTE: do not directly in this file! See notice at the top
- 
\ No newline at end of file
+; NOTE: do not directly edit this file! See notice at the top
+ 
