@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Single.php 6353 2012-05-28 17:29:23Z SteveG $
+ * @version $Id: Single.php 7500 2012-11-21 07:23:34Z capedfuzz $
  * 
  * 
  * @category Piwik
@@ -97,6 +97,16 @@ class Piwik_Archive_Single extends Piwik_Archive
 		$this->clearCache();
 	}
 	
+	/**
+	 * Returns the blob cache. For testing.
+	 * 
+	 * @return array
+	 */
+	public function getBlobCache()
+	{
+		return $this->blobCached;
+	}
+	
 	/**
 	 * Returns the pretty date of this Archive, eg. 'Thursday 20th March 2008'
 	 *
@@ -362,8 +372,10 @@ class Piwik_Archive_Single extends Piwik_Archive
 			{
 				$subDataTableLoaded = $this->getDataTable($name, $subTableID);
 				
+				$row->setSubtable( $subDataTableLoaded );
+				
 				$this->loadSubDataTables($name, $subDataTableLoaded, $addMetadataSubtableId);
-
+			
 				// we edit the subtable ID so that it matches the newly table created in memory
 				// NB: we dont overwrite the datatableid in the case we are displaying the table expanded.
 				if($addMetadataSubtableId)
@@ -371,7 +383,6 @@ class Piwik_Archive_Single extends Piwik_Archive
 					// this will be written back to the column 'idsubdatatable' just before rendering, see Renderer/Php.php
 					$row->addMetadata('idsubdatatable_in_db', $row->getIdSubDataTable());
 				}
-				$row->setSubtable( $subDataTableLoaded );
 			}
 		}
 	}
@@ -383,8 +394,8 @@ class Piwik_Archive_Single extends Piwik_Archive
 	 */
 	public function freeBlob( $name )
 	{
-		$this->blobCached[$name] = null; 
 		unset($this->blobCached[$name]);
+		$this->blobCached[$name] = null; 
 	}
 	
 	protected function uncompress($data)
@@ -408,11 +419,16 @@ class Piwik_Archive_Single extends Piwik_Archive
 
 		$db = Zend_Registry::get('db');
 		$hasBlobs = $db->hasBlobDataType();
+		
+		// select blobs w/ name like "$name_[0-9]+" w/o using RLIKE
+		$nameEnd = strlen($name) + 2;
 		$query = $db->query("SELECT value, name
 								FROM $tableBlob
 								WHERE idarchive = ?
-									AND name LIKE '$name%'",	
-								array( $this->idArchive ) 
+									AND (name = ? OR
+											(name LIKE ? AND SUBSTRING(name, $nameEnd, 1) >= '0'
+														 AND SUBSTRING(name, $nameEnd, 1) <= '9') )",
+								array( $this->idArchive, $name, $name.'%' ) 
 							);
 
 		while($row = $query->fetch())
@@ -525,7 +541,7 @@ class Piwik_Archive_Single extends Piwik_Archive
 		{
 			// This is not expected, but somehow happens in some unknown cases and very rarely.
 			// Do not throw error in this case
-			// throw new Exception("not expected");
+			//throw new Exception("not expected");
 			return new Piwik_DataTable();
 		}
 	
@@ -577,7 +593,13 @@ class Piwik_Archive_Single extends Piwik_Archive
 		{
 			return 'Goals_Metrics';
 		}
-   		return $metric;
+		// Actions metrics are processed by the Actions plugin (HACK) (3RD HACK IN FACT) (YES, THIS IS TOO MUCH HACKING)
+		// (FIXME PLEASE).
+		if (in_array($metric, Piwik_Archive::$actionsMetrics))
+		{
+			return 'Actions_Metrics';
+		}
+		return $metric;
 	}
 	
 	/**
