@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: ArchiveProcessing.php 6442 2012-06-01 14:52:28Z matt $
+ * @version $Id: ArchiveProcessing.php 7500 2012-11-21 07:23:34Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -322,22 +322,47 @@ abstract class Piwik_ArchiveProcessing
 		$this->idsite = $this->site->getId();
 		$this->periodId = $this->period->getId();
 
-		$dateStartLocalTimezone = $this->period->getDateStart();
-		$dateEndLocalTimezone = $this->period->getDateEnd();
+		$this->initDates();
 		
 		$this->tableArchiveNumeric = self::makeNumericArchiveTable($this->period);
 		$this->tableArchiveBlob = self::makeBlobArchiveTable($this->period);
 
+		$this->minDatetimeArchiveProcessedUTC = $this->getMinTimeArchivedProcessed();
+		$db = Zend_Registry::get('db');
+		$this->compressBlob = $db->hasBlobDataType();
+	}
+
+	/**
+	 * The archive processing classes have features that might be useful for live querying;
+	 * In particular, Piwik_ArchiveProcessing_Day::query*. In order to reuse those methods
+	 * outside the actual archiving or to reuse archiving code for live querying, an instance
+	 * of archive processing has to be faked.
+	 * 
+	 * For example, this code can be used in an API method:
+	 * $archiveProcessing = new Piwik_ArchiveProcessing_Day();
+	 * $archiveProcessing->setSite(new Piwik_Site($idSite));
+	 * $archiveProcessing->setPeriod(Piwik_Period::advancedFactory($period, $date));
+	 * $archiveProcessing->setSegment(new Piwik_Segment($segment, $idSite));
+	 * $archiveProcessing->initForLiveUsage(); 
+	 * Then, either use $archiveProcessing->query* or pass the instance to the archiving
+	 * code of the plugin. Note that even though we use Piwik_ArchiveProcessing_Day, this
+	 * works for any $period and $date that has been passed to the API.
+	 */
+	public function initForLiveUsage() {
+		$this->idsite = $this->site->getId();
+		$this->initDates();
+	}
+	
+	private function initDates() {
+		$dateStartLocalTimezone = $this->period->getDateStart();
+		$dateEndLocalTimezone = $this->period->getDateEnd();
+		
 		$dateStartUTC = $dateStartLocalTimezone->setTimezone($this->site->getTimezone());
 		$dateEndUTC = $dateEndLocalTimezone->setTimezone($this->site->getTimezone());
 		$this->startDatetimeUTC = $dateStartUTC->getDateStartUTC();
 		$this->endDatetimeUTC = $dateEndUTC->getDateEndUTC();
 		$this->startTimestampUTC = $dateStartUTC->getTimestamp();
-		$this->endTimestampUTC = strtotime($this->endDatetimeUTC);
-		
-		$this->minDatetimeArchiveProcessedUTC = $this->getMinTimeArchivedProcessed();
-		$db = Zend_Registry::get('db');
-		$this->compressBlob = $db->hasBlobDataType();
+		$this->endTimestampUTC = strtotime($this->endDatetimeUTC);		
 	}
 	
 	/**
@@ -637,7 +662,8 @@ abstract class Piwik_ArchiveProcessing
 		if(empty($plugin)
 		    || !Piwik_PluginsManager::getInstance()->isPluginActivated($plugin))
 	    {
-	        throw new Exception("The requested report is not a valid report, please check the request");
+	    	$pluginStr = empty($plugin) ? '' : "($plugin)";
+	        throw new Exception("Error: The report '$requestedReport' was requested but it is not available at this stage. You may also disable the related plugin $pluginStr to avoid this error.");
 	    }
 		return $plugin;
 	}
@@ -681,11 +707,17 @@ abstract class Piwik_ArchiveProcessing
 	 */
 	protected function loadNextIdarchive()
 	{
-		$db = Zend_Registry::get('db');
 		$table = $this->tableArchiveNumeric->getTableName();
+		$dbLockName = "loadNextIdArchive.$table";
+		
+		$db = Zend_Registry::get('db');
 		$locked = self::PREFIX_SQL_LOCK . Piwik_Common::generateUniqId();
 		$date = date("Y-m-d H:i:s");
-		Piwik_LockTables("$table AS tb1", $table);
+		
+		if (Piwik_GetDbLock($dbLockName, $maxRetries = 30) === false)
+		{
+			throw new Exception("loadNextIdArchive: Cannot get named lock for table $table.");
+		}
 		$db->exec("INSERT INTO $table "
 					." SELECT ifnull(max(idarchive),0)+1, 
 								'".$locked."',
@@ -695,8 +727,8 @@ abstract class Piwik_ArchiveProcessing
 								0,
 								'".$date."',
 								0 "
-					." FROM $table as tb1");		
-		Piwik_UnlockAllTables();
+					." FROM $table as tb1");
+		Piwik_ReleaseDbLock($dbLockName);
         $id = $db->fetchOne("SELECT idarchive FROM $table WHERE name = ? LIMIT 1", $locked);
 
 		$this->idArchive = $id;
