@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Day.php 6353 2012-05-28 17:29:23Z SteveG $
+ * @version $Id: Day.php 7206 2012-10-15 15:11:34Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -299,12 +299,34 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 
 	/**
 	 * Returns the actions by the given dimension
+	 * 
+	 * - The basic use case is to use $label and optionally $where.
+	 * - If you want to apply a limit and group the others, use $orderBy to sort the way you
+	 *   want the limit to be applied and pass a pre-configured instance of Piwik_RankingQuery.
+	 *   The ranking query instance has to have a limit and at least one label column.
+	 *   See Piwik_RankingQuery::setLimit() and Piwik_RankingQuery::addLabelColumn().
+	 *   If $rankingQuery is set, the return value is the array returned by 
+	 *   Piwik_RankingQuery::execute().
+	 * - By default, the method only queries log_link_visit_action. If you need data from
+	 *   log_action (e.g. to partition the result from the ranking query into the different
+	 *   action types), use $joinLogActionOnColumn and $addSelect to join log_action and select
+	 *   the column you need from log_action.
+	 * 
 	 *
-	 * @param array|string  $label
-	 * @param string        $where
+	 * @param array|string  $label      the dimensions(s) you're interested in
+	 * @param string        $where      where clause
+	 * @param bool|array    $metrics    Set this if you want to limit the columns that are returned.
+	 *                                  The possible values in the array are Piwik_Archive::INDEX_*.
+	 * @param bool|string   $orderBy    order by clause
+	 * @param Piwik_RankingQuery  $rankingQuery     pre-configured ranking query instance
+	 * @param bool|string   $joinLogActionOnColumn  column from log_link_visit_action that
+	 *                                              log_action should be joined on.
+	 * 												can be an array to join multiple times.
+	 * @param bool|string   $addSelect  additional select clause
 	 * @return mixed
 	 */
-	public function queryActionsByDimension($label, $where = '')
+	public function queryActionsByDimension($label, $where = '', $metrics = false, $orderBy = false,
+			$rankingQuery = null, $joinLogActionOnColumn = false, $addSelect = false)
 	{
 	    if(is_array($label))
 	    {
@@ -327,52 +349,123 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	        $groupBy = 'label';
 	    }
 	    
-	    if(!empty($where))
+		if(!empty($where))
 	    {
 	    	$where = sprintf($where, "log_link_visit_action", "log_link_visit_action");
 	        $where = ' AND '.$where;
 	    }
-	    
-		/*
-		 * Page URLs and Page names, general stats
-		 */
-		$select = "$select,
-				count(distinct log_link_visit_action.idvisit) as `". Piwik_Archive::INDEX_NB_VISITS ."`,
-				count(distinct log_link_visit_action.idvisitor) as `". Piwik_Archive::INDEX_NB_UNIQ_VISITORS ."`,
-				count(*) as `". Piwik_Archive::INDEX_NB_ACTIONS ."`";
+		
+		$pre = ", \n\t\t\t";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_NB_VISITS, $metrics))
+			$select .= $pre . "count(distinct log_link_visit_action.idvisit) as `". Piwik_Archive::INDEX_NB_VISITS ."`";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_NB_UNIQ_VISITORS, $metrics))
+			$select .= $pre . "count(distinct log_link_visit_action.idvisitor) as `". Piwik_Archive::INDEX_NB_UNIQ_VISITORS ."`";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_NB_ACTIONS, $metrics))
+			$select .= $pre . "count(*) as `". Piwik_Archive::INDEX_NB_ACTIONS ."`";
 
 		$from = "log_link_visit_action";
 		
+		if ($joinLogActionOnColumn !== false)
+		{
+			$multiJoin = is_array($joinLogActionOnColumn);
+			if (!$multiJoin)
+			{
+				$joinLogActionOnColumn = array($joinLogActionOnColumn);
+			}
+			
+			$from = array($from);
+			
+			foreach ($joinLogActionOnColumn as $i => $joinColumn)
+			{
+				$tableAlias = 'log_action'.($multiJoin ? $i + 1 : '');
+				if (strpos($joinColumn, ' ') === false) {
+					$joinOn = $tableAlias.'.idaction = log_link_visit_action.'.$joinColumn;
+				} else {
+					// more complex join column like IF(...)
+					$joinOn = $tableAlias.'.idaction = '.$joinColumn;
+				}
+				$from[] = array(
+					'table' => 'log_action', 
+					'tableAlias' => $tableAlias,
+					'joinOn' => $joinOn
+				);
+			}
+		}
+		
+		if ($addSelect !== false)
+		{
+			$select .= ', '.$addSelect;
+		}
+		
 		$where = "log_link_visit_action.server_time >= ?
 				AND log_link_visit_action.server_time <= ?
 				AND log_link_visit_action.idsite = ?
 				$where";
-				 		
+
 		$bind = array($this->getStartDatetimeUTC(), $this->getEndDatetimeUTC(), $this->idsite);
         
-		$query = $this->getSegment()->getSelectQuery($select, $from, $where, $bind, $orderBy=false, $groupBy);
+		$query = $this->getSegment()->getSelectQuery($select, $from, $where, $bind, $orderBy, $groupBy);
+		
+		if ($rankingQuery !== null)
+		{
+			$sumColumns = array(
+				Piwik_Archive::INDEX_NB_UNIQ_VISITORS,
+				Piwik_Archive::INDEX_NB_VISITS,
+				Piwik_Archive::INDEX_NB_ACTIONS
+			);
+			if ($metrics)
+			{
+				foreach ($sumColumns as $i => $column)
+				{
+					if (!in_array($column, $metrics))
+					{
+						unset($sumColumns[$i]);
+					}			
+				}
+				$sumColumns = array_values($sumColumns);
+			}
+			$rankingQuery->addColumn($sumColumns, 'sum');
+			return $rankingQuery->execute($query['sql'], $query['bind']);
+		}
 		
 		return $this->db->query($query['sql'], $query['bind']);
 	}
-	
+
 	/**
 	 * Query visits by dimension
 	 *
-	 * @param array|string  $label  mixed Can be a string, eg. "referer_name", will be aliased as 'label' in the returned rows
-	 * 				                Can also be an array of strings, when the dimension spans multiple fields, eg. array("referer_name", "referer_keyword")
-	 * @param string        $where  Additional condition for WHERE clause
+	 * @param array|string  $label    Can be a string, eg. "referer_name", will be aliased as 'label' in the returned rows
+	 *                                Can also be an array of strings, when the dimension spans multiple fields, 
+	 *                                eg. array("referer_name", "referer_keyword")
+	 * @param string        $where    Additional condition for WHERE clause
+	 * @param bool|array    $metrics  Set this if you want to limit the columns that are returned.
+	 *                                The possible values in the array are Piwik_Archive::INDEX_*.
+	 * @param bool|string   $orderBy  ORDER BY clause. This is needed in combination with $rankingQuery.
+	 * @param Piwik_RankingQuery $rankingQuery
+	 *                                A pre-configured ranking query instance that is used to limit the result.
+	 *                                If set, the return value is the array returned by Piwik_RankingQuery::execute().
+	 * @param string      $addSelect  Additional SELECT clause
+	 * @param bool        $addSelectGeneratesLabelColumn
+	 *                                Set to true if the $label column is generated in $addSelect.
+	 * @return mixed
 	 */
-	public function queryVisitsByDimension($label, $where = '')
+	public function queryVisitsByDimension($label, $where = '', $metrics = false, $orderBy = false,
+			$rankingQuery = null, $addSelect = false, $addSelectGeneratesLabelColumn = false)
 	{
 	    if(is_array($label))
 	    {
 	        $groupBy = "log_visit.".implode(", log_visit.", $label);
-	    	foreach($label as &$field)
+			foreach($label as &$field)
 	    	{
 	    		$field = 'log_visit.'.$field.' AS '.$field;
 	    	}
 	        $select = implode(", ", $label);
 	    }
+		else if ($addSelectGeneratesLabelColumn)
+		{
+			$select = $addSelect;
+			$groupBy = $label;
+		}
 	    else
 	    {
 	        $select = $label . " AS label ";
@@ -385,15 +478,26 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	        $where = ' AND '.$where;
 	    }
 	    
-	    $select = "$select,
-				count(distinct log_visit.idvisitor) as `". Piwik_Archive::INDEX_NB_UNIQ_VISITORS ."`,
-				count(*) as `". Piwik_Archive::INDEX_NB_VISITS ."`,
-				sum(log_visit.visit_total_actions) as `". Piwik_Archive::INDEX_NB_ACTIONS ."`,
-				max(log_visit.visit_total_actions) as `". Piwik_Archive::INDEX_MAX_ACTIONS ."`,
-				sum(log_visit.visit_total_time) as `". Piwik_Archive::INDEX_SUM_VISIT_LENGTH ."`,
-				sum(case log_visit.visit_total_actions when 1 then 1 when 0 then 1 else 0 end) as `". Piwik_Archive::INDEX_BOUNCE_COUNT ."`,
-				sum(case log_visit.visit_goal_converted when 1 then 1 else 0 end) as `". Piwik_Archive::INDEX_NB_VISITS_CONVERTED ."`";
-	    
+		$pre = ", \n\t\t\t";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_NB_UNIQ_VISITORS, $metrics))
+			$select .= $pre . "count(distinct log_visit.idvisitor) as `". Piwik_Archive::INDEX_NB_UNIQ_VISITORS ."`";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_NB_VISITS, $metrics))
+			$select .= $pre . "count(*) as `". Piwik_Archive::INDEX_NB_VISITS ."`";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_NB_ACTIONS, $metrics))
+			$select .= $pre . "sum(log_visit.visit_total_actions) as `". Piwik_Archive::INDEX_NB_ACTIONS ."`";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_MAX_ACTIONS, $metrics))
+			$select .= $pre . "max(log_visit.visit_total_actions) as `". Piwik_Archive::INDEX_MAX_ACTIONS ."`";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_SUM_VISIT_LENGTH, $metrics))
+			$select .= $pre . "sum(log_visit.visit_total_time) as `". Piwik_Archive::INDEX_SUM_VISIT_LENGTH ."`";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_BOUNCE_COUNT, $metrics))
+			$select .= $pre . "sum(case log_visit.visit_total_actions when 1 then 1 when 0 then 1 else 0 end) as `". Piwik_Archive::INDEX_BOUNCE_COUNT ."`";
+		if (!$metrics || in_array(Piwik_Archive::INDEX_NB_VISITS_CONVERTED, $metrics))
+			$select .= $pre . "sum(case log_visit.visit_goal_converted when 1 then 1 else 0 end) as `". Piwik_Archive::INDEX_NB_VISITS_CONVERTED ."`";
+		
+		if ($addSelect && !$addSelectGeneratesLabelColumn) {
+			$select .= ', '.$addSelect;
+		}
+		
 	    $from = "log_visit";
 	    
 	    $where = "log_visit.visit_last_action_time >= ?
@@ -403,7 +507,33 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		
 		$bind = array($this->getStartDatetimeUTC(), $this->getEndDatetimeUTC(), $this->idsite);
 		
-		$query = $this->getSegment()->getSelectQuery($select, $from, $where, $bind, $orderBy=false, $groupBy);
+		$query = $this->getSegment()->getSelectQuery($select, $from, $where, $bind, $orderBy, $groupBy);
+		
+		if ($rankingQuery !== null)
+		{
+			$sumColumns = array(
+				Piwik_Archive::INDEX_NB_UNIQ_VISITORS, Piwik_Archive::INDEX_NB_VISITS,
+				Piwik_Archive::INDEX_NB_ACTIONS, Piwik_Archive::INDEX_SUM_VISIT_LENGTH,
+				Piwik_Archive::INDEX_BOUNCE_COUNT, Piwik_Archive::INDEX_NB_VISITS_CONVERTED
+			);
+			if ($metrics)
+			{
+				foreach ($sumColumns as $i => $column)
+				{
+					if (!in_array($column, $metrics))
+					{
+						unset($sumColumns[$i]);
+					}			
+				}
+				$sumColumns = array_values($sumColumns);
+			}
+			$rankingQuery->addColumn($sumColumns, 'sum');
+			if (!$metrics || in_array(Piwik_Archive::INDEX_MAX_ACTIONS, $metrics))
+			{
+				$rankingQuery->addColumn(Piwik_Archive::INDEX_MAX_ACTIONS, 'max');
+			}
+			return $rankingQuery->execute($query['sql'], $query['bind']);
+		}
 		
 		return $this->db->query($query['sql'], $query['bind']);
 	}
@@ -527,7 +657,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * @param array $array
 	 * @return Piwik_DataTable
 	 */
-	public function getDataTableFromArray( $array )
+	static public function getDataTableFromArray( $array )
 	{
 		$table = new Piwik_DataTable();
 		$table->addRowsFromArrayWithIndexLabel($array);
@@ -616,7 +746,15 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 				$row = $maybeDatatableRow;
 			}
 			
-			$dataTableToReturn->addRow($row);
+			if ($row->getMetadata('issummaryrow') == true)
+			{
+				$row->deleteMetadata('issummaryrow');
+				$dataTableToReturn->addSummaryRow($row);
+			}
+			else
+			{
+				$dataTableToReturn->addRow($row);
+			}
 		}
 		return $dataTableToReturn;
 	}
@@ -925,4 +1063,4 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 						Piwik_Archive::INDEX_GOAL_ECOMMERCE_ITEMS => 0,
 		);
 	}
-}
\ No newline at end of file
+}
