@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Config.php 6300 2012-05-23 21:19:25Z SteveG $
+ * @version $Id: Config.php 7659 2012-12-19 12:38:15Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -28,11 +28,13 @@
  *    $brandingConfig = array(
  *        'use_custom_logo' => 1,
  *    );
- *    Piwik_Config::getInstance()->setConfigSection('branding', $brandingConfig);
+ *    Piwik_Config::getInstance()->branding = $brandingConfig;
  *
  * Example setting an option within a section in the configuration:
- *
- *    Piwik_Config::getInstance()->setConfigOption('branding', 'use_custom_logo', '1');
+ * 
+ *    $brandingConfig = Piwik_Config::getInstance()->branding;
+ *    $brandingConfig['use_custom_logo'] = 1;
+ *    Piwik_Config::getInstance()->branding = $brandingConfig;
  *
  * @package Piwik
  * @subpackage Piwik_Config
@@ -112,6 +114,8 @@ class Piwik_Config
 		if(is_null($pathGlobal))
 		{
 			$this->configCache['Debug'] = $this->configGlobal['Debug'];
+			$this->configCache['branding'] = $this->configGlobal['branding'];
+			$this->configCache['mail'] = $this->configGlobal['mail'];
 			$this->configCache['General'] = $this->configGlobal['General'];
 			$this->configCache['Segments'] = $this->configGlobal['Segments'];
 			$this->configCache['Tracker'] = $this->configGlobal['Tracker'];
@@ -405,21 +409,34 @@ class Piwik_Config
 				}
 
 				// Only merge if the section exists in global.ini.php (in case a section only lives in config.ini.php)
-				$config = isset($configGlobal[$section])
-					? $this->array_unmerge($configGlobal[$section], $configCache[$section])
-					: $configCache[$section];
-
-				if (count($config) == 0)
+				
+				// get local and cached config
+				$local = isset($configLocal[$section]) ? $configLocal[$section] : array();
+				$config = $configCache[$section];
+				
+				// remove default values from both (they should not get written to local)
+				if (isset($configGlobal[$section]))
 				{
-					continue;
+					$config = $this->array_unmerge($configGlobal[$section], $configCache[$section]);
+					$local = $this->array_unmerge($configGlobal[$section], $local);
 				}
-
-				if (!isset($configLocal[$section])
-					|| self::compareElements($config, $configLocal[$section]))
+				
+				// if either local/config have non-default values and the other doesn't,
+				// OR both have values, but different values, we must write to config.ini.php
+				if (empty($local) xor empty($config)
+					|| (!empty($local)
+						&& !empty($config)
+						&& self::compareElements($config, $configLocal[$section])))
 				{
 					$dirty = true;
 				}
 
+				// no point in writing empty sections, so skip if the cached section is empty
+				if (empty($config))
+				{
+					continue;
+				}
+				
 				$output .= "[$section]\n";
 
 				foreach($config as $name => $value)
