@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 6400 2012-05-30 09:50:00Z matt $
+ * @version $Id: Controller.php 7683 2012-12-22 09:02:51Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -171,17 +171,6 @@ abstract class Piwik_Controller
 	{
 		$view = Piwik_ViewDataTable::factory('graphEvolution');
 		$view->init( $currentModuleName, $currentControllerAction, $apiMethod );
-		
-		// if the date is not yet a nicely formatted date range ie. YYYY-MM-DD,YYYY-MM-DD we build it
-		// otherwise the current controller action is being called with the good date format already so it's fine
-		// see constructor
-		if( !is_null($this->date))
-		{
-			$view->setParametersToModify( 
-				$this->getGraphParamsModified( array('date' => $this->strDate))
-				);
-		}
-		
 		return $view;
 	}
 
@@ -344,7 +333,10 @@ abstract class Piwik_Controller
 	{
 		$requestString = 'method='.$methodToCall.'&format=original';
 		$request = new Piwik_API_Request($requestString);
-		return $request->process();
+		$return = $request->process();
+		$columns = $return->getFirstRow()->getColumns();
+		$values = array_values($columns);
+		return $values[0];
 	}
 
 	/**
@@ -439,15 +431,7 @@ abstract class Piwik_Controller
 				$period = new Piwik_Period_Range($periodStr, $rawDate, $this->site->getTimezone());
 			}
 			$view->rawDate = $rawDate;
-			
-			if ($period instanceof Piwik_Period_Month) // show month name when period is for a month
-			{
-				$view->prettyDate = $period->getLocalizedLongString();
-			}
-			else
-			{
-				$view->prettyDate = $period->getPrettyString();
-			}
+			$view->prettyDate = self::getCalendarPrettyDate($period);
 			
 			$view->siteName = $this->site->getName();
 			$view->siteMainUrl = $this->site->getMainUrl();
@@ -471,9 +455,11 @@ abstract class Piwik_Controller
 			$language = Piwik_LanguagesManager::getLanguageForSession();
 			$view->language = !empty($language) ? $language : Piwik_LanguagesManager::getLanguageCodeForCurrentUser();
 			
+			$view->config_action_url_category_delimiter = Piwik_Config::getInstance()->General['action_url_category_delimiter'];
+			
 			$this->setBasicVariablesView($view);
 		} catch(Exception $e) {
-			Piwik_ExitWithMessage($e->getMessage());
+			Piwik_ExitWithMessage($e->getMessage(), Piwik::shouldLoggerLog() ? $e->getTraceAsString() : '');
 		}
 	}
 	
@@ -487,6 +473,7 @@ abstract class Piwik_Controller
 		$view->topMenu = Piwik_GetTopMenu();
 		$view->debugTrackVisitsInsidePiwikUI = Piwik_Config::getInstance()->Debug['track_visits_inside_piwik_ui'];
 		$view->isSuperUser = Zend_Registry::get('access')->isSuperUser();
+		$view->hasSomeAdminAccess = Piwik::isUserHasSomeAdminAccess();
 		$view->isCustomLogo = Piwik_Config::getInstance()->branding['use_custom_logo'];
 		$view->logoHeader = Piwik_API_API::getInstance()->getHeaderLogoUrl();
 		$view->logoLarge = Piwik_API_API::getInstance()->getLogoUrl();
@@ -497,6 +484,83 @@ abstract class Piwik_Controller
 		{
 			$view->setXFrameOptions('sameorigin');
 		}
+		
+		self::setHostValidationVariablesView($view);
+	}
+	
+	/**
+	 * Checks if the current host is valid and sets variables on the given view, including:
+	 * 
+	 * isValidHost - true if host is valid, false if otherwise
+	 * invalidHostMessage - message to display if host is invalid (only set if host is invalid)
+	 * invalidHost - the invalid hostname (only set if host is invalid)
+	 * mailLinkStart - the open tag of a link to email the super user of this problem (only set
+	 *                 if host is invalid)
+	 */
+	public static function setHostValidationVariablesView( $view )
+	{
+		// check if host is valid
+		$view->isValidHost = Piwik_Url::isValidHost();
+		if (!$view->isValidHost)
+		{
+			// invalid host, so display warning to user
+			$validHost = Piwik_Config::getInstance()->General['trusted_hosts'][0];
+			$invalidHost = Piwik_Common::sanitizeInputValue($_SERVER['HTTP_HOST']);
+			
+			$emailSubject = rawurlencode(Piwik_Translate('CoreHome_InjectedHostEmailSubject', $invalidHost));
+			$emailBody = rawurlencode(Piwik_Translate('CoreHome_InjectedHostEmailBody'));
+			$superUserEmail = Piwik::getSuperUserEmail();
+			
+			$mailToUrl = "mailto:$superUserEmail?subject=$emailSubject&body=$emailBody";
+			$mailLinkStart = "<a href=\"$mailToUrl\">";
+			
+			$invalidUrl = Piwik_Url::getCurrentUrlWithoutQueryString($checkIfTrusted = false);
+			$validUrl = Piwik_Url::getCurrentScheme() . '://' . $validHost
+					  . Piwik_Url::getCurrentScriptName();
+
+			$validLink = "<a href=\"$validUrl\">$validUrl</a>";
+			$changeTrustedHostsUrl = "index.php"
+				. Piwik_Url::getCurrentQueryStringWithParametersModified(array(
+					'module' => 'CoreAdminHome',
+					'action' => 'generalSettings'
+				))
+				. "#trustedHostsSection";
+			
+			$warningStart = Piwik_Translate('CoreHome_InjectedHostWarningIntro', array(
+				'<strong>'.$invalidUrl.'</strong>',
+				'<strong>'.$validUrl.'</strong>'
+			)) . ' <br/>';
+			
+			if (Piwik::isUserIsSuperUser())
+			{
+				$view->invalidHostMessage = $warningStart . ' '
+					. Piwik_Translate('CoreHome_InjectedHostSuperUserWarning', array(
+						"<a href=\"$changeTrustedHostsUrl\">",
+						$invalidHost,
+						'</a>',
+						"<br/><a href=\"$validUrl\">",
+						$validHost,
+						'</a>'
+					));
+			}
+			else
+			{
+				$view->invalidHostMessage = $warningStart . ' '
+					. Piwik_Translate('CoreHome_InjectedHostNonSuperUserWarning', array(
+						"<br/><a href=\"$validUrl\">",
+						'</a>',
+						$mailLinkStart,
+						'</a>'
+					));
+			}
+			$view->invalidHostMessageHowToFix = '<b>How do I fix this problem and how do I login again?</b><br/> The Piwik Super User can manually edit the file piwik/config/config.ini.php
+						and add the following lines: <pre>[General]'."\n".'trusted_hosts[] = "'.$validHost.'"</pre><br/>After making the change, you will be able to login again.<br/><br/>
+						You may also <i>disable this security feature (not recommended)</i>. To do so edit config/config.ini.php and add:
+						<pre>[General]'."\n".'enable_trusted_host_check=0</pre>';
+
+			$view->invalidHost = $invalidHost; // for UserSettings warning
+			$view->invalidHostMailLinkStart = $mailLinkStart;
+		}
 	}
 
 	/**
@@ -644,7 +708,7 @@ abstract class Piwik_Controller
 		if(Piwik::isUserIsSuperUser())
 		{
 			Piwik_ExitWithMessage("Error: no website was found in this Piwik installation. 
-			<br />Check the table '". Piwik_Common::prefixTable('site') ."' that should contain your Piwik websites.", false, true);
+			<br />Check the table '". Piwik_Common::prefixTable('site') ."' in your database, it should contain your Piwik websites.", false, true);
 		}
 		
 		$currentLogin = Piwik::getCurrentUserLogin();
@@ -758,4 +822,22 @@ abstract class Piwik_Controller
 			throw new Piwik_Access_NoAccessException(Piwik_TranslateException('General_ExceptionInvalidToken'));
 		}
 	}
+	
+	/**
+	 * Returns pretty date for use in period selector widget.
+	 * 
+	 * @param Piwik_Period $period
+	 * @return string
+	 */
+	public static function getCalendarPrettyDate($period)
+	{
+		if ($period instanceof Piwik_Period_Month) // show month name when period is for a month
+		{
+			return $period->getLocalizedLongString();
+		}
+		else
+		{
+			return $period->getPrettyString();
+		}
+	}
 }
