@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Cookie.php 6325 2012-05-26 21:08:06Z SteveG $
+ * @version $Id: Cookie.php 7594 2012-12-11 01:08:40Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -158,8 +158,8 @@ class Piwik_Cookie
 					 . (empty($Domain) ? '' : '; domain=' . $Domain)
 					 . (!$Secure ? '' : '; secure')
 					 . (!$HTTPOnly ? '' : '; HttpOnly');
-
-		 header($header, false);
+		
+		Piwik_Common::sendHeader($header, false);
 	}
 
 	/**
@@ -167,7 +167,7 @@ class Piwik_Cookie
 	 */
 	protected function setP3PHeader()
 	{
-		header("P3P: CP='OTI DSP COR NID STP UNI OTPa OUR'");
+		Piwik_Common::sendHeader("P3P: CP='OTI DSP COR NID STP UNI OTPa OUR'");
 	}
 
 	/**
@@ -190,9 +190,6 @@ class Piwik_Cookie
 		if(strlen($cookieString) > self::MAX_COOKIE_SIZE)
 		{
 			// If the cookie was going to be too large, instead, delete existing cookie and start afresh
-			// This will result in slightly less accuracy in the case
-			// where someone visits more than dozen websites tracked by the same Piwik
-			// This will usually be the Piwik super user itself checking all his websites regularly
 			$this->delete();
 			return;
 		}
