@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Array.php 6353 2012-05-28 17:29:23Z SteveG $
+ * @version $Id: Array.php 7466 2012-11-14 03:18:12Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -365,4 +365,39 @@ class Piwik_DataTable_Array
 			$toTable->addRow($row);
 		}
 	}
+	
+	/**
+	 * Adds a DataTable to all the tables in this array
+	 * NOTE: Will only add $tableToSum if the childTable has some rows
+	 * 
+	 * @param Piwik_DataTable $tableToSum
+	 */
+	public function addDataTable( Piwik_DataTable $tableToSum )
+	{
+		foreach ($this->getArray() as $childTable)
+		{
+			if($childTable->getRowsCount() > 0)
+			{
+				$childTable->addDataTable($tableToSum);
+			}
+		}
+	}
+	
+	/**
+	 * Returns a new DataTable_Array w/ child tables that have had their
+	 * subtables merged.
+	 * 
+	 * @see Piwik_DataTable::mergeSubtables
+	 * 
+	 * @return Piwik_DataTable_Array
+	 */
+	public function mergeSubtables()
+	{
+		$result = new Piwik_DataTable_Array();
+		foreach ($this->array as $label => $childTable)
+		{
+			$result->addTable($childTable->mergeSubtables(), $label);
+		}
+		return $result;
+	}
 }
