@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: ColumnCallbackDeleteRow.php 6353 2012-05-28 17:29:23Z SteveG $
+ * @version $Id: ColumnCallbackDeleteRow.php 7466 2012-11-14 03:18:12Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -20,17 +20,26 @@ class Piwik_DataTable_Filter_ColumnCallbackDeleteRow extends Piwik_DataTable_Fil
 {
 	private $columnToFilter;
 	private $function;
+	private $functionParams;
 
 	/**
 	 * @param Piwik_DataTable  $table
 	 * @param string           $columnToFilter
 	 * @param callback         $function
+	 * @param array            $functionParams
 	 */
-	public function __construct( $table, $columnToFilter, $function )
+	public function __construct( $table, $columnToFilter, $function, $functionParams = array() )
 	{
 		parent::__construct($table);
+		
+		if (!is_array($functionParams))
+		{
+			$functionParams = array($functionParams);
+		}
+		
 		$this->function = $function;
 		$this->columnToFilter = $columnToFilter;
+		$this->functionParams = $functionParams;
 	}
 
 	/**
@@ -43,7 +52,7 @@ class Piwik_DataTable_Filter_ColumnCallbackDeleteRow extends Piwik_DataTable_Fil
 		foreach($table->getRows() as $key => $row)
 		{
 			$columnValue = $row->getColumn($this->columnToFilter);
-			if( !call_user_func( $this->function, $columnValue))
+			if( !call_user_func_array( $this->function, array_merge(array($columnValue), $this->functionParams)))
 			{
 				$table->deleteRow($key);
 			}
