@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Console.php 6353 2012-05-28 17:29:23Z SteveG $
+ * @version $Id: Console.php 7648 2012-12-18 02:53:55Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -98,6 +98,11 @@ class Piwik_DataTable_Renderer_Console extends Piwik_DataTable_Renderer
 	 */
 	protected function renderTable($table, $prefix = "")
 	{
+		if (is_array($table)) // convert array to DataTable
+		{
+			$table = Piwik_DataTable::makeFromSimpleArray($table);
+		}
+		
 		if($table instanceof Piwik_DataTable_Array)
 		{
 			return $this->renderDataTableArray($table, $prefix);
@@ -147,20 +152,23 @@ class Piwik_DataTable_Renderer_Console extends Piwik_DataTable_Renderer
 						. "- $i [".$columns."] [".$metadata."] [idsubtable = " 
 						. $row->getIdSubDataTable()."]<br />\n";
 			
-			if($row->getIdSubDataTable() !== null)
+			if(!is_null($row->getIdSubDataTable()))
 			{
-				$depth++;
-				try{
+				if($row->isSubtableLoaded())
+				{
+					$depth++;
 					$output.= $this->renderTable( 
 									Piwik_DataTable_Manager::getInstance()->getTable(
 												$row->getIdSubDataTable()
 											),
 											$prefix . '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;'
 										);
-				} catch(Exception $e) {
+					$depth--;
+				} 
+				else
+				{
 					$output.= "-- Sub DataTable not loaded<br />\n";
 				}
-				$depth--;
 			}
 			$i++;
 		}
