@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Csv.php 6412 2012-05-31 03:24:39Z matt $
+ * @version $Id: Csv.php 7648 2012-12-18 02:53:55Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -117,12 +117,17 @@ class Piwik_DataTable_Renderer_Csv extends Piwik_DataTable_Renderer
 	/**
 	 * Computes the output of the given data table
 	 *
-	 * @param Piwik_DataTable  $table
-	 * @param array            $allColumns
+	 * @param Piwik_DataTable|array  $table
+	 * @param array            		 $allColumns
 	 * @return string
 	 */
 	protected function renderTable($table, &$allColumns = array() )
 	{
+		if (is_array($table)) // convert array to DataTable
+		{
+			$table = Piwik_DataTable::makeFromSimpleArray($table);
+		}
+		
 		if($table instanceof Piwik_DataTable_Array)
 		{
 			$str = $this->renderDataTableArray($table, $allColumns);
