@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Php.php 6353 2012-05-28 17:29:23Z SteveG $
+ * @version $Id: Php.php 7619 2012-12-14 22:56:26Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -131,7 +131,15 @@ class Piwik_DataTable_Renderer_Php extends Piwik_DataTable_Renderer
 			$dataTable = $this->table;
 		}
 		
-		if($dataTable instanceof Piwik_DataTable_Array)
+		if (is_array($dataTable))
+		{
+			$flatArray = $dataTable;
+			if (self::shouldWrapArrayBeforeRendering($flatArray))
+			{
+				$flatArray = array($flatArray);
+			}
+		}
+		else if ($dataTable instanceof Piwik_DataTable_Array)
 		{
 			$flatArray = array();
 			foreach($dataTable->getArray() as $keyName => $table)
@@ -142,7 +150,6 @@ class Piwik_DataTable_Renderer_Php extends Piwik_DataTable_Renderer
 				$this->serialize = $serializeSave;
 			}
 		}
-		
 		else if($dataTable instanceof Piwik_DataTable_Simple)
 		{
 			$flatArray = $this->renderSimpleTable($dataTable);
@@ -203,6 +210,8 @@ class Piwik_DataTable_Renderer_Php extends Piwik_DataTable_Renderer
 	 */
 	public function originalRender()
 	{
+		Piwik::checkObjectTypeIs($this->table, array('Piwik_DataTable_Simple', 'Piwik_DataTable'));
+		
 		if($this->table instanceof Piwik_DataTable_Simple)
 		{
 			$array = $this->renderSimpleTable($this->table);
@@ -211,10 +220,6 @@ class Piwik_DataTable_Renderer_Php extends Piwik_DataTable_Renderer
 		{
 			$array = $this->renderTable($this->table);
 		}
-		else
-		{
-			throw new Exception("Unexpected data type to render.");
-		}
 				
 		if($this->serialize)
 		{
@@ -247,20 +252,16 @@ class Piwik_DataTable_Renderer_Php extends Piwik_DataTable_Renderer
 			}
 			
 			if($this->isRenderSubtables()
-				&& $row->getIdSubDataTable() !== null)
+				&& $row->isSubtableLoaded() )
 			{
-				try{
-					$subTable = $this->renderTable( Piwik_DataTable_Manager::getInstance()->getTable($row->getIdSubDataTable()));
-					$newRow['subtable'] = $subTable;
-					if($this->hideIdSubDatatable === false
-						&& isset($newRow['metadata']['idsubdatatable_in_db']))
-					{
-						$newRow['columns']['idsubdatatable'] = $newRow['metadata']['idsubdatatable_in_db'];
-					}
-					unset($newRow['metadata']['idsubdatatable_in_db']);
-				} catch (Exception $e) {
-					// the subtables are not loaded we dont do anything 
+				$subTable = $this->renderTable( Piwik_DataTable_Manager::getInstance()->getTable($row->getIdSubDataTable()));
+				$newRow['subtable'] = $subTable;
+				if($this->hideIdSubDatatable === false
+					&& isset($newRow['metadata']['idsubdatatable_in_db']))
+				{
+					$newRow['columns']['idsubdatatable'] = $newRow['metadata']['idsubdatatable_in_db'];
 				}
+				unset($newRow['metadata']['idsubdatatable_in_db']);
 			}
 			if($this->hideIdSubDatatable !== false)
 			{
