@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Row.php 6400 2012-05-30 09:50:00Z matt $
+ * @version $Id: Row.php 7160 2012-10-12 00:36:14Z matt $
  * 
  * @category Piwik
  * @package Piwik
@@ -31,6 +31,16 @@
  */
 class Piwik_DataTable_Row
 {
+	/**
+	 * List of columns that cannot be summed. An associative array for speed.
+	 * 
+	 * @var array
+	 */
+	private static $unsummableColumns = array(
+		'label' => true,
+		'full_url' => true // column used w/ old Piwik versions
+	);
+	
 	/**
 	 * This array contains the row information:
 	 * - array indexed by self::COLUMNS contains the columns, pairs of (column names, value) 
@@ -42,6 +52,10 @@ class Piwik_DataTable_Row
 	 * @see constructor for more information
 	 */
 	public $c = array();
+	private $subtableIdWasNegativeBeforeSerialize = false;
+
+	// @see sumRow - implementation detail
+	public $maxVisitsSummed = 0;
 	
 	const COLUMNS = 0;
 	const METADATA = 1;
@@ -83,8 +97,38 @@ class Piwik_DataTable_Row
 		if(isset($row[self::DATATABLE_ASSOCIATED])
 			&& $row[self::DATATABLE_ASSOCIATED] instanceof Piwik_DataTable)
 		{
-			$this->c[self::DATATABLE_ASSOCIATED] = $row[self::DATATABLE_ASSOCIATED]->getId();
-		}	
+			$this->setSubtable($row[self::DATATABLE_ASSOCIATED]);
+		}
+	}
+	
+	/**
+	 * Because $this->c[self::DATATABLE_ASSOCIATED] is negative when the table is in memory,
+	 * we must prior to serialize() call, make sure the ID is saved as positive integer
+	 *
+	 * Only serialize the "c" member
+	 */
+	public function __sleep()
+	{
+		if(!empty($this->c[self::DATATABLE_ASSOCIATED]) 
+			&& $this->c[self::DATATABLE_ASSOCIATED] < 0)
+		{
+			$this->c[self::DATATABLE_ASSOCIATED] = -1 * $this->c[self::DATATABLE_ASSOCIATED];
+			$this->subtableIdWasNegativeBeforeSerialize = true;
+		}
+		return array('c');
+	}
+
+	/**
+	 * Must be called after the row was serialized and __sleep was called
+	 * 
+	 */
+	public function cleanPostSerialize()
+	{
+		if($this->subtableIdWasNegativeBeforeSerialize)
+		{
+			$this->c[self::DATATABLE_ASSOCIATED] = -1 * $this->c[self::DATATABLE_ASSOCIATED];
+			$this->subtableIdWasNegativeBeforeSerialize = false;
+		}
 	}
 	
 	/**
@@ -92,11 +136,10 @@ class Piwik_DataTable_Row
 	 */
 	public function __destruct()
 	{
-		$idSubtable = $this->c[self::DATATABLE_ASSOCIATED];
-		if($idSubtable !== null)
+		if($this->isSubtableLoaded())
 		{
-			Piwik_DataTable_Manager::getInstance()->deleteTable($idSubtable);
-			$idSubtable = null;
+			Piwik_DataTable_Manager::getInstance()->deleteTable( $this->getIdSubDataTable() );
+			$this->c[self::DATATABLE_ASSOCIATED] = null;
 		}
 	}
 
@@ -216,7 +259,24 @@ class Piwik_DataTable_Row
 	 */
 	public function getIdSubDataTable()
 	{
-		return $this->c[self::DATATABLE_ASSOCIATED];
+		return !is_null($this->c[self::DATATABLE_ASSOCIATED])
+				// abs() is to ensure we return a positive int, @see isSubtableLoaded()
+				? abs($this->c[self::DATATABLE_ASSOCIATED])
+				: null;
+	}
+	
+	/**
+	 * Returns the associated subtable, if one exists.
+	 * 
+	 * @return Piwik_DataTable|false
+	 */
+	public function getSubtable()
+	{
+		if ($this->isSubtableLoaded())
+		{
+			return Piwik_DataTable_Manager::getInstance()->getTable($this->getIdSubDataTable());
+		}
+		return false;
 	}
 	
 	/**
@@ -229,17 +289,15 @@ class Piwik_DataTable_Row
 	 */
 	public function sumSubtable(Piwik_DataTable $subTable)
 	{
-		$thisSubtableID = $this->getIdSubDataTable();
-		if($thisSubtableID === null)
+		if($this->isSubtableLoaded())
+		{
+			$thisSubTable = $this->getSubtable();
+		}
+		else
 		{
 			$thisSubTable = new Piwik_DataTable();
 			$this->addSubtable($thisSubTable);
 		}
-		else
-		{
-			$thisSubTable = Piwik_DataTable_Manager::getInstance()->getTable( $thisSubtableID );
-		}
-		
 		$thisSubTable->addDataTable($subTable);
 	}
 	
@@ -249,8 +307,8 @@ class Piwik_DataTable_Row
 	 * If the row already has a DataTable associated to it, throws an Exception.
 	 * 
 	 * @param Piwik_DataTable  $subTable  DataTable to associate to this row
+	 * @return Piwik_DataTable Returns $subTable.
 	 * @throws Exception 
-	 * 
 	 */
 	public function addSubtable(Piwik_DataTable $subTable)
 	{
@@ -258,7 +316,7 @@ class Piwik_DataTable_Row
 		{
 			throw new Exception("Adding a subtable to the row, but it already has a subtable associated.");
 		}
-		$this->c[self::DATATABLE_ASSOCIATED] = $subTable->getId();
+		return $this->setSubtable($subTable);
 	}
 	
 	/**
@@ -266,12 +324,30 @@ class Piwik_DataTable_Row
 	 * a DataTable associated, it is simply overwritten.
 	 * 
 	 * @param Piwik_DataTable  $subTable  DataTable to associate to this row
+	 * @return Piwik_DataTable Returns $subTable.
 	 */
 	public function setSubtable(Piwik_DataTable $subTable)
 	{
-		$this->c[self::DATATABLE_ASSOCIATED] = $subTable->getId();
+		// Hacking -1 to ensure value is negative, so we know the table was loaded
+		// @see isSubtableLoaded()
+		$this->c[self::DATATABLE_ASSOCIATED] = -1 * $subTable->getId();
+		return $subTable;
 	}
 	
+	/**
+	 * Returns true if the subtable is currently loaded in memory via DataTable_Manager
+	 * 
+	 * 
+	 * @return bool
+	 */
+	public function isSubtableLoaded()
+	{
+		// self::DATATABLE_ASSOCIATED are set as negative values, 
+		// as a flag to signify that the subtable is loaded in memory
+		return !is_null($this->c[self::DATATABLE_ASSOCIATED])
+	  			&& $this->c[self::DATATABLE_ASSOCIATED] < 0;
+	}
+		
 	/**
 	 * Remove the sub table reference
 	 */
@@ -401,11 +477,11 @@ class Piwik_DataTable_Row
 	 *
 	 * @param Piwik_DataTable_Row  $rowToSum
 	 */
-	public function sumRow( Piwik_DataTable_Row $rowToSum )
+	public function sumRow( Piwik_DataTable_Row $rowToSum, $enableCopyMetadata = true )
 	{
 		foreach($rowToSum->getColumns() as $columnToSumName => $columnToSumValue)
 		{
-			if($columnToSumName != 'label')
+			if (!isset(self::$unsummableColumns[$columnToSumName])) // make sure we can add this column
 			{
 				$thisColumnValue = $this->getColumn($columnToSumName);
 				
@@ -421,10 +497,39 @@ class Piwik_DataTable_Row
 				$this->setColumn( $columnToSumName, $newValue);
 			}
 		}
+
+		if($enableCopyMetadata)
+		{
+			$this->sumRowMetadata($rowToSum);
+		}
+	}
+
+	public function sumRowMetadata($rowToSum)
+	{
+		if (!empty($rowToSum->c[self::METADATA])
+			&& !$this->isSummaryRow())
+		{
+			// We shall update metadata, and keep the metadata with the _most visits or pageviews_, rather than first or last seen
+			$visits = max($rowToSum->getColumn(Piwik_Archive::INDEX_PAGE_NB_HITS) || $rowToSum->getColumn(Piwik_Archive::INDEX_NB_VISITS),
+				// Old format pre-1.2, @see also method updateInterestStats()
+				$rowToSum->getColumn('nb_actions') || $rowToSum->getColumn('nb_visits'));
+			if (($visits && $visits > $this->maxVisitsSummed)
+				|| empty($this->c[self::METADATA])
+			) {
+				$this->maxVisitsSummed = $visits;
+				$this->c[self::METADATA] = $rowToSum->c[self::METADATA];
+			}
+		}
+	}
+
+	public function isSummaryRow()
+	{
+		return $this->getColumn('label') === Piwik_DataTable::LABEL_SUMMARY_ROW;
 	}
 
 	/**
-	 *
+	 * Helper function: sums 2 values
+	 * 
 	 * @param number|bool   $thisColumnValue
 	 * @param number|array  $columnToSumValue
 	 * @return array|int
@@ -457,6 +562,24 @@ class Piwik_DataTable_Row
 			}
 			return $newValue;
 		}
+		
+		if (is_string($columnToSumValue))
+		{
+			if ($thisColumnValue === false)
+			{
+				return $columnToSumValue;
+			}
+			else if ($columnToSumValue === false)
+			{
+				return $thisColumnValue;
+			}
+			else
+			{
+				throw new Exception("Trying to add two strings values in DataTable_Row::sumRowArray: "
+					. "'$thisColumnValue' + '$columnToSumValue'");
+			}
+		}
+		
 		return 0;
 	}
 
@@ -528,8 +651,8 @@ class Piwik_DataTable_Row
 			)
 		)
 		{
-			$subtable1 = Piwik_DataTable_Manager::getInstance()->getTable($row1->getIdSubDataTable());
-			$subtable2 = Piwik_DataTable_Manager::getInstance()->getTable($row2->getIdSubDataTable());
+			$subtable1 = $row1->getSubtable();
+			$subtable2 = $row2->getSubtable();
 			if(!Piwik_DataTable::isEqual($subtable1, $subtable2))
 			{
 				return false;
