@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Mail.php 5187 2011-09-19 01:15:27Z matt $
+ * @version $Id: Mail.php 6325 2012-05-26 21:08:06Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -21,17 +21,24 @@ class Piwik_Mail extends Zend_Mail
 {
 	/**
 	 * Default charset utf-8
-	 * @param string $charset
+	 *
+	 * @param string  $charset  charset, defaults to utf-8
 	 */
 	public function __construct($charset = 'utf-8')
 	{
 		parent::__construct($charset);
 		$this->initSmtpTransport();
 	}
-	
+
+	/**
+	 * Sets the sender to use
+	 *
+	 * @param string       $email
+	 * @param null|string  $name
+	 */
 	public function setFrom($email, $name = null)
 	{
-		$hostname = Zend_Registry::get('config')->mail->defaultHostnameIfEmpty;
+		$hostname = Piwik_Config::getInstance()->mail['defaultHostnameIfEmpty'];
 		$piwikHost = Piwik_Url::getCurrentHost($hostname);
 		
 		// If known Piwik URL, use it instead of "localhost"
@@ -46,27 +53,30 @@ class Piwik_Mail extends Zend_Mail
 		$email = str_replace('{DOMAIN}', $piwikHost, $email);
 		parent::setFrom($email, $name);
 	}
-	
+
+	/**
+	 * @return void
+	 */
 	private function initSmtpTransport()
 	{
-		$config = Zend_Registry::get('config')->mail;
-		if ( empty($config->host) 
-			 || $config->transport != 'smtp')
+		$mailConfig = Piwik_Config::getInstance()->mail;
+		if ( empty($mailConfig['host']) 
+			 || $mailConfig['transport'] != 'smtp')
 		{
 			return;
 		}
 		$smtpConfig = array();
-		if (!empty($config->type))
-			$smtpConfig['auth'] = strtolower($config->type);
-		if (!empty($config->username))
-			$smtpConfig['username'] = $config->username;
-		if (!empty($config->password))
-			$smtpConfig['password'] = $config->password;
-		if (!empty($config->encryption))
-			$smtpConfig['ssl'] = $config->encryption;
+		if (!empty($mailConfig['type']))
+			$smtpConfig['auth'] = strtolower($mailConfig['type']);
+		if (!empty($mailConfig['username']))
+			$smtpConfig['username'] = $mailConfig['username'];
+		if (!empty($mailConfig['password']))
+			$smtpConfig['password'] = $mailConfig['password'];
+		if (!empty($mailConfig['encryption']))
+			$smtpConfig['ssl'] = $mailConfig['encryption'];
 		
-		$tr = new Zend_Mail_Transport_Smtp($config->host, $smtpConfig);
+		$tr = new Zend_Mail_Transport_Smtp($mailConfig['host'], $smtpConfig);
 		Piwik_Mail::setDefaultTransport($tr);
-		ini_set("smtp_port", $config->port);
+		ini_set("smtp_port", $mailConfig['port']);
 	}
 }
