@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: PluginsManager.php 6427 2012-05-31 23:26:11Z matt $
+ * @version $Id: PluginsManager.php 7657 2012-12-19 11:03:10Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -78,6 +78,42 @@ class Piwik_PluginsManager
 		$this->dispatcher = Event_Dispatcher::getInstance();
 	}
 
+	/**
+	 * Update Plugins config
+	 *
+	 * @param array $plugins Plugins
+	 */
+	private function updatePluginsConfig($plugins)
+	{
+		$section = Piwik_Config::getInstance()->Plugins;
+		$section['Plugins'] = $plugins;
+		Piwik_Config::getInstance()->Plugins = $section;
+	}
+
+	/**
+	 * Update Plugins_Tracker config
+	 *
+	 * @param array $plugins Plugins
+	 */
+	private function updatePluginsTrackerConfig($plugins)
+	{
+		$section = Piwik_Config::getInstance()->Plugins_Tracker;
+		$section['Plugins_Tracker'] = $plugins;
+		Piwik_Config::getInstance()->Plugins_Tracker = $section;
+	}
+
+	/**
+	 * Update PluginsInstalled config
+	 *
+	 * @param array $plugins Plugins
+	 */
+	private function updatePluginsInstalledConfig($plugins)
+	{
+		$section = Piwik_Config::getInstance()->PluginsInstalled;
+		$section['PluginsInstalled'] = $plugins;
+		Piwik_Config::getInstance()->PluginsInstalled = $section;
+	}
+
 	/**
 	 * Returns true if plugin is always activated
 	 *
@@ -120,8 +156,19 @@ class Piwik_PluginsManager
 	public function readPluginsDirectory()
 	{
 		$pluginsName = _glob( PIWIK_INCLUDE_PATH . '/plugins/*', GLOB_ONLYDIR);
-		$pluginsName = $pluginsName == false ? array() : array_map('basename', $pluginsName);
-		return $pluginsName;
+		$result = array();
+		if ($pluginsName != false)
+		{
+			foreach ($pluginsName as $path)
+			{
+				$name = basename($path);
+				if (file_exists($path.'/'.$name.'.php')) // only add folder if a Plugin/Plugin.php file exists
+				{
+					$result[] = $name;
+				}
+			}
+		}
+		return $result;
 	}
 
 	/**
@@ -133,15 +180,18 @@ class Piwik_PluginsManager
 	{
 		$plugins = $this->pluginsToLoad;
 		$key = array_search($pluginName, $plugins);
-		
+
 		$plugin = $this->loadPlugin($pluginName);
-		$plugin->deactivate();
-		
+		if ($plugin !== null)
+		{
+			$plugin->deactivate();
+		}
+
 		if($key !== false)
 		{
 			unset($plugins[$key]);
-			Piwik_Config::getInstance()->Plugins['Plugins'] = $plugins;
 		}
+		$this->updatePluginsConfig($plugins);
 
 		$pluginsTracker = Piwik_Config::getInstance()->Plugins_Tracker['Plugins_Tracker'];
 		if(!is_null($pluginsTracker))
@@ -150,7 +200,7 @@ class Piwik_PluginsManager
 			if($key !== false)
 			{
 				unset($pluginsTracker[$key]);
-				Piwik_Config::getInstance()->Plugins_Tracker['Plugins_Tracker'] = $pluginsTracker;
+				$this->updatePluginsTrackerConfig($pluginsTracker);
 			}
 		}
 
@@ -191,15 +241,20 @@ class Piwik_PluginsManager
 		$existingPlugins = $this->readPluginsDirectory();
 		if( array_search($pluginName, $existingPlugins) === false)
 		{
-			throw new Exception("Unable to find the plugin '$pluginName'.");
+			Piwik::log("Unable to find the plugin '$pluginName' in activatePlugin.");
+			return;
 		}
 
 		$plugin = $this->loadPlugin($pluginName);
+		if ($plugin === null)
+		{
+			return;
+		}
 
 		$this->installPluginIfNecessary($plugin);
 
 		$plugin->activate();
-		
+
 		// we add the plugin to the list of activated plugins
 		if(!in_array($pluginName, $plugins))
 		{
@@ -212,7 +267,7 @@ class Piwik_PluginsManager
 		}
 
 		// the config file will automatically be saved with the new plugin
-		Piwik_Config::getInstance()->Plugins['Plugins'] = $plugins;
+		$this->updatePluginsConfig($plugins);
 		Piwik_Config::getInstance()->forceSave();
 
 		// Delete merged js/css files to force regenerations to include the activated plugin
@@ -341,6 +396,11 @@ class Piwik_PluginsManager
 			if(!$this->isPluginLoaded($pluginName))
 			{
 				$newPlugin = $this->loadPlugin($pluginName);
+				if ($newPlugin === null)
+				{
+					continue;
+				}
+				
 				if($this->doLoadPlugins
 					&& $this->isPluginActivated($pluginName))
 				{
@@ -356,7 +416,7 @@ class Piwik_PluginsManager
 	 *
 	 * @param string  $pluginName
 	 * @throws Exception
-	 * @return Piwik_Plugin
+	 * @return Piwik_Plugin|null
 	 */
 	public function loadPlugin( $pluginName )
 	{
@@ -376,8 +436,8 @@ class Piwik_PluginsManager
 
 		if(!file_exists($path))
 		{
-			throw new Exception("Unable to load plugin '$pluginName' because '$path' couldn't be found.
-			You can manually uninstall the plugin by removing the line <code>Plugins[] = $pluginName</code> from the Piwik config file.");
+//			Piwik::log("Unable to load plugin '$pluginName' because '$path' couldn't be found.");
+			return null;
 		}
 
 		// Don't remove this.
@@ -410,7 +470,14 @@ class Piwik_PluginsManager
 	{
 		if(!($plugin instanceof Piwik_Plugin ))
 		{
-			$plugin = $this->loadPlugin( $plugin );
+			$oPlugin = $this->loadPlugin( $plugin );
+			if ($oPlugin === null)
+			{
+				unset($this->loadedPlugins[$plugin]);
+				return;
+			}
+			
+			$plugin = $oPlugin;
 		}
 		$hooks = $plugin->getListHooksRegistered();
 
@@ -459,7 +526,7 @@ class Piwik_PluginsManager
 		try{
 			$plugin->install();
 		} catch(Exception $e) {
-			throw new Piwik_PluginsManager_PluginException($plugin->getPluginName(), $e->getMessage());		
+			throw new Piwik_PluginsManager_PluginException($plugin->getPluginName(), $e->getMessage());
 		}
 	}
 
@@ -552,6 +619,30 @@ class Piwik_PluginsManager
 		$pluginNames = Piwik_Config::getInstance()->PluginsInstalled['PluginsInstalled'];
 		return $pluginNames;
 	}
+	
+	/**
+	 * Returns names of plugins that should be loaded, but cannot be since their
+	 * files cannot be found.
+	 * 
+	 * @return array
+	 */
+	public function getMissingPlugins()
+	{
+		$missingPlugins = array();
+		if (isset(Piwik_Config::getInstance()->Plugins['Plugins']))
+		{
+			$plugins = Piwik_Config::getInstance()->Plugins['Plugins'];
+			foreach ($plugins as $pluginName)
+			{
+				// if a plugin is listed in the config, but is not loaded, it does not exist in the folder
+				if (!Piwik_PluginsManager::getInstance()->isPluginLoaded($pluginName))
+				{
+					$missingPlugins[] = $pluginName;
+				}
+			}
+		}
+		return $missingPlugins;
+	}
 
 	/**
 	 * Install a plugin, if necessary
@@ -563,15 +654,14 @@ class Piwik_PluginsManager
 		$pluginName = $plugin->getPluginName();
 
 		$saveConfig = false;
-			
+
 		// is the plugin already installed or is it the first time we activate it?
 		$pluginsInstalled = $this->getInstalledPluginsName();
 		if(!in_array($pluginName, $pluginsInstalled))
 		{
 			$this->installPlugin($plugin);
 			$pluginsInstalled[] = $pluginName;
-			Piwik_Config::getInstance()->PluginsInstalled['PluginsInstalled'] = $pluginsInstalled;
-			
+			$this->updatePluginsInstalledConfig($pluginsInstalled);
 			$saveConfig = true;
 		}
 
@@ -589,11 +679,11 @@ class Piwik_PluginsManager
 			if(!in_array($pluginName, $pluginsTracker))
 			{
 				$pluginsTracker[] = $pluginName;
-				Piwik_Config::getInstance()->Plugins_Tracker['Plugins_Tracker'] = $pluginsTracker;
+				$this->updatePluginsTrackerConfig($pluginsTracker);
 				$saveConfig = true;
 			}
 		}
-		
+
 		if($saveConfig)
 		{
 			Piwik_Config::getInstance()->forceSave();
