@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: ReportRenderer.php 4879 2011-06-05 22:59:00Z JulienM $
+ * @version $Id: ReportRenderer.php 6918 2012-09-04 21:44:26Z JulienM $
  * 
  * @category Piwik
  * @package Piwik
@@ -27,13 +27,16 @@ abstract class Piwik_ReportRenderer
 	const TABLE_CELL_BORDER_COLOR =  "231,231,231";
 	const TABLE_BG_COLOR = "249,250,250";
 
-	static public $availableReportRenderers = array(
-		'pdf' => 'plugins/UserSettings/images/plugins/pdf.gif',
-		'html' => 'themes/default/images/html_icon.png',
+	const HTML_FORMAT = 'html';
+	const PDF_FORMAT = 'pdf';
+
+	static private $availableReportRenderers = array(
+		self::PDF_FORMAT,
+		self::HTML_FORMAT,
 	);
 
 	/**
-	 * Returns the ReportRenderer associated to the renderer type $rendererType
+	 * Return the ReportRenderer associated to the renderer type $rendererType
 	 *
 	 * @throws exception If the renderer is unknown
 	 * @param string $rendererType
@@ -54,7 +57,7 @@ abstract class Piwik_ReportRenderer
 			throw new Exception(
 				Piwik_TranslateException(
 					'General_ExceptionInvalidReportRendererFormat',
-					array($name, implode(', ', array_keys(self::$availableReportRenderers)))
+					array($name, implode(', ', self::$availableReportRenderers))
 				)
 			);
 		}
@@ -83,6 +86,18 @@ abstract class Piwik_ReportRenderer
 	 */
 	abstract public function sendToBrowserDownload($filename);
 
+	/**
+	 * Output rendering to browser
+	 *
+	 * @param string $filename without path & without format extension
+	 */
+	abstract public function sendToBrowserInline($filename);
+
+	/**
+	 * Get rendered report
+	 */
+	abstract public function getRenderedReport();
+
 	/**
 	 * Generate the first page.
 	 *
@@ -115,7 +130,7 @@ abstract class Piwik_ReportRenderer
 	}
 
 	/**
-	 * Returns $filename with temp directory and delete file
+	 * Return $filename with temp directory and delete file
 	 *
 	 * @static
 	 * @param  $filename
@@ -129,6 +144,42 @@ abstract class Piwik_ReportRenderer
 		return $outputFilename;
 	}
 
+	protected static function writeFile($filename, $extension, $content)
+	{
+		$filename = self::appendExtension($filename, $extension);
+		$outputFilename = self::getOutputPath($filename);
+
+		$emailReport = @fopen($outputFilename, "w");
+
+		if (!$emailReport) {
+			throw new Exception ("The file : " . $outputFilename . " can not be opened in write mode.");
+		}
+
+		fwrite($emailReport, $content);
+		fclose($emailReport);
+
+		return $outputFilename;
+	}
+
+	protected static function sendToBrowser($filename, $extension, $contentType, $content)
+	{
+		$filename = Piwik_ReportRenderer::appendExtension($filename, $extension);
+
+		Piwik::overrideCacheControlHeaders();
+		header('Content-Description: File Transfer');
+		header('Content-Type: ' . $contentType);
+		header('Content-Disposition: attachment; filename="'.str_replace('"', '\'', basename($filename)).'";');
+		header('Content-Length: '.strlen($content));
+
+		echo $content;
+	}
+
+	protected static function inlineToBrowser($contentType, $content)
+	{
+		header('Content-Type: ' . $contentType);
+		echo $content;
+	}
+
 	/**
 	 * Convert a dimension-less report to a multi-row two-column data table
 	 *
@@ -140,25 +191,67 @@ abstract class Piwik_ReportRenderer
 	 */
 	protected static function processTableFormat($reportMetadata, $report, $reportColumns)
 	{
-		if(!isset($reportMetadata['dimension']))
+		$finalReport = $report;
+		if(empty($reportMetadata['dimension']))
 		{
+//			var_dump($report);
 			$simpleReportMetrics = $report->getFirstRow();
-			$report = new Piwik_DataTable_Simple();
-			foreach($simpleReportMetrics->getColumns() as $metricId => $metric)
+			if($simpleReportMetrics)
 			{
-				$newRow = new Piwik_DataTable_Row();
-				$report->addRow($newRow);
-				$newRow->addColumn("label",$reportColumns[$metricId]);
-				$newRow->addColumn("value",$metric);
+				$finalReport = new Piwik_DataTable_Simple();
+				foreach($simpleReportMetrics->getColumns() as $metricId => $metric)
+				{
+					$newRow = new Piwik_DataTable_Row();
+					$newRow->addColumn("label", $reportColumns[$metricId]);
+					$newRow->addColumn("value", $metric);
+					$finalReport->addRow($newRow);
+				}
 			}
 
-			$reportColumns = array('label' => Piwik_Translate('General_Name'),
-										 'value' => Piwik_Translate('General_Value'),);
+			$reportColumns = array(
+				'label' => Piwik_Translate('General_Name'),
+				'value' => Piwik_Translate('General_Value'),
+			);
 		}
 
 		return array(
-				$report,
-				$reportColumns
-			);
+			$finalReport,
+			$reportColumns,
+		);
+	}
+
+	public static function getStaticGraph($reportMetadata, $width, $height, $evolution) {
+
+		$imageGraphUrl = $reportMetadata['imageGraphUrl'];
+
+		if($evolution && !empty($reportMetadata['imageGraphEvolutionUrl']))
+		{
+			$imageGraphUrl = $reportMetadata['imageGraphEvolutionUrl'];
+		}
+
+		$request = new Piwik_API_Request(
+			$imageGraphUrl .
+			'&outputType='.Piwik_ImageGraph_API::GRAPH_OUTPUT_PHP.
+			'&format=original&serialize=0'.
+			'&filter_truncate='.
+			'&width='.$width.
+			'&height='.$height
+		);
+
+		try {
+			$imageGraph = $request->process();
+
+			// Get image data as string
+			ob_start();
+			imagepng($imageGraph);
+			$imageGraphData = ob_get_contents();
+			ob_end_clean();
+			imagedestroy($imageGraph);
+
+			return $imageGraphData;
+
+		} catch(Exception $e) {
+			throw new Exception("ImageGraph API returned an error: ".$e->getMessage()."\n");
+		}
 	}
 }
