@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Session.php 6325 2012-05-26 21:08:06Z SteveG $
+ * @version $Id: Session.php 7681 2012-12-22 02:05:40Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -79,7 +79,7 @@ class Piwik_Session extends Zend_Session
 			// Note: this handler doesn't work well in load-balanced environments and may have a concurrency issue with locked session files
 
 			// for "files", use our own folder to prevent local session file hijacking 
-			$sessionPath = PIWIK_USER_PATH . '/tmp/sessions';
+			$sessionPath = self::getSessionsDirectory();
 			// We always call mkdir since it also chmods the directory which might help when permissions were reverted for some reasons 
 			Piwik_Common::mkdir($sessionPath); 
 
@@ -137,4 +137,14 @@ class Piwik_Session extends Zend_Session
 			Piwik_ExitWithMessage($message);
 		}
 	}
+	
+	/**
+	 * Returns the directory session files are stored in.
+	 * 
+	 * @return string
+	 */
+	public static function getSessionsDirectory()
+	{
+		return PIWIK_USER_PATH . '/tmp/sessions';
+	}
 }
