@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: function.sparkline.php 6300 2012-05-23 21:19:25Z SteveG $
+ * @version $Id: function.sparkline.php 6520 2012-07-19 07:08:35Z capedfuzz $
  * 
  * @category Piwik
  * @package SmartyPlugins
@@ -18,7 +18,8 @@
 function smarty_function_sparkline($params, &$smarty = false)
 {
 	$src = $params['src'];
-	$width = Piwik_Visualization_Sparkline::getWidth();
-	$height = Piwik_Visualization_Sparkline::getHeight();
+	$graph = new Piwik_Visualization_Sparkline();
+	$width = $graph->getWidth();
+	$height = $graph->getHeight();
 	return "<img class=\"sparkline\" alt=\"\" src=\"$src\" width=\"$width\" height=\"$height\" />";
 }
