@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: GoalManager.php 6300 2012-05-23 21:19:25Z SteveG $
+ * @version $Id: GoalManager.php 7485 2012-11-19 01:42:06Z vipsoft $
  * 
  * @category Piwik
  * @package Piwik
@@ -234,19 +234,15 @@ class Piwik_Tracker_GoalManager
 	 * @param string $referrerCampaignName
 	 * @param string $referrerCampaignKeyword
 	 */
-	public function recordGoals($idSite, $visitorInformation, $visitCustomVariables, $action, $referrerTimestamp, $referrerUrl, $referrerCampaignName, $referrerCampaignKeyword)
+	public function recordGoals($idSite, $visitorInformation, $visitCustomVariables, $action, $referrerTimestamp, $referrerUrl, $referrerCampaignName, $referrerCampaignKeyword, $browserLanguage)
 	{
 		$location_country = isset($visitorInformation['location_country']) 
 							? $visitorInformation['location_country'] 
 							: Piwik_Common::getCountry( 
-									Piwik_Common::getBrowserLanguage(), 
+									$browserLanguage, 
 									$enableLanguageToCountryGuess = Piwik_Config::getInstance()->Tracker['enable_language_to_country_guess'],
 									$visitorInformation['location_ip'] 
 							);
-							
-		$location_continent = isset($visitorInformation['location_continent']) 
-								? $visitorInformation['location_continent'] 
-								: Piwik_Common::getContinent($location_country);
 
 		$goal = array(
 			'idvisit' 			=> $visitorInformation['idvisit'],
@@ -254,13 +250,21 @@ class Piwik_Tracker_GoalManager
 			'idvisitor' 		=> $visitorInformation['idvisitor'],
 			'server_time' 		=> Piwik_Tracker::getDatetimeFromTimestamp($visitorInformation['visit_last_action_time']),
 			'location_country'  => $location_country,
-			'location_continent'=> $location_continent,
 			'visitor_returning' => $visitorInformation['visitor_returning'],
 			'visitor_days_since_first' => $visitorInformation['visitor_days_since_first'],
 			'visitor_days_since_order' => $visitorInformation['visitor_days_since_order'],
 			'visitor_count_visits' => $visitorInformation['visitor_count_visits'],
 		);
-
+		
+		$extraLocationCols = array('location_region', 'location_city', 'location_latitude', 'location_longitude');
+		foreach ($extraLocationCols as $col)
+		{
+			if (isset($visitorInformation[$col]))
+			{
+				$goal[$col] = $visitorInformation[$col];
+			}
+		}
+		
 		// Copy Custom Variables from Visit row to the Goal conversion
 		for($i=1; $i<=Piwik_Tracker::MAX_CUSTOM_VARIABLES; $i++) 
 		{
@@ -293,7 +297,7 @@ class Piwik_Tracker_GoalManager
         
         // 0) In some (unknown!?) cases the campaign is not found in the attribution cookie, but the URL ref was found.
 		//    In this case we look up if the current visit is credited to a campaign and will credit this campaign rather than the URL ref (since campaigns have higher priority)
-		if(empty($refererCampaignName)
+		if(empty($referrerCampaignName)
 			&& $type == Piwik_Common::REFERER_TYPE_CAMPAIGN
 			&& !empty($name)
 		)
@@ -775,7 +779,7 @@ class Piwik_Tracker_GoalManager
 	 * Records a standard non-Ecommerce goal in the DB (URL/Title matching),
 	 * linking the conversion to the action that triggered it
 	 * @param $goal
-	 * @param $action
+	 * @param Piwik_Tracker_Action $action
 	 * @param $visitorInformation
 	 */
 	protected function recordStandardGoals($goal, $action, $visitorInformation)
@@ -790,7 +794,7 @@ class Piwik_Tracker_GoalManager
 			
 			if(!is_null($action))
 			{
-				$newGoal['idaction_url'] = (int)$action->getIdActionUrl();
+				$newGoal['idaction_url'] = $action->getIdActionUrl();
 				$newGoal['idlink_va'] = $action->getIdLinkVisitAction();
 			}
 
