@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Visit.php 6403 2012-05-30 10:49:44Z matt $
+ * @version $Id: Visit.php 7721 2013-01-03 02:00:18Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -35,12 +35,15 @@ interface Piwik_Tracker_Visit_Interface {
  */
 class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 {
+	const UNKNOWN_CODE = 'xx';
+	
 	/**
 	 * @var Piwik_Cookie
 	 */
 	protected $cookie = null;
 	protected $visitorInfo = array();
 	protected $userSettingsInformation = null;
+	protected $visitorCustomVariables = array();
 	protected $idsite;
 	protected $visitorKnown;
 	protected $request;
@@ -48,6 +51,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	// can be overwritten in constructor
 	protected $timestamp;
 	protected $ip;
+	protected $authenticated = false;
 	
 	// Set to true when we set some custom variables from the cookie
 	protected $customVariablesSetFromRequest = false;
@@ -57,7 +61,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	 */
 	protected $goalManager;
 
-	public function __construct($forcedIpString = null, $forcedDateTime = null)
+	public function __construct($forcedIpString = null, $forcedDateTime = null, $authenticated = false)
 	{
 		$this->timestamp = time();
 		if(!empty($forcedDateTime))
@@ -76,6 +80,8 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 		$ip = Piwik_IP::P2N($ipString);
 		$this->ip = $ip;
+
+		$this->authenticated = $authenticated;
 	}
 
 	function setForcedVisitorId($visitorId)
@@ -91,7 +97,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		Piwik_PostEvent('Tracker.setRequest.idSite', $idsite, $requestArray);
 		if($idsite <= 0)
 		{
-			Piwik_Tracker_ExitWithException(new Exception('Invalid idSite'));
+			throw new Exception('Invalid idSite');
 		}
 		$this->idsite = $idsite;
 
@@ -143,6 +149,8 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		$this->visitorCustomVariables = self::getCustomVariables($scope = 'visit', $this->request);
 		if(!empty($this->visitorCustomVariables))
 		{
+			printDebug("Visit level Custom Variables: ");
+			printDebug($this->visitorCustomVariables);
 			$this->customVariablesSetFromRequest = true;
 		}
 	
@@ -188,7 +196,10 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$visitIsConverted = $someGoalsConverted;
 			
 			$action->loadIdActionNameAndUrl();
-			$idActionUrl = (int)$action->getIdActionUrl();
+			$idActionUrl = $action->getIdActionUrl();
+			if ($idActionUrl !== null) {
+				$idActionUrl = (int)$idActionUrl;
+			}
 			$idActionName = (int)$action->getIdActionName();
 			$actionType = $action->getActionType();
 		}
@@ -280,7 +291,8 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 										$refererTimestamp,
 										$refererUrl,
 										$refererCampaignName,
-										$refererCampaignKeyword
+										$refererCampaignKeyword,
+										$this->getBrowserLanguage()
 			);
 		}
 		unset($this->goalManager);
@@ -308,7 +320,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		{
 			$type = Piwik_Tracker_Action::getActionTypeName($action->getActionType());
 			printDebug("Action is a $type,
-						Action name =  ". $action->getActionName() . ",
+						Action name =  ". $action->getActionName() .",
 						Action URL = ". $action->getActionUrl() );
 		}
 	}
@@ -336,13 +348,26 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	{
 		// gather information that needs to be updated
 		$valuesToUpdate = array();
-
+		$incrementActions = false;
 		$sqlActionUpdate = '';
+
+		if(!empty($idActionName))
+		{
+			$valuesToUpdate['visit_exit_idaction_name'] = (int)$idActionName;
+		}
 		if($idActionUrl !== false)
 		{
 			$valuesToUpdate['visit_exit_idaction_url'] = $idActionUrl;
-			$sqlActionUpdate = "visit_total_actions = visit_total_actions + 1, ";
-			$valuesToUpdate['visit_exit_idaction_name'] = (int)$idActionName;
+			$incrementActions = true;
+		}
+		if($actionType == Piwik_Tracker_Action::TYPE_SITE_SEARCH)
+		{
+			$sqlActionUpdate .= "visit_total_searches = visit_total_searches + 1, ";
+			$incrementActions = true;
+		}
+		if($incrementActions)
+		{
+			$sqlActionUpdate .= "visit_total_actions = visit_total_actions + 1, ";
 		}
 
 		$datetimeServer = Piwik_Tracker::getDatetimeFromTimestamp($this->getCurrentTimestamp());
@@ -506,16 +531,18 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 		// User settings
 		$userInfo = $this->getUserSettingsInformation();
-		$country = Piwik_Common::getCountry($userInfo['location_browser_lang'],
-											$enableLanguageToCountryGuess = Piwik_Config::getInstance()->Tracker['enable_language_to_country_guess'],
-											$this->getVisitorIp());
-
+		
 		// Referrer data
 		$referrer = new Piwik_Tracker_Visit_Referer();
 		$refererUrl	= Piwik_Common::getRequestVar( 'urlref', '', 'string', $this->request);
 		$currentUrl	= Piwik_Common::getRequestVar( 'url', '', 'string', $this->request);
 		$refererInfo = $referrer->getRefererInformation($refererUrl, $currentUrl, $this->idsite);
-		
+
+		$visitorReturning = $isReturningCustomer
+								? 2 /* Returning customer */
+								: ($visitCount > 1 || $this->isVisitorKnown() || $daysSinceLastVisit > 0
+									? 1 /* Returning */
+									: 0 /* New */ );
 		/**
 		 * Save the visitor
 		 */
@@ -523,7 +550,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			'idsite' 					=> $this->idsite,
 			'visitor_localtime' 		=> $localTime,
 			'idvisitor' 				=> $idcookie,
-			'visitor_returning' 		=> $isReturningCustomer ? 2 : ($visitCount > 1 || $this->isVisitorKnown() ? 1 : 0),
+			'visitor_returning' 		=> $visitorReturning,
 			'visitor_count_visits'		=> $visitCount,
 			'visitor_days_since_last'	=> $daysSinceLastVisit,
 			'visitor_days_since_order'	=> $daysSinceLastOrder,
@@ -536,9 +563,11 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			'visit_exit_idaction_name' 	=> (int)$idActionName,
 			'visit_total_actions' 		=> in_array($actionType,
 												array(Piwik_Tracker_Action::TYPE_ACTION_URL,
-													 Piwik_Tracker_Action::TYPE_DOWNLOAD,
-													 Piwik_Tracker_Action::TYPE_OUTLINK))
+													Piwik_Tracker_Action::TYPE_DOWNLOAD,
+													Piwik_Tracker_Action::TYPE_OUTLINK,
+													Piwik_Tracker_Action::TYPE_SITE_SEARCH))
 											? 1 : 0, // if visit starts with something else (e.g. ecommerce order), don't record as an action
+			'visit_total_searches'      => $actionType == Piwik_Tracker_Action::TYPE_SITE_SEARCH ? 1 : 0,
 			'visit_total_time' 			=> $defaultTimeOnePageVisit,
 			'visit_goal_converted'  	=> $visitIsConverted ? 1: 0,
 			'visit_goal_buyer'			=> $this->goalManager->getBuyerType(),
@@ -563,8 +592,11 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			'config_cookie' 			=> $userInfo['config_cookie'],
 			'location_ip' 				=> $this->getVisitorIp(),
 			'location_browser_lang'		=> $userInfo['location_browser_lang'],
-			'location_country' 			=> $country,
 		);
+		
+		// add optional location components
+		$location = $this->getVisitorLocation($userInfo['location_browser_lang']);
+		$this->updateVisitInfoWithLocation($location);
 
 		// Add Custom variable key,value to the visitor array
 		$this->visitorInfo = array_merge($this->visitorInfo, $this->visitorCustomVariables);
@@ -578,6 +610,105 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 		$this->saveVisitorInformation();
 	}
+	
+	/**
+	 * Returns the location of the visitor, based on the visitor's IP and browser language.
+	 * 
+	 * @param string $browserLang
+	 * @return array See Piwik_UserCountry_LocationProvider::getLocation for more info.
+	 */
+	private function getVisitorLocation( $browserLang )
+	{
+		$location = array();
+		$userInfo = array('lang' => $browserLang, 'ip' => Piwik_IP::N2P($this->getVisitorIp()));
+		Piwik_PostEvent('Tracker.getVisitorLocation', $location, $userInfo);
+
+		if($this->authenticated)
+		{
+			// check for location override query parameters (ie, lat, long, country, region, city)
+			$locationOverrideParams = array(
+				'country' => array('string', Piwik_UserCountry_LocationProvider::COUNTRY_CODE_KEY),
+				'region' => array('string', Piwik_UserCountry_LocationProvider::REGION_CODE_KEY),
+				'city' => array('string', Piwik_UserCountry_LocationProvider::CITY_NAME_KEY),
+				'lat' => array('float', Piwik_UserCountry_LocationProvider::LATITUDE_KEY),
+				'long' => array('float', Piwik_UserCountry_LocationProvider::LONGITUDE_KEY),
+			);
+			foreach ($locationOverrideParams as $queryParamName => $info)
+			{
+				list($type, $locationResultKey) = $info;
+
+				$value = Piwik_Common::getRequestVar($queryParamName, false, $type, $this->request);
+				if (!empty($value))
+				{
+					$location[$locationResultKey] = $value;
+				}
+			}
+		}
+
+		if (empty($location['country_code'])) // sanity check
+		{
+			$location['country_code'] = self::UNKNOWN_CODE;
+		}
+		
+		return $location;
+	}
+	
+	/**
+	 * Sets visitor info array with location info.
+	 * 
+	 * @param array $location See Piwik_UserCountry_LocationProvider::getLocation for more info.
+	 */
+	private function updateVisitInfoWithLocation( $location )
+	{
+		static $logVisitToLowerLocationMapping = array(
+			'location_country' => Piwik_UserCountry_LocationProvider::COUNTRY_CODE_KEY,
+		);
+		
+		static $logVisitToLocationMapping = array(
+			'location_region' => Piwik_UserCountry_LocationProvider::REGION_CODE_KEY,
+			'location_city' => Piwik_UserCountry_LocationProvider::CITY_NAME_KEY,
+			'location_latitude' => Piwik_UserCountry_LocationProvider::LATITUDE_KEY,
+			'location_longitude' => Piwik_UserCountry_LocationProvider::LONGITUDE_KEY,
+		);
+		
+		foreach ($logVisitToLowerLocationMapping as $column => $locationKey)
+		{
+			if (!empty($location[$locationKey]))
+			{
+				$this->visitorInfo[$column] = strtolower($location[$locationKey]);
+			}
+		}
+		
+		foreach ($logVisitToLocationMapping as $column => $locationKey)
+		{
+			if (!empty($location[$locationKey]))
+			{
+				$this->visitorInfo[$column] = $location[$locationKey];
+			}
+		}
+		
+		// if the location has provider/organization info, set it
+		if (!empty($location[Piwik_UserCountry_LocationProvider::ISP_KEY]))
+		{
+			$providerValue = $location[Piwik_UserCountry_LocationProvider::ISP_KEY];
+			
+			// if the org is set and not the same as the isp, add it to the provider value
+			if (!empty($location[Piwik_UserCountry_LocationProvider::ORG_KEY])
+				&& $location[Piwik_UserCountry_LocationProvider::ORG_KEY] != $providerValue)
+			{
+				$providerValue .= ' - ' . $location[Piwik_UserCountry_LocationProvider::ORG_KEY];
+			}
+		}
+		else if (!empty($location[Piwik_UserCountry_LocationProvider::ORG_KEY]))
+		{
+			$providerValue = $location[Piwik_UserCountry_LocationProvider::ORG_KEY];
+		}
+		
+		if (isset($providerValue))
+		{
+			$this->visitorInfo['location_provider'] = $providerValue;
+		}
+	}
 
 	/**
 	 * Save new visitor information to log_visit table.
@@ -587,11 +718,6 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	{
 		Piwik_PostEvent('Tracker.saveVisitorInformation', $this->visitorInfo);
 
-		if(empty($this->visitorInfo['location_country']))
-		{
-			$this->visitorInfo['location_country'] = 'xx';
-		}
-		$this->visitorInfo['location_continent'] = Piwik_Common::getContinent( $this->visitorInfo['location_country'] );
 		$this->visitorInfo['location_browser_lang'] = substr($this->visitorInfo['location_browser_lang'], 0, 20);
 		$this->visitorInfo['referer_name'] = substr($this->visitorInfo['referer_name'], 0, 70);
 		$this->visitorInfo['referer_keyword'] = substr($this->visitorInfo['referer_keyword'], 0, 255);
@@ -651,9 +777,20 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	 *
 	 * @return string
 	 */
-	protected function getUserAgent()
+	static public function getUserAgent($request)
 	{
-		return @$_SERVER['HTTP_USER_AGENT'];
+		$default = @$_SERVER['HTTP_USER_AGENT'];
+		return Piwik_Common::getRequestVar('ua', is_null($default) ? false : $default, 'string', $request);
+	}
+	
+	/**
+	 * Returns the language the visitor is viewing.
+	 * 
+	 * @return string browser language code, eg. "en-gb,en;q=0.5"
+	 */
+	protected function getBrowserLanguage()
+	{
+	    return Piwik_Common::getRequestVar('lang', Piwik_Common::getBrowserLanguage(), 'string', $this->request);
 	}
 
 	/**
@@ -691,7 +828,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		$excluded = false;
 
 		$ip = $this->getVisitorIp();
-		$ua = $this->getUserAgent();
+		$ua = $this->getUserAgent($this->request);
 
 		/*
 		 * Live/Bing/MSN bot and Googlebot are evolving to detect cloaked websites.
@@ -715,6 +852,10 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 						'207.46.0.0/16',
 						'207.68.128.0/18',
 						'207.68.192.0/20',
+						'131.253.26.0/20',
+						'131.253.24.0/20',
+						// Yahoo
+						'98.137.207.0/20',
 						// Chinese bot hammering websites
 						'1.202.218.8' 
 					)))) 
@@ -734,7 +875,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$toRecord = Piwik_Common::getRequestVar($parameterForceRecord, false, 'int', $this->request);
 			if(!$toRecord)
 			{
-				printDebug($_SERVER['REQUEST_METHOD'].' parameter '.$parameterForceRecord.' not found in URL, request excluded');
+				printDebug(@$_SERVER['REQUEST_METHOD'].' parameter '.$parameterForceRecord.' not found in URL, request excluded');
 				$excluded = true;
 				printDebug("'$parameterForceRecord' parameter not found.");
 			}
@@ -767,6 +908,28 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 				printDebug("IP excluded.");
 			}
 		}
+		
+		// Check if user agent should be excluded
+		if (!$excluded)
+		{
+			$excluded = $this->isUserAgentExcluded($ua);
+			if ($excluded)
+			{
+				printDebug("User agent excluded.");
+			}
+		}
+		
+		if(!$excluded)
+		{
+			if( (isset($_SERVER["HTTP_X_PURPOSE"]) 
+					&& in_array($_SERVER["HTTP_X_PURPOSE"], array("preview", "instant")))
+			 || (isset($_SERVER['HTTP_X_MOZ'])
+			 		&& $_SERVER['HTTP_X_MOZ'] == "prefetch"))
+	 		{
+	 			$excluded = true;
+	 			printDebug("Prefetch request detected, not a real visit so we Ignore this visit/pageview");
+	 		}
+		}
 
 		if($excluded)
 		{
@@ -810,6 +973,32 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		}
 		return false;
 	}
+	
+	/**
+	 * Returns true if the specified user agent should be excluded for the current site or not.
+	 * 
+	 * Visits whose user agent string contains one of the excluded_user_agents strings for the
+	 * site being tracked (or one of the global strings) will be excluded.
+	 * 
+	 * @param string $ua The user agent string.
+	 * @return bool
+	 */
+	protected function isUserAgentExcluded( $ua )
+	{
+		$websiteAttributes = Piwik_Common::getCacheWebsiteAttributes($this->idsite);
+		if (!empty($websiteAttributes['excluded_user_agents']))
+		{
+			foreach ($websiteAttributes['excluded_user_agents'] as $excludedUserAgent)
+			{
+				// if the excluded user agent string part is in this visit's user agent, this visit should be excluded
+				if (stripos($ua, $excludedUserAgent) !== false)
+				{
+					return true;
+				}
+			}
+		}
+		return false;
+	}
 
 	/**
 	 * Returns the cookie name used for the Piwik Tracker cookie
@@ -953,7 +1142,10 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 							visitor_days_since_first,
 							visitor_days_since_order,
 							location_country,
-							location_continent,
+							location_region,
+							location_city,
+							location_latitude,
+							location_longitude,
 							referer_name,
 							referer_keyword,
 							referer_type,
@@ -1070,7 +1262,10 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$this->visitorInfo['visitor_count_visits'] = $visitRow['visitor_count_visits'];
 			$this->visitorInfo['visit_goal_buyer'] = $visitRow['visit_goal_buyer'];
 			$this->visitorInfo['location_country'] = $visitRow['location_country'];
-			$this->visitorInfo['location_continent'] = $visitRow['location_continent'];
+			$this->visitorInfo['location_region'] = $visitRow['location_region'];
+			$this->visitorInfo['location_city'] = $visitRow['location_city'];
+			$this->visitorInfo['location_latitude'] = $visitRow['location_latitude'];
+			$this->visitorInfo['location_longitude'] = $visitRow['location_longitude'];
 			
 			// Referer information will be potentially used for Goal Conversion attribution
 			$this->visitorInfo['referer_name'] = $visitRow['referer_name'];
@@ -1111,15 +1306,10 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 	static public function getCustomVariables($scope, $request)
 	{
-		if($scope == 'visit')
-		{
+		if($scope == 'visit') {
 			$parameter = '_cvar';
-			$debug = 'Visit level';
-		}
-		else
-		{
+		} else {
 			$parameter = 'cvar';
-			$debug = 'Page level';
 		}
 		
 		$customVar = Piwik_Common::unsanitizeInputValues(Piwik_Common::getRequestVar($parameter, '', 'json', $request));
@@ -1152,17 +1342,13 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$customVariables['custom_var_k'.$id] = $key;
 			$customVariables['custom_var_v'.$id] = $value;
 		}
-		if(!empty($customVariables))
-		{
-			printDebug("$debug Custom Variables: ");
-			printDebug($customVariables);
-		}
+
 		return $customVariables;
 	}
 
 	static public function truncateCustomVariable($input)
 	{
-		return substr($input, 0, Piwik_Tracker::MAX_LENGTH_CUSTOM_VARIABLE);
+		return substr(trim($input), 0, Piwik_Tracker::MAX_LENGTH_CUSTOM_VARIABLE);
 	}
 
 	/**
@@ -1190,7 +1376,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		$plugin_Silverlight		= Piwik_Common::getRequestVar( 'ag', 0, 'int', $this->request);
 		$plugin_Cookie 			= Piwik_Common::getRequestVar( 'cookie', 0, 'int', $this->request);
 
-		$userAgent		= Piwik_Common::sanitizeInputValues($this->getUserAgent());
+		$userAgent		= $this->getUserAgent($this->request);
 		$aBrowserInfo	= UserAgentParser::getBrowser($userAgent);
 
 		$browserName	= ($aBrowserInfo !== false && $aBrowserInfo['id'] !== false) ? $aBrowserInfo['id'] : 'UNK';
@@ -1201,7 +1387,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 		$resolution		= Piwik_Common::getRequestVar('res', 'unknown', 'string', $this->request);
 
-		$browserLang	= Piwik_Common::getBrowserLanguage();
+		$browserLang	= $this->getBrowserLanguage();
 
 		$configurationHash = $this->getConfigHash(
 												$os,
@@ -1446,9 +1632,11 @@ class Piwik_Tracker_Visit_Referer
 			$refererUrl = '';
 		}
 		
+		$currentUrl = Piwik_Tracker_Action::cleanupUrl($currentUrl);
+		
 		$this->refererUrl = $refererUrl;
 		$this->refererUrlParse = @parse_url($this->refererUrl);
-		$this->currentUrlParse = @parse_url(Piwik_Common::unsanitizeInputValue($currentUrl));
+		$this->currentUrlParse = @parse_url($currentUrl);
 		$this->typeRefererAnalyzed = Piwik_Common::REFERER_TYPE_DIRECT_ENTRY;
 		$this->nameRefererAnalyzed = '';
 		$this->keywordRefererAnalyzed = '';
@@ -1493,8 +1681,9 @@ class Piwik_Tracker_Visit_Referer
 		return $refererInformation;
 	}
 
-	/*
+	/**
 	 * Search engine detection
+     * @return bool
 	 */
 	protected function detectRefererSearchEngine()
 	{
@@ -1510,7 +1699,11 @@ class Piwik_Tracker_Visit_Referer
 		return true;
 	}
 
-	protected function detectCampaignFromString($string)
+    /**
+     * @param string $string
+     * @return bool
+     */
+    protected function detectCampaignFromString($string)
 	{
 		foreach($this->campaignNames as $campaignNameParameter)
 		{
@@ -1540,8 +1733,9 @@ class Piwik_Tracker_Visit_Referer
 		return false;
 	}
 	
-	/*
+	/**
 	 * Campaign analysis
+     * @return bool
 	 */
 	protected function detectRefererCampaign()
 	{
@@ -1571,11 +1765,12 @@ class Piwik_Tracker_Visit_Referer
 		return $found;
 	}
 
-	/*
+	/**
 	 * We have previously tried to detect the campaign variables in the URL
 	 * so at this stage, if the referer host is the current host,
 	 * or if the referer host is any of the registered URL for this website,
 	 * it is considered a direct entry
+     * @return bool
 	 */
 	protected function detectRefererDirectEntry()
 	{
