@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Unzip.php 6325 2012-05-26 21:08:06Z SteveG $
+ * @version $Id: Unzip.php 7550 2012-11-26 22:14:37Z capedfuzz $
  *
  * @category Piwik
  * @package Piwik
@@ -31,10 +31,20 @@ class Piwik_Unzip
 			case 'ZipArchive':
 				if(class_exists('ZipArchive', false))
 					return new Piwik_Unzip_ZipArchive($filename);
-
+				break;
+			case 'tar.gz':
+				return new Piwik_Unzip_Tar($filename, 'gz');
+			case 'tar.bz2':
+				return new Piwik_Unzip_Tar($filename, 'bz2');
+			case 'gz':
+				if (function_exists('gzopen'))
+					return new Piwik_Unzip_Gzip($filename);
+				break;
 			case 'PclZip':
 			default:
 				return new Piwik_Unzip_PclZip($filename);
 		}
+		
+		return new Piwik_Unzip_PclZip($filename);
 	}
 }
