@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: UpdateCheck.php 6404 2012-05-30 11:46:29Z matt $
+ * @version $Id: UpdateCheck.php 7683 2012-12-22 09:02:51Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -18,6 +18,7 @@
 class Piwik_UpdateCheck 
 {
 	const CHECK_INTERVAL = 28800; // every 8 hours
+	const UI_CLICK_CHECK_INTERVAL = 10; // every 10s when user clicks UI link
 	const LAST_TIME_CHECKED = 'UpdateCheck_LastTimeChecked';
 	const LATEST_VERSION = 'UpdateCheck_LatestVersion';
 	const SOCKET_TIMEOUT = 2;
@@ -27,12 +28,17 @@ class Piwik_UpdateCheck
 	 *
 	 * @param bool  $force  Force check
 	 */
-	public static function check($force = false)
+	public static function check($force = false, $interval = null)
 	{
+		if ($interval === null)
+		{
+			$interval = self::CHECK_INTERVAL;
+		}
+		
 		$lastTimeChecked = Piwik_GetOption(self::LAST_TIME_CHECKED);
 		if($force
 			|| $lastTimeChecked === false
-			|| time() - self::CHECK_INTERVAL > $lastTimeChecked )
+			|| time() - $interval > $lastTimeChecked )
 		{
 			// set the time checked first, so that parallel Piwik requests don't all trigger the http requests
 			Piwik_SetOption(self::LAST_TIME_CHECKED, time(), $autoload = 1);
