@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: ViewDataTable.php 6436 2012-06-01 13:53:33Z matt $
+ * @version $Id: ViewDataTable.php 7612 2012-12-14 08:56:21Z capedfuzz $
  *
  * @category Piwik
  * @package Piwik
@@ -292,6 +292,7 @@ abstract class Piwik_ViewDataTable
 		$this->viewProperties['show_table_all_columns'] = Piwik_Common::getRequestVar('show_table_all_columns', true);
 		$this->viewProperties['show_all_views_icons'] = Piwik_Common::getRequestVar('show_all_views_icons', true);
 		$this->viewProperties['hide_all_views_icons'] = Piwik_Common::getRequestVar('hide_all_views_icons', false);
+		$this->viewProperties['hide_annotations_view'] = Piwik_Common::getRequestVar('hide_annotations_view', true);
 		$this->viewProperties['show_bar_chart'] = Piwik_Common::getRequestVar('show_barchart', true);
 		$this->viewProperties['show_pie_chart'] = Piwik_Common::getRequestVar('show_piechart', true);
 		$this->viewProperties['show_tag_cloud'] = Piwik_Common::getRequestVar('show_tag_cloud', true);
@@ -300,17 +301,21 @@ abstract class Piwik_ViewDataTable
 		$this->viewProperties['show_exclude_low_population'] = Piwik_Common::getRequestVar('show_exclude_low_population', true);
 		$this->viewProperties['show_offset_information'] = Piwik_Common::getRequestVar('show_offset_information', true);
 		$this->viewProperties['show_pagination_control'] = Piwik_Common::getRequestVar('show_pagination_control', true);
+		$this->viewProperties['show_limit_control'] = false;
 		$this->viewProperties['show_footer'] = Piwik_Common::getRequestVar('show_footer', true);
 		$this->viewProperties['show_footer_icons'] = ($this->idSubtable == false);
+		$this->viewProperties['show_related_reports'] = Piwik_Common::getRequestVar('show_related_reports', true);
 		$this->viewProperties['apiMethodToRequestDataTable'] = $this->apiMethodToRequestDataTable;
 		$this->viewProperties['uniqueId'] = $this->getUniqueIdViewDataTable();
 		$this->viewProperties['exportLimit'] = Piwik_Config::getInstance()->General['API_datatable_default_limit'];
+
 		$this->viewProperties['highlight_summary_row'] = false;
 		$this->viewProperties['metadata'] = array();
 		
 		$this->viewProperties['relatedReports'] = array();
 		$this->viewProperties['title'] = 'unknown';
 		$this->viewProperties['self_url'] = $this->getBaseReportUrl($currentControllerName, $currentControllerAction);
+		$this->viewProperties['tooltip_metadata_name'] = false;
 		
 		$standardColumnNameToTranslation = array_merge(
 			Piwik_API_API::getInstance()->getDefaultMetrics(),
@@ -430,15 +435,13 @@ abstract class Piwik_ViewDataTable
 	 */
 	protected function checkStandardDataTable()
 	{
-		if(!($this->dataTable instanceof Piwik_DataTable))
-		{
-			throw new Exception("Unexpected data type to render.");
-		}
+		Piwik::checkObjectTypeIs($this->dataTable, array('Piwik_DataTable'));
 	}
 	
 	/**
 	 * Hook called after the dataTable has been loaded from the API
 	 * Can be used to add, delete or modify the data freshly loaded
+	 * 
 	 * @return bool
 	 */
 	protected function postDataTableLoadedFromAPI()
@@ -468,7 +471,7 @@ abstract class Piwik_ViewDataTable
 			$this->dataTable->filter($filterName, $filterParameters);
 		}
 		
-		if(0 == Piwik_Common::getRequestVar('disable_generic_filters', '0', 'string'))
+		if (!$this->areGenericFiltersDisabled())
 		{
 			// Second, generic filters (Sort, Limit, Replace Column Names, etc.)
 			$requestString = $this->getRequestString();
@@ -479,12 +482,12 @@ abstract class Piwik_ViewDataTable
 			{
 				$request['filter_sort_column'] = $request['filter_sort_order'] = '';
 			}
+			
 			$genericFilter = new Piwik_API_DataTableGenericFilter($request);
 			$genericFilter->filter($this->dataTable);
 		}
 		
-		if (!isset($this->variablesDefault['disable_queued_filters'])
-			|| !$this->variablesDefault['disable_queued_filters'])
+		if (!$this->areQueuedFiltersDisabled())
 		{
 			// Finally, apply datatable filters that were queued (should be 'presentation' filters that
 			// do not affect the number of rows)
@@ -498,6 +501,40 @@ abstract class Piwik_ViewDataTable
 		return true;
 	}
 	
+	/**
+	 * Returns true if generic filters have been disabled, false if otherwise.
+	 * 
+	 * @return bool
+	 */
+	private function areGenericFiltersDisabled()
+	{
+		// if disable_generic_filters query param is set to '1', generic filters are disabled
+		if (Piwik_Common::getRequestVar('disable_generic_filters', '0', 'string') == 1)
+		{
+			return true;
+		}
+		
+		// if $this->disableGenericFilters() was called, generic filters are disabled
+		if (isset($this->variablesDefault['disable_generic_filters'])
+			&& $this->variablesDefault['disable_generic_filters'] === true)
+		{
+			return true;
+		}
+		
+		return false;
+	}
+	
+	/**
+	 * Returns true if queued filters have been disabled, false if otherwise.
+	 * 
+	 * @return bool
+	 */
+	private function areQueuedFiltersDisabled()
+	{
+		return isset($this->variablesDefault['disable_queued_filters'])
+			&& $this->variablesDefault['disable_queued_filters'];
+	}
+	
 	/**
 	 * Returns prettified and translated text that describes when a report was last updated.
 	 * 
@@ -831,6 +868,14 @@ abstract class Piwik_ViewDataTable
 		$this->viewProperties['show_pagination_control'] = false;
 	}
 	
+	/**
+	 * Ensures the limit dropdown will always be shown, even if pagination is disabled.
+	 */
+	public function alwaysShowLimitDropdown()
+	{
+		$this->viewProperties['show_limit_control'] = true;
+	}
+	
 	/**
 	 * The "X-Y of Z" won't be displayed under this table
 	 */
@@ -914,6 +959,20 @@ abstract class Piwik_ViewDataTable
 		$this->viewProperties['hide_all_views_icons'] = true;
 	}
 	
+	/**
+	 * Whether or not to show the annotations view. This method has no effect if
+	 * the Annotations plugin is not loaded.
+	 */
+	public function showAnnotationsView()
+	{
+		if (!Piwik_PluginsManager::getInstance()->isPluginLoaded('Annotations'))
+		{
+			return;
+		}
+		
+		$this->viewProperties['hide_annotations_view'] = false;
+	}
+	
 	/**
 	 * Whether or not to show the bar chart icon.
 	 */
@@ -938,6 +997,14 @@ abstract class Piwik_ViewDataTable
 		$this->viewProperties['show_tag_cloud'] = false;
 	}
 
+	/**
+	 * Whether or not to show related reports in the footer
+	 */
+	public function disableShowRelatedReports()
+	{
+		$this->viewProperties['show_related_reports'] = false;
+	}
+
 	/**
 	 * Whether or not to show the export to RSS feed icon
 	 */
@@ -1182,7 +1249,7 @@ abstract class Piwik_ViewDataTable
 				$columnsNames = array($columnsNames);
 			}
 		}
-		$this->columnsToDisplay = $columnsNames;
+		$this->columnsToDisplay = array_filter($columnsNames);
 	}
 
 	/**
@@ -1217,6 +1284,14 @@ abstract class Piwik_ViewDataTable
 		$this->viewProperties['highlight_summary_row'] = $highlightSummaryRow;
 	}
 	
+	/**
+	 * Sets the name of the metadata to use for a custom tooltip.
+	 */
+	public function setTooltipMetadataName( $metadataName )
+	{
+		$this->viewProperties['tooltip_metadata_name'] = $metadataName;
+	}
+	
 	/**
 	 * Sets columns translations array.
 	 *
