@@ -1,19 +1,19 @@
 <?php
 /**
  * Piwik - Open source web analytics
- * 
+ *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Cloud.php 3565 2011-01-03 05:49:45Z matt $
- * 
+ * @version $Id: Cloud.php 6300 2012-05-23 21:19:25Z SteveG $
+ *
  * @category Piwik
  * @package Piwik
  */
 
-/** 
- * Reads the requested DataTable from the API, and prepares the data to give 
+/**
+ * Reads the requested DataTable from the API, and prepares the data to give
  * to Piwik_Visualization_Cloud that will display the tag cloud (via the template cloud.tpl).
- * 
+ *
  * @package Piwik
  * @subpackage Piwik_ViewDataTable
  */
@@ -30,17 +30,21 @@ class Piwik_ViewDataTable_Cloud extends Piwik_ViewDataTable
 	{
 		return 'cloud';
 	}
-		
+
 	/**
 	 * @see Piwik_ViewDataTable::init()
+	 * @param string $currentControllerName
+	 * @param string $currentControllerAction
+	 * @param string $apiMethodToRequestDataTable
+	 * @param null|string $controllerActionCalledWhenRequestSubTable
 	 */
 	function init($currentControllerName,
-						$currentControllerAction, 
+						$currentControllerAction,
 						$apiMethodToRequestDataTable,
 						$controllerActionCalledWhenRequestSubTable = null)
 	{
 		parent::init($currentControllerName,
-						$currentControllerAction, 
+						$currentControllerAction,
 						$apiMethodToRequestDataTable,
 						$controllerActionCalledWhenRequestSubTable);
 		$this->dataTableTemplate = 'CoreHome/templates/cloud.tpl';
@@ -51,10 +55,10 @@ class Piwik_ViewDataTable_Cloud extends Piwik_ViewDataTable
 	/**
 	 * @see Piwik_ViewDataTable::main()
 	 *
+	 * @return null
 	 */
 	public function main()
 	{
-		$this->setLimit( 30 );
 		if($this->mainAlreadyExecuted)
 		{
 			return;
@@ -99,7 +103,7 @@ class Piwik_ViewDataTable_Cloud extends Piwik_ViewDataTable
 				{
 					$logo =  $row->getMetadata('logo');
 				}
-				$labelMetadata[$row->getColumn('label')] = array( 
+				$labelMetadata[$row->getColumn('label')] = array(
 					'logo' => $logo,
 					'url' => $row->getMetadata('url'),
 				);
@@ -108,7 +112,7 @@ class Piwik_ViewDataTable_Cloud extends Piwik_ViewDataTable
 			foreach($labels as $i => $label)
 			{
 				$cloud->addWord($label, $values[$i]);
-			}		
+			}
 			$cloudValues  = $cloud->render('array');
 			foreach($cloudValues as &$value)
 			{
@@ -120,6 +124,13 @@ class Piwik_ViewDataTable_Cloud extends Piwik_ViewDataTable
 		}
 		$view->javascriptVariablesToSet = $this->getJavascriptVariablesToSet();
 		$view->properties = $this->getViewProperties();
+		$view->reportDocumentation = $this->getReportDocumentation();
+		
+		// if it's likely that the report data for this data table has been purged,
+		// set whether we should display a message to that effect.
+		$view->showReportDataWasPurgedMessage = $this->hasReportBeenPurged();
+		$view->deleteReportsOlderThan = Piwik_GetOption('delete_reports_older_than');
+		
 		return $view;
 	}
 }
