@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Chart.php 5454 2011-11-18 16:28:33Z vipsoft $
+ * @version $Id: Chart.php 7190 2012-10-15 07:41:12Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -34,6 +34,11 @@ abstract class Piwik_Visualization_Chart implements Piwik_View_Interface
 	protected $displayPercentageInTooltip = true;
 	protected $xSteps = 2;
 	
+	/**
+	 * Whether to show every x-axis tick or only every other one.
+	 */
+	protected $showAllTicks = false;
+	
 	public function setAxisXLabels(&$xLabels)
 	{
 		$this->axes['xaxis']['ticks'] = &$xLabels;
@@ -142,9 +147,12 @@ abstract class Piwik_Visualization_Chart implements Piwik_View_Interface
 		$this->xSteps = $steps;
 	}
 	
-	public function setSelectabelColumns($selectableColumns)
+	/**
+	 * Show every x-axis tick instead of just every other one.
+	 */
+	public function showAllTicks()
 	{
-		$this->seriesPicker['selectableColumns'] = $selectableColumns;
+		$this->showAllTicks = true;
 	}
 
 	public function render()
@@ -173,7 +181,7 @@ abstract class Piwik_Visualization_Chart implements Piwik_View_Interface
 			foreach ($this->axes['xaxis']['ticks'] as $i => &$xLabel)
 			{
 				$this->axes['xaxis']['labels'][$i] = $xLabel;
-				if (($i % $this->xSteps) != 0)
+				if (!$this->showAllTicks && ($i % $this->xSteps) != 0)
 				{
 					$xLabel = ' ';
 				}
