@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Evolution.php 4814 2011-05-26 21:21:22Z matt $
+ * @version $Id: Evolution.php 5872 2012-02-21 09:09:16Z EZdesign $
  *
  * @category Piwik
  * @package Piwik
@@ -19,10 +19,10 @@
 class Piwik_Visualization_Chart_Evolution extends Piwik_Visualization_Chart
 {
 	
-	protected $seriesColors = array('#5170AE', '#CC3399', '#9933CC', '#80a033', '#FD9816',
+	protected $seriesColors = array('#5170AE','#F29007', '#CC3399', '#9933CC', '#80a033', 
 			'#246AD2', '#FD16EA', '#49C100');
 	
-	function customizeChartProperties()
+	public function customizeChartProperties()
 	{
 		parent::customizeChartProperties();
 		
@@ -34,4 +34,15 @@ class Piwik_Visualization_Chart_Evolution extends Piwik_Visualization_Chart
 			$this->axes['yaxis']['ticks'] = array(0, 50, 100);
 		}
 	}
+	
+	public function getSeriesColors()
+	{
+		return $this->seriesColors;
+	}
+
+	public function setSelectableRows($selectableRows)
+	{
+		$this->seriesPicker['selectableRows'] = $selectableRows;
+	}
+	
 }
