@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: testMinimumPhpVersion.php 6300 2012-05-23 21:19:25Z SteveG $
+ * @version $Id: testMinimumPhpVersion.php 7701 2012-12-26 05:30:59Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -65,13 +65,12 @@ else
 /**
  * Displays info/warning/error message in a friendly UI and exits.
  *
- * @param string $message Main message
+ * @param string $message Main message, must be html encoded before calling
  * @param bool|string $optionalTrace Backtrace; will be displayed in lighter color
  * @param bool $optionalLinks If true, will show links to the Piwik website for help
  */
 function Piwik_ExitWithMessage($message, $optionalTrace = false, $optionalLinks = false)
 {
-	global $minimumPhpInvalid;
 	@header('Content-Type: text/html; charset=utf-8');
 	if($optionalTrace)
 	{
@@ -80,11 +79,11 @@ function Piwik_ExitWithMessage($message, $optionalTrace = false, $optionalLinks
 	if($optionalLinks)
 	{
 		$optionalLinks = '<ul>
-						<li><a target="_blank" href="?module=Proxy&action=redirect&url=http://piwik.org">Piwik.org homepage</a></li>
-						<li><a target="_blank" href="?module=Proxy&action=redirect&url=http://piwik.org/faq/">Piwik Frequently Asked Questions</a></li>
-						<li><a target="_blank" href="?module=Proxy&action=redirect&url=http://piwik.org/docs/">Piwik Documentation</a></li>
-						<li><a target="_blank" href="?module=Proxy&action=redirect&url=http://forum.piwik.org/">Piwik Forums</a></li>
-						<li><a target="_blank" href="?module=Proxy&action=redirect&url=http://demo.piwik.org">Piwik Online Demo</a></li>
+						<li><a target="_blank" href="http://piwik.org">Piwik.org homepage</a></li>
+						<li><a target="_blank" href="http://piwik.org/faq/">Piwik Frequently Asked Questions</a></li>
+						<li><a target="_blank" href="http://piwik.org/docs/">Piwik Documentation</a></li>
+						<li><a target="_blank" href="http://forum.piwik.org/">Piwik Forums</a></li>
+						<li><a target="_blank" href="http://demo.piwik.org">Piwik Online Demo</a></li>
 						</ul>';
 	}
 	$headerPage = file_get_contents(PIWIK_INCLUDE_PATH . '/themes/default/simple_structure_header.tpl');
@@ -104,11 +103,3 @@ if(!empty($piwik_errorMessage))
 {
 	Piwik_ExitWithMessage($piwik_errorMessage, false, true);
 }
-
-/**
- * Usually used in Tracker code, but sometimes triggered from Core
- */
-if(!function_exists('printDebug')) 
-{ 
-	function printDebug($i) {} 
-}
