@@ -55,7 +55,6 @@ $translations = array(
 	'General_Website' => 'ድር ጣቢያ',
 	'General_NoDataForGraph' => 'ለዚህ ግራፍ ምንም ውሂብ የለም',
 	'General_NoDataForTagCloud' => 'ለዚህ መለያ ክላውድ ምንም ውሂብ የለም.',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s ፒዊክ %2$s በትብብር የተዘረጋ ፕሮጀክት ነው። %3$s ፒዊክ ከተስማማችሁ ድጋፍ መሰጠት ትችላላችሁ! ለፒዊክ ፕሮጀክት %4$s እንዴት አስተዋፃኦ ማድረግ እንደሚችሉ ይመልከቱ?%5$s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'ፒዊክን %1$s ማግኘት ይቻላል። %2$s እባክዎን ያልቁት!%3$s (ለውጦቹን%4$s ይመልከቱ%5$s).',
 	'General_BackToPiwik' => 'ወደፒዊክ ተመለስ',
 	'General_ShortMonth_1' => 'ጥር',
@@ -244,11 +243,7 @@ $translations = array(
 	'Login_LogIn' => 'ግባ',
 	'Login_Logout' => 'ውጣ',
 	'Login_LostYourPassword' => 'የይለፍ ቃል ጠፋብህ?',
-	'Login_RemindPassword' => 'የይለፍ ቃል አስታውስ',
-	'Login_PasswordReminder' => 'እባክህ የተጠቃሚ ስም ወይም የኢ-ሜይል አድራሻ አስገባ. አዲስ የይለፍ ቃል በኢ-ሜይል ይላካል።',
 	'Login_InvalidUsernameEmail' => 'የተሳሳት የተጠቃሚ ስም እና/ወይም ኢ-ሜይል አድራሻ',
-	'Login_MailTopicPasswordRecovery' => 'የይለፍ ቃል ማግኛ',
-	'Login_PasswordSent' => 'የይለፍ ቃል አሁን ተልኳል። ኢ-ሜይልዎን አሁን ይመልከቱ',
 	'Login_ContactAdmin' => 'ተገቢው ምክንያት: አስተናጋጅዎ የ ሜይል() ተግባርን አቦዝኖት ሊሆን ይችላል። <br />እባክዎ የፒዊክ መናጅዎን ያነጋግሩ',
 	'Provider_WidgetProviders' => 'አቅራቢዎች',
 	'Provider_ColumnProvider' => 'አቅራቢ',
@@ -258,7 +253,6 @@ $translations = array(
 	'Referers_Keywords' => 'ቁልፍ ቃላት',
 	'Referers_DirectEntry' => 'ቀጥተኛ ምዝግብ',
 	'Referers_Websites' => 'ድር ጣቢያዎች',
-	'Referers_Campaigns' => 'Campaigns',
 	'Referers_Evolution' => 'Evolution በክፍለ ጊዜው',
 	'Referers_Type' => 'የምልከታ ዓይነት',
 	'Referers_ColumnRefererType' => 'የአመላካች ዓይነት',
@@ -266,7 +260,6 @@ $translations = array(
 	'Referers_ColumnWebsite' => 'ድር ጣቢያዎች',
 	'Referers_ColumnWebsitePage' => 'የድር ጣቢያዎች ገፅ',
 	'Referers_ColumnKeyword' => 'ቁልፍ ቃላት',
-	'Referers_ColumnCampaign' => 'Campaign',
 	'Referers_DetailsByRefererType' => 'ዝርዝር በአመላካች ዓይነት',
 	'Referers_TypeDirectEntries' => '%s ቀጥተኛ ምዝግቦች',
 	'Referers_TypeSearchEngines' => '%s ከመፈለጊያ ሞተሮች',
@@ -279,7 +272,6 @@ $translations = array(
 	'Referers_DistinctWebsites' => 'የተለዩ ድር ጣቢያዎች',
 	'Referers_SubmenuSearchEngines' => 'የመፈለጊያ ሞተሮች እና ቁልፍ ቃላት',
 	'Referers_SubmenuWebsites' => 'ድር ጣቢያዎች',
-	'Referers_SubmenuCampaigns' => 'Campaigns',
 	'Referers_WidgetKeywords' => 'የቁልፍ ቃላት ዝርዝር',
 	'Referers_WidgetCampaigns' => 'የCampaigns ዝርዝር',
 	'Referers_WidgetExternalWebsites' => 'የውጫዊ ድር ጣቢያዎች ዝርዝር',
@@ -315,8 +307,6 @@ $translations = array(
 	'UserCountry_Continent' => 'አህጉር',
 	'UserCountry_DistinctCountries' => '%s የተለዩ ሀገራት',
 	'UserCountry_SubmenuLocations' => 'አቀማመጦች',
-	'UserCountry_WidgetContinents' => 'የጎብኚዎች አህጉራት',
-	'UserCountry_WidgetCountries' => 'የጎብኚዎች ሀገራት',
 	'UserCountry_country_ac' => 'Ascension Islands',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'United Arab Emirates',
@@ -658,7 +648,6 @@ $translations = array(
 	'VisitsSummary_NbUniqueVisitors' => '%s የተለዩ ጎብኚዎች',
 	'VisitsSummary_MaxNbActions' => '%s በአንድ ጉብኝት የተወሰዱ ከፍተኛ ርምጃዎች',
 	'VisitsSummary_NbVisitsBounced' => '%s የተመለሱ ጉብኝቶች (ከአንድ ገፅ በኋላ ገፁን የተዉ)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolution በመጨረሻው ላይ %s',
 	'VisitsSummary_GenerateTime' => '%s ሰከንዶች ገፁን ለማመንጨት',
 	'VisitsSummary_GenerateQueries' => '%s ጥያቄዎች ተሰርተዋል',
 	'VisitsSummary_WidgetLastVisits' => 'የመጨረሻው ጉብኝቶች ግራፍ',
@@ -673,5 +662,4 @@ $translations = array(
 	'VisitTime_WidgetLocalTime' => 'ጉብኝቶች በአካባቢያዊ ሰዓት',
 	'VisitTime_WidgetServerTime' => 'ጉብኝቶች በአገልጋይ ሰዓት',
 	'VisitTime_SubmenuTimes' => 'ሰዓታት',
-	'VisitTime_NHour' => '%sh',
 );
