@@ -12,6 +12,7 @@ $translations = array(
 	'General_DashboardForASpecificWebsite' => 'Tauler per un lloc web concret',
 	'General_MultiSitesSummary' => 'Tots els llocs web',
 	'General_AllWebsitesDashboard' => 'Tauler de tots els llocs web',
+	'General_SingleWebsitesDashboard' => 'Tauler per un sol lloc web',
 	'General_API' => 'API',
 	'General_Widgets' => 'Ginys',
 	'General_Settings' => 'Tauler de control',
@@ -30,11 +31,16 @@ $translations = array(
 	'General_Delete' => 'Esborra',
 	'General_Report' => 'Informe',
 	'General_Reports' => 'Informes',
+	'General_RelatedReport' => 'Informe relacionat',
+	'General_RelatedReports' => 'Informes relacionats',
+	'General_Metric' => 'Mètrica',
+	'General_Metrics' => 'Mètriques',
 	'General_Edit' => 'Edita',
 	'General_Download' => 'Descàrrega',
 	'General_Upload' => 'Càrrega',
 	'General_Ok' => 'D\'acord',
 	'General_Close' => 'Tanca',
+	'General_Cancel' => 'Cancel·lar',
 	'General_OrCancel' => 'o %s cancel·la %s',
 	'General_Logout' => 'Surt',
 	'General_Username' => 'Usuari',
@@ -48,7 +54,6 @@ $translations = array(
 	'General_Name' => 'Nom',
 	'General_Value' => 'Valor',
 	'General_Total' => 'Total',
-	'General_TotalVisitsActionsRevenue' => '(Total: %s visite, %s accions, %s ingressos)',
 	'General_AverageOrderValue' => 'Valor mig de les comandes',
 	'General_PurchasedProducts' => 'Productes comprats',
 	'General_EcommerceOrders' => 'Comandes d\'e-commerce',
@@ -100,6 +105,8 @@ $translations = array(
 	'General_InvalidDateRange_js' => 'Rang de dates no vàlid, si us plau proveu-ho de nou',
 	'General_DateRangeFrom_js' => 'De',
 	'General_DateRangeTo_js' => 'Fins',
+	'General_LastDaysShort' => 'Últims %s dies',
+	'General_PreviousDaysShort' => 'Anteriors %s dies',
 	'General_PreviousDays' => '%s dies anteriors (sense incloure avui)',
 	'General_LastDays' => 'Últims %s dies (incloent avui)',
 	'General_LoadingData' => 'Les dades s\'estan carregant…',
@@ -163,10 +170,13 @@ $translations = array(
 	'General_ColumnUniqueExits' => 'Sortides úniques',
 	'General_ColumnExitsDocumentation' => 'Número de visites que acaben en aquesta pàgina.',
 	'General_ColumnAverageTimeOnPage' => 'Temps mig a la pàgina',
+	'General_TimeOnPage' => 'Temps a la pàgina',
 	'General_ColumnAverageTimeOnPageDocumentation' => 'La mitjana de temps que els visitants s\'han passat en aquesta pàgina (només la pàgina no el lloc enter).',
 	'General_ColumnValuePerVisit' => 'Valor per visita',
 	'General_ColumnVisitsWithConversions' => 'Visites amb conversions',
 	'General_VisitsWith' => 'Visites amb %s',
+	'General_YearsDays' => '%1$s anys %2$s dies',
+	'General_DaysHours' => '%1$s dies %2$s hores',
 	'General_HoursMinutes' => '%1$s hores %2$s min',
 	'General_MinutesSeconds' => '%1$s min %2$ss',
 	'General_Seconds' => '%ss',
@@ -183,17 +193,26 @@ $translations = array(
 	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Informes per avui (o un altre rang de dates incloent avui) es processaran com a molt cada',
 	'General_NSeconds' => '%s segons',
 	'General_SmallTrafficYouCanLeaveDefault' => 'Per llocs amb poc transit, pots deixar el valor per defecte de %s segons i accedir als informes en temps real.',
+	'General_MediumToHighTrafficItIsRecommendedTo' => 'Per llocs de mig i alt transit, recomanem processar informes per avui com a molt cada mitja hora (%s segons) o cada hora (%s segons)',
 	'General_RequiresFlash' => 'Mostrar gràfics en el Piwik requereix Flash',
+	'General_GraphHelp' => 'Més informació sobre mostrar gràfiques al Piwik.',
 	'General_NoDataForGraph' => 'No hi ha dades...',
+	'General_DataForThisGraphHasBeenPurged' => 'Les dades per aquest gràfic tenen més de %s mesos d\'antiguitat i s\'han purgat',
 	'General_NoDataForTagCloud' => 'No hi ha dades...',
+	'General_DataForThisTagCloudHasBeenPurged' => 'Les dades per aquest nuvol d\'etiquetes tenen més de %s mesos i s\'han purgat.',
 	'General_DisplaySimpleTable' => 'Mostrar una taula simple',
 	'General_DisplayTableWithMoreMetrics' => 'Mostrar una taula amb més paràmetres',
 	'General_DisplayTableWithGoalMetrics' => 'Mostrar una taula amb paràmetres globals',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => 'El %1$s Piwik %2$s és un projecte col·laboratiu. %3$s Si us agrada, podeu ajudar-nos! Mireu-vos %4$s Com col·laborar amb el Piwik (en anglès)%5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Ara mateix estàs veient la demo del Piwik',
 	'General_YouAreCurrentlyUsing' => 'Ara mateix estàs fent servir el Piwik %s.',
+	'General_DownloadFullVersion' => '%1$sDescarrega%2$s la versió completa! Ves a %3$s',
 	'General_NewUpdatePiwikX' => 'Nova actualització: Piwik %s',
+	'General_AboutPiwikX' => 'Sobre Piwik %s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Hi ha una nova versió del Piwik, %1$s, disponible! %2$s Si us plau, actualitzeu ara!%3$s (%4$s Mostra els canvis%5$s)',
+	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s és disponible. Si us plau notifiqueu l\'administrador del lloc.',
+	'General_NewReportsWillBeProcessedByCron' => 'Quan l\'arxivat del piwik no es dispara per el navegador, els nous informes es processaran per el crontab.',
+	'General_ReportsWillBeProcessedAtMostEveryHour' => 'El informes per tant es processaran com a molt cada hora.',
+	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Assumint que l\'arxivat és ràpid en el vostre entorn, podeu programar el crontab per funcionar més freqüentment.',
 	'General_BackToPiwik' => 'Torna al Piwik',
 	'General_ClickHere' => 'Fes clic aquí per més informació.',
 	'General_ShortMonth_1' => 'Gen',
@@ -237,16 +256,42 @@ $translations = array(
 	'General_Daily' => 'Diariament',
 	'General_Weekly' => 'Setmanalment',
 	'General_Monthly' => 'Mensualment',
+	'General_DailyReports' => 'Informe diari',
+	'General_WeeklyReports' => 'Informe setmanal',
+	'General_MonthlyReports' => 'Informe mensual',
+	'General_YearlyReports' => 'Informe anual',
+	'General_RangeReports' => 'Rang de data personalitzat',
 	'General_ConfigFileIsNotWritable' => 'El fitxer de configuració del Piwiki %s no es pot modificar, alguns dels canvis que has fet no es guardaran. Si us plau %s canvia els permisos del fitxer de configuració per tal que es pugui modificar.',
 	'General_ExceptionDatabaseVersion' => 'La teva %1$s versió és %s2$s però el Piwik necessita com a mínim %3$s',
+	'General_ExceptionIncompatibleClientServerVersions' => 'El vostre client %1$s té la versió %2$s que és incompatbile amb la versió de servidor %3$s.',
 	'General_ExceptionMissingFile' => 'Falta fitxer: %s',
+	'General_ExceptionFilesizeMismatch' => 'Mida de fitxer incohoerent: %1$s (mida esperada: %2$s, real: %3$s)',
 	'General_ExceptionFileIntegrity' => 'Ha fallat la verificació de integritat: %s',
 	'General_ExceptionNonceMismatch' => 'No s\'ha pogut verificar el token del formulari.',
+	'General_PleaseSpecifyValue' => 'Si us plau especifiqueu el valor per \'%s\'',
+	'General_ExceptionMethodNotFound' => 'El mètode \'%s\' no existeix o no està disponible en el mòdul  \'%s\'.',
+	'General_ExceptionInvalidRendererFormat' => 'El format generador \'%s\' no és vàlid. Proveu-ne un dels següents en el seu lloc: %s.',
+	'General_ExceptionInvalidReportRendererFormat' => 'El format de l\'informe \'%s\' no és vàlid. Proveu-ne un dels següent en el seu lloc: %s.',
+	'General_ExceptionInvalidStaticGraphType' => 'El gràfic estàtic tipus \'%s\' no és vàlid. Proveu-ne un dels següents en el seu lloc: %s.',
+	'General_ExceptionInvalidAggregateReportsFormat' => 'El format de informes agregats \'%s\' no és vàlid. Proveu-ne algun dels següents en el seu lloc: %s.',
+	'General_ExceptionInvalidPeriod' => 'El període \'%s\' no està suportat. Proveu-ne algun dels següents en el seu lloc: %s.',
+	'General_ExceptionInvalidDateRange' => 'La data \'%s\' no és un rang correcte de data. Hauria de tenir el format següent: %s.',
 	'General_ExceptionGoalNotFound' => 'L\'objectiu amb id = %s no s\'ha trobat.',
 	'General_ExceptionUndeletableFile' => 'No s\'ha pogut esborrar %s',
 	'General_ExceptionPrivilege' => 'No podeu accedir a aquest recurs perquè requereix un accés de %s',
+	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'No podeu accedir a aquest recurs perquè requereix un accés %s .per al menys un lloc web',
+	'General_ExceptionPrivilegeAccessWebsite' => 'No podeu accedir a aquest recurs perquè requereix un accés %s per el lloc web id = %d.',
+	'General_ExceptionInvalidArchiveTimeToLive' => 'El temps límit per fer l\'arxivat avui ha de ser més gran que zero.',
+	'General_ExceptionConfigurationFileNotFound' => 'El fitxer de configuració {%s} no s\'ha trobat.',
+	'General_ExceptionUnreadableFileDisabledMethod' => 'El fitxer de configuració {%s} no s\'ha pogut llegir. El vostre host pot tenir deshabilitat %s.',
+	'General_ExceptionInvalidToken' => 'El token no és vàlid.',
 	'General_ExceptionLanguageFileNotFound' => 'El fitxer d\'idioma \'%s\' no s\'ha trobat.',
 	'General_ExceptionUnableToStartSession' => 'No s\'ha pogut començar la sessió.',
+	'General_ExceptionCheckUserIsSuperUserOrTheUser' => 'L\'usuari ha de ser o bé un Super Usuari o el mateix usuari \'%s\'.',
+	'General_WarningFileIntegritySkipped' => 'Entorn de desenvolupament detectat. Evitem la verificació de la integritat dels fitxers.',
+	'General_WarningFileIntegrityNoManifest' => 'La verificació de la integritat dels fitxers no s\'ha pogut fer perquè falta el manifest.inc.php.',
+	'General_WarningFileIntegrityNoMd5file' => 'La verificació de la integritat dels fitxers no s\'ha pogut completar perquè falta la funció md5_file();',
+	'General_FileIntegrityWarningExplanation' => 'La verificació de la integritat dels fitxers ha fallat i ha trobat alguns errors. Això segurament és causa de una carrega parcial o incorrecta dels fitxers del Piwik. Haurieu de tornar a pujar tots els fitxers del Piwik en mode BINARY i refrescar aquesta pàgina fins que no mostri errors.',
 	'General_UseSMTPServerForEmail' => 'Fer servir un servidor SMTP per el correu',
 	'General_SmtpServerAddress' => 'adreça del servidor SMTP',
 	'General_SmtpPort' => 'Port SMTP',
@@ -254,19 +299,50 @@ $translations = array(
 	'General_SmtpUsername' => 'usuari SMTP',
 	'General_SmtpPassword' => 'contrasenya SMTP',
 	'General_SmtpEncryption' => 'encriptació SMTP',
+	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Trieu "si" si voleu o heu d\'enviar el correu a través de un servidor enlloc de a través de la funció mail local.',
+	'General_OptionalSmtpPort' => 'Opcional. Per defecte té el valor 25 per no xifrat i TLS SMTP, i 465 per SSL SMTP.',
+	'General_OnlyUsedIfUserPwdIsSet' => 'Només es fa servir si l\'usuari/contrasenya estan configurats, pregunteu al vostre proveïdor si no esteu segur de quin mètode fer servir.',
+	'General_OnlyEnterIfRequired' => 'Només entreu un usuari si el vostre servidor SMTP ho requereix.',
+	'General_OnlyEnterIfRequiredPassword' => 'Només entreu una contrasenya si el vostre servidor STMP ho requereix.',
+	'General_WarningPasswordStored' => '%sAlerta:%s Aquesta contrasenya es guardarà en un fitxer de configuració visible on tothom pot accedir.',
+	'General_EncryptedSmtpTransport' => 'Entreu el xifrat de la capa de transport requerit per el vostre servidor SMTP.',
 	'General_InvalidResponse' => 'Les dades rebudes són invàlides.',
 	'General_ChooseLanguage' => 'Tria idioma',
 	'General_ChoosePeriod' => 'Triar període',
 	'General_ChooseWebsite' => 'Triar lloc web',
 	'General_Language' => 'Idioma',
 	'General_PleaseUpdatePiwik' => 'Si us plau actualitzeu el Piwik',
+	'General_RequestTimedOut' => 'Una petició a %s ha caducat. Proveu-ho de nou.',
 	'General_UsePlusMinusIconsDocumentation' => 'Fes servir les icones de més i menys a l\'esquerra per navegar.',
+	'General_BrokenDownReportDocumentation' => 'Està separada en diferents informes, que es mostren amb línies de punts al peu de la pàgina. Podeu augmentar aquests gràfics clicant en l\'informe que voleu veure.',
+	'General_ChangeTagCloudView' => 'Si us plau, tingueu en compte que podeu veure l\'informe en altres formes que en nuvol d\'etiquetes. Feu servir els controls al peu de l\'informe per fer-ho.',
 	'General_Recommended' => '(recomanat)',
+	'General_NotRecommended' => '(no recomanat)',
 	'General_Goal' => 'Objectiu',
 	'General_Outlink' => 'Enllaç extern',
 	'General_Help' => 'Ajuda',
+	'General_DailySum' => 'suma diaria',
+	'General_AfterEntry' => 'després d\'entrar aquí',
+	'General_Metadata' => 'Metadata',
+	'General_OneVisit' => '1 visita',
+	'General_NVisits' => '%s visites',
+	'General_OneDay' => '1 dia',
+	'General_NDays' => '%s dies',
+	'General_MainMetrics' => 'Mètriques principals',
+	'General_Mobile' => 'Mòbil',
+	'General_Desktop' => 'Escriptori',
+	'General_Rows' => 'Files',
+	'General_GeneralInformation' => 'Informació General',
+	'General_ReportGeneratedFrom' => 'Aquest informe s\'ha generat fent servir dades de %s.',
+	'Actions_PluginDescription' => 'Informe sobre les pàgines vistes, les enllaços de sortida i descarregues. Els enllaços de sortida i el seguiment de les descàrregues és automàtic.',
 	'Actions_Actions' => 'Accions',
 	'Actions_SubmenuPages' => 'Pàgines',
+	'Actions_SubmenuPagesEntry' => 'Pàgines d\'entrada',
+	'Actions_SubmenuPagesExit' => 'Pàgines de sortida',
+	'Actions_EntryPageTitles' => 'Titols de les pàgines d\'entrada',
+	'Actions_ExitPageTitles' => 'Titols de les pàgines de sortida',
+	'Actions_SubmenuPageTitles' => 'Titols de les pàgines',
+	'Actions_PageUrls' => 'URLs de les pàgines',
 	'Actions_SubmenuOutlinks' => 'Enllaços externs',
 	'Actions_SubmenuDownloads' => 'Descàrregues',
 	'Actions_ColumnClicks' => 'Clics',
@@ -276,7 +352,9 @@ $translations = array(
 	'Actions_ColumnPageName' => 'Nom de la pàgina',
 	'Actions_ColumnClickedURL' => 'URL picada',
 	'Actions_ColumnDownloadURL' => 'URL de descàrrega',
+	'AnonymizeIP_PluginDescription' => 'Anonimitzar el(s) últim(s) de la IP de les adreces dels visitants per complir amb la vostra política de privacitat/llei.',
 	'API_LoadedAPIs' => 'S\'ha carregat correctament un total de %s API',
+	'CoreAdminHome_UseCustomLogo' => 'Utilitza un logo personalitzat',
 	'CoreHome_CategoryNoData' => 'No hi ha dades en aquesta categoria. Proveu d\'<em>incloure tota la població</em>.',
 	'CoreHome_ShowJSCode' => 'Mostra el codi JavaScript necessari',
 	'CoreHome_PageOf_js' => '%1$s de %2$s',
@@ -376,6 +454,14 @@ $translations = array(
 	'DBStats_DataSize' => 'Grandària de les dades',
 	'DBStats_IndexSize' => 'Grandària del l\'índex',
 	'DBStats_TotalSize' => 'Grandària total',
+	'Goals_Goals' => 'Objectius',
+	'Goals_EcommerceAndGoalsMenu' => 'Ecomerç i Objectius',
+	'Goals_Ecommerce' => 'Ecomerç',
+	'Goals_EcommerceOverview' => 'Vista general ecomerç',
+	'Goals_EcommerceOrder' => 'Ordre d\'ecomerç',
+	'Goals_EcommerceLog' => 'Registre d\'ecomerç',
+	'Goals_AbandonedCart' => 'Cistella abandonada',
+	'Goals_GoalsOverview' => 'Vista general d\'objectius',
 	'Goals_ColumnConversions' => 'Conversions',
 	'Goals_ColumnRevenue' => 'Ingressos',
 	'Installation_Installation' => 'Instal·lació',
@@ -448,16 +534,9 @@ $translations = array(
 	'Login_LogIn' => 'Inicia la sessió',
 	'Login_Logout' => 'Surt',
 	'Login_LostYourPassword' => 'Heu perdut la contrasenya?',
-	'Login_RemindPassword' => 'Recorda la contrasenya',
-	'Login_PasswordResetToken' => 'Codi de reinicialització de la contrasenya.',
-	'Login_PasswordReminder' => 'Si us plau, inseriu el vostre nom d\'usuari o el vostre correu-e. Rebreu una contrasenya nova al vostre correu-e.',
 	'Login_PasswordsDoNotMatch' => 'Les contrasenyes no coincideixen',
-	'Login_PasswordSuccessfullyChanged' => 'La contrasenya ha estat canviada amb èxit!',
 	'Login_InvalidUsernameEmail' => 'Aquest usuari i/o direcció de correu-e és invàlid.',
 	'Login_InvalidOrExpiredToken' => 'El codi és invàlid o ha caducat',
-	'Login_MailTopicPasswordRecovery' => 'Recuperació de la contrasenya',
-	'Login_MailPasswordRecoveryBody' => 'Hola %1$s, una petició de reinicialització de la contrasenya ha estat rebuda de %2$s. Per a reiniciar-la: 1)Aneu al formulari de reinicialització de contrasenyes a %3$s 2)Introduïu el següent codi: %4$s 3)Ompliu el formulari (introduint la nova contrasenya dos cops) i envieu-lo. Nota: el codi caduca en 24 hores.',
-	'Login_PasswordSent' => 'La informació per a canviar la contrasenya s\'ha enviat. Reviseu el vostre correu-e',
 	'Login_ContactAdmin' => 'Possiblement sigui perquè el vostre proveïdor d\'allotjament ha desactivat la funció mail().<br />Contacteu amb l\'administrador del lloc.',
 	'Provider_WidgetProviders' => 'Proveïdors',
 	'Provider_ColumnProvider' => 'Proveïdor',
@@ -525,8 +604,6 @@ $translations = array(
 	'UserCountry_Continent' => 'Continent',
 	'UserCountry_DistinctCountries' => 'Hi ha %s països diferents',
 	'UserCountry_SubmenuLocations' => 'Localització',
-	'UserCountry_WidgetContinents' => 'Continents',
-	'UserCountry_WidgetCountries' => 'Països',
 	'UserCountry_country_ac' => 'Illes Ascensió',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'Emirats Àrabs Units',
@@ -872,7 +949,6 @@ $translations = array(
 	'VisitsSummary_NbUniqueVisitors' => '%s visitants únics',
 	'VisitsSummary_MaxNbActions' => 'Hi ha %s accions màximes en una visita',
 	'VisitsSummary_NbVisitsBounced' => '%s visites han rebotat (abandonat el lloc després de veure una pàgina)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolució dels darrers %s',
 	'VisitsSummary_GenerateTime' => 'S\'han trigat %s segons en generar la pàgina',
 	'VisitsSummary_GenerateQueries' => 'S\'ha executat un total de %s consultes',
 	'VisitsSummary_WidgetLastVisits' => 'Gràfic de les darreres visites',
