@@ -102,7 +102,6 @@ $translations = array(
 	'CorePluginsAdmin_Plugins' => 'Pluginad',
 	'CorePluginsAdmin_PluginsManagement' => 'Pluginate haldus',
 	'CorePluginsAdmin_MainDescription' => 'Plugins võimendavad ja suurendavad Piwik-i funktsionaalsust. Kui plugin on installeeritud ja aktiveeritud saad seda sisse ja välja lülitada siin.',
-	'CorePluginsAdmin_Plugin' => 'Plugin',
 	'CorePluginsAdmin_Version' => 'Versioon',
 	'CorePluginsAdmin_Status' => 'Olek',
 	'CorePluginsAdmin_Action' => 'Tegevus',
@@ -120,7 +119,6 @@ $translations = array(
 	'CoreUpdater_UpgradePiwik' => 'Uuenda Piwik',
 	'CoreUpdater_HelpMessageContent' => 'Vaata %1$s Piwik KKK %2$s milles selgitadakse tavapäraste probleemide põhjuseid ja lahendusi. %3$s Kui sa ei leia lahendust, siis küsi oma süsteemi administraatoritelt abi- nad võivad aidata juhul, kui need vead on seotud serveri või MySQL seadetega.',
 	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kriitiline viga uuendamise protsessi ajal:',
-	'CoreUpdater_HelpMessageIntroductionWhenError' => 'The above is the core error message. It should help explain the cause, but if you require further help please:',
 	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Uuendamine edukalt lõpetatud, siiski esines protsessis vigu. Palun tutvu ülal vigade kirjeldustega. Saamaks rohkem abi:',
 	'CoreUpdater_UpgradeComplete' => 'Uuendamine lõpuni viidud!',
 	'CoreUpdater_WarningMessages' => 'Hoiatussõnumid:',
@@ -151,11 +149,9 @@ $translations = array(
 	'Installation_SetupWebsiteError' => 'Veebilehe lisamisel tekkis viga',
 	'Installation_SystemCheck' => 'Süsteemi kontroll',
 	'Installation_SystemCheckPhp' => 'PHP versioon',
-	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
 	'Installation_SystemCheckWriteDirsHelp' => 'Parandamaks seda viga linux süsteemis, trüki sisse käsk/käsud.',
 	'Installation_SystemCheckMemoryLimit' => 'Mälu limiit',
 	'Installation_SystemCheckMemoryLimitHelp' => 'Suure liiklusega veebileht võib vajada arhiveerimiseks rohkem mälu, kui hetkel lubatud.<br />Vaata üle oma memory_limit oma php.ini failis, kui see osutub vajalikuks.',
-	'Installation_SystemCheckGD' => 'GD > 2.x (graphics)',
 	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
 	'Installation_SystemCheckTimeLimitHelp' => 'Suure liiklusega veebilehe puhul, või arhiveerimisprotssess võtta rohkem aega, kui hetkel lubatud.<br />Vaata direktiiv max_execution_time  oma php.ini failis, kui see on vajalik',
 	'Installation_SystemCheckError' => 'Ilmnes viga - Enne jätkamist tuleb see parandada.',
@@ -176,11 +172,7 @@ $translations = array(
 	'Login_LogIn' => 'Sisene',
 	'Login_Logout' => 'Välju',
 	'Login_LostYourPassword' => 'Kaotasid oma salasõna?',
-	'Login_RemindPassword' => 'Meenuta salasõna',
-	'Login_PasswordReminder' => 'Palun sisesta kasutaja või e-mail address. Sulle saadetakse salasõna e-mailiga.',
 	'Login_InvalidUsernameEmail' => 'Vale kasutajanimi ja/või e-maili address',
-	'Login_MailTopicPasswordRecovery' => 'Salasõna taastamine',
-	'Login_PasswordSent' => 'Salasõna saadetud. Kontrolli oma e-maili.',
 	'Login_ContactAdmin' => 'Võimalik põhjus: sinu majutusel on mail() funktsioon välja lülitatud. <br />Palun kontakteeru administraatoriga.',
 	'Provider_WidgetProviders' => 'Pakkujad',
 	'Provider_SubmenuLocationsProvider' => 'Asukoht & pakkuja',
@@ -219,7 +211,6 @@ $translations = array(
 	'TranslationsAdmin_MenuTranslations' => 'Tõlked',
 	'TranslationsAdmin_MenuLanguages' => 'Keeled',
 	'TranslationsAdmin_LanguageCode' => 'Keele kood',
-	'TranslationsAdmin_Plugin' => 'Plugin',
 	'TranslationsAdmin_Definition' => 'Definitsioon',
 	'TranslationsAdmin_DefaultString' => 'Vaikimisi keel (Inglise keel)',
 	'TranslationsAdmin_TranslationString' => 'Tõlke tõmmis (Praegune keel: %s)',
@@ -232,8 +223,6 @@ $translations = array(
 	'UserCountry_Continent' => 'Kontinent',
 	'UserCountry_DistinctCountries' => '%s eri riigist',
 	'UserCountry_SubmenuLocations' => 'Asukohad',
-	'UserCountry_WidgetContinents' => 'Külastuste kontinendid',
-	'UserCountry_WidgetCountries' => 'Külastuste riigid',
 	'UserCountry_country_ac' => 'Ascension Saared',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'Ühendatud Araabia-Emiraadid',
@@ -513,11 +502,8 @@ $translations = array(
 	'UsersManager_User' => 'Kasutaja',
 	'UsersManager_PrivNone' => 'Ligipääs puudub',
 	'UsersManager_PrivView' => 'Vaata',
-	'UsersManager_PrivAdmin' => 'Admin',
 	'UsersManager_ChangeAllConfirm' => 'Kas sa oled kindel soovis anda \'%s\' õigused kõigile veebilehtedele?',
 	'UsersManager_Password' => 'Salasõna',
-	'UsersManager_Email' => 'Email',
-	'UsersManager_Alias' => 'Alias',
 	'UsersManager_Edit' => 'Muuda',
 	'UsersManager_AddUser' => 'Lisa uus kasutaja',
 	'UsersManager_MenuUsers' => 'Kasutajad',
@@ -529,18 +515,14 @@ $translations = array(
 	'UsersManager_ExceptionAdminAnonymous' => 'Sa ei saa anda \'admin\' õiguseid \'anonymous\' kasutajale.',
 	'UsersManager_ExceptionEditAnonymous' => 'Anonüümset kasutajat ei saa muuta ega kustutada. Piwik kasutab seda määratlemaks kasutajat, kes ei ole veel sisse loginud. Näiteks, saad teha statistika lubada \'view\' statistikat õigused \'anonymous\' kasutajale.',
 	'UsersManager_ExceptionUserDoesNotExist' => 'Kasutaja \'%s\' puudub.',
-	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
 	'VisitFrequency_Evolution' => 'Perioodi areng',
 	'VisitFrequency_ReturnVisits' => '%s korduvat külastust',
 	'VisitFrequency_ReturnActions' => '%s tegevust tegi korduv külastaja',
 	'VisitFrequency_WidgetOverview' => 'Sageduse ülevaade',
 	'VisitFrequency_WidgetGraphReturning' => 'Korduvate külastuste graafik',
 	'VisitFrequency_SubmenuFrequency' => 'Sagedus',
-	'VisitorInterest_VisitsPerDuration' => 'Visits per visit duration',
-	'VisitorInterest_VisitsPerNbOfPages' => 'Visits per number of pages',
 	'VisitorInterest_WidgetLengths' => 'Külastuste kestvus',
 	'VisitorInterest_WidgetPages' => 'Erinevaid lehti külastuse kohta',
-	'VisitorInterest_PlusXMin' => '%s min',
 	'VisitorInterest_OnePage' => '1 leht',
 	'VisitorInterest_NPages' => '%s lehte',
 	'VisitsSummary_NbVisits' => '%s külastust',
