@@ -104,7 +104,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => 'Bistaratu taula sinplea',
 	'General_DisplayTableWithMoreMetrics' => 'Bistaratu taula estatistika gehiagorekin',
 	'General_DisplayTableWithGoalMetrics' => 'Bistaratu taula helburuen estatistikekin',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s auzolaneko proiektua da. %3$s Piwik gustoko baduzu, laguntza eman dezakezu! Emaiozu begirada: %4$s Nola lagundu Piwik-en?%5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Piwiken demoa ikusten ari zara',
 	'General_NewUpdatePiwikX' => 'Eguneraketa berria: Piwik %s',
 	'General_AboutPiwikX' => 'Piwik %s(r)i buruz',
@@ -427,44 +426,9 @@ $translations = array(
 	'Login_LogIn' => 'Hasi saioa',
 	'Login_Logout' => 'Amaitu saioa',
 	'Login_LostYourPassword' => 'Pasahitza galdu duzu?',
-	'Login_RemindPassword' => 'Bidali pasahitz berrezartzea',
-	'Login_PasswordResetToken' => 'Pasahitza berrezartzeko tokena',
-	'Login_PasswordReminder' => 'Idatzi zure erabiltzaile-izen edo e-posta. Mezu elektroniko bat jasoko duzu zure pasahitza berrezartzeko informazioarekin.',
 	'Login_PasswordsDoNotMatch' => 'Pasahitzak ez datoz bat.',
-	'Login_PasswordSuccessfullyChanged' => 'Pasahitza ondo aldatu da!',
 	'Login_InvalidUsernameEmail' => 'Erabiltzaile-izen edo helbide elektroniko baliogabea',
 	'Login_InvalidOrExpiredToken' => 'Tokena baliogabea da edo iraungi egin da',
-	'Login_MailTopicPasswordRecovery' => 'Pasahitza berreskuratzea',
-	'Login_MailPasswordRecoveryBody' => 'Kaixo %1$s,
-
-
-
-Pasahitza berrezartzeko eskaria jaso da %2$s helbidetik.
-
-
-
-Zure pasahitza berrezartzeko:
-
-
-
-1) Zoaz pasahitza berrezartzeko inprimakira:
-
-	%3$s
-
-
-
-2) Idatz ezazu ondorengo tokena:
-
-	%4$s
-
-
-
-3) Bete eta bidal ezazu inprimakia (zure pasahitz berria birritan sartuz) inprimakia.
-
-
-
-Oharra: tokena 24 ordutan iraungiko da.',
-	'Login_PasswordSent' => 'Zure pasahitza berrezartzeko informazioa bidali da. Begira ezazu zure posta elektronikoa.',
 	'Login_ContactAdmin' => 'Arrazoi posiblea: zure ostalariak mail() funtzioa ezgaituta izan dezake.<br />Jar zaitez harremanetan zure Piwik kudeatzailearekin.',
 	'Provider_WidgetProviders' => 'Hornitzaileak',
 	'Provider_ColumnProvider' => 'Hornitzailea',
@@ -538,8 +502,6 @@ Oharra: tokena 24 ordutan iraungiko da.',
 	'UserCountry_Continent' => 'Kontinentea',
 	'UserCountry_DistinctCountries' => '%s herrialde desberdin',
 	'UserCountry_SubmenuLocations' => 'Kokalekuak',
-	'UserCountry_WidgetContinents' => 'Bisitarien kontinenteak',
-	'UserCountry_WidgetCountries' => 'Bisitarien herrialdeak',
 	'UserCountry_country_ac' => 'Ascension uharteak',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'Arabiar Emirerri Batuak',
@@ -885,7 +847,6 @@ Oharra: tokena 24 ordutan iraungiko da.',
 	'VisitsSummary_NbUniqueVisitors' => '%s bisitari desberdin',
 	'VisitsSummary_MaxNbActions' => '%s ekintza gehienez bisita batean',
 	'VisitsSummary_NbVisitsBounced' => '%s bisita errebotatu dira (webgunea utzi dute orri bat ikusi ondoren)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Bilakaera azken %san zehar',
 	'VisitsSummary_GenerateTime' => '%s segundo orria sortzeko',
 	'VisitsSummary_GenerateQueries' => '%s galdera exekutatuta',
 	'VisitsSummary_WidgetLastVisits' => 'Azken bisiten grafikoa',
