@@ -237,11 +237,7 @@ $translations = array(
 	'Login_LogIn' => 'Conectar',
 	'Login_Logout' => 'Desconectar',
 	'Login_LostYourPassword' => 'Esqueceu o contrasinal?',
-	'Login_RemindPassword' => 'Lembrar contrasinal',
-	'Login_PasswordReminder' => 'Por favor, introduzca o seu nome de usuario ou enderezo de correo electrónico. Recibirá un novo contrasinal por correo electrónico',
 	'Login_InvalidUsernameEmail' => 'O nome do usuario ou o enderezo de correo electrónicoo son incorrectos',
-	'Login_MailTopicPasswordRecovery' => 'Recuperar contrasinal',
-	'Login_PasswordSent' => 'O contrasinal acaba de ser enviado. Comprobe o seu correo electrónico.',
 	'Login_ContactAdmin' => 'Posible razón: o seu aloxamento pode ter deshabilitado a función mail().<br>Por favor contacte co seu administrador de piwik.',
 	'Provider_WidgetProviders' => 'Provedores',
 	'Provider_SubmenuLocationsProvider' => 'Localizacións e provedor',
@@ -290,8 +286,6 @@ $translations = array(
 	'UserCountry_Continent' => 'Continente',
 	'UserCountry_DistinctCountries' => '%s continentes distintos',
 	'UserCountry_SubmenuLocations' => 'Lugares',
-	'UserCountry_WidgetContinents' => 'Continentes dos visitantes',
-	'UserCountry_WidgetCountries' => 'Países dos visitantes',
 	'UserCountry_country_ac' => 'Isla Ascensión',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'Emiratos Árabes Unidos',
