@@ -134,7 +134,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => 'להציג טבלה פשוטה',
 	'General_DisplayTableWithMoreMetrics' => 'להציג טבלה עם יותר נתונים',
 	'General_DisplayTableWithGoalMetrics' => 'להציג טבלה עם נתוני יעדים',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s הוא פרוייקט שיתופי. %3$s כל מעריץ של Piwik יכול לתרום! כנסו ל %4$s כיצד לתרום לPiwik? %5$s',
 	'General_YouAreViewingDemoShortMessage' => 'הנך צופה בגרסת ההדגמה של Piwik',
 	'General_DownloadFullVersion' => '%1$sהורדת%2$s הגרסה המלאה! כנסו ל%3$s',
 	'General_NewUpdatePiwikX' => 'עדכון חדש: Piwik %s',
@@ -417,8 +416,6 @@ $translations = array(
 	'DBStats_IndexSize' => 'משקל מפתח (index)',
 	'DBStats_TotalSize' => 'משקל כולל',
 	'ExampleAPI_PluginDescription' => 'תוסף לדוגמה: כיצד להכין API לתוסף שלך, שייצא מידע במספר פורמטים ללא תכנות מיוחד?',
-	'ExampleFeedburner_PluginDescription' => 'תוסף לדוגמה: כיצד להציג את עוקבי הFeedburner שלך ביישומון בפאנל הסקירה?',
-	'ExampleFeedburner_Help' => 'עזרה אודות סטטיסטיקת הFeed',
 	'ExampleRssWidget_PluginDescription' => 'תוסף לדוגמה: כיצד ליצור יישומון חדש המציג עדכוני RSS?',
 	'ExampleUI_PluginDescription' => 'תוסף לדוגמה: תוסף זה מדגים כיצד לעבוד עם הממשק של Piwik: יצירת טבלאות, גרפים וכדומה.',
 	'Installation_Installation' => 'התקנה',
@@ -456,12 +453,8 @@ $translations = array(
 	'Login_LogIn' => 'התחברות',
 	'Login_Logout' => 'התנתקות',
 	'Login_LostYourPassword' => 'שכחת סיסמה?',
-	'Login_RemindPassword' => 'שליחת איפוס סיסמה',
-	'Login_PasswordResetToken' => 'כרטיס איפוס סיסמה',
 	'Login_PasswordsDoNotMatch' => 'הסיסמאות אינן תואמות.',
-	'Login_PasswordSuccessfullyChanged' => 'סיסמה שונתה בהצלחה!',
 	'Login_InvalidUsernameEmail' => 'שם משתמש ו/או אימייל לא תקניים',
-	'Login_MailTopicPasswordRecovery' => 'שחזור סיסמה',
 	'TranslationsAdmin_PluginDescription' => 'עזרו לתרגם את Piwik לשפה שלכם.',
 	'TranslationsAdmin_MenuTranslations' => 'תרגומים',
 	'TranslationsAdmin_MenuLanguages' => 'שפות',
@@ -485,7 +478,6 @@ $translations = array(
 	'VisitsSummary_MaxNbActions' => '%s מספר פעולות מקסימלי בביקור אחד',
 	'VisitsSummary_NbActionsPerVisit' => '%s פעולות בביקור',
 	'VisitsSummary_NbVisitsBounced' => '%s ביקורים קפצו (עזבו את האתר אחרי עמוד אחד)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'צמיחה ב%s האחרון/ה',
 	'VisitsSummary_GenerateTime' => '%s שניות בכדי לחולל את העמוד',
 	'VisitsSummary_GenerateQueries' => '%s שאילתות בוצעו',
 	'VisitsSummary_WidgetLastVisits' => 'גרף ביקורים אחרונים',
