@@ -1,11 +1,11 @@
 <?php
 $translations = array(
 	'General_Locale' => 'hu_HU.UTF-8',
-	'General_TranslatorName' => '<a href="http://www.oldalgazda.hu/">József Jároli</a>, Viktor Horvath & Mr. Balu',
-	'General_TranslatorEmail' => 'en@innen.hu, fityazz@yahoo.co.uk',
+	'General_TranslatorName' => '<a href="http://www.oldalgazda.hu/">József Jároli</a>, Viktor Horvath & Mr. Balu, KardiWeb',
+	'General_TranslatorEmail' => 'en@innen.hu, fityazz@yahoo.co.uk, kw@kardiweb.org',
 	'General_EnglishLanguageName' => 'Hungarian',
 	'General_OriginalLanguageName' => 'Magyar',
-	'General_HelloUser' => 'Szia, %s!',
+	'General_HelloUser' => 'Üdv, %s!',
 	'General_OpenSourceWebAnalytics' => 'Nyílt forráskódú webanalitika',
 	'General_Dashboard' => 'Vezérlőpult',
 	'General_DashboardForASpecificWebsite' => 'Vezérlőpult egy adott weboldalhoz',
@@ -14,7 +14,7 @@ $translations = array(
 	'General_API' => 'API',
 	'General_Widgets' => 'Modulok',
 	'General_Settings' => 'Beállítások',
-	'General_GiveUsYourFeedback' => 'Küldj visszajelzést!',
+	'General_GiveUsYourFeedback' => 'Visszajelzés küldése',
 	'General_Unknown' => 'Ismeretlen',
 	'General_Never' => 'Soha',
 	'General_Required' => '%s kötelező',
@@ -23,27 +23,29 @@ $translations = array(
 	'General_Id' => 'Azonosító',
 	'General_Error' => 'Hiba',
 	'General_Warning' => 'Figyelmeztetés',
-	'General_BackToHomepage' => 'Vissza a Piwik nyitólapra',
+	'General_BackToHomepage' => 'Vissza a Piwik kezdőlapra',
 	'General_Yes' => 'Igen',
 	'General_No' => 'Nem',
-	'General_Delete' => 'Töröl',
+	'General_Delete' => 'Törlés',
 	'General_Report' => 'Jelentés',
 	'General_Reports' => 'Jelentések',
-	'General_Edit' => 'Szerkeszt',
-	'General_Download' => 'Letölt',
+	'General_RelatedReport' => 'Kapcsolódó jelentés',
+	'General_RelatedReports' => 'Kapcsolódó jelentések',
+	'General_Edit' => 'Szerkesztés',
+	'General_Download' => 'Letöltés',
 	'General_Upload' => 'Feltöltés',
 	'General_Ok' => 'Rendben',
-	'General_Close' => 'Bezár',
-	'General_OrCancel' => 'or %s megszakít %s',
-	'General_Logout' => 'Kilép',
-	'General_Username' => 'Felhasználói név',
+	'General_Close' => 'Bezárás',
+	'General_Cancel' => 'Mégse',
+	'General_OrCancel' => 'vagy %s megszakít %s',
+	'General_Logout' => 'Kilépés',
+	'General_Username' => 'Felhasználónév',
 	'General_Description' => 'Leírás',
 	'General_Done' => 'Kész',
 	'General_PoweredBy' => 'Működteti:',
 	'General_Name' => 'Név',
 	'General_Value' => 'Érték',
 	'General_Total' => 'Összesítve',
-	'General_TotalVisitsActionsRevenue' => '(Összesen: %s látogatás, %s akció, %s bevétel)',
 	'General_AverageOrderValue' => 'Átlagos rendelési érték',
 	'General_PurchasedProducts' => 'Vásárolt termékek',
 	'General_EcommerceOrders' => 'E-kereskedelmi rendelések',
@@ -180,7 +182,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => 'Egyszerű táblázat megjelenítése',
 	'General_DisplayTableWithMoreMetrics' => 'Több adatot mutató táblázat megjelenítése',
 	'General_DisplayTableWithGoalMetrics' => 'A Célokat mutató táblázat megjelenítése',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s egy közösségi projekt. %3$s Ha Piwik rajongó vagy, Te is tudsz segíteni! Nézd meg, %4$s hogyan tudsz Te is részt venni a Piwik fejlesztésében! %5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Jelenleg a Piwik demóváltozatát láthatod.',
 	'General_DownloadFullVersion' => '%1$sTöltsd le%2$s a teljes verziót! Nézd meg ezt: %3$s',
 	'General_NewUpdatePiwikX' => 'Új verzió: Piwik %s',
@@ -466,8 +467,6 @@ $translations = array(
 	'DBStats_IndexSize' => 'Indexméret',
 	'DBStats_TotalSize' => 'Teljes méret',
 	'ExampleAPI_PluginDescription' => 'Példakiegészítő: Hogyan kell létrehozni egy API-t a kiegészítődhöz annak érdekében, hogy kiexportálhasd az adatokat többféle formátumban mindenféle speciális kódolás nélkül?',
-	'ExampleFeedburner_PluginDescription' => 'Példakiegészítő: hogyan kell megjeleníteni a Feedburner-ből származó adatokat a vezérlőpulton?',
-	'ExampleFeedburner_Help' => 'RSS csatorna-analitikai súgó',
 	'ExampleRssWidget_PluginDescription' => 'Példakiegészítő: Hogyan lehet egy olyan új modult létrehozni, mely egy adott RSS csatornát jelenít meg?',
 	'ExampleUI_PluginDescription' => 'Példakiegészítő: Ez a kiegészítő bemutatja, hogyan lehet a Piwik felhasználói felületével dolgozni: táblázatokat, grafikonokat létrehozni, stb.',
 	'Feedback_PluginDescription' => 'Küldd el véleményedet a Piwik fejlesztőinek. Oszd meg ötleteid, javaslataid velük!',
@@ -674,23 +673,16 @@ $translations = array(
 	'Login_PasswordRepeat' => 'Jelszó (ismét)',
 	'Login_ChangePassword' => 'Jelszó megváltoztatása',
 	'Login_LoginOrEmail' => 'Felhasználói név vagy e-mail cím',
-	'Login_RememberMe' => 'Emlékezz a felhasználói nevemre',
+	'Login_RememberMe' => 'Megjegyzés',
 	'Login_LogIn' => 'Bejelentkezés',
 	'Login_Logout' => 'Kijelentkezés',
 	'Login_LostYourPassword' => 'Elfelejtetted jelszavad?',
-	'Login_RemindPassword' => 'Jelszó-visszaállítás kezdeményezése',
-	'Login_PasswordResetToken' => 'Jelszó-visszaállító kód',
-	'Login_PasswordReminder' => 'Kérjük, add meg a felhasználói neved vagy e-mail címed. A jelszó visszaállításához szükséges adatokat e-mailben küldjük el.',
 	'Login_PasswordsDoNotMatch' => 'Nem egyeznek a jelszavak',
-	'Login_PasswordSuccessfullyChanged' => 'Jelszó sikeresen megváltoztatva!',
 	'Login_InvalidUsernameEmail' => 'Helytelen felhasználói név és/vagy e-mail cím',
 	'Login_InvalidOrExpiredToken' => 'A kód érvénytelen vagy lejárt.',
-	'Login_MailTopicPasswordRecovery' => 'Jelszó visszaállítása',
-	'Login_MailPasswordRecoveryBody' => 'Kedves %1$s! Jelszó-visszaállításra irányuló kérés érkezett innen: %2$s. A jelszó visszaállításához kérjük: 1) Látogassa meg a jelszó-visszaállító űrlapot itt: %3$s 2) Adja meg a következő kódot: %4$s 3) Töltse ki az űrlapot (megadva az új jelszót kétszer), majd küldje el. Megjegyzés: ez a kód csak 24 óráig érvényes.',
-	'Login_PasswordSent' => 'A jelszó visszaállításához szükséges információkat elküldtük. Kérjük, ellenőrizd postaládád.',
 	'Login_ContactAdmin' => 'Lehetséges ok: talán a szolgáltatód tiltja a mail() funkciót. <br /> Kérjük, lépj kapcsolatba a Piwik adminisztrátoroddal.',
 	'Login_ExceptionPasswordMD5HashExpected' => 'A jelszóparaméternek egyeznie kellene a jelszó MD5 hash értékével.',
-	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Mindenható felhasználó (Super User) autentikációja nem lehetséges a \'%s\' módszerrel.',
+	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Adminisztrátor (Super User) autentikációja nem lehetséges a \'%s\' módszerrel.',
 	'MultiSites_PluginDescription' => 'Összefoglaló statisztikákat jelenít meg több weboldal látogatottságáról. A kiegészítő jelenleg a Piwik magjához tartozik.',
 	'MultiSites_Evolution' => 'Trendek',
 	'Provider_PluginDescription' => 'Jelentések a látogatók internetszolgáltatóról',
@@ -741,7 +733,6 @@ $translations = array(
 	'SEO_AlexaRank' => 'Alexa Rank',
 	'SEO_DomainAge' => 'Domain életkora',
 	'SEO_Rank' => 'Lekérdezés',
-	'SEO_Backlinks' => 'külső link',
 	'SEO_Pages' => 'weblap',
 	'SEO_SEORankingsFor' => 'Keresőoptimalizálási adatok a %s oldalhoz',
 	'SitesManager_PluginDescription' => 'Weboldalak kezelése a Piwik rendszerében: Új weboldal hozzáadása, meglévő weboldal szerkesztése, a weblapokba beillesztendő JavaScript követőkódok megjelenítése. Az összes funkció elérhető az API-n keresztül is.',
@@ -809,8 +800,6 @@ $translations = array(
 	'UserCountry_DistinctCountries' => '%s különböző ország',
 	'UserCountry_Location' => 'Hely',
 	'UserCountry_SubmenuLocations' => 'Helyek',
-	'UserCountry_WidgetContinents' => 'Látogatók kontinensei',
-	'UserCountry_WidgetCountries' => 'Látogatók országai',
 	'UserCountry_country_ac' => 'Ascension-sziget',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'Egyesült Arab Emirátusok',
@@ -1148,7 +1137,6 @@ $translations = array(
 	'UsersManager_MenuUsers' => 'Felhasználók',
 	'UsersManager_MenuUserSettings' => 'Felhasználói beállítások',
 	'UsersManager_MenuAnonymousUserSettings' => 'Névtelen felhasználók beállításai',
-	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Megjegyzés: mivel nincs jelenleg olyan weboldal-statisztika, melyhez névtelen felhasználók is hozzáférhetnek, a következő beállítások nem kerülnek sehol felhasználásra.',
 	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Amikor a felhasználók nincsenek belépve a Piwik-be és így keresik fel a Piwik-et, akkor a következőhöz férjenek hozzá:',
 	'UsersManager_ChangePassword' => 'Jelszó megváltoztatása',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Ha szeretnéd megváltoztatni a jelszót, írd ide be az újat. Egyéb esetben hagyd üresen ezt a mezőt.',
@@ -1217,7 +1205,6 @@ $translations = array(
 	'VisitsSummary_MaxNbActions' => '%s akció egy látogatás során maximum',
 	'VisitsSummary_NbActionsPerVisit' => '%s akció látogatásonként',
 	'VisitsSummary_NbVisitsBounced' => '%s látogatás csak egy weblap megtekintésével',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Trendek az elmúlt %s során',
 	'VisitsSummary_GenerateTime' => '%s másodperc kellett a lap legenerálásához',
 	'VisitsSummary_GenerateQueries' => '%s kérés végrehajtva',
 	'VisitsSummary_WidgetLastVisits' => 'Utolsó látogatások grafikonja',
