@@ -111,7 +111,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => 'Sýna einfalda töflu.',
 	'General_DisplayTableWithMoreMetrics' => 'Sýna töflu með mörgum mæligildum.',
 	'General_DisplayTableWithGoalMetrics' => 'Sýna töflu með mælingum á markmið.',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s er samvinnuverkefni. %3$s Ef þú ert aðdáandi Piwik, þá geturðu hjálpað til! Kannaðu %4$s hvernig hægt er að taka þátt í Piwik?%5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Núna ertu að skoða tilraunaútgáfu af Piwik',
 	'General_DownloadFullVersion' => '%1$sDownload%2$s heildarútgáfuna! Kannaðu  %3$s',
 	'General_NewUpdatePiwikX' => 'Ný uppfærsla: Piwik %s',
@@ -376,13 +375,8 @@ $translations = array(
 	'Login_LogIn' => 'Innskrá',
 	'Login_Logout' => 'Útskrá',
 	'Login_LostYourPassword' => 'Tapaðirðu lykilroðinu?',
-	'Login_RemindPassword' => 'Senda lykilorðs endurnýjun',
-	'Login_PasswordReminder' => 'Vinsamlegast sláðu inn notendanafn eða tölvupóstfang. Þú munt fá sendan tóölvupóst með upplýsingum til að endurnýja lykilorðið þitt.',
 	'Login_PasswordsDoNotMatch' => 'Lykilorðin stemma ekki.',
-	'Login_PasswordSuccessfullyChanged' => 'Lykilorði hefur verið breytt.',
 	'Login_InvalidUsernameEmail' => 'Ekki gilt notendanafn og/eða tölvupóstfang',
-	'Login_MailTopicPasswordRecovery' => 'Endurheimta lykilroð',
-	'Login_PasswordSent' => 'Upplýsingar til að endurnýja lykilorðið hava verið sendar. Skoðaðu tölvupóstinn þinn.',
 	'Login_ContactAdmin' => 'Möguleg ástæða: þjónninn þinn gæti hafa slökkt á mail() fallinu. <br/>Vinsamlegast hafðu samband við umsjónarmann Piwik þjónsins.',
 	'Login_ExceptionPasswordMD5HashExpected' => 'Búist er við að lykilorðs færibreytan sé MD5 dulmál af lykilorðinu.',
 	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Ekki er hægt að auðkenna yfirnotandan með \'%s\' aðferðinni.',
@@ -455,8 +449,6 @@ $translations = array(
 	'UserCountry_DistinctCountries' => '%s mismunandi lönd',
 	'UserCountry_Location' => 'Staðsetning',
 	'UserCountry_SubmenuLocations' => 'Staðsetningar',
-	'UserCountry_WidgetContinents' => 'Heimsálfur gesta',
-	'UserCountry_WidgetCountries' => 'Lönd gesta',
 	'UserCountry_country_ac' => '(Uppstigningareyja)Sankti Helena',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'Sameinuðu arabísku furstadæmin',
@@ -640,8 +632,8 @@ $translations = array(
 	'UserCountry_country_py' => 'Paragvæ',
 	'UserCountry_country_qa' => 'Katar',
 	'UserCountry_country_ro' => 'Rúmenía',
-	'UserCountry_country_ru' => 'Rússland',
 	'UserCountry_country_rs' => 'Serbía',
+	'UserCountry_country_ru' => 'Rússland',
 	'UserCountry_country_rw' => 'Rúanda',
 	'UserCountry_country_sa' => 'Sádi-Arabía',
 	'UserCountry_country_sb' => 'Salómonseyjar',
@@ -797,7 +789,6 @@ $translations = array(
 	'VisitsSummary_MaxNbActions' => '%s hámark aðgerða í einni heimsókn',
 	'VisitsSummary_NbActionsPerVisit' => '%s aðgerðir á heimsókn',
 	'VisitsSummary_NbVisitsBounced' => '%s heimsóknir hafa skoppað (yfirgefið vefinn eftir eina síðu)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Þróun yfir síðustu %s',
 	'VisitsSummary_GenerateTime' => '%s sekúndur að gera þessa síðu',
 	'VisitsSummary_GenerateQueries' => '%s fyrirspurnir framkvæmdar',
 	'VisitsSummary_WidgetLastVisits' => 'Línurit yfir síðustu heimsóknir',
