@@ -55,7 +55,6 @@ $translations = array(
 	'General_Website' => '웹사이트',
 	'General_NoDataForGraph' => '이 그래프를 위한 데이터가 없습니다.',
 	'General_NoDataForTagCloud' => '이 태그 클라우드를 위한 데이터가 없습니다.',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s 은 협력 프로젝트입니다. %3$s 만약 Piwik이 마음에 드신다면, 도와주실 수 있습니다! %4$s 어떻게 Piwik에 도움을 줄 수 있는지 보시겠습니까?%5$s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s 이 사용 가능합니다. %2$s 지금 업데이트하세요!%3$s (보기: %4$s 변경%5$s).',
 	'General_BackToPiwik' => 'Piwik으로 돌아가기',
 	'General_ShortMonth_1' => '1월',
@@ -279,11 +278,7 @@ $translations = array(
 	'Login_LogIn' => '로그인',
 	'Login_Logout' => '로그아웃',
 	'Login_LostYourPassword' => '비밀번호를 잊으셨습니까?',
-	'Login_RemindPassword' => '비밀번호 떠올리기',
-	'Login_PasswordReminder' => '사용자명 또는 이메일 주소를 입력하세요. 새 비밀번호를 이메일을 통해 받게될 것입니다.',
 	'Login_InvalidUsernameEmail' => '잘못된 사용자명 그리고/또는 이메일 주소',
-	'Login_MailTopicPasswordRecovery' => '비밀번호 복구',
-	'Login_PasswordSent' => '비밀번호는 방금 전송되었습니다. 이메일을 확인하세요.',
 	'Login_ContactAdmin' => '가능한 이유: 호스트가 메일 기능을 비활성화했을 수 있습니다. <br />당신의 Piwik 관리자에게 연락해보세요.',
 	'Provider_WidgetProviders' => '공급자',
 	'Provider_ColumnProvider' => '공급자',
@@ -351,8 +346,6 @@ $translations = array(
 	'UserCountry_Continent' => '대륙',
 	'UserCountry_DistinctCountries' => '%s 개의 나라',
 	'UserCountry_SubmenuLocations' => '위치',
-	'UserCountry_WidgetContinents' => '대륙',
-	'UserCountry_WidgetCountries' => '나라',
 	'UserCountry_country_ac' => '어센션 섬',
 	'UserCountry_country_ad' => '안도라',
 	'UserCountry_country_ae' => '아랍에미리트',
@@ -697,7 +690,6 @@ $translations = array(
 	'VisitsSummary_NbUniqueVisitors' => '%s 고유 방문자 수',
 	'VisitsSummary_MaxNbActions' => '%s 한번 방문의 최대 활동 수',
 	'VisitsSummary_NbVisitsBounced' => '%s 바로 떠난 방문 비율 (한 페이지만 보고 떠난 방문자)',
-	'VisitsSummary_EvolutionOverLastPeriods' => '지난 %s 진행 과정',
 	'VisitsSummary_GenerateTime' => '페이지 생성에 %s 초 걸림',
 	'VisitsSummary_GenerateQueries' => '%s 쿼리 실행됨',
 	'VisitsSummary_WidgetLastVisits' => '최근 방문 그래프',
