@@ -42,7 +42,6 @@ $translations = array(
 	'General_Name' => 'Pavadinimas',
 	'General_Value' => 'Reikšmė',
 	'General_Total' => 'Iš viso',
-	'General_TotalVisitsActionsRevenue' => '(Iš viso: %s apsilankymų, %s veiksmų, %s pajamų)',
 	'General_AverageOrderValue' => 'Vidutinė užsakymo vertė',
 	'General_PurchasedProducts' => 'Įsigyta produkcija',
 	'General_EcommerceOrders' => 'El. prekybos užsakymai',
@@ -158,7 +157,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => 'Rodyti paprastą lentelę',
 	'General_DisplayTableWithMoreMetrics' => 'Rodyti lentelę su daugiau duomenų',
 	'General_DisplayTableWithGoalMetrics' => 'Rodyti lentelę su uždavinių duomenimis',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s yra bendras projektas. %3$s Jei Jums patinka Piwik, Jūs taip pat galite prisijungti! %4$s Kaip prisidėti prie Piwik? %5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Šiuo metu Jūs stebite Piwik demonstraciją',
 	'General_DownloadFullVersion' => '%1$sAtsisiųskite%2$s pilną versiją! Išsamiau %3$s',
 	'General_NewUpdatePiwikX' => 'Atnaujinimai: Piwik %s',
@@ -440,7 +438,6 @@ $translations = array(
 	'DBStats_IndexSize' => 'Indekso dydis',
 	'DBStats_TotalSize' => 'Bendras dydis',
 	'ExampleAPI_PluginDescription' => 'Pavyzdinis papildinys: Kaip sukurti API sąsają jūsų papildiniui, kad būtų galima eksportuoti duomenis daugeliu formatų be papildomo programavimo?',
-	'ExampleFeedburner_PluginDescription' => 'Pavyzdinis papildinys: Kaip pavaizduoti jūsų Feedburner prenumeratą skydelio valdiklyje?',
 	'ExampleRssWidget_PluginDescription' => 'Pavyzdinis papildinys: Kaip sukurti naują valdiklį, kuris skaito RSS santraukas?',
 	'ExampleUI_PluginDescription' => 'Pavyzdinis papildinys: Šis papildinys parodys kaip dirbti su Piwik UI: kurti lenteles, grafikus ir pan.',
 	'Feedback_PluginDescription' => 'Siųskite savo atsiliepimus Piwik komandai. Dalinkitės savo idėjomis ir pasiūlymais su mumis!',
@@ -634,16 +631,9 @@ $translations = array(
 	'Login_LogIn' => 'Prisijungti',
 	'Login_Logout' => 'Atsijungti',
 	'Login_LostYourPassword' => 'Pamiršote slaptažodį?',
-	'Login_RemindPassword' => 'Priminti slaptažodį',
-	'Login_PasswordResetToken' => 'Slaptažodžio keitimo talonas',
-	'Login_PasswordReminder' => 'Prašome įvesti naudotojo vardą arba el. pašto adresą. Naują slaptažodį gausite el. paštu.',
 	'Login_PasswordsDoNotMatch' => 'Slaptažodžiai nesutampa',
-	'Login_PasswordSuccessfullyChanged' => 'Slaptažodis pakeistas sėkmingai!',
 	'Login_InvalidUsernameEmail' => 'Netinkamas naudotojo vardas ir/arba el. pašto adresas',
 	'Login_InvalidOrExpiredToken' => 'Netinkamas arba pasibaigęs talonas',
-	'Login_MailTopicPasswordRecovery' => 'Slaptažodžio atkūrimas',
-	'Login_MailPasswordRecoveryBody' => 'Sveiki, %1$s, Iš %2$s buvo gautas slaptažodžio nustatymo iš naujo prašymas. Slaptažodžio nustatymui iš naujo: 1) Eikite į slaptažodžio nustatymo formą: %3$s 2) Įveskite šią žymą: %4$s 3) Užpildykite formą (dukart pakartojant slaptažodį) ir išsiųskite. Pastaba: ši žymas nustos galioti po 24 val.',
-	'Login_PasswordSent' => 'Slaptažodis nusiųstas. Pasitikrinkite el. paštą.',
 	'Login_ContactAdmin' => 'Galima priežastis: Jūsų pagr. kompiuteryje (serveryje) gali būti išjungta mail() funkcija.<br />Prašome susisiekti su savo Piwik administratoriumi.',
 	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Super naudojas negali būti patikrintas naudojantis \'%s\' mechanizmu.',
 	'MultiSites_Evolution' => 'Raida',
@@ -696,7 +686,6 @@ $translations = array(
 	'SEO_AlexaRank' => 'Alexa reitingas',
 	'SEO_DomainAge' => 'Adresų srities amžius',
 	'SEO_Rank' => 'Reitingas',
-	'SEO_Backlinks' => 'Nuorodos į svetainę',
 	'SEO_Pages' => 'Puslapiai',
 	'SEO_SEORankingsFor' => 'SEO reitingai skirti %s',
 	'SitesManager_PluginDescription' => 'Svetainių administravimas: Pridėkite naujas svetaines, redaguokite esamas, gaukite Javascript kodą įkėlimui į savo svetainę. Visi šie veiksmai taip pat pasiekiami per API sąsają.',
@@ -766,8 +755,6 @@ $translations = array(
 	'UserCountry_DistinctCountries' => '%s atskirti šalis',
 	'UserCountry_Location' => 'Vietovė',
 	'UserCountry_SubmenuLocations' => 'Vietovės',
-	'UserCountry_WidgetContinents' => 'Lankytojų kontinentai',
-	'UserCountry_WidgetCountries' => 'Lankytojų šalys',
 	'UserCountry_country_ac' => 'Ascension Islands',
 	'UserCountry_country_ad' => 'Andora',
 	'UserCountry_country_ae' => 'Jungtiniai Arabų Emyratai',
@@ -1100,7 +1087,6 @@ $translations = array(
 	'UsersManager_MenuUsers' => 'Naudotojai',
 	'UsersManager_MenuUserSettings' => 'Naudotojo nustatymai',
 	'UsersManager_MenuAnonymousUserSettings' => 'Anonimo nustatymai',
-	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Pastaba: Jūs neturite jokių svetainių, kurias gali pasiekti anonimas, todėl šie nustatymai nebus naudojami.',
 	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Kai naudotojai neprisijungę apsilanko Piwik, jie turi pasiekti',
 	'UsersManager_ChangePassword' => 'Pakeisti slaptažodį',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Jei norite pakeisti slaptažodį, įrašykite naują. Jei ne, palikite laukelį tuščią.',
@@ -1156,7 +1142,6 @@ $translations = array(
 	'VisitsSummary_MaxNbActions' => '%s daugiausia veiksmų per apsilankymą',
 	'VisitsSummary_NbActionsPerVisit' => '%s veiksmų per apsilankymą',
 	'VisitsSummary_NbVisitsBounced' => '%s atsitiktiniai apsilankymai (paliko svetainę po pirmojo puslapio)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Paskutinio %s raida',
 	'VisitsSummary_GenerateTime' => '%s sekundės puslapiui sugeneruoti',
 	'VisitsSummary_GenerateQueries' => '%s aktyvuotos užklausos',
 	'VisitsSummary_WidgetLastVisits' => 'Paskutinių apsilankymų diagrama',
