@@ -48,7 +48,6 @@ $translations = array(
 	'General_Name' => 'Vārds',
 	'General_Value' => 'Vērtība',
 	'General_Total' => 'Kopā',
-	'General_TotalVisitsActionsRevenue' => '(Kopā: %s apmeklējumi, %s darbības, %s ienākumi)',
 	'General_AverageOrderValue' => 'Vidējā pasūtījuma vērtība',
 	'General_PurchasedProducts' => 'Iegādātie produkti',
 	'General_EcommerceOrders' => 'E-komercijas pasūtījumi',
@@ -192,7 +191,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => 'Rādīt vienkāršu tabulu',
 	'General_DisplayTableWithMoreMetrics' => 'Rādīt tabulu ar vairāk datiem',
 	'General_DisplayTableWithGoalMetrics' => 'Rādīt tabulu ar mērķu datiem',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s ir sadarbības projekts. %3$s Ja Jūs esat Piwik fans, Jūs varat palīdzēt! Apskatiet %4$s Kā piedalīties Piwik projektā?%5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Jūs pašlaik skatāties Piwik demonstrāciju',
 	'General_DownloadFullVersion' => '%1$sLejupielādējiet%2$s pilno versiju! Paskaties %3$s',
 	'General_NewUpdatePiwikX' => 'Jauns atjauninājums: Piwik %s',
@@ -473,7 +471,6 @@ $translations = array(
 	'DBStats_DataSize' => 'Datu izmērs',
 	'DBStats_IndexSize' => 'Indeksa izmērs',
 	'DBStats_TotalSize' => 'Kopējais izmērs',
-	'ExampleFeedburner_Help' => 'Barotņu analīzes palīdzība',
 	'Feedback_PluginDescription' => 'Sūtiet savas atsauksmes Piwik komandai. Dalieties ar savām idejām un ieteikumiem ar mums!',
 	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Vai Jums ir kļūdas ziņojums vai papildus funkcionalitātes pieprasījums?',
 	'Feedback_WhyAreMyVisitsNoTracked' => 'Kāpēc netiek uzskaitīts manas vietnes apmeklējums?',
@@ -643,16 +640,10 @@ $translations = array(
 	'Login_LogIn' => 'Pieteikties',
 	'Login_Logout' => 'Beigt darbu',
 	'Login_LostYourPassword' => 'Pazaudēji savu paroli?',
-	'Login_RemindPassword' => 'Sūtīt paroles atjaunošanas info',
-	'Login_PasswordResetToken' => 'Paroles atjaunošanas kods',
-	'Login_PasswordReminder' => 'Lūdzu ievadiet savu lietotājvārdu vai e-pasta adresi. Jūs saņemsiet e-pastu ar informāciju kā atjaunot savu paroli.',
 	'Login_PasswordsDoNotMatch' => 'Paroles nesakrīt.',
-	'Login_PasswordSuccessfullyChanged' => 'Parole veiksmīgi nomainīta!',
 	'Login_InvalidUsernameEmail' => 'Nepareizs lietotājvārds un/vai e-pasta adrese',
 	'Login_InvalidNonceOrHeadersOrReferer' => 'Formas drošība nenostrādāja. Lūdzu pārlādējiet formu un pārbaudiet vai sīkfailu atbalsts ir ieslēgts. Ja lietojat starpniekserveri, Jums %s jāiestata Piwik  lai pieņemtu starpniekservera galveni %s, kas pārsūta resursdatora galveni. Papildus pārbaudiet vai Jūsu iepriekšējās vietnes galvene ir nosūtīta pareizi.',
 	'Login_InvalidOrExpiredToken' => 'Kods ir nepareizs vai tam ir beidzies termiņš.',
-	'Login_MailTopicPasswordRecovery' => 'Paroles atjaunošana',
-	'Login_PasswordSent' => 'Informācija, kas palīdzēs atjaunot Jūsu paroli, ir nosūtīta. Pārbaudiet savu e-pastu.',
 	'Login_ContactAdmin' => 'Iespējams, ka Jūsu resursdatoram ir atslēgta mail() metode. <br />Sazinieties ar savu Piwik administrātoru.',
 	'Login_ExceptionPasswordMD5HashExpected' => 'Paroles parametram ir jābūt paroles MD5 summai.',
 	'Mobile_AddAccount' => 'Pievienot kontu',
@@ -713,7 +704,6 @@ $translations = array(
 	'SEO_AlexaRank' => 'Alexa ranks',
 	'SEO_DomainAge' => 'Domēna vecums',
 	'SEO_Rank' => 'ranks',
-	'SEO_Backlinks' => 'atpakaļsaites',
 	'SEO_Pages' => 'lapas',
 	'SEO_SEORankingsFor' => '%s SEO ranks',
 	'SitesManager_PluginDescription' => 'Piwik vietņu pārvaldība: pievienojiet jaunu vietni, labojiet esošās, apskatiet ievietošanai lapās paredzēto kodu. Visas darbības ir pieejamas arī izmantojot API.',
@@ -782,8 +772,6 @@ $translations = array(
 	'UserCountry_Continent' => 'Kontinents',
 	'UserCountry_Location' => 'Lokācijas',
 	'UserCountry_SubmenuLocations' => 'Lokācijas',
-	'UserCountry_WidgetContinents' => 'Apmeklētāju kontinenti',
-	'UserCountry_WidgetCountries' => 'Apmeklētāju valstis',
 	'UserCountry_country_ac' => 'Debesbraukšanas sala',
 	'UserCountry_country_ad' => 'Andora',
 	'UserCountry_country_ae' => 'Apvienotie Arābu Emirāti',
@@ -1127,7 +1115,6 @@ $translations = array(
 	'UsersManager_MenuUsers' => 'Lietotāji',
 	'UsersManager_MenuUserSettings' => 'Lietotāju iestatījumi',
 	'UsersManager_MenuAnonymousUserSettings' => 'Anonīmu lietotāju iestatījumi',
-	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Piezīme: Jums nav nevienas vietnes, kas atļautu anonīmu lietotāju pieejas atskaitēm. Sekojošie iestatījumi netiks izmantoti.',
 	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Kad lietotāji nav pieteikušies un apmeklē Piwik, tiem rādam',
 	'UsersManager_ChangePassword' => 'Mainīt paroli',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Ja vēlaties mainīt paroli, ievadiet jauno. Pretējā gadījumā atstājiet tukšu.',
@@ -1208,5 +1195,4 @@ $translations = array(
 	'PDFReports_TopOfReport' => 'Atpakaļ uz sākumu',
 	'PDFReports_Pagination' => '%s. lapa no %s',
 	'ImageGraph_PluginDescription' => 'Ģenerējiet skaistus, statiskus PNG formāta grafikus jebkurai Piwik atskaitei.',
-	'ImageGraph_ColumnOrdinateMissing' => 'Kolonna \'%s\' šajā atskaitē netika atrasta.',
 );
