@@ -128,7 +128,6 @@ $translations = array(
 	'General_NoDataForTagCloud' => 'Ingen data for denne merkelappskyen.',
 	'General_DisplaySimpleTable' => 'Vis enkel tabell',
 	'General_DisplayTableWithMoreMetrics' => 'Vis en tabell mer flere måltall',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s er et samarbeidsprosjekt. %3$s Hvis du liker Piwik, så kan du hjelpe til! Les om %4$s hvordan du kan bidra %5$s.',
 	'General_YouAreViewingDemoShortMessage' => 'Du ser for øyeblikket på Piwik-demoen',
 	'General_DownloadFullVersion' => '%1$sLast ned%2$s den fullstendige utgaven! Prøv %3$s',
 	'General_NewUpdatePiwikX' => 'Ny utgave: Piwik %s',
@@ -510,13 +509,8 @@ $translations = array(
 	'Login_LogIn' => 'Logg inn',
 	'Login_Logout' => 'Logg ut',
 	'Login_LostYourPassword' => 'Glemt passord?',
-	'Login_RemindPassword' => 'Husk passord',
-	'Login_PasswordReminder' => 'Vennligst skriv inn ditt brukernavn eller epost-adresse. Du vil få et nytt passord på epost.',
 	'Login_PasswordsDoNotMatch' => 'Passordene stemmer ikke overens.',
-	'Login_PasswordSuccessfullyChanged' => 'Passord endret.',
 	'Login_InvalidUsernameEmail' => 'Feil brukernavn og/eller epost-adresse.',
-	'Login_MailTopicPasswordRecovery' => 'Gjennoppretting av passord',
-	'Login_PasswordSent' => 'Passordet har nettopp blitt sendt. Sjekk din e-post.',
 	'Login_ContactAdmin' => 'Mulig grunn: Din tjener har kanskje deaktivert mail()-funksjonen. <br />Kontakt din Piwik administrator.',
 	'MultiSites_Evolution' => 'Utvikling',
 	'Provider_PluginDescription' => 'Rapporterer tilbyderen for de besøkende.',
@@ -614,8 +608,6 @@ $translations = array(
 	'UserCountry_DistinctCountries' => '%s bestemte land',
 	'UserCountry_Location' => 'Lokasjon',
 	'UserCountry_SubmenuLocations' => 'Lokasjoner',
-	'UserCountry_WidgetContinents' => 'Besøkendes kontinent',
-	'UserCountry_WidgetCountries' => 'Besøkendes land',
 	'UserCountry_country_ac' => 'Ascension øyene',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'De forente arabiske emirater',
@@ -942,7 +934,6 @@ $translations = array(
 	'UsersManager_MenuUsers' => 'Brukere',
 	'UsersManager_MenuUserSettings' => 'Brukerinnstillinger',
 	'UsersManager_MenuAnonymousUserSettings' => 'Innstillinger for anonym bruker',
-	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Merk: Du har ingen nettsteder hvor anonyme brukere har tilgang så de følgende innstillingene blir ikke brukt.',
 	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Brukere som ikke er logget og besøker Piwik, skal sendes til',
 	'UsersManager_ChangePassword' => 'Endre passord',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Hvis du vil endre passordet, skriv inn et nytt. Hvis ikke, lar du feltet være tomt.',
@@ -995,7 +986,6 @@ $translations = array(
 	'VisitsSummary_MaxNbActions' => '%s maks handlinger i ett besøk',
 	'VisitsSummary_NbActionsPerVisit' => '%s handlinger per besøk',
 	'VisitsSummary_NbVisitsBounced' => '%s besøk har sprettet (forlatt nettstedet etter en side)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Utvikling over de siste %s',
 	'VisitsSummary_GenerateTime' => '%s sekunder for å generere denne siden',
 	'VisitsSummary_GenerateQueries' => '%s spørringer kjørt',
 	'VisitsSummary_WidgetLastVisits' => 'Graf over siste besøk',
