@@ -6,20 +6,17 @@ $translations = array(
 	'General_EnglishLanguageName' => 'Brazilian Portuguese',
 	'General_OriginalLanguageName' => 'Português brasileiro',
 	'General_HelloUser' => 'Olá, %s!',
-	'General_OpenSourceWebAnalytics' => 'Open Source Web Analytics',
 	'General_Dashboard' => 'Painel de Ferramentas',
 	'General_DashboardForASpecificWebsite' => 'Painel de Ferramentas para um site especifico',
 	'General_MultiSitesSummary' => 'Todos os sites',
 	'General_AllWebsitesDashboard' => 'Painel de Ferramentas de Todos os sites',
-	'General_API' => 'API',
-	'General_Widgets' => 'Widgets',
 	'General_Settings' => 'Configurações',
 	'General_GiveUsYourFeedback' => 'Dê o seu feedback!',
 	'General_Unknown' => 'Desconhecido',
+	'General_Never' => 'Nunca',
 	'General_Required' => '%s necessário',
 	'General_NotValid' => '%s não é válido',
 	'General_NotDefined' => '%s não definido',
-	'General_Id' => 'Id',
 	'General_Error' => 'Erro',
 	'General_Warning' => 'Aviso',
 	'General_BackToHomepage' => 'Voltar a página do Piwik',
@@ -28,40 +25,85 @@ $translations = array(
 	'General_Delete' => 'Apagar',
 	'General_Report' => 'Relatório',
 	'General_Reports' => 'Relatórios',
+	'General_RelatedReport' => 'Relatório Relacionado',
+	'General_RelatedReports' => 'Relatórios Relacionados',
+	'General_Metric' => 'Métrica',
+	'General_Metrics' => 'Métricas',
 	'General_Edit' => 'Editar',
 	'General_Download' => 'Baixar',
-	'General_Upload' => 'Upload',
-	'General_Ok' => 'Ok',
 	'General_Close' => 'Fechar',
+	'General_Cancel' => 'Cancelar',
 	'General_OrCancel' => 'ou %s Cancele %s',
 	'General_Logout' => 'Sair',
 	'General_Username' => 'Nome de Usuário',
 	'General_Description' => 'Descrição',
 	'General_Done' => 'Pronto',
-	'General_PoweredBy' => 'Powered by',
+	'General_MetricsToPlot' => 'Métricas para "plotar"',
+	'General_RowsToDisplay' => 'Linhas para visualizar',
+	'General_MetricToPlot' => 'Métrica para "plotar"',
+	'General_RecordsToPlot' => 'Registros para "plotar"',
 	'General_Name' => 'Nome',
 	'General_Value' => 'Valor',
+	'General_AverageOrderValue' => 'Média de Pedidos',
+	'General_PurchasedProducts' => 'Produtos Adquiridos',
+	'General_EcommerceOrders' => 'Pedidos',
+	'General_TotalRevenue' => 'Total de Revendas',
+	'General_ProductRevenue' => 'Produto Revendido',
+	'General_AveragePrice' => 'Média de Preço',
+	'General_AverageQuantity' => 'Média Qualidade',
+	'General_UniquePurchases' => 'Pedidos únicos',
+	'General_Quantity' => 'Quantidade',
+	'General_Price' => 'Preço',
+	'General_Subtotal' => 'Subtoal',
+	'General_Tax' => 'Taxas',
+	'General_Shipping' => 'Envio',
+	'General_Discount' => 'Desconto',
 	'General_Details' => 'Detalhes',
 	'General_Default' => 'Padrão',
+	'General_Visit' => 'Visita',
+	'General_FromReferrer' => 'origem',
+	'General_VisitorIP' => 'IP do Visitante',
+	'General_VisitorID' => 'Visitante ID',
+	'General_VisitType' => 'Tipo do Visitante',
+	'General_DaysSinceLastVisit' => 'Dias desde a última visita',
+	'General_DaysSinceFirstVisit' => 'Dias desde a primeira visita',
+	'General_DaysSinceLastEcommerceOrder' => 'Dias desde o último pedido',
+	'General_NumberOfVisits' => 'Número de visitantes',
+	'General_VisitConvertedGoalId' => 'Visita convertida em uma específica Meta',
+	'General_VisitConvertedNGoals' => 'Visita convertida %s Objetivos',
+	'General_NewVisitor' => 'Novo visitante',
+	'General_NewVisits' => 'Novos visitantes',
+	'General_ReturningVisitor' => 'Retorno do Visitante',
+	'General_Visitor' => 'Visitante',
 	'General_Date' => 'Data',
 	'General_Period' => 'Período',
+	'General_ChooseDate' => 'Escolha a Data',
 	'General_Today' => 'Hoje',
 	'General_Yesterday' => 'Ontem',
 	'General_CurrentWeek' => 'Semana atual',
 	'General_CurrentMonth' => 'Mês atual',
 	'General_CurrentYear' => 'Ano atual',
 	'General_DateRange' => 'Entre as datas:',
+	'General_DateRangeInPeriodList' => 'Período Datas',
+	'General_DateRangeFromTo' => 'De %s para %s',
+	'General_ApplyDateRange' => 'Aplicar para este período',
+	'General_InvalidDateRange_js' => 'Período de datas inválido , Por favor tente novamente',
+	'General_DateRangeFrom_js' => 'De',
+	'General_DateRangeTo_js' => 'Para',
 	'General_LoadingData' => 'Carregando dados...',
 	'General_Loading_js' => 'Carregando...',
 	'General_GoTo' => 'Ir para %s',
 	'General_Next' => 'Próximo',
 	'General_Previous' => 'Anterior',
+	'General_First' => 'Primeiro',
 	'General_Search' => 'Pesquisar',
 	'General_Others' => 'Outros',
 	'General_Table' => 'Tabela',
 	'General_Piechart' => 'Gráfico circular',
 	'General_TagCloud' => 'Núvem de Tag',
 	'General_VBarGraph' => 'Gráfico de barras verticais',
+	'General_View' => 'Visualização',
+	'General_OpenInNewWindow_js' => 'Abre uma nova janela',
 	'General_SaveImageOnYourComputer_js' => 'Para salvar a imagem em seu computador, clique com o direito na imagem e selecione "Salvar Imagem Como..."',
 	'General_Refresh' => 'Atualizar página',
 	'General_Visitors' => 'Visitantes',
@@ -74,6 +116,7 @@ $translations = array(
 	'General_ColumnNbVisits' => 'Visitas',
 	'General_ColumnPercentageVisits' => '% Visitas',
 	'General_ColumnNbActions' => 'Ações',
+	'General_NbActions' => 'Número de Ações',
 	'General_ColumnMaxActions' => 'Ações máximas em uma visita',
 	'General_ColumnSumVisitLength' => 'Tempo total gasto pelos visitantes (em segundos)',
 	'General_ColumnLabel' => 'Rótulo',
@@ -81,11 +124,13 @@ $translations = array(
 	'General_ColumnActionsPerVisit' => 'Ações por visita',
 	'General_VisitDuration' => 'Média da duração das visitas (em segundos)',
 	'General_ColumnAvgTimeOnSite' => 'Tempo médio no site',
+	'General_ColumnVisitDuration' => 'Duração da Visita em segundos',
 	'General_ColumnBounceRate' => 'Taxa de saída',
 	'General_ColumnExitRate' => 'Taxa de saída',
 	'General_ColumnPageviews' => 'Exibições da página',
 	'General_ColumnUniquePageviews' => 'Exbições únicas da página',
 	'General_ColumnBounces' => 'Saídas',
+	'General_ColumnUniqueEntrances' => 'Entradas únicas',
 	'General_ColumnEntrances' => 'Entradas',
 	'General_ColumnExits' => 'Saídas',
 	'General_ColumnAverageTimeOnPage' => 'Média de tempo na página',
@@ -99,7 +144,6 @@ $translations = array(
 	'General_Save' => 'Salvar',
 	'General_ForExampleShort' => 'ex.',
 	'General_YouMustBeLoggedIn' => 'Tem de estar ligado para aceder a essa funcionalidade.',
-	'General_Website' => 'Website',
 	'General_GeneralSettings' => 'Configurações Gerais',
 	'General_AllowPiwikArchivingToTriggerBrowser' => 'Permitir que o Piwik salve numa trigger quando relatórios são vistos do navegador',
 	'General_ArchivingInlineHelp' => 'Para sites com tráfego de médio a alto, é recomendado desabilitar a trigger que salva do navegador. Em vez disso, nós recomendamos que instale um cron job para processar os relatorios Piwik a cada hora.',
@@ -115,7 +159,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => 'Apresentar tabela simples.',
 	'General_DisplayTableWithMoreMetrics' => 'Apresentar a tabela com mais detalhes',
 	'General_DisplayTableWithGoalMetrics' => 'Apresentar a tabela com os detalhes dos objectivos',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s é um projeto colaborativo. %3$s Se você gostou do Piwik, você pode ajudar! Veja como %4$s contribuir para o Piwik%5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Está atualmente a ver a demonstração do Piwik',
 	'General_DownloadFullVersion' => '%1$sBaixar%2$s a versão completa! Ver %3$s',
 	'General_NewUpdatePiwikX' => 'Nova atualização: Piwik %s',
@@ -126,17 +169,12 @@ $translations = array(
 	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Os relatórios irão então ser processados no máximo a cada hora.',
 	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Assumindo que o arquivamento é rápido para as suas configurações, você pode programar o crontab para funcionar com mais frequência.',
 	'General_BackToPiwik' => 'Volta ao Piwik',
-	'General_ShortMonth_1' => 'Jan',
 	'General_ShortMonth_2' => 'Fev',
-	'General_ShortMonth_3' => 'Mar',
 	'General_ShortMonth_4' => 'Abr',
 	'General_ShortMonth_5' => 'Mai',
-	'General_ShortMonth_6' => 'Jun',
-	'General_ShortMonth_7' => 'Jul',
 	'General_ShortMonth_8' => 'Ago',
 	'General_ShortMonth_9' => 'Set',
 	'General_ShortMonth_10' => 'Out',
-	'General_ShortMonth_11' => 'Nov',
 	'General_ShortMonth_12' => 'Dez',
 	'General_LongMonth_1' => 'Janeiro',
 	'General_LongMonth_2' => 'Fevereiro',
@@ -200,6 +238,7 @@ $translations = array(
 	'General_AuthenticationMethodSmtp' => 'Método de autenticação para SMTP',
 	'General_SmtpUsername' => 'Nome de usuário SMTP',
 	'General_SmtpPassword' => 'Password SMTP',
+	'General_SmtpEncryption' => 'Criptografia SMTP',
 	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Selecione "Sim" se pretende ou precisa de enviar email através de um nome de servidor em vez de usar a função de email local.',
 	'General_OnlyUsedIfUserPwdIsSet' => 'Usado apenas se um nome de usuário e palavra chave estiverem definidas. Pergunte ao seu fornecedor se não tem a certeza de qual método deve usar.',
 	'General_OnlyEnterIfRequired' => 'Insira um nome de usuário SMTP apenas se o servidor necessitar de um.',
@@ -211,22 +250,42 @@ $translations = array(
 	'General_Language' => 'Idioma',
 	'General_PleaseUpdatePiwik' => 'Por favor atualize o seu Piwik',
 	'General_RequestTimedOut' => 'O pedido de informação %s expirou. Por favor tente novamente.',
+	'General_Recommended' => 'Recomendado',
+	'General_NotRecommended' => 'Não recomendado',
+	'General_Goal' => 'Objetivo',
+	'General_Outlink' => 'Saída',
+	'General_Help' => 'Ajuda',
+	'General_DailySum' => 'Soma diariamente',
+	'General_AfterEntry' => 'Após entrar aqui',
+	'General_Metadata' => 'Metadados',
+	'General_OneVisit' => '1 visita',
+	'General_OneDay' => '1 dia',
+	'General_MainMetrics' => 'Métricas principais',
+	'General_Rows' => 'Linhas',
+	'General_GeneralInformation' => 'Informações Gerais',
 	'Actions_PluginDescription' => 'Relatórios sobre visualização de páginas, links externos e downaloads. Rastramentos de links externos e downloads é automático!',
 	'Actions_Actions' => 'Ações',
 	'Actions_SubmenuPages' => 'Páginas',
 	'Actions_SubmenuPagesEntry' => 'Páginas de entrada',
 	'Actions_SubmenuPagesExit' => 'Páginas de saída',
+	'Actions_EntryPageTitles' => 'Título de Páginas de Entradas',
+	'Actions_ExitPageTitles' => 'Título de Páginas de Saídas',
 	'Actions_SubmenuPageTitles' => 'Títulos das páginas',
+	'Actions_PageUrls' => 'URLs de Página(s)',
 	'Actions_SubmenuOutlinks' => 'Links Externos',
-	'Actions_SubmenuDownloads' => 'Downloads',
+	'Actions_PagesReportDocumentation' => 'Este relatório contém informações sobre URL de páginas as quais foram visitadas. %s A tabela está organizada hierarquicamente, as URLs estão apresentadas como estrutura de pastas',
+	'Actions_PageTitlesReportDocumentation' => 'Este relatório contém informações sobre títulos de páginas as quais foram visitadas. %s O título da página é um HTML %s Tag a qual é mais visualizada nos títulos do browser.',
+	'Actions_OutlinksReportDocumentation' => 'Este relatório mostra a lista de hierarquia de outlinks URLs as quais foram clicadas pelos seus visitantes',
+	'Actions_OutlinkDocumentation' => 'Um "outlink" é um link a qual guia o visitante a sair do seu website para outro domínio',
+	'Actions_DownloadsReportDocumentation' => 'Neste relatório, você pode ver quais arquivos seus visitantes baixaram. %s Piwik registra como download como um click em um link de download. Se o download foi completado ou não o Piwik não consegue determinar.',
 	'Actions_ColumnClicks' => 'Cliques',
+	'Actions_ColumnClicksDocumentation' => 'O número de vezes que link foi clicado.',
 	'Actions_ColumnUniqueClicks' => 'Cliques únicos',
-	'Actions_ColumnDownloads' => 'Downloads',
+	'Actions_ColumnUniqueClicksDocumentation' => 'O número de visitantes as quais se acionaram um click no link. Se um link foi clicado várias vezes durante uma visita, isto é somente registrado uma vez.',
 	'Actions_ColumnUniqueDownloads' => 'Downloads Únicos',
 	'Actions_ColumnPageName' => 'Nome da página',
 	'Actions_ColumnPageURL' => 'URL da página',
 	'Actions_ColumnClickedURL' => 'URL clicado',
-	'Actions_ColumnDownloadURL' => 'Download URL',
 	'AnonymizeIP_PluginDescription' => 'Anonimize o último byte do endereço IP dos visitantes para obedecer suas leis/guias locais de privacidade.',
 	'API_PluginDescription' => 'Todos os dados no Piwik estão disponíveis através de APIs simples. Esse plugin é o ponto de entrada para o web service, que você pode chamar para ter seus dados Web Analytics em xml, json, php, csv, etc.',
 	'API_QuickDocumentationTitle' => 'API documentação rápida',
@@ -274,17 +333,12 @@ $translations = array(
 	'CoreHome_LongDay_5_js' => 'Quinta',
 	'CoreHome_LongDay_6_js' => 'Sexta',
 	'CoreHome_LongDay_7_js' => 'Sábado',
-	'CoreHome_ShortMonth_1_js' => 'Jan',
 	'CoreHome_ShortMonth_2_js' => 'Fev',
-	'CoreHome_ShortMonth_3_js' => 'Mar',
 	'CoreHome_ShortMonth_4_js' => 'Abr',
 	'CoreHome_ShortMonth_5_js' => 'Mai',
-	'CoreHome_ShortMonth_6_js' => 'Jun',
-	'CoreHome_ShortMonth_7_js' => 'Jul',
 	'CoreHome_ShortMonth_8_js' => 'Ago',
 	'CoreHome_ShortMonth_9_js' => 'Set',
 	'CoreHome_ShortMonth_10_js' => 'Out',
-	'CoreHome_ShortMonth_11_js' => 'Nov',
 	'CoreHome_ShortMonth_12_js' => 'Dez',
 	'CoreHome_MonthJanuary_js' => 'Janeiro',
 	'CoreHome_MonthFebruary_js' => 'Fevereiro',
@@ -299,12 +353,9 @@ $translations = array(
 	'CoreHome_MonthNovember_js' => 'Novembro',
 	'CoreHome_MonthDecember_js' => 'Dezembro',
 	'CorePluginsAdmin_PluginDescription' => 'Interface de Administração de Plugins',
-	'CorePluginsAdmin_Plugins' => 'Plugins',
 	'CorePluginsAdmin_PluginsManagement' => 'Gerenciamento de plugins',
 	'CorePluginsAdmin_MainDescription' => 'Plugins estendem e expandem a funcionalidade do Piwik. Uma vez que um plugin for instalado, você pode ativá-lo ou desativá-lo aqui.',
-	'CorePluginsAdmin_Plugin' => 'Plugin',
 	'CorePluginsAdmin_Version' => 'Versão',
-	'CorePluginsAdmin_Status' => 'Status',
 	'CorePluginsAdmin_Action' => 'Ação',
 	'CorePluginsAdmin_PluginHomepage' => 'Página do Plugin',
 	'CorePluginsAdmin_Activated' => 'Ativado',
@@ -312,7 +363,6 @@ $translations = array(
 	'CorePluginsAdmin_Inactive' => 'Inativo',
 	'CorePluginsAdmin_Deactivate' => 'Desativar',
 	'CorePluginsAdmin_Activate' => 'Ativar',
-	'CorePluginsAdmin_MenuPlugins' => 'Plugins',
 	'CoreUpdater_PluginDescription' => 'Mecanismo de update Piwik',
 	'CoreUpdater_UpdateTitle' => 'Atualiza',
 	'CoreUpdater_DatabaseUpgradeRequired' => 'Atualização do banco de dados requerida',
@@ -381,7 +431,6 @@ $translations = array(
 	'DBStats_IndexSize' => 'Tamanho do índice',
 	'DBStats_TotalSize' => 'Tamanho total',
 	'ExampleAPI_PluginDescription' => 'Plugin Exemplo: Como criar uma API para seu plugin, para exportar seus dados em multiplos formatos sem nenhum código especial?',
-	'ExampleFeedburner_PluginDescription' => 'Plugin Exemplo: Como mostrar seu assinante Feedburner em um widget no painel de ferramentas?',
 	'ExampleRssWidget_PluginDescription' => 'Plugin Exemplo: Como criar um novo widget que lê um RSS feed?',
 	'ExampleUI_PluginDescription' => 'Plugin Exemplo: Esse plugin mostra como trabalhar com o Piwik UI: criar tabelas, gráficos, etc.',
 	'Feedback_PluginDescription' => 'Envie seu FeedBack para a Equipe Piwik. Compartilhe suas ideias e sugestões conosco!',
@@ -437,7 +486,6 @@ $translations = array(
 	'Goals_Manually' => 'manualmente',
 	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'A meta é manualmente triggered usando a API do Javascript trackGoal()',
 	'Goals_VisitUrl' => 'Visitar a URL dada(página ou grupo de páginas)',
-	'Goals_URL' => 'URL',
 	'Goals_Filename' => 'nome do arquivo',
 	'Goals_ExternalWebsiteUrl' => 'URL de website externo',
 	'Goals_Download' => 'Baixar um arquivo',
@@ -466,7 +514,6 @@ $translations = array(
 	'Installation_NoConfigFound' => 'O arquivo de configuração de relatórios não pode ser encontrado e você está tentando acessar uma página do Piwik.<br /><b>  » Você poderá <a href=\'index.php\'>instalar o Piwik agora</a></b><br /><small>Se você instalou o Piwik antes e possui algumas tabelas em seu banco de dados, não se preocupe, você poderá reutilizar as mesmas tabelas e manter os dados existentes!</small>',
 	'Installation_DatabaseSetup' => 'Setup do banco de dados',
 	'Installation_DatabaseSetupServer' => 'servidor de banco de dados',
-	'Installation_DatabaseSetupLogin' => 'login',
 	'Installation_DatabaseSetupPassword' => 'senha',
 	'Installation_DatabaseSetupDatabaseName' => 'nome do banco de dados',
 	'Installation_DatabaseSetupTablePrefix' => 'prefixo da tabela',
@@ -492,7 +539,6 @@ $translations = array(
 	'Installation_SuperUserLogin' => 'login super usuário',
 	'Installation_Password' => 'senha',
 	'Installation_PasswordRepeat' => 'senha (repetir)',
-	'Installation_Email' => 'email',
 	'Installation_SecurityNewsletter' => 'envie-me um email quando houver alertas de segurança e atualizações importantes',
 	'Installation_CommunityNewsletter' => 'envie-me um email com atualizações da comunidade (novos plugins, novas funções, etc.)',
 	'Installation_PasswordDoNotMatch' => 'senha não confere',
@@ -526,7 +572,6 @@ $translations = array(
 	'Installation_SystemCheckDebugBacktraceHelp' => 'View Factory não será permitida para criar views pelo módulo chamado.',
 	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik usa funções anônimas para callbacks',
 	'Installation_SystemCheckEvalHelp' => 'Requisitado pelo HTML QuickForm e sistema Smarty de templating.',
-	'Installation_SystemCheckMbstring' => 'mbstring',
 	'Installation_SystemCheckMbstringExtensionHelp' => 'A extensão mbstring é requisitada para caracteres multibyte na resposta da API usando valores separados por vírgula (CSV) ou valores separados por tab (TSB).',
 	'Installation_SystemCheckMbstringFuncOverloadHelp' => 'Você deveria definir mbstring.func_overload para "0".',
 	'Installation_SystemCheckFileIntegrity' => 'Integridade de arquivo.',
@@ -567,19 +612,13 @@ $translations = array(
 	'Login_PasswordRepeat' => 'Senha (repetir)',
 	'Login_ChangePassword' => 'Troca senha',
 	'Login_LoginOrEmail' => 'Nome de Usuário ou E-mail',
+	'Login_RememberMe' => 'Lembrar meu login',
 	'Login_LogIn' => 'Entrar',
 	'Login_Logout' => 'Sair',
 	'Login_LostYourPassword' => 'Esqueceu a sua senha?',
-	'Login_RemindPassword' => 'Lembrar senha',
-	'Login_PasswordResetToken' => 'Token de lembrança de senha',
-	'Login_PasswordReminder' => 'Por favor digite o seu nome de usuário ou endereço de e-mail. Você receberá uma nova senha via e-mail com informações para resetar a sua senha.',
 	'Login_PasswordsDoNotMatch' => 'Senhas não conferem.',
-	'Login_PasswordSuccessfullyChanged' => 'Senha trocada com sucesso!',
 	'Login_InvalidUsernameEmail' => 'Nome de usuário e/ou e-mail inválido',
 	'Login_InvalidOrExpiredToken' => 'Token inválido ou expirado',
-	'Login_MailTopicPasswordRecovery' => 'Recuperação de senha',
-	'Login_MailPasswordRecoveryBody' => 'Olá %1$s, um pedido de recuperação de senha foi recebido de %2$s. Para resetar sua senha: 1) Vá até o formulário de recuperação de senha em: %3$s 2) Entre com o seguinte token: %4$s 3) Preencha o formulário (colocando sua nova senha duas vezes) e envie. Observação: este token irá expirar em 24 horas.',
-	'Login_PasswordSent' => 'Informações para resetar sua senha foram enviadas. Verifique seu e-mail.',
 	'Login_ContactAdmin' => 'Possível razão: o seu host desabilitou a função mail(). <br />Por favor contacte o administrador do Piwik.',
 	'Login_ExceptionPasswordMD5HashExpected' => 'É esperado que o parâmetro da senha seja um hash MD5 da senha.',
 	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'O Super Usuário não pode ser autenticado usando o mecanismo "%s".',
@@ -601,13 +640,11 @@ $translations = array(
 	'Referers_SearchEngines' => 'Sistemas de Busca',
 	'Referers_Keywords' => 'Palavras Chaves',
 	'Referers_DirectEntry' => 'Entrada Direta',
-	'Referers_Websites' => 'Websites',
 	'Referers_Campaigns' => 'Campanhas',
 	'Referers_Evolution' => 'Evolução no período',
 	'Referers_Type' => 'Tipo de Referer',
 	'Referers_ColumnRefererType' => 'Tipo de Referer',
 	'Referers_ColumnSearchEngine' => 'Sistema de Busca',
-	'Referers_ColumnWebsite' => 'Website',
 	'Referers_ColumnWebsitePage' => 'Página da Web',
 	'Referers_ColumnKeyword' => 'Palavra chave',
 	'Referers_ColumnCampaign' => 'campanha',
@@ -623,7 +660,6 @@ $translations = array(
 	'Referers_DistinctWebsites' => 'Websites distintos',
 	'Referers_UsingNDistinctUrls' => '(usando urls %s distintas)',
 	'Referers_SubmenuSearchEngines' => 'Sistemas de Buscas e Palavras Chaves',
-	'Referers_SubmenuWebsites' => 'Websites',
 	'Referers_SubmenuCampaigns' => 'Campanhas',
 	'Referers_WidgetKeywords' => 'Lista de Palavras Chave',
 	'Referers_WidgetCampaigns' => 'Lista de Campanhas',
@@ -638,12 +674,9 @@ $translations = array(
 	'SEO_SeoRankings' => 'Ranking SEO',
 	'SEO_AlexaRank' => 'Rank Alexa',
 	'SEO_DomainAge' => 'Idade de Domínio',
-	'SEO_Rank' => 'Rank',
-	'SEO_Backlinks' => 'Backlinks',
 	'SEO_Pages' => 'Páginas',
 	'SEO_SEORankingsFor' => 'Ranking SEO para %s',
 	'SitesManager_PluginDescription' => 'Gerenciamento de websites no Piwik: adiciona um novo website, edita um existente, mostra código JavaScript para incluir em suas páginas. Todas as ações também estão disponíveis através da API.',
-	'SitesManager_Sites' => 'Websites',
 	'SitesManager_TrackingTags' => 'Rastreando tags para %s',
 	'SitesManager_WebsitesManagement' => 'Gerenciamento de Sites',
 	'SitesManager_MainDescription' => 'Seus relatórios de Web Analytics precisam de websites! Adiciona, atualiza, elimina websites, e mostra o JavaScript necessário para inserir em suas páginas.',
@@ -656,8 +689,6 @@ $translations = array(
 	'SitesManager_AddSite' => 'Adicionar novo Site',
 	'SitesManager_NotFound' => 'Nenhum site encontrado para',
 	'SitesManager_AliasUrlHelp' => 'É recomendado, mas não necessário, especificar as várias URLs que seus visitantes usam para acessar esse site, uma por linha. Pseudônimos de URLs para websites não aparecerão em Referencias > relatórios de websites. Note que não é necessário especificar as URLs com ou sem \'www\' como o Piwik considera automaticamente ambos.',
-	'SitesManager_Urls' => 'URLs',
-	'SitesManager_MenuSites' => 'Websites',
 	'SitesManager_DeleteConfirm_js' => 'Tem certeza que deseja excluir o website %s?',
 	'SitesManager_ExceptionDeleteSite' => 'Não é possível excluir este website já que ele é o único website registrado. Adiicone um novo website primeiro, depois exclua este.',
 	'SitesManager_ExceptionNoUrl' => 'Você precisa especificar no mínimo uma URL para o site.',
@@ -694,7 +725,6 @@ $translations = array(
 	'TranslationsAdmin_MenuTranslations' => 'Traduções',
 	'TranslationsAdmin_MenuLanguages' => 'Idiomas',
 	'TranslationsAdmin_LanguageCode' => 'Código do Idioma',
-	'TranslationsAdmin_Plugin' => 'Plugin',
 	'TranslationsAdmin_Definition' => 'Definição',
 	'TranslationsAdmin_DefaultString' => 'String Padrão (Inglês)',
 	'TranslationsAdmin_TranslationString' => 'String de tradução (idioma atual: %s)',
@@ -709,75 +739,46 @@ $translations = array(
 	'UserCountry_DistinctCountries' => '%s países distintos',
 	'UserCountry_Location' => 'Localização',
 	'UserCountry_SubmenuLocations' => 'Locais',
-	'UserCountry_WidgetContinents' => 'Continente dos Visitantes',
-	'UserCountry_WidgetCountries' => 'País dos Visitantes',
-	'UserCountry_country_ac' => 'Ascension Islands',
-	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'Emirados Árabes Unidos',
 	'UserCountry_country_af' => 'Afeganistão',
 	'UserCountry_country_ag' => 'Antigua e Barbuda',
-	'UserCountry_country_ai' => 'Anguilla',
 	'UserCountry_country_al' => 'Albânia',
 	'UserCountry_country_am' => 'Armênia',
 	'UserCountry_country_an' => 'Antilhas Holandesas',
-	'UserCountry_country_ao' => 'Angola',
 	'UserCountry_country_aq' => 'Antártida',
-	'UserCountry_country_ar' => 'Argentina',
 	'UserCountry_country_as' => 'Samoa Americana',
 	'UserCountry_country_at' => 'Áustria',
 	'UserCountry_country_au' => 'Austrália',
-	'UserCountry_country_aw' => 'Aruba',
 	'UserCountry_country_ax' => 'Ilhas Aland',
 	'UserCountry_country_az' => 'Azerbaijão',
 	'UserCountry_country_ba' => 'Bósnia Herzegovina',
-	'UserCountry_country_bb' => 'Barbados',
-	'UserCountry_country_bd' => 'Bangladesh',
 	'UserCountry_country_be' => 'Bélgica',
-	'UserCountry_country_bf' => 'Burkina Faso',
 	'UserCountry_country_bg' => 'Bulgária',
 	'UserCountry_country_bh' => 'Bahrein',
-	'UserCountry_country_bi' => 'Burundi',
-	'UserCountry_country_bj' => 'Benin',
-	'UserCountry_country_bl' => 'Saint Barthelemy',
-	'UserCountry_country_bm' => 'Bermuda',
 	'UserCountry_country_bn' => 'Brunei',
 	'UserCountry_country_bo' => 'Bolívia',
 	'UserCountry_country_br' => 'Brasil',
-	'UserCountry_country_bs' => 'Bahamas',
 	'UserCountry_country_bt' => 'Butão',
 	'UserCountry_country_bu' => 'Birmânia',
-	'UserCountry_country_bv' => 'Bouvet Island',
-	'UserCountry_country_bw' => 'Botswana',
 	'UserCountry_country_by' => 'Bielorússia',
-	'UserCountry_country_bz' => 'Belize',
 	'UserCountry_country_ca' => 'Canadá',
-	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
 	'UserCountry_country_cd' => 'Congo, República Democrática do',
 	'UserCountry_country_cf' => 'República Centro-Africana',
-	'UserCountry_country_cg' => 'Congo',
 	'UserCountry_country_ch' => 'Suíça',
 	'UserCountry_country_ci' => 'Costa do Marfim',
 	'UserCountry_country_ck' => 'Ilhas Cook',
-	'UserCountry_country_cl' => 'Chile',
 	'UserCountry_country_cm' => 'Camarões',
-	'UserCountry_country_cn' => 'China',
 	'UserCountry_country_co' => 'Colômbia',
 	'UserCountry_country_cp' => 'Ilha Clipperton',
-	'UserCountry_country_cr' => 'Costa Rica',
 	'UserCountry_country_cs' => 'Sérvia e Montenegro',
-	'UserCountry_country_cu' => 'Cuba',
 	'UserCountry_country_cv' => 'Cabo Verde',
 	'UserCountry_country_cx' => 'Ilha Christmas',
 	'UserCountry_country_cy' => 'Chipre',
 	'UserCountry_country_cz' => 'República Tcheca',
 	'UserCountry_country_de' => 'Alemanha',
-	'UserCountry_country_dg' => 'Diego Garcia',
-	'UserCountry_country_dj' => 'Djibouti',
 	'UserCountry_country_dk' => 'Dinamarca',
-	'UserCountry_country_dm' => 'Dominica',
 	'UserCountry_country_do' => 'República Dominicana',
 	'UserCountry_country_dz' => 'Argélia',
-	'UserCountry_country_ea' => 'Ceuta, Melilla',
 	'UserCountry_country_ec' => 'Equador',
 	'UserCountry_country_ee' => 'Estônia',
 	'UserCountry_country_eg' => 'Egito',
@@ -787,7 +788,6 @@ $translations = array(
 	'UserCountry_country_et' => 'Etiópia',
 	'UserCountry_country_eu' => 'União Européia',
 	'UserCountry_country_fi' => 'Finlândia',
-	'UserCountry_country_fj' => 'Fiji',
 	'UserCountry_country_fk' => 'Ilhas Falkland (Malvinas)',
 	'UserCountry_country_fm' => 'Micronesia, Estados Federados da',
 	'UserCountry_country_fo' => 'Ilhas Faroe',
@@ -798,9 +798,7 @@ $translations = array(
 	'UserCountry_country_gd' => 'Granada',
 	'UserCountry_country_ge' => 'Geórgia',
 	'UserCountry_country_gf' => 'Guiana Francesa',
-	'UserCountry_country_gg' => 'Guernsey',
 	'UserCountry_country_gh' => 'Gana',
-	'UserCountry_country_gi' => 'Gibraltar',
 	'UserCountry_country_gl' => 'Groenlândia',
 	'UserCountry_country_gm' => 'Gâmbia',
 	'UserCountry_country_gn' => 'Guiné',
@@ -808,20 +806,14 @@ $translations = array(
 	'UserCountry_country_gq' => 'Guiné Equatorial',
 	'UserCountry_country_gr' => 'Grécia',
 	'UserCountry_country_gs' => 'South Georgia e Ilhas South Sandwich',
-	'UserCountry_country_gt' => 'Guatemala',
-	'UserCountry_country_gu' => 'Guam',
 	'UserCountry_country_gw' => 'Guiné-Bissau',
 	'UserCountry_country_gy' => 'Guiana',
-	'UserCountry_country_hk' => 'Hong Kong',
 	'UserCountry_country_hm' => 'Ilha Heard e Ilhas McDonald',
-	'UserCountry_country_hn' => 'Honduras',
 	'UserCountry_country_hr' => 'Croácia',
-	'UserCountry_country_ht' => 'Haiti',
 	'UserCountry_country_hu' => 'Hungria',
 	'UserCountry_country_ic' => 'Ilhas Canárias',
 	'UserCountry_country_id' => 'Indonésia',
 	'UserCountry_country_ie' => 'Irlanda',
-	'UserCountry_country_il' => 'Israel',
 	'UserCountry_country_im' => 'Ilha de Man',
 	'UserCountry_country_in' => 'Índia',
 	'UserCountry_country_io' => 'Território Oceânico das Índias Britânicas',
@@ -829,26 +821,19 @@ $translations = array(
 	'UserCountry_country_ir' => 'Irã, República Islâmica do',
 	'UserCountry_country_is' => 'Islândia',
 	'UserCountry_country_it' => 'Itália',
-	'UserCountry_country_je' => 'Jersey',
-	'UserCountry_country_jm' => 'Jamaica',
 	'UserCountry_country_jo' => 'Jordânia',
 	'UserCountry_country_jp' => 'Japão',
 	'UserCountry_country_ke' => 'Quênia',
 	'UserCountry_country_kg' => 'Kirguistão',
 	'UserCountry_country_kh' => 'Camboja',
-	'UserCountry_country_ki' => 'Kiribati',
-	'UserCountry_country_km' => 'Comoros',
 	'UserCountry_country_kn' => 'Saint Kitts e Nevis',
 	'UserCountry_country_kp' => 'Coréia, República Democrática Popular da',
 	'UserCountry_country_kr' => 'Coréia, República da',
-	'UserCountry_country_kw' => 'Kuwait',
 	'UserCountry_country_ky' => 'Ilhas Cayman',
 	'UserCountry_country_kz' => 'Cazaquistão',
 	'UserCountry_country_la' => 'Laos',
 	'UserCountry_country_lb' => 'Líbano',
 	'UserCountry_country_lc' => 'Santa Lúcia',
-	'UserCountry_country_li' => 'Liechtenstein',
-	'UserCountry_country_lk' => 'Sri Lanka',
 	'UserCountry_country_lr' => 'Libéria',
 	'UserCountry_country_ls' => 'Lesoto',
 	'UserCountry_country_lt' => 'Lituânia',
@@ -858,55 +843,37 @@ $translations = array(
 	'UserCountry_country_ma' => 'Marrocos',
 	'UserCountry_country_mc' => 'Mônaco',
 	'UserCountry_country_md' => 'Moldávia, República da',
-	'UserCountry_country_me' => 'Montenegro',
 	'UserCountry_country_mf' => 'Saint Martin',
-	'UserCountry_country_mg' => 'Madagascar',
 	'UserCountry_country_mh' => 'Ilhas Marshall',
 	'UserCountry_country_mk' => 'Macedônia',
-	'UserCountry_country_ml' => 'Mali',
-	'UserCountry_country_mm' => 'Myanmar',
 	'UserCountry_country_mn' => 'Mongólia',
-	'UserCountry_country_mo' => 'Macau',
 	'UserCountry_country_mp' => 'Ilhas Marianas do Norte',
 	'UserCountry_country_mq' => 'Martinica',
 	'UserCountry_country_mr' => 'Mauritânia',
-	'UserCountry_country_ms' => 'Montserrat',
-	'UserCountry_country_mt' => 'Malta',
 	'UserCountry_country_mu' => 'Ilhas Maurício',
 	'UserCountry_country_mv' => 'Maldivas',
-	'UserCountry_country_mw' => 'Malawi',
 	'UserCountry_country_mx' => 'México',
 	'UserCountry_country_my' => 'Malásia',
 	'UserCountry_country_mz' => 'Moçambique',
 	'UserCountry_country_na' => 'Namíbia',
 	'UserCountry_country_nc' => 'Nova Caledônia',
-	'UserCountry_country_ne' => 'Niger',
-	'UserCountry_country_nf' => 'Norfolk Island',
 	'UserCountry_country_ng' => 'Nigéria',
 	'UserCountry_country_ni' => 'Nicarágua',
 	'UserCountry_country_nl' => 'Holanda',
 	'UserCountry_country_no' => 'Noruega',
-	'UserCountry_country_np' => 'Nepal',
-	'UserCountry_country_nr' => 'Nauru',
 	'UserCountry_country_nt' => 'Zona Neutra',
-	'UserCountry_country_nu' => 'Niue',
 	'UserCountry_country_nz' => 'Nova Zelândia',
 	'UserCountry_country_om' => 'Omã',
 	'UserCountry_country_pa' => 'Panamá',
-	'UserCountry_country_pe' => 'Peru',
 	'UserCountry_country_pf' => 'Polinésia Francesa',
 	'UserCountry_country_pg' => 'Papua Nova Guiné',
 	'UserCountry_country_ph' => 'Filipinas',
 	'UserCountry_country_pk' => 'Paquistão',
 	'UserCountry_country_pl' => 'Polônia',
 	'UserCountry_country_pm' => 'Saint Pierre e Miquelon',
-	'UserCountry_country_pn' => 'Pitcairn',
 	'UserCountry_country_pr' => 'Porto Rico',
 	'UserCountry_country_ps' => 'Território Palestino',
-	'UserCountry_country_pt' => 'Portugal',
-	'UserCountry_country_pw' => 'Palau',
 	'UserCountry_country_py' => 'Paraguai',
-	'UserCountry_country_qa' => 'Qatar',
 	'UserCountry_country_re' => 'Ilhas Reunião',
 	'UserCountry_country_ro' => 'Romênia',
 	'UserCountry_country_rs' => 'Sérvia',
@@ -914,7 +881,6 @@ $translations = array(
 	'UserCountry_country_rw' => 'Ruanda',
 	'UserCountry_country_sa' => 'Arábia Saudita',
 	'UserCountry_country_sb' => 'Ilhas Salomão',
-	'UserCountry_country_sc' => 'Seychelles',
 	'UserCountry_country_sd' => 'Sudão',
 	'UserCountry_country_se' => 'Suécia',
 	'UserCountry_country_sf' => 'Finlândia',
@@ -924,37 +890,27 @@ $translations = array(
 	'UserCountry_country_sj' => 'Svalbard',
 	'UserCountry_country_sk' => 'Eslováquia',
 	'UserCountry_country_sl' => 'Serra Leoa',
-	'UserCountry_country_sm' => 'San Marino',
-	'UserCountry_country_sn' => 'Senegal',
 	'UserCountry_country_so' => 'Somália',
-	'UserCountry_country_sr' => 'Suriname',
 	'UserCountry_country_st' => 'São Tome e Príncipe',
 	'UserCountry_country_su' => 'Antiga U.R.S.S.',
-	'UserCountry_country_sv' => 'El Salvador',
 	'UserCountry_country_sy' => 'República Árabe da Síria',
 	'UserCountry_country_sz' => 'Suazilândia',
 	'UserCountry_country_ta' => 'Tristão da Cunha',
 	'UserCountry_country_tc' => 'Ilhas Turks e Caicos',
 	'UserCountry_country_td' => 'Chade',
 	'UserCountry_country_tf' => 'Territórios Franceses do Sul',
-	'UserCountry_country_tg' => 'Togo',
 	'UserCountry_country_th' => 'Tailândia',
 	'UserCountry_country_tj' => 'Tadjiquistão',
-	'UserCountry_country_tk' => 'Tokelau',
 	'UserCountry_country_tl' => 'Timor Leste',
 	'UserCountry_country_tm' => 'Turkmenistão',
 	'UserCountry_country_tn' => 'Tunísia',
-	'UserCountry_country_to' => 'Tonga',
 	'UserCountry_country_tp' => 'Timor Leste',
 	'UserCountry_country_tr' => 'Turquia',
 	'UserCountry_country_tt' => 'Trinidade e Tobago',
-	'UserCountry_country_tv' => 'Tuvalu',
 	'UserCountry_country_tw' => 'Taiwan',
 	'UserCountry_country_tz' => 'Tanzânia, República Unida da',
 	'UserCountry_country_ua' => 'Ucrânia',
-	'UserCountry_country_ug' => 'Uganda',
 	'UserCountry_country_uk' => 'Reino Unido',
-	'UserCountry_country_um' => 'United States Minor Outlying Islands',
 	'UserCountry_country_us' => 'Estados Unidos da América',
 	'UserCountry_country_uy' => 'Uruguai',
 	'UserCountry_country_uz' => 'Uzbequistão',
@@ -964,22 +920,17 @@ $translations = array(
 	'UserCountry_country_vg' => 'Ilhas Virgens Britânicas',
 	'UserCountry_country_vi' => 'Ilhas Virgens Americanas',
 	'UserCountry_country_vn' => 'Vietnã',
-	'UserCountry_country_vu' => 'Vanuatu',
 	'UserCountry_country_wf' => 'Wallis e Futuna',
-	'UserCountry_country_ws' => 'Samoa',
 	'UserCountry_country_ye' => 'Iêmen',
-	'UserCountry_country_yt' => 'Mayotte',
 	'UserCountry_country_yu' => 'Iugoslávia',
 	'UserCountry_country_za' => 'África do Sul',
 	'UserCountry_country_zm' => 'Zâmbia',
-	'UserCountry_country_zr' => 'Zaire',
 	'UserCountry_country_zw' => 'Zimbabue',
 	'UserCountry_continent_eur' => 'Europa',
 	'UserCountry_continent_afr' => 'África',
 	'UserCountry_continent_asi' => 'Ásia',
 	'UserCountry_continent_amn' => 'América do Norte',
 	'UserCountry_continent_ams' => 'América do Sul e Central',
-	'UserCountry_continent_oce' => 'Oceania',
 	'UserCountryMap_map' => 'mapa',
 	'UserCountryMap_worldMap' => 'mapa mundi',
 	'UserCountryMap_toggleFullscreen' => 'Alternar tela cheia',
@@ -987,14 +938,11 @@ $translations = array(
 	'UserSettings_VisitorSettings' => 'Configurações dos visitantes',
 	'UserSettings_BrowserFamilies' => 'Família de Navegadores',
 	'UserSettings_Browsers' => 'Navegadores',
-	'UserSettings_Plugins' => 'Plugins',
 	'UserSettings_Configurations' => 'Configurações',
 	'UserSettings_OperatingSystems' => 'Sistemas Operacionais',
 	'UserSettings_Resolutions' => 'Resoluções',
-	'UserSettings_WideScreen' => 'Wide Screen',
 	'UserSettings_ColumnBrowserFamily' => 'Família do Navegador',
 	'UserSettings_ColumnBrowser' => 'Navegador',
-	'UserSettings_ColumnPlugin' => 'Plugin',
 	'UserSettings_ColumnConfiguration' => 'Configuração',
 	'UserSettings_ColumnOperatingSystem' => 'Sistema Operacional',
 	'UserSettings_ColumnResolution' => 'Resolução',
@@ -1003,7 +951,6 @@ $translations = array(
 	'UserSettings_WidgetBrowsers' => 'Navegador dos Visitantes',
 	'UserSettings_WidgetPlugins' => 'Lista de Plugins',
 	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Nota: a detecção de plugins não funciona no Internet Explorer. Esse relatório é baseado apenas em navegadores não IE.',
-	'UserSettings_WidgetWidescreen' => 'Normal / Widescreen',
 	'UserSettings_WidgetBrowserFamilies' => 'Navegadores por Família',
 	'UserSettings_WidgetOperatingSystems' => 'Sistemas Operacionais',
 	'UserSettings_WidgetGlobalVisitors' => 'Configuração Global de Visitante',
@@ -1013,16 +960,13 @@ $translations = array(
 	'UsersManager_UsersManagementMainDescription' => 'Crie novos usuários ou atualize os usuários existentes. Você poderá então ajustar as permissões deles acima.',
 	'UsersManager_ManageAccess' => 'Gerenciar acesso',
 	'UsersManager_MainDescription' => 'Decida quais usuários terão acesso ao Piwik nos seus websites. Você pode também ajustar as permissões em todos os websites de uma só vez.',
-	'UsersManager_Sites' => 'Websites',
 	'UsersManager_AllWebsites' => 'Todos os websites',
 	'UsersManager_ApplyToAllWebsites' => 'Aplicar a todos os websites',
 	'UsersManager_User' => 'Usurário',
 	'UsersManager_PrivNone' => 'Sem acesso',
 	'UsersManager_PrivView' => 'Ver',
-	'UsersManager_PrivAdmin' => 'Admin',
 	'UsersManager_ChangeAllConfirm' => 'Você tem certeza que deseja alterar as permissões de %s em todos os websites?',
 	'UsersManager_Password' => 'Senha',
-	'UsersManager_Email' => 'Email',
 	'UsersManager_Alias' => 'Apelido',
 	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'O pseudônimo do Super Usuário não pode ser alterado.',
 	'UsersManager_ReportToLoadByDefault' => 'Relate para carregar por padrão',
@@ -1038,7 +982,6 @@ $translations = array(
 	'UsersManager_MenuUsers' => 'Usuários',
 	'UsersManager_MenuUserSettings' => 'Configurações de usuário',
 	'UsersManager_MenuAnonymousUserSettings' => 'Configurações de usuário anônimo',
-	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Nota: Você não tem nenhum website que um usuário anônimo pode acessar, as seguintes configurações não serão usadas.',
 	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Quando usuários não estão logados e visitam o Piwik, eles deveriam acessar',
 	'UsersManager_ChangePassword' => 'Mudar senha',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Se você gostaria de mudar a senha, digite uma nova. Senão, deixe em branco.',
@@ -1079,7 +1022,6 @@ $translations = array(
 	'VisitorInterest_WidgetLengths' => 'Duração das Visitas',
 	'VisitorInterest_WidgetPages' => 'Páginas por Visita',
 	'VisitorInterest_Engagement' => 'Compromisso',
-	'VisitorInterest_PlusXMin' => '%s min',
 	'VisitorInterest_OnePage' => '1 página',
 	'VisitorInterest_NPages' => '%s páginas',
 	'VisitsSummary_PluginDescription' => 'Relata os números gerais Analytics: visitas, visitantes únicos, número de ações, taxas, etc.',
@@ -1089,7 +1031,6 @@ $translations = array(
 	'VisitsSummary_NbActionsDescription' => '%s ações (visualizações de páginas, downloads e links externos)',
 	'VisitsSummary_MaxNbActions' => '%s ações máximas em uma visita',
 	'VisitsSummary_NbVisitsBounced' => '%s visitantes saíram (deixaram o website após uma página)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolução nos/nas últimos(as) %s',
 	'VisitsSummary_GenerateTime' => '%s segundos para gerar a página',
 	'VisitsSummary_GenerateQueries' => '%s consultas executadas',
 	'VisitsSummary_WidgetLastVisits' => 'Gráfico dos últimos visitantes',
@@ -1105,6 +1046,5 @@ $translations = array(
 	'VisitTime_WidgetLocalTime' => 'Visitas pelo horário local',
 	'VisitTime_WidgetServerTime' => 'Visitas pelo horário do servidor',
 	'VisitTime_SubmenuTimes' => 'Horários',
-	'VisitTime_NHour' => '%sh',
 	'Widgetize_PluginDescription' => 'O plugin faz ficar muito fácil exportar qualquer widget Piwik para seu blog, website ou em Igoogle e Netvibes!',
 );
