@@ -30,11 +30,16 @@ $translations = array(
 	'General_Delete' => 'Stergere',
 	'General_Report' => 'Raport',
 	'General_Reports' => 'Rapoarte',
+	'General_RelatedReport' => 'Raport asemănător',
+	'General_RelatedReports' => 'Rapoarte asemănătoare',
+	'General_Metric' => 'Metric',
+	'General_Metrics' => 'Metrice',
 	'General_Edit' => 'Editare',
 	'General_Download' => 'Descarca',
 	'General_Upload' => 'Incarca',
 	'General_Ok' => 'Ok',
 	'General_Close' => 'Inchide',
+	'General_Cancel' => 'Anulează',
 	'General_OrCancel' => 'sau %s Anuleaza %s',
 	'General_Logout' => 'Iesire',
 	'General_Username' => 'Nume utilizator',
@@ -42,12 +47,12 @@ $translations = array(
 	'General_Done' => 'Gata',
 	'General_PoweredBy' => 'Oferit de',
 	'General_MetricsToPlot' => 'Metrici de adaugat',
+	'General_RowsToDisplay' => 'Afişează liniile',
 	'General_MetricToPlot' => 'Metric de adaugat',
 	'General_RecordsToPlot' => 'Inregistrari de adaugat',
 	'General_Name' => 'Nume',
 	'General_Value' => 'Valoare',
 	'General_Total' => 'Total',
-	'General_TotalVisitsActionsRevenue' => '(Total: %s vizite, %s actiuni, %s venit)',
 	'General_AverageOrderValue' => 'Valoare medie a comenzii',
 	'General_PurchasedProducts' => 'Produse cumparate',
 	'General_EcommerceOrders' => 'Comenzi ecommerce',
@@ -172,6 +177,7 @@ $translations = array(
 	'General_MinutesSeconds' => '%1$s min %2$ss',
 	'General_Seconds' => '%ss',
 	'General_Save' => 'Salvare',
+	'General_Faq' => 'FAQ',
 	'General_ForExampleShort' => 'ex.',
 	'General_YouMustBeLoggedIn' => 'Trebuie sa fiti logat pentru a accesa aceasta functionalitate.',
 	'General_Website' => 'Website',
@@ -187,12 +193,14 @@ $translations = array(
 	'General_RequiresFlash' => 'Afisarea graficelor in Piwik necesita Flash',
 	'General_GraphHelp' => 'Mai multe informatii despre afisarea graficelor in Piwik',
 	'General_NoDataForGraph' => 'Nici o informatie pentru acest grafic',
+	'General_DataForThisGraphHasBeenPurged' => 'Datele din acest grafic sunt mai vechi de %s luni şi au fost curăţate.',
 	'General_NoDataForTagCloud' => 'No data for this tag cloud.',
+	'General_DataForThisTagCloudHasBeenPurged' => 'Datele din acest nor de etichete sunt mai vechi de %s luni şi au fost curăţate.',
 	'General_DisplaySimpleTable' => 'Afisarea unui tabel simplu',
 	'General_DisplayTableWithMoreMetrics' => 'Afisarea unui tabel cu mai multi metrici',
 	'General_DisplayTableWithGoalMetrics' => 'Afisarea unui tabel cu scopurile',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s este un proiect colaborativ. %3$s Daca sunteti fan Piwik, puteti ajuta! Vedeti %4$s Cum sa participati la Piwik?%5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Vizualizati o versiune demo a Piwik',
+	'General_YouAreCurrentlyUsing' => 'Foloseşti Piwik %s.',
 	'General_DownloadFullVersion' => '%1$sDescarcati%2$s versiunea full! Accesati %3$s',
 	'General_NewUpdatePiwikX' => 'Update nou: Piwik %s',
 	'General_AboutPiwikX' => 'Despre Piwik %s',
@@ -244,6 +252,12 @@ $translations = array(
 	'General_Daily' => 'Zilnic',
 	'General_Weekly' => 'Saptamanal',
 	'General_Monthly' => 'Lunar',
+	'General_DailyReports' => 'Rapoarte zilnice',
+	'General_WeeklyReports' => 'Rapoarte săptămânale',
+	'General_MonthlyReports' => 'Rapoarte lunare',
+	'General_YearlyReports' => 'Rapoarte anuale',
+	'General_RangeReports' => 'Particularizare perioadă',
+	'General_ConfigFileIsNotWritable' => 'Fişierul de configurare  %s Piwik nu se poate scrie, e posibil ca o parte din modificările tale să nu se fi salvat. %s Schimbă permisiile fişierului de configurare pentru a-l putea modifica.',
 	'General_ExceptionDatabaseVersion' => 'Versiunea dvs. %1$s este %2$s dar Piwik necesita minim %3$s.',
 	'General_ExceptionIncompatibleClientServerVersions' => 'Versiunea clientului dvs. %1$s este %2$s, care este incompatibila cu versiunea de pe server, %3$s.',
 	'General_ExceptionMissingFile' => 'Fisier lipsa: %s',
@@ -254,6 +268,7 @@ $translations = array(
 	'General_ExceptionMethodNotFound' => 'Metoda \'%s\' nu exista sau nu e valabila in modulul \'%s\'.',
 	'General_ExceptionInvalidRendererFormat' => 'Formatul \'%s\' este invalid. Incercati-l pe oricare dintre acestea: %s.',
 	'General_ExceptionInvalidReportRendererFormat' => 'Formatul raportului \'%s\' este invalid. Incercati-l pe oricare dintre acestea: %s.',
+	'General_ExceptionInvalidStaticGraphType' => 'Tipul graficului static \'%s\' nu este valid. Încearcă unul din următoarele: %s.',
 	'General_ExceptionInvalidAggregateReportsFormat' => 'Formatul rapoartelor agregate \'%s\' este invalid. Incercati-l pe oricare dintre acestea: %s.',
 	'General_ExceptionInvalidPeriod' => 'Perioada \'%s\' nu este suportata. Incercati-o pe oricare dintre acestea: %s.',
 	'General_ExceptionInvalidDateRange' => 'Data \'%s\' nu este un interval corect. Ar trebui sa aiba urmatorul format: %s.',
@@ -269,6 +284,7 @@ $translations = array(
 	'General_ExceptionInvalidDateFormat' => 'Formatul datei trebuie sa fie: %s sau alt cuvant cheie suportat de functia %s (vedeti %s pentru mai multe informatii)',
 	'General_ExceptionLanguageFileNotFound' => 'Fisierul de limba \'%s\' nu a fost gasit.',
 	'General_ExceptionUnableToStartSession' => 'Sesiunea nu a putut fi pornita',
+	'General_ExceptionCheckUserIsSuperUserOrTheUser' => 'Utilizatorul trebuie să fie ori Super User ori utilizatorul  \'%s\' însuşi.',
 	'General_WarningFileIntegritySkipped' => 'Mediu de development detectat. Verificare integritatii fisierelor a fost sarita.',
 	'General_WarningFileIntegrityNoManifest' => 'Verificare integritatii fisierelor nu a putut fi efectuata din cauza lipsei manifest.inc.php.',
 	'General_WarningFileIntegrityNoMd5file' => 'Verificare integritatii fisierelor nu a putut fi efectuata din cauza lipsei functiei md5_file()',
@@ -298,6 +314,7 @@ $translations = array(
 	'General_BrokenDownReportDocumentation' => 'Este segmentat in diferite rapoarte, afisate in josul paginii. Puteti mari graficele facand click pe rapoartele pe care doriti sa le vedeti.',
 	'General_ChangeTagCloudView' => 'Va rugam notati, puteti vizualiza rapoartele in alte feluri, pe langa tag cloud. Folositi controalele din josul raportului pentru a face asta',
 	'General_Recommended' => '(recomandat)',
+	'General_NotRecommended' => '(nerecomandat)',
 	'General_Goal' => 'Scop',
 	'General_Outlink' => 'Link extern',
 	'General_Help' => 'Ajutor',
@@ -309,10 +326,47 @@ $translations = array(
 	'General_OneDay' => '1 zi',
 	'General_NDays' => '%s zile',
 	'General_MainMetrics' => 'Metrici principali',
+	'General_Mobile' => 'Mobil',
+	'General_Desktop' => 'Desktop',
+	'General_Rows' => 'Linii',
+	'General_GeneralInformation' => 'Informaţii Generale',
+	'Actions_PluginDescription' => 'Rapoarte despre numărul de pagini văzute, outlink-uri şi descărcări. Outlink-uri şi Descărcările sunt urmărite automat!',
 	'Actions_Actions' => 'Actiune',
 	'Actions_SubmenuPages' => 'Pagini',
+	'Actions_SubmenuPagesEntry' => 'Pagini de intrare',
+	'Actions_SubmenuPagesExit' => 'Pagini de ieşire',
+	'Actions_EntryPageTitles' => 'Titlurile paginilor de intrare',
+	'Actions_ExitPageTitles' => 'Titlurile paginilor de ieşire',
+	'Actions_SubmenuPageTitles' => 'Titluri pagini',
+	'Actions_PageUrls' => 'URL-uri pagini',
 	'Actions_SubmenuOutlinks' => 'Linkuri externe',
 	'Actions_SubmenuDownloads' => 'Descarcari',
+	'Actions_PagesReportDocumentation' => 'Acest raport conţine informaţii despre URL-urile paginilor ce au fost vizitate. %s Acest tabel este organizat ierarhic,URL-urile sunt afişate într-o structură tip arbore.',
+	'Actions_PageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor ce au fost vizitate. %s Titlul paginii este Tag-ul HTML %s afişat de cele mai multe browsere ca nume al ferestrei.',
+	'Actions_OutlinksReportDocumentation' => 'Acest raport arată o listă ierarhică al URL-urilor outlink-urilor ce au fost click-uite de vizitatorii tăi.',
+	'Actions_OutlinkDocumentation' => 'Un outlink este un link ce trimite vizitatori de pe website-ul tău (către alt domeniu).',
+	'Actions_DownloadsReportDocumentation' => 'În acest raport, poţi vedea ce fişiere au fost descărcate de vizitatorii tăi. %s Ceea ce Piwik socoteşte ca fiind o descărcare este un click pe un link de descărcare. Dacă a fost terminată sau nu nu este cunoscut de către Piwik.',
+	'Actions_ColumnClicks' => 'Click-uri',
+	'Actions_ColumnClicksDocumentation' => 'Numărul de ori link-ul a fost click-uit.',
+	'Actions_ColumnUniqueClicks' => 'Click-uri unice.',
+	'Actions_ColumnUniqueClicksDocumentation' => 'Numărul de vizite ce a presupus un click pe acest link. Dacă un link a fost click-uit de mai multe ori în timpul unei vizite, este numărat o dată.',
+	'Actions_ColumnDownloads' => 'Descărcări',
+	'Actions_ColumnUniqueDownloads' => 'Descărcări Unice',
+	'Actions_ColumnOutlinks' => 'Outlink-uri',
+	'Actions_ColumnUniqueOutlinks' => 'Outlink-uri Unice',
+	'Actions_ColumnPageName' => 'Numele Paginii',
+	'Actions_ColumnPageURL' => 'URL-ul Paginii',
+	'Actions_ColumnClickedURL' => 'URL-uri Click-uite',
+	'Actions_ColumnDownloadURL' => 'URL Descărcare',
+	'Actions_ColumnEntryPageURL' => 'URL Paginii de Intrare',
+	'Actions_ColumnEntryPageTitle' => 'Titlul Paginii de Intrare',
+	'Actions_ColumnExitPageURL' => 'URL-ul Paginii de Ieşire',
+	'Actions_ColumnExitPageTitle' => 'Titlul Paginii de Ieşire',
+	'Actions_EntryPagesReportDocumentation' => 'Acest raport conţinte informaţii despre paginile de intrare ce au fost folosite în perioada specificată. O pagină de intrare este prima pagină ce a fost văzută de un vizitator în timpul vizitei sale. %s URL-urile de intrare sunt afişate într-o structură arborescentă.',
+	'Actions_EntryPageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor de intrare ce au fost folosite în timpul perioadei specificate.',
+	'Actions_ExitPagesReportDocumentation' => 'Acest raport conţine informaţii despre paginile de ieşire ce au fost folosite în timpul perioadei specificate. O pagină de ieşire este ultima pagină ce a fost văzută de un vizitator în timpul vizitei sale. %s URL-urile de ieşire sunt afişate ca o structură tip arbore.',
+	'Actions_ExitPageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor de ieşire ce au fost folosite în timpul perioadei specificate.',
+	'AnonymizeIP_PluginDescription' => 'Ascunde ultimele cifre ale IP-ului vizitatorilor pentru a fi în conformitate cu legile privind protecţia datelor personale.',
 	'API_LoadedAPIs' => 'Incarcare de succes %s al API',
 	'CoreHome_CategoryNoData' => 'Nici o data in aceasta categorie. Incearca "Include toata populatia".',
 	'CoreHome_ShowJSCode' => 'Arat codul  javascript ce trebuie folosit',
@@ -405,69 +459,70 @@ $translations = array(
 	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Creaza o copie a fisierului configuratie in %s',
 	'CoreUpdater_InstallingTheLatestVersion' => 'Instaleaza ultima versiune',
 	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik actualizat cu succes!',
+	'Dashboard_PluginDescription' => 'Tabloul tău de control. Poţi particulariza tabloul tău de control: adaugă noi widget-uri, schimbă ordinea widget-urilor. Fiecare utilizator îşi poate accesa tabloul său de control particularizat.',
 	'Dashboard_Dashboard' => 'Tablou de bord',
+	'Dashboard_AddAWidget' => 'Adaugă un widget',
 	'Dashboard_DeleteWidgetConfirm' => 'Esti sigur ca doresti sa stergi dispozitivul din  tabloul de bord ?',
-	'Dashboard_SelectWidget' => 'Selecteaza dispozitivul ce doresti sa-l adaugi in panoul de bord',
+	'Dashboard_SelectWidget' => 'Selecteaza dispozitivul ce doresti sa-l adaugi in tabloul de bord',
+	'Dashboard_AddPreviewedWidget_js' => 'Dă click ca să adaugi un widget la tabloul tău de control',
+	'Dashboard_WidgetPreview_js' => 'Previzualizează widget-ul',
+	'Dashboard_Close_js' => 'Închide',
+	'Dashboard_Maximise_js' => 'Maximizează',
+	'Dashboard_Minimise_js' => 'Minimizează',
 	'Dashboard_TitleWidgetInDashboard_js' => 'Dispozitivul este in tabloul de bord',
-	'Dashboard_TitleClickToAdd_js' => 'Adauga la panoul de bord',
+	'Dashboard_TitleClickToAdd_js' => 'Adauga la tabloul de bord',
 	'Dashboard_LoadingWidget_js' => 'Se incarca dispozitivul, asteapta...',
 	'Dashboard_WidgetNotFound_js' => 'Dispozitivul nu exista',
+	'Dashboard_ResetDashboard' => 'Resetează tabloul de control',
+	'Dashboard_ResetDashboardConfirm' => 'Eşti sigur(ă) că vrei să resetezi aspectul tabloului de control la selecţia implicită de Widget-uri?',
+	'Dashboard_WidgetsAndDashboard' => 'Widget-uri & Tabloul de control',
+	'Dashboard_ChangeDashboardLayout' => 'Schimbă aşezarea tabloului de control',
+	'Dashboard_SelectDashboardLayout' => 'Te rog selectează aşezarea noului tablou de control',
+	'Dashboard_DashboardOf' => 'Tabloul de control %s',
+	'Dashboard_ManageDashboard' => 'Administreză tablou de comandă',
+	'Dashboard_CreateNewDashboard' => 'Creează un tablou de comandă nou',
+	'Dashboard_RenameDashboard' => 'Redenumeşte tabloul de comandă',
+	'Dashboard_DashboardName' => 'Numele tabloului de comandă:',
+	'Dashboard_EmptyDashboard' => 'Tablou de comandă gol - Alege-ţi widget-urile preferate',
+	'Dashboard_DefaultDashboard' => 'Tablou de comandă implicit - Folosind widget-urile selectate şi coloanele implicite',
+	'Dashboard_RemoveDashboard' => 'Şterge tabloul de comandă',
+	'Dashboard_SetAsDefaultWidgets' => 'Stabileşte ca implicită selecţia de widget-uri',
+	'Dashboard_SetAsDefaultWidgetsConfirm' => 'Eşti sigur(ă) că vrei să stabileşti selecţia curentă de widget-uri şi aşezarea tabloului de comandă ca fiind şablonul implicit al tabloului de comandă?',
+	'Dashboard_SetAsDefaultWidgetsConfirmHelp' => 'Această selecţie de widget-uri şi aşezarea coloanelor tabloului de comandă va fi folosită când un utilizator creează un tablou de comandă nou sau când caracteristica "%s" este folosită.',
+	'Dashboard_RemoveDashboardConfirm' => 'Eşti sigur(ă) că vrei să ştergi tabloul de comandă "%s"?',
+	'Dashboard_NotUndo' => 'Nu o să poţi revoca acestă operaţie.',
+	'Dashboard_DashboardEmptyNotification' => 'Tabloul tău de comandă nu conţine niciun widget. Începi prin a adăuga câteva widget-uri sau doar resetează tabloul de comandă către selecţia implicită de widget-uri.',
 	'DBStats_DatabaseUsage' => 'Utilizare baza date',
 	'DBStats_MainDescription' => 'Piwik stocheaza toate datele statistice in baza de date Mysql . Curent, tabela Piwik utilizeaza %s.',
 	'DBStats_Table' => 'Tabela',
 	'DBStats_DataSize' => 'Marime date',
 	'DBStats_IndexSize' => 'Marime index',
 	'DBStats_TotalSize' => 'Marime totala',
-	'Installation_Installation' => 'Installation',
-	'Installation_InstallationStatus' => 'Installation status',
-	'Installation_PercentDone' => '%s %% Done',
-	'Installation_NoConfigFound' => 'The Piwik configuration file couldn\'t be found and you are trying to access a Piwik page.<br /><b>  » You can <a href=\'index.php\'>install Piwik now</a></b><br /><small>If you installed Piwik before and have some tables in your DB, don\'t worry, you can reuse the same tables and keep your existing data!</small>',
 	'Installation_JsTag' => 'Javascript tag',
-	'Installation_Congratulations' => 'Congratulations',
 	'Installation_CongratulationsHelp' => '<p>Congratulations! Your Piwik installation is complete.</p><p>Make sure your javascript code is entered on your pages, and wait for your first visitors!</p>',
-	'Installation_ContinueToPiwik' => 'Continue to Piwik',
 	'Installation_SetupWebsite' => 'Setup a website',
-	'Installation_SetupWebsiteError' => 'There was an error when adding the website',
-	'Installation_SuperUserLogin' => 'super user login',
-	'Installation_Password' => 'password',
-	'Installation_PasswordRepeat' => 'password (repeat)',
-	'Installation_Email' => 'email',
-	'Installation_SecurityNewsletter' => 'email me with major Piwik upgrades and security alerts',
-	'Installation_CommunityNewsletter' => 'email me with community updates (new plugins, new features, etc.)',
-	'Installation_PasswordDoNotMatch' => 'password do not match',
 	'Installation_SystemCheck' => 'System check',
-	'Installation_SystemCheckPhp' => 'PHP version',
-	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
-	'Installation_SystemCheckWriteDirsHelp' => 'To fix this error on your Linux system, try typing in the following command(s)',
-	'Installation_SystemCheckMemoryLimit' => 'Memory limit',
 	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.<br />See the directive memory_limit in your php.ini file if necessary.',
-	'Installation_SystemCheckGD' => 'GD > 2.x (graphics)',
 	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
 	'Installation_SystemCheckTimeLimitHelp' => 'On a high traffic website, executing the archiving process may require more time than currently allowed.<br />See the directive max_execution_time  in your php.ini file if necessary',
-	'Installation_SystemCheckError' => 'An error occured - must be fixed before you proceed',
-	'Installation_SystemCheckWarning' => 'Piwik will work normally but some features may be missing',
 	'Installation_Tables' => 'Creating the tables',
-	'Installation_TablesFound' => 'The following tables have been found in the database',
-	'Installation_TablesWarningHelp' => 'Either choose to reuse the existing database tables or select a clean install to erase all existing data in the database.',
-	'Installation_TablesReuse' => 'Reuse the existing tables',
-	'Installation_TablesDelete' => 'Delete the detected tables',
-	'Installation_TablesDeletedSuccess' => 'Existing Piwik tables deleted with success',
-	'Installation_TablesCreatedSuccess' => 'Tables created with success!',
-	'Installation_DatabaseCreatedSuccess' => 'Database %s created with success!',
 	'Installation_Welcome' => 'Bine ai venit!',
-	'Installation_WelcomeHelp' => '<p>Piwik is an open source web analytics software that makes it easy to get the information you want from your visitors.</p><p>This process is split up into %s easy steps and will take around 5 minutes.</p>',
+	'Login_PluginDescription' => 'Modul de autentintificare, ce citeşte credenţialele din fişierul config/config.inc.php pentru Super User şi din Baza de date pentru alţi useri. Poate fi uşor schimbat pentru a folosi un nou mecanism de Autentificare (OpenID, htaccess, custom Auth, etc.).',
 	'Login_LoginPasswordNotCorrect' => 'Numele si parola nu sunt corecte',
 	'Login_Password' => 'Parola',
+	'Login_PasswordRepeat' => 'Parolă (repetă)',
+	'Login_ChangePassword' => 'Schimbă parola',
 	'Login_LoginOrEmail' => 'Login sau E-mail',
+	'Login_RememberMe' => 'Ţine-mă minte',
 	'Login_LogIn' => 'Intrare',
 	'Login_Logout' => 'Iesire',
 	'Login_LostYourPassword' => 'Ai pierdut parola?',
-	'Login_RemindPassword' => 'Reaminteste-mi parola',
-	'Login_PasswordReminder' => 'Introduce-ti nume si adresa de mail. Vei primi parola pe adresa de mail indicata.',
+	'Login_PasswordsDoNotMatch' => 'Parolele nu se potrivesc.',
 	'Login_InvalidUsernameEmail' => 'Nume/adresa mail invalida',
-	'Login_MailTopicPasswordRecovery' => 'Recuperare parola',
-	'Login_PasswordSent' => 'Parola a fost trimisa. Verifica emailul.',
+	'Login_InvalidOrExpiredToken' => 'Jetonul este invalid sau expirat.',
 	'Login_ContactAdmin' => 'Motiv posibil: gazda ta poate avea dezactivata functia email . <br/>Contactati adminstratorul.',
+	'Login_ExceptionPasswordMD5HashExpected' => 'Parametrul parolei este aşteptat să fie un hash MD5 al parolei.',
+	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Super Userul nu poate fi autentificat folosind \'%s\' mecanism.',
 	'Provider_WidgetProviders' => 'Provideri',
 	'Provider_SubmenuLocationsProvider' => 'Locatie si provideri',
 	'Referers_Referers' => 'Referinte',
@@ -490,22 +545,23 @@ $translations = array(
 	'Referers_WidgetExternalWebsites' => 'Lista siteurilor externe',
 	'Referers_WidgetSearchEngines' => 'Cel mai bun motor cautare',
 	'Referers_WidgetOverview' => 'Rezumat',
+	'SEO_SeoRankings' => 'Poziţionări SEO',
+	'SEO_AlexaRank' => 'Poziţie în Alexa',
+	'SEO_DomainAge' => 'Vechime domeniu',
+	'SEO_Rank' => 'Poziţie',
+	'SEO_Pages' => 'Pagini',
+	'SEO_SEORankingsFor' => 'Poziţionări SEO pentru %s',
 	'SitesManager_Sites' => 'Situri',
 	'SitesManager_WebsitesManagement' => 'Mangementul siteurilor',
 	'SitesManager_MainDescription' => 'Your Web Analytics reports need Websites! Add, update, delete Websites, and show the Javascript to insert in your pages.',
-	'SitesManager_NoWebsites' => 'You don\'t have any website to administrate.',
 	'SitesManager_AddSite' => 'Adauga un site',
 	'SitesManager_Urls' => 'Adresa',
 	'SitesManager_MenuSites' => 'Situri',
-	'SitesManager_DeleteConfirm_js' => 'Are you sure you want to delete the website %s?',
-	'SitesManager_ExceptionDeleteSite' => 'It is not possible to delete this website as it is the only registered website. Add a new website first, then delete this one.',
 	'SitesManager_ExceptionNoUrl' => 'You must specify at least one URL for the site.',
 	'SitesManager_ExceptionEmptyName' => 'The site name can\'t be empty.',
-	'SitesManager_ExceptionInvalidUrl' => 'The url \'%s\' is not a valid URL.',
 	'TranslationsAdmin_MenuTranslations' => 'Traducere',
 	'TranslationsAdmin_MenuLanguages' => 'Limba',
 	'TranslationsAdmin_LanguageCode' => 'Cod limba',
-	'TranslationsAdmin_Plugin' => 'Plugin',
 	'TranslationsAdmin_Definition' => 'Definitie',
 	'TranslationsAdmin_DefaultString' => 'Limba curenta (English)',
 	'TranslationsAdmin_TranslationString' => 'Traducere (Limba curenta: %s)',
@@ -518,8 +574,6 @@ $translations = array(
 	'UserCountry_Continent' => 'Continent',
 	'UserCountry_DistinctCountries' => '%s tari distincte',
 	'UserCountry_SubmenuLocations' => 'Locatie',
-	'UserCountry_WidgetContinents' => 'Continente vizitatori',
-	'UserCountry_WidgetCountries' => 'Tari vizitatori',
 	'UserCountry_country_ac' => 'Ascension Islands',
 	'UserCountry_country_ad' => 'Andorra',
 	'UserCountry_country_ae' => 'United Arab Emirates',
@@ -814,11 +868,8 @@ $translations = array(
 	'UsersManager_User' => 'Utilizator',
 	'UsersManager_PrivNone' => 'Fara acces',
 	'UsersManager_PrivView' => 'Vezi',
-	'UsersManager_PrivAdmin' => 'Admin',
 	'UsersManager_ChangeAllConfirm' => 'Esti sigur ca vrei sa scimbi \'%s\' permisiunile tuturor siteurilor?',
 	'UsersManager_Password' => 'Parola',
-	'UsersManager_Email' => 'Email',
-	'UsersManager_Alias' => 'Alias',
 	'UsersManager_Edit' => 'Editeaza',
 	'UsersManager_AddUser' => 'Adauga user',
 	'UsersManager_MenuUsers' => 'Useri',
@@ -831,7 +882,6 @@ $translations = array(
 	'UsersManager_ExceptionAdminAnonymous' => 'Nu poti autoriza \'admin\' accesul la \'anonymous\' user.',
 	'UsersManager_ExceptionEditAnonymous' => 'Userul anonim nu poate fi editat sau sters.De exemplu poti face ca statisticile tale sa fie publice autorizand \'view\' accesul la \'anonymous\' user.',
 	'UsersManager_ExceptionUserDoesNotExist' => 'User \'%s\' nu exista.',
-	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
 	'VisitFrequency_Evolution' => 'Evolutii peste perioada',
 	'VisitFrequency_ReturnVisits' => '%s vizitatori intorsi',
 	'VisitFrequency_ReturnActions' => '%s actiuni ale vizitatorilor intorsi',
@@ -842,7 +892,6 @@ $translations = array(
 	'VisitorInterest_VisitsPerNbOfPages' => 'Vizite per numar pagini',
 	'VisitorInterest_WidgetLengths' => 'Durata vizitelor',
 	'VisitorInterest_WidgetPages' => 'Pagini per vizita',
-	'VisitorInterest_PlusXMin' => '%s min',
 	'VisitorInterest_OnePage' => '1 pagina',
 	'VisitorInterest_NPages' => '%s pagini',
 	'VisitsSummary_NbVisits' => '%s vizitari',
@@ -855,10 +904,12 @@ $translations = array(
 	'VisitsSummary_WidgetLastVisitors' => 'Grafic ultimi vizitatori unici',
 	'VisitsSummary_WidgetOverviewGraph' => 'Rezumatul grafic',
 	'VisitsSummary_SubmenuOverview' => 'Rezumat',
+	'VisitTime_PluginDescription' => 'Afişează ora locală şi cea a serverului. Timpul serverului poate fi folositor pentru a programa mentenanţa Websiteului.',
 	'VisitTime_LocalTime' => 'Vizite pe timpul local',
 	'VisitTime_ServerTime' => 'Vizite pe timpul serverului',
+	'VisitTime_ColumnServerTime' => 'Ora serverului',
+	'VisitTime_ColumnLocalTime' => 'Ora locală',
 	'VisitTime_WidgetLocalTime' => 'Vizite dupa timpul local',
 	'VisitTime_WidgetServerTime' => 'Vizite dupa timpul serverului',
 	'VisitTime_SubmenuTimes' => 'Timp',
-	'VisitTime_NHour' => '%sh',
 );
