@@ -47,7 +47,6 @@ $translations = array(
 	'General_Name' => 'Meno',
 	'General_Value' => 'Hodnota',
 	'General_Total' => 'Spolu',
-	'General_TotalVisitsActionsRevenue' => '(Spolu: %s návštev, %s akcií, %s príjmov)',
 	'General_AverageOrderValue' => 'Prierná hodnota nákupu',
 	'General_PurchasedProducts' => 'Nakúpené produkty',
 	'General_EcommerceOrders' => 'Ecommerce objednávky',
@@ -191,7 +190,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => 'Zobrazenie jednoduchej tabuľky',
 	'General_DisplayTableWithMoreMetrics' => 'Zobraziť tabuľku s viacerými metrikami',
 	'General_DisplayTableWithGoalMetrics' => 'Zobraziť tabuľku s cieľmi metrík',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s je kolaboratívny projekt. %3$s Ak sa Vám Piwik páči, tak môžete pomôcť! Pozrite sa na %4$sAko prispieť do projektu Piwik?%5$s',
 	'General_YouAreViewingDemoShortMessage' => 'Momentálne vidíte demo Piwiku',
 	'General_DownloadFullVersion' => '%1$sStiahnuť%2$s plnú verziu! Pozri %3$s',
 	'General_NewUpdatePiwikX' => 'Nová aktualizácia: Piwik %s',
@@ -319,13 +317,17 @@ $translations = array(
 	'Actions_SubmenuOutlinks' => 'Externé stránky',
 	'Actions_SubmenuDownloads' => 'Sťahovania',
 	'Actions_ColumnClicks' => 'Kliknutia',
+	'Actions_ColumnClicksDocumentation' => 'Počet kliknutí na odkaz.',
 	'Actions_ColumnUniqueClicks' => 'Jedinečné kliknutia',
 	'Actions_ColumnDownloads' => 'Sťahovania',
 	'Actions_ColumnUniqueDownloads' => 'Jedinečné sťahovania',
+	'Actions_ColumnOutlinks' => 'Konkajšie odkazy',
 	'Actions_ColumnPageName' => 'Názov stránky',
 	'Actions_ColumnPageURL' => 'Adresa stránky',
 	'Actions_ColumnClickedURL' => 'Kliknutí na odkaz',
 	'Actions_ColumnDownloadURL' => 'Stiahnuté URL',
+	'Actions_ColumnExitPageURL' => 'URL výstupnej stránky',
+	'Actions_ColumnExitPageTitle' => 'Titulok výstupnej stránky',
 	'AnonymizeIP_PluginDescription' => 'Anonymnosť posledný bajt IP adresy návštevníkov v súlade s miestnymi zákonmi na ochranu súkromia.',
 	'API_UserAuthentication' => 'Overenie užívateľa',
 	'API_LoadedAPIs' => 'Úspešne načítané %s API',
@@ -552,16 +554,9 @@ $translations = array(
 	'Login_LogIn' => 'Prihlásiť sa',
 	'Login_Logout' => 'Odhlásiť sa',
 	'Login_LostYourPassword' => 'Zabudli ste heslo?',
-	'Login_RemindPassword' => 'Pripomenúť heslo',
-	'Login_PasswordResetToken' => 'Token pre obnovenie hesla',
-	'Login_PasswordReminder' => 'Vložte prosím svoje meno používateľa alebo e-mailovú adresu. E-mailom Vám bude doručené nové heslo.',
 	'Login_PasswordsDoNotMatch' => 'Heslá sa nezhodujú.',
-	'Login_PasswordSuccessfullyChanged' => 'Heslo úspešne zmenené!',
 	'Login_InvalidUsernameEmail' => 'Neplatné meno používateľa alebo e-mailová adresa',
 	'Login_InvalidOrExpiredToken' => 'Token je neplatný, alebo už vypršal.',
-	'Login_MailTopicPasswordRecovery' => 'Obnova hesla',
-	'Login_MailPasswordRecoveryBody' => 'Ahoj %1$s, heslo bolo zmenené a žiadosť bola doručená %2$s. Ak chcete obnoviť vaše heslo: 1) Choďte na formulár Obnovenie hesla na adrese: %3$s 2) Zadajte nasledujúci token: %4$s 3) Vyplňte formulár (zadajte nové heslo dvakrát) a odošlite. Poznámka: tento token vyprší za 24 hodín.',
-	'Login_PasswordSent' => 'Heslo bolo práve odoslané. Skontrolujte si e-mail.',
 	'Login_ContactAdmin' => 'Možné dôvody: Váš server ma zakázanú funkciu mail().<br /> Skontaktujte svojho administrátora Piwik.',
 	'Login_ExceptionPasswordMD5HashExpected' => 'Očakávajte že heslo bude v MD5 hash.',
 	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Super používateľ nemôže overiť pomocou \'%s\' mechanizmu.',
@@ -612,7 +607,6 @@ $translations = array(
 	'SEO_AlexaRank' => 'Alexa hodnotenie',
 	'SEO_DomainAge' => 'Vek domény',
 	'SEO_Rank' => 'Hodnotenie',
-	'SEO_Backlinks' => 'Spätné linky',
 	'SEO_Pages' => 'Stránky',
 	'SEO_SEORankingsFor' => 'SEO hodnotenie pre %s',
 	'SitesManager_Sites' => 'Stránky',
@@ -648,8 +642,6 @@ $translations = array(
 	'UserCountry_DistinctCountries' => 'Počet rôznych krajín: %s',
 	'UserCountry_Location' => 'Miesto',
 	'UserCountry_SubmenuLocations' => 'Umiestnenie',
-	'UserCountry_WidgetContinents' => 'Návštevníci z kontinentov',
-	'UserCountry_WidgetCountries' => 'Návštevníci z krajín',
 	'UserCountry_country_ac' => 'Ostrov Ascension',
 	'UserCountry_country_ad' => 'Andora',
 	'UserCountry_country_ae' => 'Spojené arabské emiráty',
@@ -1028,7 +1020,6 @@ $translations = array(
 	'VisitsSummary_MaxNbActions' => 'Max. akcií na jednu návštevu: %s',
 	'VisitsSummary_NbActionsPerVisit' => '%s akcia za návštevu',
 	'VisitsSummary_NbVisitsBounced' => '%s návštev odskočilo (odišli po zobrazení jednej stránky)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Vývoj za posledné %s',
 	'VisitsSummary_GenerateTime' => '%s sekúnd na vygenerovanie strany',
 	'VisitsSummary_GenerateQueries' => 'spustené požiadavky: %s',
 	'VisitsSummary_WidgetLastVisits' => 'Graf posledných návštev',
@@ -1058,4 +1049,7 @@ $translations = array(
 	'PDFReports_PiwikReports' => 'Reporty',
 	'PDFReports_EmailHello' => 'Ahoj,',
 	'PDFReports_PleaseFindAttachedFile' => 'Nájdete v priloženom súbore %1$s reporte pre %2$s.',
+
+	// FOR REVIEW
+	'GeoIP_ColumnCity' => 'Mesto',
 );
