@@ -1,16 +1,18 @@
 <?php
 $translations = array(
 	'General_Locale' => 'sl_SI.UTF-8',
-	'General_TranslatorName' => 'Aleksej Lazanski',
-	'General_TranslatorEmail' => 'alazanski@tuts23.com',
+	'General_TranslatorName' => 'Aleksej Lazanski, Tom Merc',
+	'General_TranslatorEmail' => 'alazanski@tuts23.com, tom@hupso.com',
 	'General_EnglishLanguageName' => 'Slovenian',
 	'General_OriginalLanguageName' => 'Slovenščina',
+	'General_LayoutDirection' => 'ltr',
 	'General_HelloUser' => 'Pozdravljen, %s!',
 	'General_OpenSourceWebAnalytics' => 'Odprtokodna Spletna Analitika',
 	'General_Dashboard' => 'Nadzorna Plošča',
-	'General_DashboardForASpecificWebsite' => 'Nazdporna plošča za določeno spletno stran',
+	'General_DashboardForASpecificWebsite' => 'Nadzorna plošča za določeno spletno stran',
 	'General_MultiSitesSummary' => 'Vse Spletne Strani',
 	'General_AllWebsitesDashboard' => 'Vse nadzorne plošče spletnih strani',
+	'General_SingleWebsitesDashboard' => 'Nadzorna plošča posamezne spletne strani',
 	'General_API' => 'API',
 	'General_Widgets' => 'Gradniki',
 	'General_Settings' => 'Nastavitve',
@@ -29,24 +31,29 @@ $translations = array(
 	'General_Delete' => 'Izbriši',
 	'General_Report' => 'Poročilo',
 	'General_Reports' => 'Poročila',
+	'General_RelatedReport' => 'Povezano poročilo',
+	'General_RelatedReports' => 'Povezana poročila',
+	'General_Metric' => 'Metrika',
+	'General_Metrics' => 'Metrike',
 	'General_Edit' => 'Uredi',
 	'General_Download' => 'Prenesi',
 	'General_Upload' => 'Naloži',
 	'General_Ok' => 'Ok',
 	'General_Close' => 'Zapri',
+	'General_Cancel' => 'Prekliči',
 	'General_OrCancel' => 'ali %s Prekliči %s',
 	'General_Logout' => 'Izpis',
-	'General_Username' => 'Uporaniško Ime',
+	'General_Username' => 'Uporabniško Ime',
 	'General_Description' => 'Opis',
 	'General_Done' => 'Narejeno',
 	'General_PoweredBy' => 'Poganja',
 	'General_MetricsToPlot' => 'Metrično v spletko',
 	'General_RowsToDisplay' => 'Vrst za prikaz',
 	'General_MetricToPlot' => 'Metrično v spletko',
+	'General_RecordsToPlot' => 'Zapisi za prikaz',
 	'General_Name' => 'Ime',
 	'General_Value' => 'Vrednost',
 	'General_Total' => 'Skupaj',
-	'General_TotalVisitsActionsRevenue' => '(Skupaj: %s obiskov, %s dejanj, %s izkupiček)',
 	'General_AverageOrderValue' => 'Povprečna vrednost naročila',
 	'General_PurchasedProducts' => 'Kupljeni Izdelki',
 	'General_EcommerceOrders' => 'Ecommerce Naročila',
@@ -56,6 +63,7 @@ $translations = array(
 	'General_AveragePrice' => 'Povprečna Cena',
 	'General_AverageQuantity' => 'Povprečna Količina',
 	'General_UniquePurchases' => 'Edinstveni Nakupi',
+	'General_ProductConversionRate' => 'Stopnja konverzije izdelka',
 	'General_Quantity' => 'Količina',
 	'General_Price' => 'Cena',
 	'General_Subtotal' => 'Vmesni seštevek',
@@ -76,6 +84,7 @@ $translations = array(
 	'General_NumberOfVisits' => 'Število obiskov',
 	'General_VisitConvertedGoal' => 'Obisk je spreobrnil vsaj en Cilj',
 	'General_VisitConvertedGoalId' => 'Obisk je spreobrnil specifičen Id Cilja',
+	'General_EcommerceVisitStatus' => 'Obiščite \'Status naročil\' na koncu obiska. Na primer, za izbiro vseh ob obiskov, ki so opravili naročilo, bi API zahtevek vseboval %s',
 	'General_VisitConvertedNGoals' => 'Obisk spreobrnil %s Ciljev',
 	'General_NewVisitor' => 'Nov Obiskovalec',
 	'General_NewVisits' => 'Novi obiski',
@@ -96,6 +105,8 @@ $translations = array(
 	'General_InvalidDateRange_js' => 'Neveljaven Datumski Razpon. Prosimo, Poskusite Znova',
 	'General_DateRangeFrom_js' => 'Od',
 	'General_DateRangeTo_js' => 'Za',
+	'General_LastDaysShort' => 'Zadnjih %s dni',
+	'General_PreviousDaysShort' => 'Prejšnjih %s dni',
 	'General_PreviousDays' => 'Prejšnjih %s dni (brez današnjega dne)',
 	'General_LastDays' => 'Zadnjih %s dni (vklj. z današ. dnem)',
 	'General_LoadingData' => 'Nalagam podatke...',
@@ -118,6 +129,7 @@ $translations = array(
 	'General_ExportThisReport' => 'Izvoti to razpredelnico v drugih formatih',
 	'General_ExportAsImage_js' => 'Izvozi kot Sliko',
 	'General_Export' => 'Izvozi',
+	'General_ParameterMustIntegerBetween' => 'Parameter %s mora biti celo število med %s in %s.',
 	'General_YourChangesHaveBeenSaved' => 'Vaše spremembe so bile shranjene.',
 	'General_ErrorRequest' => 'Opa... Med zahtevo je prišlo do napake. Prosimo, poskusite znova.',
 	'General_ColumnNbUniqVisitors' => 'Edinstveni Obiskovalci',
@@ -126,6 +138,7 @@ $translations = array(
 	'General_ColumnNbVisitsDocumentation' => 'V primeru da pride obiskovalec na vašo spletno stran prvič, ali pa je njegov obisk daljši od 30 minut, se bo to štelo kot novi obisk.',
 	'General_ColumnPercentageVisits' => '% Obiskov',
 	'General_ColumnNbActions' => 'Dejanj',
+	'General_ColumnNbActionsDocumentation' => 'Število akcij obiskovalcev. Akcije so lahko prikazi strani, prenosi ali izhodi preko zunanjih povezav.',
 	'General_NbActions' => 'Šttevilo Dejanj',
 	'General_ColumnMaxActions' => 'Maksimalno dejanj v enem obisku',
 	'General_ColumnSumVisitLength' => 'Skupni čas, ki so ga porabili obiskovalci (v sekundah)',
@@ -149,6 +162,7 @@ $translations = array(
 	'General_ColumnUniquePageviews' => 'Edinstvenih Ogledov Strani',
 	'General_ColumnUniquePageviewsDocumentation' => 'Število obiskov, ki so vključevali to stran. V primeru, da je bila stran ogledana večkrat, se to šteje kot le-en ogled.',
 	'General_ColumnBounces' => 'Odbojev',
+	'General_ColumnBouncesDocumentation' => 'Število obiskov, ki so se začeli in končali na tej strani. To pomeni, da je obiskovalec odšel po ogledu ene same strani.',
 	'General_ColumnUniqueEntrances' => 'Edinstveni vhodi',
 	'General_ColumnEntrances' => 'Vhodov',
 	'General_ColumnEntrancesDocumentation' => 'Število obiskov, ki so se začeli na tej strani.',
@@ -156,6 +170,7 @@ $translations = array(
 	'General_ColumnUniqueExits' => 'Edinstveni izhodi',
 	'General_ColumnExitsDocumentation' => 'Število obiskov, ki so se zaključili na tej strani.',
 	'General_ColumnAverageTimeOnPage' => 'Povpr. čas na strani',
+	'General_TimeOnPage' => 'Čas na strani',
 	'General_ColumnAverageTimeOnPageDocumentation' => 'Povprečen čas, ki so ga obiskovalci porabili na tej strani (samo na strani, ne na celotni spletni strani).',
 	'General_ColumnValuePerVisit' => 'Vrednost na Obisk',
 	'General_ColumnVisitsWithConversions' => 'Obiski s Spreobrnitvami',
@@ -172,21 +187,32 @@ $translations = array(
 	'General_Website' => 'Spletna stran',
 	'General_GeneralSettings' => 'Splošne Nastavitve',
 	'General_AllowPiwikArchivingToTriggerBrowser' => 'Dovoli, da se akitivira Piwik arhiviranje, ko se poročila ogledujejo v brskalniku.',
+	'General_ArchivingInlineHelp' => 'Za srednje velike in velike spletne strani izklopite arhiviranje preko spletnega brskalnika. Namesto tega vam priporočamo, da nastavite "cron job" tako, da bodo poročila ustvarjena vsako uro.',
+	'General_ArchivingTriggerDescription' => 'Priporočamo za večje namestitve. %sNastavite "cron job"%s za avtomatsko procesiranje.',
 	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Za več informacij, si oglejte %suradno dokumentacijo%s.',
+	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Današnja poročila (ali kak drug časovni razpon, ki vključuje današnji dan) bodo procesirana vsakih',
 	'General_NSeconds' => '%s sekund',
+	'General_SmallTrafficYouCanLeaveDefault' => 'Za manjše spletne strani lahko pustite privzetih %s sekund in dostopate do poročil v realnem času.',
+	'General_MediumToHighTrafficItIsRecommendedTo' => 'Za srednje velike in velike spletne strani vam priporočamo, da procesirate poročila največ na pol ure (%s sekund) ali na eno uro (%s sekund).',
 	'General_RequiresFlash' => 'Za prikazovanje Grafov v Piwik-u potrebujete Flash',
 	'General_GraphHelp' => 'Več informacij o prikazovanju Grafov v Piwik-u.',
 	'General_NoDataForGraph' => 'Nobenih podatkov za ta graf.',
+	'General_DataForThisGraphHasBeenPurged' => 'Podatki za ta graf so stari več kot %s mesecev in so bili izbrisani.',
 	'General_NoDataForTagCloud' => 'Ni podatkov za oblaček z etiketami',
+	'General_DataForThisTagCloudHasBeenPurged' => 'Podatki za ta oblak oznak so stari več kot %s mesecev in so bili izbrisani.',
 	'General_DisplaySimpleTable' => 'Prikaži preprosto tabelo',
 	'General_DisplayTableWithMoreMetrics' => 'Prikaži podrobnejšo tabelo',
 	'General_DisplayTableWithGoalMetrics' => 'Prikaži tabelo z metričnimi cilji',
 	'General_YouAreViewingDemoShortMessage' => 'Trenutno si ogledujete Piwik v demo načinu',
+	'General_YouAreCurrentlyUsing' => 'Trenutno uporabljate Piwik %s.',
 	'General_DownloadFullVersion' => '%1$sPrenesite%2$s celotno verzijo! Oglejte si %3$s',
 	'General_NewUpdatePiwikX' => 'Nova Posodobitev: Piwik %s',
 	'General_AboutPiwikX' => 'O Piwik %s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s je na voljo. %2$sProsimo posodobite ga zdaj!ow!%3$s (oglejte si %4$sspremembe%5$s).',
 	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s je na voljo. Prosimo, da o tem obvestite skrbnika strani.',
+	'General_NewReportsWillBeProcessedByCron' => 'Ko se arhiviranje ne sproži preko brskalnika, bodo nova poročila generirana preko crontaba.',
+	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Poročila bodo torej generirana največ vsako uro.',
+	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Če bo arhiviranje na vašem sistemu hitro, lahko popravite crontab, tako da se bo arhiviranje zagnalo pogosteje.',
 	'General_BackToPiwik' => 'Nazaj na Piwik',
 	'General_ClickHere' => 'Za več informacij, kliknite tu.',
 	'General_ShortMonth_1' => 'Jan',
@@ -230,19 +256,43 @@ $translations = array(
 	'General_Daily' => 'Dnevno',
 	'General_Weekly' => 'Tedensko',
 	'General_Monthly' => 'Mesečno',
+	'General_DailyReports' => 'Dnevna poročila',
+	'General_WeeklyReports' => 'Tedenska poročila',
+	'General_MonthlyReports' => 'Mesečna poročila',
+	'General_YearlyReports' => 'Letna poročila',
+	'General_RangeReports' => 'Časovni razpon po meri',
 	'General_ConfigFileIsNotWritable' => 'Piwik-ova konfiguracijska datoteka %s ni zapisljiva, zato nekaterih vaših sprememb ni bilo mogoče shraniti. %s Prosimo, da spremenite dovoljenja konfiguracijske datoteke tako, da bo zapisljiva.',
 	'General_ExceptionDatabaseVersion' => 'Vaša %1$s verzija je %2$s, vendar Piwik potrebuje vsaj %3$s.',
+	'General_ExceptionIncompatibleClientServerVersions' => 'Vaša %1$s različica odjemalca je %2$s, ki je nezdružljiva s strežniško različico %3$s.',
 	'General_ExceptionMissingFile' => 'Manjkajoča datoteka: %s',
+	'General_ExceptionFilesizeMismatch' => 'Velikost datoteke se ne ujema: %1$s (pričakovana dolžina: %2$s, najdeno: %3$s)',
 	'General_ExceptionFileIntegrity' => 'Preverjanje integritete ni bilo uspešno: %s',
+	'General_ExceptionNonceMismatch' => 'Ne morem preveriti varnostnega žetona na tem obrazcu.',
 	'General_PleaseSpecifyValue' => 'Prosimo, navedite vrednost za "%s"',
+	'General_ExceptionMethodNotFound' => 'Metoda \'%s\' ne obstaja ali ni na voljo v modulu \'%s\'.',
+	'General_ExceptionInvalidRendererFormat' => 'Oblika prikaza \'%s\' ni pravilna. Namesto tega poskusite kaj od tega: %s.',
+	'General_ExceptionInvalidReportRendererFormat' => 'Oblika poročila \'%s\' ni pravilna. Namesto tega poskusite kaj od tega: %s.',
+	'General_ExceptionInvalidStaticGraphType' => 'Tip statičnega grafa \'%s\' ni pravilen. Namesto tega poskusite kaj od tega: %s.',
+	'General_ExceptionInvalidAggregateReportsFormat' => 'Oblika skupnega poročila \'%s\' ni pravilna. Namesto tega poskusite kaj od tega: %s.',
+	'General_ExceptionInvalidPeriod' => 'Obdobje \'%s\' ni podprto. Namesto tega poskusite kaj od tega: %s.',
+	'General_ExceptionInvalidDateRange' => '\'%s\' ni pravilen datumski razpon. Moral bi imeti naslednjo obliko: %s.',
+	'General_ExceptionGoalNotFound' => 'Cilja z id = %s ni mogoče najti.',
 	'General_ExceptionUndeletableFile' => '%s ni možno izbrisati.',
 	'General_ExceptionPrivilege' => 'Ne morete dostopati do tega vira, saj je za to potreben %s dostop.',
+	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Ne morete dostopati do tega vira, ker potrebujete %s dostop za vsaj eno spletno stran.',
+	'General_ExceptionPrivilegeAccessWebsite' => 'Ne morete dostopati do tega vira, ker potrebujete %s dostop za spletno stran z id = %d.',
+	'General_ExceptionInvalidArchiveTimeToLive' => '"Today archive time to live" mora biti število sekund več kot nič.',
 	'General_ExceptionConfigurationFileNotFound' => 'Konfiguracijska datoteka {%s} ni bila najdena.',
 	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfiguracijske datoteke {%s} ni bilo mogoče prebrati. Možno je, da je vaš gostitelj onemogočil %s.',
 	'General_ExceptionInvalidToken' => 'Žeton ni veljaven.',
+	'General_ExceptionInvalidDateFormat' => 'Oblika datuma mora biti: %s ali katerakoli ključna beseda, podprta v funkciji %s (oglejte si %s za več informacij)',
 	'General_ExceptionLanguageFileNotFound' => 'Jezikovne datoteke "%s" ni bilo mogoče najti.',
+	'General_ExceptionUnableToStartSession' => 'Ne morem začeti seje.',
+	'General_ExceptionCheckUserIsSuperUserOrTheUser' => 'Uporabnik mora biti administrator ali uporabnik \'%s\'.',
 	'General_WarningFileIntegritySkipped' => 'Zaznano je bilo razvojno okolje. Pregled integritete datotek je bil preskočen.',
 	'General_WarningFileIntegrityNoManifest' => 'Pregleda integritete datotek ni bilo mogoče izvesti, saj manjka manifest.inc.php.',
+	'General_WarningFileIntegrityNoMd5file' => 'Ne morem preveriti integritete datoteke, ker manjka funkcija md5_file().',
+	'General_FileIntegrityWarningExplanation' => 'Preverjanje integritete ni uspelo in je javilo neke napake. Vzrok za to so verjetno nekatere Piwik datoteke, ki so se delno ali narobe prenesle. Ponovno morate prenesti vse Piwik datoteke na strežnik v BINARY načinu in osvežiti to stran, tako da ne bo več vidne nobene napake.',
 	'General_UseSMTPServerForEmail' => 'Uporabljaj SMTP strežnik za e-pošto',
 	'General_SmtpServerAddress' => 'Naslov SMTP strežnika',
 	'General_SmtpPort' => 'SMTP Vrata',
@@ -250,38 +300,66 @@ $translations = array(
 	'General_SmtpUsername' => 'SMTP uporabniško ime',
 	'General_SmtpPassword' => 'SMTP geslo',
 	'General_SmtpEncryption' => 'SMTP enkripcija',
+	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Izberite "da" če želite pošiljanje emaila preko strežnika, namesto preko lokalne mail funkcije',
+	'General_OptionalSmtpPort' => 'Neobvezno. Privzeto je 25 za nekriptiran prometi in za TLS SMTP. 465 za SSL SMTP.',
 	'General_OnlyUsedIfUserPwdIsSet' => 'Uporabljeno samo če je nastavljeno uporabniško ime in geslo. Če niste prepričani katero metodo bi uporabili, prosmo kontaktirajte vašega ponudnika.',
 	'General_OnlyEnterIfRequired' => 'Uporabniško ime vnesite le, če to zahteva vaš SMTP strežnik.',
 	'General_OnlyEnterIfRequiredPassword' => 'Geslo vnesite le, če to zahteva vaš SMTP strežnik.',
 	'General_WarningPasswordStored' => '%sPozor:%s To geslo bo shranjeno v config datoteki. Tako bo vidna vsem, ki imajo dostop do te datoteke.',
+	'General_EncryptedSmtpTransport' => 'Vnesite nivo enkripcije, ki jo uporablja vaš SMTP strežnik.',
 	'General_InvalidResponse' => 'Prejeti podatki niso pravilni.',
 	'General_ChooseLanguage' => 'Izberite jezik',
 	'General_ChoosePeriod' => 'Izberite obdobje',
 	'General_ChooseWebsite' => 'Izberite spletno stran',
 	'General_Language' => 'Jezik',
 	'General_PleaseUpdatePiwik' => 'Prosimo, da posodobite Piwik',
+	'General_RequestTimedOut' => 'Podatkovna zahteva za %s je pretekla. Prosimo, poskusite znova.',
 	'General_UsePlusMinusIconsDocumentation' => 'Uporabite plus in minus ikoni na levi za navigacijo.',
+	'General_BrokenDownReportDocumentation' => 'Razčlenjen je na različna poročila, ki so prikazana z grafi na dnu strani. grafe lahko povečate s klikov na poročilo, ki bi si ga radi ogledali.',
+	'General_ChangeTagCloudView' => 'Zavedajte se, da si lahko ogledate proočila na drugačne načine kot oblak oznak. Za spremembo uporabite izbire na dnu poročila.',
 	'General_Recommended' => '(priporočano)',
+	'General_NotRecommended' => '(ni priporočljivo)',
 	'General_Goal' => 'Cilj',
 	'General_Outlink' => 'Izhodna povezaba',
 	'General_Help' => 'Pomoč',
+	'General_DailySum' => 'dnevna vsota',
 	'General_AfterEntry' => 'po tukajšnjem vstopu',
 	'General_Metadata' => 'Metadata',
 	'General_OneVisit' => '1 obisk',
 	'General_NVisits' => '%s obiskov',
 	'General_OneDay' => '1 dan',
 	'General_NDays' => '%s dni',
+	'General_MainMetrics' => 'Glavna meterika',
+	'General_Mobile' => 'Mobilno',
+	'General_Desktop' => 'Namizno',
+	'General_Rows' => 'Vrstice',
+	'General_GeneralInformation' => 'Splošne informacije',
+	'General_ReportGeneratedFrom' => 'To poročilo je bilo ustvarjeno s podatki iz %s.',
+	'Actions_PluginDescription' => 'Poročila o prikazih strani, izhodih preko zunanjih povezav in prenosih. Sledenje prenosom in izhodom preko zunanjih povezav je samodejno.',
 	'Actions_Actions' => 'Dejanja',
 	'Actions_SubmenuPages' => 'Strani',
 	'Actions_SubmenuPagesEntry' => 'Vstopne strani',
+	'Actions_WidgetPagesEntry' => 'Vstopne strani',
 	'Actions_SubmenuPagesExit' => 'Izhodne strani',
+	'Actions_WidgetPagesExit' => 'Izhodne strani',
+	'Actions_EntryPageTitles' => 'Nazivi vhodnih strani',
+	'Actions_WidgetEntryPageTitles' => 'Naslovi vstopnih strani',
+	'Actions_ExitPageTitles' => 'Nazivi izhodnih strani',
+	'Actions_WidgetExitPageTitles' => 'Naslovi izhodnih strani',
 	'Actions_SubmenuPageTitles' => 'Naslovi strani',
+	'Actions_WidgetPageTitles' => 'Naslovi strani',
 	'Actions_PageUrls' => 'URL-ji strani',
 	'Actions_SubmenuOutlinks' => 'Izhodne povezave',
 	'Actions_SubmenuDownloads' => 'Prenosi',
+	'Actions_PagesReportDocumentation' => 'To poročilo vsebuje informacije o URL-jih strani, ki so bile obiskane. %s Tabela je hierarhično organizirana. URL-ji so prikazani kot struktura mape.',
+	'Actions_PageTitlesReportDocumentation' => 'To poročilo vsebuje informacije o nazivih strani, ki so bile obiskane. %s Naziv strani je HTML oznaka %s Oznaka, ki jo večina brskalnikov prikaže v nazivu okna.',
+	'Actions_OutlinksReportDocumentation' => 'To poročilo prikazuje hierarhični seznam URL-jev zunanjih povezav na katere so uporabniki kliknili.',
+	'Actions_OutlinkDocumentation' => 'Zunanja povezava je povezava, ki vodi obiskovalca stran od vaše splete strani (na drugo domeno).',
+	'Actions_DownloadsReportDocumentation' => 'V tem poročilu lahko visite, katere datoteke so prenesli vaši uporabniki. %s Piwik šteje vse klike na povezavo za prenos. Piwik ne ve ali je bila datoteka uspešno prenesena.',
 	'Actions_ColumnClicks' => 'Kliki',
 	'Actions_ColumnClicksDocumentation' => 'Število klikov na to povezavo.',
 	'Actions_ColumnUniqueClicks' => 'Edinstveni Kliki',
+	'Actions_ColumnUniqueClicksDocumentation' => 'Število obiskov, ki so vsebovali klik na to povezavo. Če je bilo klikov na isto povezavo več v istem obisku, se to šteje kot en sam klik.',
 	'Actions_ColumnDownloads' => 'Prenosi',
 	'Actions_ColumnUniqueDownloads' => 'Edinstveni Prenosi',
 	'Actions_ColumnOutlinks' => 'Izhodne povezave',
@@ -294,13 +372,24 @@ $translations = array(
 	'Actions_ColumnEntryPageTitle' => 'Naslov vstopne strani',
 	'Actions_ColumnExitPageURL' => 'URL izhodne strani',
 	'Actions_ColumnExitPageTitle' => 'Naslov izhodne strani',
+	'Actions_EntryPagesReportDocumentation' => 'To poročilo vsebuje informacije o vhodnih straneh, ki so bile obiskane v izbranem časovnem obdobju. Vhodna stran je prva stran, ki si jo je obiskovalec ogledal med svojim obiskom. %s Vhodni URL naslovi so prikazani kot struktura mape.',
+	'Actions_EntryPageTitlesReportDocumentation' => 'To poročilo vsebuje informacije o nazivih vhodnih strani, ki so bile obiskane v izbranem časovnam obdobju.',
+	'Actions_ExitPageTitlesReportDocumentation' => 'To poročilo vsebuje informacije o nazivih izhodnih strani, ki so bile obiskane v izbranem časovnam obdobju.',
+	'AnonymizeIP_PluginDescription' => 'Anonimiziraj zadnji bajt IP naslova obiskovalca, da se s tem izpolnijo zahteve lokalnih zakonov/smernic o zasebnosti.',
+	'API_PluginDescription' => 'Vsi podatki v Piwiku so na voljo preko prepreostega API vmesnika. Ta vtičnik je vstopna točka spletne storitve, ki jo lahko pokličete, če želite svoje podatke preko xml, json, php, csv, itd.',
 	'API_QuickDocumentationTitle' => 'API hitra dokumentacija',
+	'API_GenerateVisits' => 'Če nimate današnjih podatkov, potem lahko najprej ustvarite nekaj podatkov s %s vtičnikom. Vtičnik %s lahko omogočite in nato kliknete na \'Visitor Generator\' meni v Piwik administraciji.',
+	'API_MoreInformation' => 'Za več informacij o Piwik API-ju, si oglejte %sNavodila za uporabo Piwik API-ja %s in %s Piwik API Reference %s.',
 	'API_UserAuthentication' => 'Overitev uporabnika',
+	'API_UsingTokenAuth' => 'Če želite %s zahtevati podatke preko skripte, crontaba, itd. %s potem morate dodati parameter %s v URL API klica za overitev.',
+	'API_KeepTokenSecret' => 'Ta žeton je skriven, kot vaše uporabniško ime in geslo, %s ne delite ga z drugimi %s!',
 	'API_LoadedAPIs' => 'Uspešno naloženih %s API-jev',
-	'CoreAdminHome_PluginDescription' => 'Piwik-ovo administrativno okolje.',
+	'CoreAdminHome_PluginDescription' => 'Administrativno okolje Piwik.',
 	'CoreAdminHome_MenuGeneralSettings' => 'Splošne nastavitve',
 	'CoreAdminHome_Administration' => 'Administracija',
 	'CoreAdminHome_EmailServerSettings' => 'Nastavitev strežnika za email',
+	'CoreAdminHome_OptOutForYourVisitors' => '\'Opt-out\' za vaše obiskovalce',
+	'CoreAdminHome_OptOutExplanation' => 'Piwik želi zagotoviti zasebnost na internetu. Če želite svojim obiskovalcem omogočiti \'opt-out\' iz Piwik spletne analitike, potem lahko dodate naslednjo HTML kodo na vašo spletno stran, npr. na stran \'Varovanje zasebnosti\'.',
 	'CoreAdminHome_YouAreOptedIn' => 'Trenutno ste pridruženi.',
 	'CoreAdminHome_YouAreOptedOut' => 'Trenutno niste pridruženi.',
 	'CoreAdminHome_ClickHereToOptOut' => 'Kliknite tu, če želite odstopiti.',
@@ -322,6 +411,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Za to poročilo ni podatkov.',
 	'CoreHome_CategoryNoData' => 'V tej kategoriji ni podatkov. Poizkusite "Vključiti celotno populacijo".',
 	'CoreHome_ShowJSCode' => 'Prikaži JavaScript kodo za vstavljanje',
+	'CoreHome_Default_js' => 'privzeto',
 	'CoreHome_PageOf_js' => '%1$s od %2$s',
 	'CoreHome_PeriodDay' => 'Dan',
 	'CoreHome_PeriodWeek' => 'Teden',
@@ -433,6 +523,7 @@ $translations = array(
 	'Dashboard_AddPreviewedWidget_js' => 'Kliknite, če želite dodati gradnik na kontrolno ploščo',
 	'Dashboard_WidgetPreview_js' => 'Predogled gradnika',
 	'Dashboard_Close_js' => 'Zapri',
+	'Dashboard_Refresh_js' => 'Osveži',
 	'Dashboard_Maximise_js' => 'Povečaj',
 	'Dashboard_Minimise_js' => 'Pomanjšaj',
 	'Dashboard_TitleWidgetInDashboard_js' => 'Gradnik je že na v kontrolni plošči',
@@ -484,6 +575,7 @@ $translations = array(
 	'Goals_AbandonedCart' => 'Opuščen voziček',
 	'Goals_GoalsOverview' => 'Pregled ciljev',
 	'Goals_GoalsManagement' => 'Upravljanje ciljev',
+	'Goals_ColumnRevenue' => 'Prihodki',
 	'Goals_GoalX' => 'Cilj %s',
 	'Goals_GoalConversion' => 'Spreobrnitev cilja',
 	'Goals_GoalConversions' => 'Spreobrnitve ciljev',
@@ -495,6 +587,7 @@ $translations = array(
 	'Goals_WhenVisitors' => 'ko obiskovalci',
 	'Goals_Manually' => 'ročno',
 	'Goals_URL' => 'URL',
+	'Goals_PageTitle' => 'Naslov strani',
 	'Goals_Filename' => 'ime datoteke',
 	'Goals_Download' => 'Prenesite datoteko',
 	'Goals_Optional' => '(opcijsko)',
@@ -546,10 +639,11 @@ $translations = array(
 	'Installation_Welcome' => 'Dobrodošli!',
 	'LanguagesManager_PluginDescription' => 'Ta vtičnik bo prikazoval seznam vseh jezikov, ki so na voljo za Piwik-ov vmesnik. Izbrani jezik bo shranjen v nastavitvah vsakega uporabnika.',
 	'LanguagesManager_AboutPiwikTranslations' => 'O prevodih Piwik-a',
-	'Live_PluginDescription' => 'Vohunite za vašimi obiskovalci, v živo!',
+	'Live_PluginDescription' => 'Opazujte vaše obiskovalce v živo!',
 	'Live_LinkVisitorLog' => 'Ogled podrobnega dnevnika obiskovalcev',
 	'Live_Actions' => 'Dejanja',
 	'Live_Action' => 'Dejanje',
+	'Live_VisitorsInRealTime' => 'Obiskovalci v živo',
 	'Live_VisitorLog' => 'Dnevnik obiskovalcev',
 	'Live_Time' => 'Čas',
 	'Live_LastMinutes' => 'Zadnjih %s minutah',
@@ -565,10 +659,7 @@ $translations = array(
 	'Login_LogIn' => 'Vpis',
 	'Login_Logout' => 'Izpis',
 	'Login_LostYourPassword' => 'Ste pozabili geslo?',
-	'Login_RemindPassword' => 'Ponovno pošlji geslo',
 	'Login_PasswordsDoNotMatch' => 'Gesli se ne ujemata.',
-	'Login_PasswordSuccessfullyChanged' => 'Geslo je bilo uspešno spremenjeno!',
-	'Login_MailTopicPasswordRecovery' => 'Povrnitev gesla',
 	'Mobile_LastUpdated' => 'Zadnje posodobljeno: %s',
 	'Mobile_PullDownToRefresh' => 'Potegnite navzdol za osvežitev...',
 	'Mobile_Refresh' => 'Osveži',
@@ -617,7 +708,6 @@ $translations = array(
 	'SEO_AlexaRank' => 'Alexa položaj',
 	'SEO_DomainAge' => 'Starost domene',
 	'SEO_Rank' => 'Položaj',
-	'SEO_Backlinks' => 'Povratne povezave',
 	'SEO_Pages' => 'Strani',
 	'SitesManager_Sites' => 'Spletne strani',
 	'SitesManager_TrackingTags' => 'Sledilna koda za %s',
@@ -670,8 +760,6 @@ $translations = array(
 	'UserCountry_Continent' => 'Kontitent',
 	'UserCountry_Location' => 'Lokacija',
 	'UserCountry_SubmenuLocations' => 'Lokacije',
-	'UserCountry_WidgetContinents' => 'Kontinenti obiskovalcev',
-	'UserCountry_WidgetCountries' => 'Države obiskovalcev',
 	'UserCountry_country_ad' => 'Andora',
 	'UserCountry_country_al' => 'Albanija',
 	'UserCountry_country_ar' => 'Argentina',
@@ -837,9 +925,27 @@ $translations = array(
 	'VisitorInterest_PlusXMin' => '%s min',
 	'VisitorInterest_OnePage' => '1 stran',
 	'VisitorInterest_NPages' => '%s strani',
+	'VisitsSummary_PluginDescription' => 'Prikaže splošne statistike glede obiska na spletni strani: obiske, unikatne obiske, število akcij, odbojno stopnjo, itd.',
+	'VisitsSummary_VisitsSummary' => 'Povzetek obiskov',
+	'VisitsSummary_VisitsSummaryDocumentation' => 'To je pregled obiskov v zadnjem času.',
+	'VisitsSummary_NbVisits' => '%s obiskov',
+	'VisitsSummary_NbUniqueVisitors' => '%s unikatnih obiskovalcev',
+	'VisitsSummary_NbActionsDescription' => '%s akcij',
+	'VisitsSummary_NbPageviewsDescription' => '%s ogledov',
+	'VisitsSummary_NbUniquePageviewsDescription' => '%s unikatnih ogledov',
 	'VisitsSummary_NbDownloadsDescription' => '%s prenosov',
-	'VisitsSummary_NbUniqueDownloadsDescription' => '%s edinstvenih prenosov',
+	'VisitsSummary_NbUniqueDownloadsDescription' => '%s unikatnih prenosov',
+	'VisitsSummary_NbOutlinksDescription' => '%s izhodnih povezav',
+	'VisitsSummary_NbUniqueOutlinksDescription' => '%s unikatnih izhodnih povezav',
 	'VisitsSummary_AverageVisitDuration' => '%s povprečno trajanje obiska',
+	'VisitsSummary_MaxNbActions' => '%s največje število akcij v enem obisku',
+	'VisitsSummary_NbActionsPerVisit' => '%s akcij (ogledov, prenosov, izhodnih povezav) na obisk',
+	'VisitsSummary_NbVisitsBounced' => '%s ogledov je bilo odbojev (so zapustili stran po ogledu ene strani)',
+	'VisitsSummary_GenerateTime' => '%s sekund za prikaz strani',
+	'VisitsSummary_GenerateQueries' => '%s ukazov izvršenih',
+	'VisitsSummary_WidgetLastVisits' => 'Graf zadnjih obiskov',
+	'VisitsSummary_WidgetVisits' => 'Povzetek obiskov',
+	'VisitsSummary_WidgetLastVisitors' => 'Graf zadnjih unikatnih obiskov',
 	'VisitsSummary_WidgetOverviewGraph' => 'Pregled z grafom',
 	'VisitsSummary_SubmenuOverview' => 'Pregled',
 	'VisitTime_LocalTime' => 'Obiski na lokalni čas',
@@ -873,5 +979,15 @@ $translations = array(
 	'PDFReports_TopOfReport' => 'Nazaj na vrh',
 	'PDFReports_Pagination' => 'Stran %s od %s',
 	'ImageGraph_PluginDescription' => 'Ustvarite prelepe, statične, PNG grafe za vsa Piwik poročila.',
-	'ImageGraph_ColumnOrdinateMissing' => 'Vrstice \'%s\' ni bilo moč najti v tem poročilu.',
+
+	// FOR REVIEW
+	'Forecast_Actions' => 'Obiski strani',
+	'Forecast_Column' => 'Napoved',
+	'GeoIP_ColumnCity' => 'Mesto',
+	'GeoIP_Continent' => 'Kontinent',
+	'GeoIP_Country' => 'Država',
+	'GeoIP_DistinctCountries' => '%s različnih držav',
+	'GeoIP_SubmenuLocations' => 'Kraji',
+	'GeoIP_WidgetContinents' => 'Kontinenti obiskovalcev',
+	'GeoIP_WidgetCountries' => 'Države obiskovalcev',
 );
