@@ -21,10 +21,12 @@ $translations = array(
 	'General_No' => 'కాదు',
 	'General_Delete' => 'తొలగించు',
 	'General_Report' => 'నివేదించు',
+	'General_Reports' => 'నివేదికలు',
 	'General_Edit' => 'మార్చు',
 	'General_Download' => 'దింపుకోలు',
 	'General_Ok' => 'సరే',
 	'General_Close' => 'మూసివేయి',
+	'General_Cancel' => 'రద్దుచేయి',
 	'General_Logout' => 'నిష్క్రమించు',
 	'General_Username' => 'వాడుకరిపేరు',
 	'General_Description' => 'వివరణ',
@@ -33,6 +35,7 @@ $translations = array(
 	'General_Value' => 'విలువ',
 	'General_Details' => 'వివరాలు',
 	'General_Default' => 'అప్రమేయం',
+	'General_NumberOfVisits' => 'సందర్శనల సంఖ్య',
 	'General_Date' => 'తేదీ',
 	'General_Period' => 'కాలవ్యవధి',
 	'General_Today' => 'ఈరోజు',
@@ -122,6 +125,11 @@ $translations = array(
 	'General_ChooseWebsite' => 'వెబ్ సైటుని ఎంచుకోండి',
 	'General_Language' => 'భాష',
 	'General_PleaseUpdatePiwik' => 'దయచేసి మీ పివిక్‌ని నవీకరించుకోండి',
+	'General_Help' => 'సహాయం',
+	'General_OneVisit' => '1 సందర్శన',
+	'General_OneDay' => '1 రోజు',
+	'General_NDays' => '%s రోజులు',
+	'General_GeneralInformation' => 'సాధారణ సమాచారం',
 	'Actions_Actions' => 'చర్యలు',
 	'Actions_SubmenuPages' => 'పుటలు',
 	'Actions_SubmenuPagesEntry' => 'ప్రవేశ పుటలు',
@@ -133,9 +141,14 @@ $translations = array(
 	'Actions_ColumnDownloads' => 'దింపుకోళ్ళు',
 	'Actions_ColumnPageName' => 'పుట పేరు',
 	'Actions_ColumnPageURL' => 'పుట చిరునామా',
+	'Actions_ColumnClickedURL' => 'నొక్కిన URL',
+	'Actions_ColumnDownloadURL' => 'దింపుకోలు URL',
 	'CoreAdminHome_PluginDescription' => 'పివిక్ యొక్క నిర్వహణా కేంద్రం.',
 	'CoreAdminHome_MenuGeneralSettings' => 'సాధారణ అమరికలు',
 	'CoreAdminHome_Administration' => 'నిర్వహణ',
+	'PrivacyManager_TeaserHeadline' => 'గోప్యతా అమరికలు',
+	'PrivacyManager_MenuPrivacySettings' => 'గోప్యత',
+	'PrivacyManager_DeleteMaxRowsNoLimit' => 'పరిమితి లేదు',
 	'CoreHome_PeriodDay' => 'రోజు',
 	'CoreHome_PeriodWeek' => 'వారం',
 	'CoreHome_PeriodMonth' => 'నెల',
@@ -234,9 +247,17 @@ $translations = array(
 	'Live_Action' => 'చర్య',
 	'Live_VisitorLog' => 'సందర్శకుల చిట్టా',
 	'Live_Time' => 'సమయం',
+	'Live_LastMinutes' => 'గత %s నిమిషాలు',
+	'Live_LastHours' => 'గత %s గంటలు',
 	'Live_GoalType' => 'రకం',
 	'Live_GoalRevenue' => 'ఆదాయం',
 	'Live_GoalDetails' => 'వివరాలు',
+	'Login_Password' => 'సంకేతపదం',
+	'Login_PasswordRepeat' => 'సంకేతపదం (మళ్ళీ)',
+	'Login_RememberMe' => 'నన్ను గుర్తుంచుకో',
+	'Login_LostYourPassword' => 'మీ సంకేతపదాన్ని మర్చిపోయారా?',
+	'Mobile_Accounts' => 'ఖాతాలు',
+	'Mobile_DefaultReportDate' => 'నివేదిక తేదీ',
 	'Referers_SearchEngines' => 'శోధనయంత్రాలు',
 	'Referers_Keywords' => 'కీపదాలు',
 	'Referers_DirectEntry' => 'నేరు సందర్శన',
@@ -271,12 +292,16 @@ $translations = array(
 	'TranslationsAdmin_AddLanguage' => 'భాషని చేర్చండి',
 	'TranslationsAdmin_Export' => 'భాషని ఎగుమతించు',
 	'TranslationsAdmin_Import' => 'భాషని దిగుమతించు',
+	'TranslationsAdmin_TranslationAlreadyExists' => 'అనువాదం ఇప్పటికే ఉంది',
+	'TranslationsAdmin_InvalidCountry' => 'చెల్లని దేశం',
+	'TranslationsAdmin_InvalidLanguage' => 'చెల్లని భాష',
 	'UserCountry_Country' => 'దేశం',
 	'UserCountry_Continent' => 'ఖండం',
+	'UserCountry_City' => 'నగరం',
+	'UserCountry_Latitude' => 'అక్షాంశం',
+	'UserCountry_Longitude' => 'రేఖాంశం',
 	'UserCountry_Location' => 'ప్రాంతం',
 	'UserCountry_SubmenuLocations' => 'ప్రాంతాలు',
-	'UserCountry_WidgetContinents' => 'సందర్శకుల ఖండాలు',
-	'UserCountry_WidgetCountries' => 'సందర్శకుల దేశాలు',
 	'UserCountry_country_ae' => 'యునైటెడ్ అరబ్ ఎమిరేట్స్',
 	'UserCountry_country_af' => 'ఆఫ్ఘనిస్తాన్',
 	'UserCountry_country_al' => 'అల్బేనియా',
@@ -384,8 +409,8 @@ $translations = array(
 	'UserCountry_country_py' => 'పరాగ్వే',
 	'UserCountry_country_qa' => 'ఖతార్',
 	'UserCountry_country_ro' => 'రొమేనియా',
-	'UserCountry_country_ru' => 'రష్యా',
 	'UserCountry_country_rs' => 'సెర్బియా',
+	'UserCountry_country_ru' => 'రష్యా',
 	'UserCountry_country_rw' => 'రువాండా',
 	'UserCountry_country_sa' => 'సౌదీ అరేబియా',
 	'UserCountry_country_sc' => 'సీషెల్స్',
@@ -422,6 +447,7 @@ $translations = array(
 	'UserCountry_continent_afr' => 'ఆఫ్రికా',
 	'UserCountry_continent_asi' => 'ఆసియా',
 	'UserCountry_continent_amn' => 'ఉత్తర అమెరికా',
+	'UserCountry_continent_amc' => 'మధ్య అమెరికా',
 	'UserCountry_continent_ams' => 'దక్షిణ మరియు మధ్య అమెరికా',
 	'UserCountryMap_map' => 'పటం',
 	'UserCountryMap_worldMap' => 'ప్రపంచ పటం',
@@ -435,7 +461,9 @@ $translations = array(
 	'UserSettings_ColumnPlugin' => 'ప్లగిన్',
 	'UserSettings_ColumnConfiguration' => 'స్వరూపణం',
 	'UserSettings_ColumnOperatingSystem' => 'నిర్వాహక వ్యవస్థ',
+	'UserSettings_ColumnTypeOfScreen' => 'తెర యొక్క రకం',
 	'UserSettings_WidgetBrowsers' => 'సందర్శకుల విహారిణులు',
+	'UserSettings_WidgetBrowserFamilies' => 'విహారిణి కుటుంబం',
 	'UserSettings_WidgetOperatingSystems' => 'నిర్వాహక వ్యవస్థలు',
 	'UserSettings_SubmenuSettings' => 'అమరికలు',
 	'UsersManager_UsersManagement' => 'వాడుకరుల నిర్వహణ',
@@ -453,6 +481,7 @@ $translations = array(
 	'UsersManager_ExceptionLoginExists' => '\'%s\' వాడుకరి ఇప్పటికే ఉన్నారు.',
 	'VisitFrequency_ColumnReturningVisits' => 'పునః సందర్శనలు',
 	'VisitFrequency_SubmenuFrequency' => 'తరచుదనం',
+	'VisitorGenerator_Submit' => 'దాఖలుచేయి',
 	'VisitorInterest_PluginDescription' => 'సందర్శకుల ఆసక్తి గురించిన నివేదికలు: చూసిన పుటల సంఖ్య, సైటులో గడిపిన సమయం.',
 	'VisitorInterest_VisitsPerDuration' => 'నిడివి ప్రకారం సందర్శనలు',
 	'VisitorInterest_VisitsPerNbOfPages' => 'పుటల సంఖ్య ప్రకారం సందర్శనలు',
@@ -466,4 +495,21 @@ $translations = array(
 	'VisitorInterest_NPages' => '%s పుటలు',
 	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$sక్ష',
 	'VisitsSummary_VisitsSummary' => 'సందర్శనల సంగ్రహం',
+	'VisitTime_ColumnLocalTime' => 'స్థానిక సమయం',
+	'PDFReports_PiwikReports' => 'పివిక్ నివేదికలు',
+
+	// FOR REVIEW
+	'Forecast_Visitors' => 'సందర్శకులు',
+	'GeoIP_ColumnCity' => 'నగరం',
+	'GeoIP_Continent' => 'ఖండం',
+	'GeoIP_Country' => 'దేశం',
+	'UserLanguage_Language' => 'భాషలు',
+	'UserLanguage_Language_bn' => 'బెంగాలీ',
+	'UserLanguage_Language_en' => 'ఆంగ్లం',
+	'UserLanguage_Language_hi' => 'హిందీ',
+	'UserLanguage_Language_ja' => 'జపనీ',
+	'UserLanguage_Language_la' => 'లాటిన్',
+	'UserLanguage_Language_or' => 'ఒరియా',
+	'UserLanguage_SubmenuLanguage' => 'భాషలు',
+	'UserLanguage_WidgetLanguage' => 'సందర్శకుల భాషలు',
 );
