@@ -44,7 +44,6 @@ $translations = array(
 	'General_Name' => 'İsim',
 	'General_Value' => 'Değer',
 	'General_Total' => 'Toplam',
-	'General_TotalVisitsActionsRevenue' => '(Toplam: %s ziyaretçi, %s eylem, %s kazanç)',
 	'General_AverageOrderValue' => 'Ortalama Sipariş Değeri',
 	'General_PurchasedProducts' => 'Satın Alınan Ürünler',
 	'General_EcommerceOrders' => 'ETicaret Siparişleri',
@@ -161,7 +160,6 @@ $translations = array(
 	'General_NoDataForGraph' => 'Bu grafikte veri yok.',
 	'General_NoDataForTagCloud' => 'Bu etiket bulutunda veri yok.',
 	'General_DisplaySimpleTable' => 'Basit tablo göster',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s işbirlikçi bir projedir. %3$s Eğer Piwik\'den hoşlandıysanız, yardım edebilirsiniz! %4$s Piwik\'e nasıl katılacağınızı%5$s kontrol edin?',
 	'General_NewUpdatePiwikX' => 'Yeni Güncelleme: Piwik %s',
 	'General_AboutPiwikX' => 'Piwik %s Hakkında',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s kullanılabilir durumda.. %2$s Lütfen şimdi güncelleyin!%3$s (%4$s değişiklikleri%5$s görün).',
@@ -413,7 +411,6 @@ $translations = array(
 	'DBStats_IndexSize' => 'Dizin boyutu',
 	'DBStats_TotalSize' => 'Toplam boyut',
 	'ExampleAPI_PluginDescription' => 'Örnek Eklenti:Özel bir kodlama bilmeden, verilerinizi değişik formatlarda dışarı aktarabilmek için kendi oluşturacağınız eklentinize nasıl bir API oluşturacaksınız?',
-	'ExampleFeedburner_PluginDescription' => 'Örnek Eklenti: Sizin Feedburner aboneliğiniz Pano\'da nasil bir birleşen olarak gösterilecek?',
 	'ExampleRssWidget_PluginDescription' => 'Örnek Eklenti: RSS beslemesini okuyan bir eklentiyi nasıl oluştururuz?',
 	'ExampleUI_PluginDescription' => 'Örnek Eklenti: Bu eklenti Piwik arayüzü ile nasıl çalışacağınızı gösterir: tablo yaratmak, grafikler, vs.',
 	'Feedback_PluginDescription' => 'Piwik takımına geribildirimlerinizi gönderin. Düşüncelerinizi ve önerilerinizi paylaşın!',
@@ -529,15 +526,9 @@ $translations = array(
 	'Login_LogIn' => 'Oturum aç',
 	'Login_Logout' => 'Oturumu kapat',
 	'Login_LostYourPassword' => 'Şifrenizi mi unuttunuz?',
-	'Login_RemindPassword' => 'Parola sıfırlama gönder',
-	'Login_PasswordResetToken' => 'Parola sıfırlama kodu',
-	'Login_PasswordReminder' => 'Lütfen kullanıcı adınızı veya e-posta adresinizi giriniz. Şifrenizi sıfırlamak için bilgi e-postası alacaksınız.',
 	'Login_PasswordsDoNotMatch' => 'Şifre eşleşmedi',
-	'Login_PasswordSuccessfullyChanged' => 'Şifre başarıyla değiştirildi!',
 	'Login_InvalidUsernameEmail' => 'Geçersiz kullanıcı adı ve/veya e-posta adresi',
 	'Login_InvalidOrExpiredToken' => 'Güvenlik kodu yanlış yada süresi dolmuş.',
-	'Login_MailTopicPasswordRecovery' => 'Şifre kurtarma',
-	'Login_PasswordSent' => 'Sizin parolanızın sıfırlama bilgilendirmesi gönderildi. Lütfen e-postanızı kontrol ediniz.',
 	'Provider_PluginDescription' => 'Ziyaretciden Sağlayıcının Rapoarları',
 	'Provider_WidgetProviders' => 'Sağlayıcılar',
 	'Provider_ColumnProvider' => 'Sağlayıcı',
@@ -550,7 +541,6 @@ $translations = array(
 	'SEO_AlexaRank' => 'Alexa Sırası',
 	'SEO_DomainAge' => 'Alan Ad Yaşı',
 	'SEO_Rank' => 'Sıralama',
-	'SEO_Backlinks' => 'Dönünen Linkler',
 	'SEO_Pages' => 'Sayfalar',
 	'SEO_SEORankingsFor' => '\'%s\'için SEO Sıralama',
 	'SitesManager_Sites' => 'Websiteler',
@@ -600,7 +590,6 @@ $translations = array(
 	'UserCountry_Continent' => 'Kıta',
 	'UserCountry_Location' => 'Konum',
 	'UserCountry_SubmenuLocations' => 'Konumlar',
-	'UserCountry_WidgetCountries' => 'Ziyaretçi ülkeleri',
 	'UserCountry_country_ac' => 'Ascension Adası',
 	'UserCountry_country_ad' => 'Andora',
 	'UserCountry_country_ae' => 'Birleşik Arap Emirlikleri',
@@ -858,7 +847,6 @@ $translations = array(
 	'UsersManager_MenuUsers' => 'Kullanıcılar',
 	'UsersManager_MenuUserSettings' => 'Kullanıcı ayarlari',
 	'UsersManager_MenuAnonymousUserSettings' => 'İsimsiz kullanıcı ayarlari',
-	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Not: Sizin isimsiz ziyaretçiler için erişilebilecek websitesi yok, aşağidaki ayarları kullanımda değil.',
 	'UsersManager_ChangePassword' => 'Şifre değiştir',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Şifrenizi değiştirmek istiyorsaniz eğer doldurunuz, aksi halde değiştirmeyecekseniz boş bırakınız.',
 	'UsersManager_TypeYourPasswordAgain' => 'Yeni parolanizi yeniden yazınız',
@@ -880,7 +868,6 @@ $translations = array(
 	'VisitsSummary_NbActionsDescription' => 'Etkinlik sayısı %s (sayfa gösterimi, dosya indirme, dış linkler)',
 	'VisitsSummary_MaxNbActions' => 'Bir ziyarette yapılan max etkinlik %s',
 	'VisitsSummary_NbVisitsBounced' => '%s ziyaret sıçrama yaşadı (ziyaretçi 1 sayfaya baktıktan sonra siteyi terketti )',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Son %s değerlendirmesi',
 	'VisitsSummary_GenerateTime' => 'sayfa %s saniyede oluşturulmuştur.',
 	'VisitsSummary_GenerateQueries' => '%s sorgu çalıştırılmıştır.',
 	'VisitsSummary_WidgetLastVisits' => 'Son ziyaret grafiği',
