@@ -11,7 +11,6 @@ $translations = array(
 	'General_DashboardForASpecificWebsite' => '特定网站控制台',
 	'General_MultiSitesSummary' => '所有网站',
 	'General_AllWebsitesDashboard' => '所有网站控制台',
-	'General_API' => 'API',
 	'General_Widgets' => '组件',
 	'General_Settings' => '设置',
 	'General_GiveUsYourFeedback' => '提交您的意见反馈！',
@@ -376,7 +375,6 @@ $translations = array(
 	'DBStats_IndexSize' => '索引空间大小',
 	'DBStats_TotalSize' => '总容量',
 	'ExampleAPI_PluginDescription' => '范例插件：如何为您的插件建立一个 API, 然后將多种格式的资料导出且无须任何源码？',
-	'ExampleFeedburner_PluginDescription' => '范例插件：如何在控制台里以模组来显示您的 Feedburner 订阅者？',
 	'ExampleRssWidget_PluginDescription' => '范例插件：如何建立一個新模組來读取 RSS feed？',
 	'ExampleUI_PluginDescription' => '范例插件：这个插件让您了解如何使 Piwik UI 运作：建立数据表、图表等等。',
 	'Feedback_PluginDescription' => '传送您的意见反馈給 Piwik 小組。与我们分享您的点子及建议！',
@@ -520,8 +518,6 @@ $translations = array(
 	'Installation_SystemCheckDebugBacktraceHelp' => '检查::无法建立模組检查。',
 	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik 在callbacks上使用匿名函式。',
 	'Installation_SystemCheckEvalHelp' => '必须为 HTML QuickForm 及 Smarty 模板系统。',
-	'Installation_SystemCheckMbstring' => 'mbstring',
-	'Installation_SystemCheckMbstringExtensionHelp' => 'The mbstring extension is required for multibyte characters in API responses using comma-separated values (CSV) or tab-separated values (TSV).',
 	'Installation_SystemCheckMbstringFuncOverloadHelp' => '您应该将 mbstring.func_overload 设定为 "0"。',
 	'Installation_SystemCheckFileIntegrity' => '文件完整性',
 	'Installation_SystemCheckAutoUpdateHelp' => '注意：Piwik 的一键更新功能必须要有 Piwik 目录及內容的写入权限。',
@@ -563,17 +559,10 @@ $translations = array(
 	'Login_LogIn' => '登录',
 	'Login_Logout' => '注销',
 	'Login_LostYourPassword' => '遗失了您的密码吗?',
-	'Login_RemindPassword' => '记忆密码',
-	'Login_PasswordResetToken' => '密码重置凭证',
-	'Login_PasswordReminder' => '请输入您的用户名称或 E-mail 地址！ 您将透过 E-mail 接收到一组新密码！',
 	'Login_PasswordsDoNotMatch' => '密码不相符。',
-	'Login_PasswordSuccessfullyChanged' => '密码已成功变更！',
 	'Login_InvalidUsernameEmail' => '无效的使用者名称 和/或 E-mail 地址',
 	'Login_InvalidNonceOrHeadersOrReferer' => '表单安全检查失败，请重新打开表单，检查是否启用cookie。如果配置了代理服务器，需要 %s 设置Piwik接收代理头信息 %s ，同时检查Referer头是否正确',
 	'Login_InvalidOrExpiredToken' => '凭证无效或已经过期。',
-	'Login_MailTopicPasswordRecovery' => '重取得密码',
-	'Login_MailPasswordRecoveryBody' => '%1$s 您好，%2$s 收到了一个密码重置请求。若要重新设定您的密码：1) 前往密码重设表单: %3$s 2) 输入以下凭证：%4$s 3) 填妥表单（输入您的新密码两次）然后送出。注意：凭证将在 24 小时后过期。',
-	'Login_PasswordSent' => '密码刚刚已经发送！ 请检查您的 E-mail 信箱！',
 	'Login_ContactAdmin' => '可能的原因：您的主机可能已经停用了 mail() 函数！ <br />请联络您的 Piwik 管理员！',
 	'Login_ExceptionPasswordMD5HashExpected' => '密码参数是一个 MD5 加密的密码。',
 	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => '超级使用者无法以 \'%s\' 机制通过身份验证。',
@@ -633,7 +622,6 @@ $translations = array(
 	'SEO_AlexaRank' => 'Alexa 排名',
 	'SEO_DomainAge' => '网域名称年龄',
 	'SEO_Rank' => '评比',
-	'SEO_Backlinks' => '反向链接',
 	'SEO_Pages' => '页面',
 	'SEO_SEORankingsFor' => '%s 的 SEO 评比',
 	'SitesManager_PluginDescription' => 'Piwik 网站管理：新知一个新网站、编辑一个已存在的网站、显示插入您网页的 JavaScript 源代码。所有动作都可以通过 API 使用。',
@@ -701,8 +689,6 @@ $translations = array(
 	'UserCountry_DistinctCountries' => '%s 个不同的国家/地区',
 	'UserCountry_Location' => '位置',
 	'UserCountry_SubmenuLocations' => '所在地',
-	'UserCountry_WidgetContinents' => '访客大陆洲',
-	'UserCountry_WidgetCountries' => '访客国家/地区',
 	'UserCountry_country_ac' => '英属亚森松岛',
 	'UserCountry_country_ad' => '安道尔',
 	'UserCountry_country_ae' => '阿拉伯联合大公国',
@@ -1030,7 +1016,6 @@ $translations = array(
 	'UsersManager_MenuUsers' => '用户',
 	'UsersManager_MenuUserSettings' => '使用者设定',
 	'UsersManager_MenuAnonymousUserSettings' => '匿名用戶设定',
-	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => '注意：您沒有任何网站能让匿名用戶存取，以下设定将无效。',
 	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => '当使用者未登录且访问 Piwik 时，他们应该前往',
 	'UsersManager_ChangePassword' => '变更密码',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => '如果您要变更密码时请输入新的密码。否则留空。',
@@ -1096,7 +1081,6 @@ $translations = array(
 	'VisitsSummary_MaxNbActions' => '%s 在一次会话中最大活动数',
 	'VisitsSummary_NbActionsPerVisit' => '%s 每个访客的活动数',
 	'VisitsSummary_NbVisitsBounced' => '%s 已经跳出的访客数 (浏览一个页面以后就离开网站)',
-	'VisitsSummary_EvolutionOverLastPeriods' => '最近的发展趋势 %s',
 	'VisitsSummary_GenerateTime' => '%s 秒来生成这个页面',
 	'VisitsSummary_GenerateQueries' => '%s 查询已执行',
 	'VisitsSummary_WidgetLastVisits' => '最近访问者走势图',
@@ -1114,7 +1098,6 @@ $translations = array(
 	'VisitTime_SubmenuTimes' => '访问时段',
 	'VisitTime_NHour' => '%s时',
 	'Widgetize_PluginDescription' => '这个插件让您轻松输出任何 Piwik 模组至您的博客、网站或 iGoogle 及 Netvibes!',
-	'PDFReports_PDF' => 'PDF',
 	'PDFReports_EmailSchedule' => 'Email 排程',
 	'PDFReports_SendReportTo' => '寄送报告至',
 	'PDFReports_SentToMe' => '寄给我',
