@@ -11,7 +11,6 @@ $translations = array(
 	'General_DashboardForASpecificWebsite' => '特定網站展示板',
 	'General_MultiSitesSummary' => '所有網站',
 	'General_AllWebsitesDashboard' => '所有網站展示板',
-	'General_API' => 'API',
 	'General_Widgets' => '組件',
 	'General_Settings' => '設定',
 	'General_GiveUsYourFeedback' => '給我們反饋意見！',
@@ -111,7 +110,6 @@ $translations = array(
 	'General_DisplaySimpleTable' => '顯示簡易表格',
 	'General_DisplayTableWithMoreMetrics' => '顯示更多數據表',
 	'General_DisplayTableWithGoalMetrics' => '顯示目標數據表',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s 是一個協同專案。 %3$s 如果你喜歡 Piwik，你可以提供協助！ 請查看 %4$s 如何參與 Piwik？%5$s',
 	'General_YouAreViewingDemoShortMessage' => '你正在瀏覽 Piwik 範例',
 	'General_DownloadFullVersion' => '%1$s下載%2$s完整版本！來吧 %3$s',
 	'General_NewUpdatePiwikX' => '新的更新：Piwik %s',
@@ -380,7 +378,6 @@ $translations = array(
 	'DBStats_IndexSize' => '索引大小',
 	'DBStats_TotalSize' => '總容量',
 	'ExampleAPI_PluginDescription' => '範例外掛：如何為你的外掛建立一個 API, 然後將多種格式的資料匯出且無須任何原始碼？',
-	'ExampleFeedburner_PluginDescription' => '範例外掛：如何在展示板裡以組件來顯示你的 Feedburner 訂閱者？',
 	'ExampleRssWidget_PluginDescription' => '範例外掛：如何建立一個新組件來讀取 RSS feed？',
 	'ExampleUI_PluginDescription' => '範例外掛：這個外掛讓你瞭解如何使 Piwik UI 運作：建立資料表、圖表等等。',
 	'Feedback_PluginDescription' => '傳送你的意見反應給 Piwik 小組。與我們分享你的點子及建議！',
@@ -525,8 +522,6 @@ $translations = array(
 	'Installation_SystemCheckDebugBacktraceHelp' => '檢視::無法建立模組檢視。',
 	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik 在callbacks上使用匿名函式。',
 	'Installation_SystemCheckEvalHelp' => '必須為 HTML QuickForm 及 Smarty 模版系統。',
-	'Installation_SystemCheckMbstring' => 'mbstring',
-	'Installation_SystemCheckMbstringExtensionHelp' => 'The mbstring extension is required for multibyte characters in API responses using comma-separated values (CSV) or tab-separated values (TSV).',
 	'Installation_SystemCheckMbstringFuncOverloadHelp' => '你應該將 mbstring.func_overload 設定為 "0"。',
 	'Installation_SystemCheckFileIntegrity' => '檔案完整性',
 	'Installation_SystemCheckAutoUpdateHelp' => '注意：Piwik 的一鍵更新功能必須要有 Piwik 目錄及內容的寫入權限。',
@@ -556,10 +551,6 @@ $translations = array(
 	'Live_VisitorLog' => '訪客記錄',
 	'Live_Time' => '時間',
 	'Live_Referrer_URL' => '推薦連結',
-	'Live_GoalType' => 'Type',
-	'Live_GoalTime' => '1st Conversion time',
-	'Live_GoalRevenue' => 'Revenue',
-	'Live_GoalDetails' => 'Details',
 	'Login_PluginDescription' => '登入驗證外掛，超級使用者從 config/config.inc.php 檔案讀取憑證，其他使用者則從資料庫。可以很容易取代或導入新的驗證機制（OpenID, htaccess, 自訂驗證等等）。',
 	'Login_LoginPasswordNotCorrect' => '使用者名稱 & 密碼不正確。',
 	'Login_Password' => '密碼',
@@ -569,16 +560,9 @@ $translations = array(
 	'Login_LogIn' => '登入',
 	'Login_Logout' => '登出',
 	'Login_LostYourPassword' => '遺失了您的密碼嗎？',
-	'Login_RemindPassword' => '傳送重置密碼',
-	'Login_PasswordResetToken' => '重置密碼權杖',
-	'Login_PasswordReminder' => '請輸入您的使用者名稱或 E-mail 位址！ 您將收到一封含有您重置密碼資訊的 E-mail！',
 	'Login_PasswordsDoNotMatch' => '密碼並不相符！',
-	'Login_PasswordSuccessfullyChanged' => '密碼成功變更！',
 	'Login_InvalidUsernameEmail' => '無效的使用者名稱 和/或 E-mail 位址',
 	'Login_InvalidOrExpiredToken' => '權杖不正確或已過期！',
-	'Login_MailTopicPasswordRecovery' => '重取得密碼',
-	'Login_MailPasswordRecoveryBody' => '%1$s 你好，%2$s 收到了一個密碼重置請求。若要重新設定你的密碼：1) 前往密碼重設表單: %3$s 2) 輸入以下憑證：%4$s 3) 填妥表單（輸入你的新密碼兩次）然後送出。注意：憑證將在 24 小時後過期。',
-	'Login_PasswordSent' => '重置密碼訊息已經寄出。請檢查你的 E-mail 信箱。',
 	'Login_ContactAdmin' => '可能原因：您的伺服主機可能已經停用了 mail() 函式。<br />請聯絡您的 Piwik 管理員！',
 	'Login_ExceptionPasswordMD5HashExpected' => '密碼參數會是一個 MD5 雜湊加密的密碼！',
 	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => '超級使用者無法以 \'%s\' 機制通過身份驗證。',
@@ -638,7 +622,6 @@ $translations = array(
 	'SEO_AlexaRank' => 'Alexa 排名',
 	'SEO_DomainAge' => '網域名稱年齡',
 	'SEO_Rank' => '評比',
-	'SEO_Backlinks' => '反向連結',
 	'SEO_Pages' => '頁面',
 	'SEO_SEORankingsFor' => '%s 的 SEO 評比',
 	'SitesManager_PluginDescription' => 'Piwik 網站管理：新增一個新網站、編輯一個已存在的網站、顯示插入你網頁的 JavaScript 原始碼。所有動作都可以透過 API 使用。',
@@ -706,8 +689,6 @@ $translations = array(
 	'UserCountry_DistinctCountries' => '%s 個不同的國家',
 	'UserCountry_Location' => '位置',
 	'UserCountry_SubmenuLocations' => '所在地',
-	'UserCountry_WidgetContinents' => '訪客大陸洲',
-	'UserCountry_WidgetCountries' => '訪客國家',
 	'UserCountry_country_ac' => '英屬亞森松島',
 	'UserCountry_country_ad' => '安道爾',
 	'UserCountry_country_ae' => '阿拉伯聯合大公國',
@@ -1035,7 +1016,6 @@ $translations = array(
 	'UsersManager_MenuUsers' => '使用者',
 	'UsersManager_MenuUserSettings' => '使用者設定',
 	'UsersManager_MenuAnonymousUserSettings' => '匿名用戶設定',
-	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => '注意：你沒有任何網站能讓匿名用戶存取，以下設定將無效。',
 	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => '當使用者未登入且訪問 Piwik 時，他們應該前往',
 	'UsersManager_ChangePassword' => '變更密碼',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => '如果你要變更密碼時請輸入新的密碼。否則留空。',
@@ -1101,7 +1081,6 @@ $translations = array(
 	'VisitsSummary_MaxNbActions' => '%s 由單一次造訪所產生的最大活動數',
 	'VisitsSummary_NbActionsPerVisit' => '%s 每個訪客的活動數',
 	'VisitsSummary_NbVisitsBounced' => '%s 跳出率（於瀏覽單一網頁後離開網站）',
-	'VisitsSummary_EvolutionOverLastPeriods' => '最近 %s 的發展趨勢',
 	'VisitsSummary_GenerateTime' => '頁面生成時間： %s 秒',
 	'VisitsSummary_GenerateQueries' => '%s 個查詢已執行',
 	'VisitsSummary_WidgetLastVisits' => '最近造訪圖表',
@@ -1120,7 +1099,6 @@ $translations = array(
 	'VisitTime_NHour' => '%s 時',
 	'Widgetize_PluginDescription' => '這個外掛讓你輕鬆輸出任何 Piwik 模組至你的網誌、網站或 iGoogle 及 Netvibes!',
 	'PDFReports_EmailReports' => '郵寄報表',
-	'PDFReports_PDF' => 'PDF',
 	'PDFReports_SendReportNow' => '立即寄送報表',
 	'PDFReports_EmailSchedule' => '郵寄排程',
 	'PDFReports_SendReportTo' => '寄送報表至',
