@@ -11,7 +11,7 @@
  *  - CURL or STREAM extensions (to issue the http request to Piwik)
  *  
  * @license released under BSD License http://www.opensource.org/licenses/bsd-license.php
- * @version $Id: PiwikTracker.php 6450 2012-06-03 00:14:03Z matt $
+ * @version $Id: PiwikTracker.php 7569 2012-12-04 00:26:22Z matt $
  * @link http://piwik.org/docs/tracking-api/
  *
  * @category Piwik
@@ -51,6 +51,13 @@ class PiwikTracker
 	 * @ignore
 	 */
 	const LENGTH_VISITOR_ID = 16;
+
+	/**
+	 * Charset
+	 * @see setPageCharset
+	 * @ignore
+	 */
+	const DEFAULT_CHARSET_PARAMETER_VALUES = 'utf-8';
 	
 	/**
 	 * Builds a PiwikTracker object, used to track visits, pages and Goal conversions 
@@ -81,6 +88,7 @@ class PiwikTracker
     	$this->requestCookie = '';
     	$this->idSite = $idSite;
     	$this->urlReferrer = @$_SERVER['HTTP_REFERER'];
+    	$this->pageCharset = self::DEFAULT_CHARSET_PARAMETER_VALUES;
     	$this->pageUrl = self::getCurrentUrl();
     	$this->ip = @$_SERVER['REMOTE_ADDR'];
     	$this->acceptLanguage = @$_SERVER['HTTP_ACCEPT_LANGUAGE'];
@@ -89,12 +97,27 @@ class PiwikTracker
     	{
     		self::$URL = $apiUrl;
     	}
-    	$this->visitorId = substr(md5(uniqid(rand(), true)), 0, self::LENGTH_VISITOR_ID);
+    	$this->setNewVisitorId();
     	
 		// Allow debug while blocking the request
     	$this->requestTimeout = 600;
+    	$this->doBulkRequests = false;
+    	$this->storedTrackingActions = array();
     }
-    
+
+	/**
+	 * By default, Piwik expects utf-8 encoded values, for example
+	 * for the page URL parameter values, Page Title, etc.
+	 * It is recommended to only send UTF-8 data to Piwik.
+	 * If required though, you can also specify another charset using this function.
+	 *
+	 * @param string $charset
+	 */
+	public function setPageCharset( $charset = false )
+	{
+		$this->pageCharset = $charset;
+	}
+
     /**
      * Sets the current URL being tracked
      * 
@@ -220,8 +243,13 @@ class PiwikTracker
     	return $cookieDecoded[$id];
     }
     
-    
-    
+    /**
+     * Sets the current visitor ID to a random new one.
+     */
+    public function setNewVisitorId()
+    {
+    	$this->visitorId = substr(md5(uniqid(rand(), true)), 0, self::LENGTH_VISITOR_ID);
+    }
     
     /**
      * Sets the Browser language. Used to guess visitor countries when GeoIP is not enabled
@@ -244,25 +272,109 @@ class PiwikTracker
     	$this->userAgent = $userAgent;
     }
     
-
+    /**
+     * Sets the country of the visitor. If not used, Piwik will try to find the country
+     * using either the visitor's IP address or language.
+     *
+     * Allowed only for Admin/Super User, must be used along with setTokenAuth().
+     * @param string $country
+     */
+    public function setCountry($country)
+    {
+    	$this->country = $country;
+    }
+    
+    /**
+     * Sets the region of the visitor. If not used, Piwik may try to find the region
+     * using the visitor's IP address (if configured to do so).
+     *
+     * Allowed only for Admin/Super User, must be used along with setTokenAuth().
+     * @param string $region
+     */
+    public function setRegion($region)
+    {
+    	$this->region = $region;
+    }
+    
+    /**
+     * Sets the city of the visitor. If not used, Piwik may try to find the city
+     * using the visitor's IP address (if configured to do so).
+     *
+     * Allowed only for Admin/Super User, must be used along with setTokenAuth().
+     * @param string $city
+     */
+    public function setCity($city)
+    {
+    	$this->city = $city;
+    }
+    
+    /**
+     * Sets the latitude of the visitor. If not used, Piwik may try to find the visitor's
+     * latitude using the visitor's IP address (if configured to do so).
+     *
+     * Allowed only for Admin/Super User, must be used along with setTokenAuth().
+     * @param float $lat
+     */
+    public function setLatitude($lat)
+    {
+    	$this->lat = $lat;
+    }
+    
+    /**
+     * Sets the longitude of the visitor. If not used, Piwik may try to find the visitor's
+     * longitude using the visitor's IP address (if configured to do so).
+     *
+     * Allowed only for Admin/Super User, must be used along with setTokenAuth().
+     * @param float $long
+     */
+    public function setLongitude($long)
+    {
+    	$this->long = $long;
+    }
+    
+	/**
+	 * Enables the bulk request feature. When used, each tracking action is stored until the
+	 * doBulkTrack method is called. This method will send all tracking data at once.
+	 */
+	public function enableBulkTracking()
+	{
+		$this->doBulkRequests = true;
+	}
+	
     /**
      * Tracks a page view
      * 
      * @param string $documentTitle Page title as it will appear in the Actions > Page titles report
-     * @return string Response
+     * @return string|true Response or true if using bulk requests.
      */
     public function doTrackPageView( $documentTitle )
     {
     	$url = $this->getUrlTrackPageView($documentTitle);
     	return $this->sendRequest($url);
-    } 
-    
+    }
+
+	/**
+	 * Tracks an internal Site Search query, and optionally tracks the Search Category, and Search results Count.
+	 * These are used to populate reports in Actions > Site Search.
+	 *
+	 * @param string $keyword Searched query on the site
+	 * @param string $category Optional, Search engine category if applicable
+	 * @param int $countResults results displayed on the search result page. Used to track "zero result" keywords.
+	 *
+	 * @return string|true Response or true if using bulk requests.
+	 */
+	public function doTrackSiteSearch( $keyword, $category = false, $countResults = false )
+	{
+		$url = $this->getUrlTrackSiteSearch($keyword, $category, $countResults);
+		return $this->sendRequest($url);
+	}
+
     /**
      * Records a Goal conversion
      * 
      * @param int $idGoal Id Goal to record a conversion
      * @param float $revenue Revenue for this conversion
-     * @return string Response
+     * @return string|true Response or true if using bulk request
      */
     public function doTrackGoal($idGoal, $revenue = false)
     {
@@ -275,7 +387,7 @@ class PiwikTracker
      * 
      * @param string $actionUrl URL of the download or outlink
      * @param string $actionType Type of the action: 'download' or 'link'
-     * @return string Response
+     * @return string|true Response or true if using bulk request
      */
     public function doTrackAction($actionUrl, $actionType)
     {
@@ -322,6 +434,35 @@ class PiwikTracker
     	return $this->sendRequest($url); 
     }
     
+    /**
+     * Sends all stored tracking actions at once. Only has an effect if bulk tracking is enabled.
+     * 
+     * To enable bulk tracking, call enableBulkTracking().
+     * 
+     * @return string Response
+     */
+    public function doBulkTrack()
+    {
+    	if (empty($this->token_auth))
+    	{
+    		throw new Exception("Token auth is required for bulk tracking.");
+    	}
+    	
+    	if (empty($this->storedTrackingActions))
+    	{
+    		throw new Exception("Error:  you must call the function doTrackPageView or doTrackGoal from this class, before calling this method doBulkTrack()");
+    	}
+    	
+    	$data = array('requests' => $this->storedTrackingActions, 'token_auth' => $this->token_auth);
+		
+    	$postData = json_encode($data);
+    	$response = $this->sendRequest($this->getBaseUrl(), 'POST', $postData, $force = true);
+    	
+    	$this->storedTrackingActions = array();
+    	
+    	return $response;
+    }
+    
     /**
 	 * Tracks an Ecommerce order.
 	 * 
@@ -337,6 +478,7 @@ class PiwikTracker
 	 * @param float $tax (optional) Tax amount for this order
 	 * @param float $shipping (optional) Shipping amount for this order
 	 * @param float $discount (optional) Discounted amount in this order
+	 * @return string|true Response or true if using bulk request
      */
     public function doTrackEcommerceOrder($orderId, $grandTotal, $subTotal = false, $tax = false, $shipping = false, $discount = false)
     {
@@ -483,6 +625,22 @@ class PiwikTracker
     	}
     	return $url;
     }
+
+	/**
+	 * @see doTrackSiteSearch()
+	 */
+	public function getUrlTrackSiteSearch($keyword, $category, $countResults)
+	{
+		$url = $this->getRequest( $this->idSite );
+		$url .= '&search=' . urlencode($keyword);
+		if($category !== false) {
+			$url .= '&search_cat=' . urlencode($category);
+		}
+		if($countResults !== false) {
+			$url .= '&search_count=' . (int)$countResults;
+		}
+		return $url;
+	}
     
     /**
      * @see doTrackGoal()
@@ -545,7 +703,7 @@ class PiwikTracker
      * 
      * This is typically used with the Javascript getVisitorId() function.
      * 
-     * Allowed only for Super User, must be used along with setTokenAuth().
+     * Allowed only for Admin/Super User, must be used along with setTokenAuth().
      * @see setTokenAuth()
      * @param string $visitorId 16 hexadecimal characters visitor ID, eg. "33c31e01394bdc63"
      */
@@ -735,8 +893,19 @@ class PiwikTracker
     /**
      * @ignore
      */
-    protected function sendRequest($url)
+    protected function sendRequest( $url, $method = 'GET', $data = null, $force = false )
     {
+    	// if doing a bulk request, store the url
+    	if ($this->doBulkRequests && !$force)
+    	{
+    		$this->storedTrackingActions[]
+    			= $url
+    			. (!empty($this->userAgent) ? ('&ua='.urlencode($this->userAgent)) : '')
+    			. (!empty($this->acceptLanguage) ? ('&lang='.urlencode($this->acceptLanguage)) : '')
+    			;
+    		return true;
+    	}
+    	
 		$response = '';
 
 		if(!$this->cookieSupport)
@@ -745,8 +914,7 @@ class PiwikTracker
 		}
 		if(function_exists('curl_init'))
 		{
-			$ch = curl_init();
-			curl_setopt_array($ch, array(
+			$options = array(
 				CURLOPT_URL => $url,
 				CURLOPT_USERAGENT => $this->userAgent,
 				CURLOPT_HEADER => true,
@@ -755,8 +923,27 @@ class PiwikTracker
 				CURLOPT_HTTPHEADER => array(
 					'Accept-Language: ' . $this->acceptLanguage,
 					'Cookie: '. $this->requestCookie,
-				),
-			));
+				));
+			
+			switch ($method)
+			{
+				case 'POST':
+					$options[CURLOPT_POST] = TRUE;
+					break;
+				default:
+					break;
+			}
+			
+			// only supports JSON data
+			if (!empty($data))
+			{
+				$options[CURLOPT_HTTPHEADER][] = 'Content-Type: application/json';
+				$options[CURLOPT_HTTPHEADER][] = 'Expect:';
+				$options[CURLOPT_POSTFIELDS] = $data;
+			}
+			
+			$ch = curl_init();
+			curl_setopt_array($ch, $options);
 			ob_start();
 			$response = @curl_exec($ch);
 			ob_end_clean();
@@ -770,12 +957,21 @@ class PiwikTracker
 		{
 			$stream_options = array(
 				'http' => array(
+					'method' => $method,
 					'user_agent' => $this->userAgent,
 					'header' => "Accept-Language: " . $this->acceptLanguage . "\r\n" .
 					            "Cookie: ".$this->requestCookie. "\r\n" ,
 					'timeout' => $this->requestTimeout, // PHP 5.2.1
 				)
 			);
+			
+			// only supports JSON data
+			if (!empty($data))
+			{
+				$stream_options['http']['header'] .= "Content-Type: application/json \r\n";
+				$stream_options['http']['content'] = $data;
+			}
+			
 			$ctx = stream_context_create($stream_options);
 			$response = file_get_contents($url, 0, $ctx);
 			$header = implode("\r\n", $http_response_header); 
@@ -816,9 +1012,9 @@ class PiwikTracker
     }
     
     /**
-     * @ignore
+     * Returns the base URL for the piwik server.
      */
-    protected function getRequest( $idSite )
+    protected function getBaseUrl()
     {
     	if(empty(self::$URL))
     	{
@@ -829,22 +1025,29 @@ class PiwikTracker
     	{
     		self::$URL .= '/piwik.php';
     	}
-    	
-    	$url = self::$URL .
+    	return self::$URL;
+    }
+    
+    /**
+     * @ignore
+     */
+    protected function getRequest( $idSite )
+    {
+    	$url = $this->getBaseUrl() .
 	 		'?idsite=' . $idSite .
 			'&rec=1' .
 			'&apiv=' . self::VERSION . 
 	        '&r=' . substr(strval(mt_rand()), 2, 6) .
     	
     		// XDEBUG_SESSIONS_START and KEY are related to the PHP Debugger, this can be ignored in other languages
-    		(!empty($_GET['XDEBUG_SESSION_START']) ? '&XDEBUG_SESSION_START=' . @$_GET['XDEBUG_SESSION_START'] : '') . 
-	        (!empty($_GET['KEY']) ? '&KEY=' . @$_GET['KEY'] : '') .
+    		(!empty($_GET['XDEBUG_SESSION_START']) ? '&XDEBUG_SESSION_START=' . @urlencode($_GET['XDEBUG_SESSION_START']) : '') . 
+	        (!empty($_GET['KEY']) ? '&KEY=' . @urlencode($_GET['KEY']) : '') .
     	 
     		// Only allowed for Super User, token_auth required,
 			(!empty($this->ip) ? '&cip=' . $this->ip : '') .
     		(!empty($this->forcedVisitorId) ? '&cid=' . $this->forcedVisitorId : '&_id=' . $this->visitorId) . 
 			(!empty($this->forcedDatetime) ? '&cdt=' . urlencode($this->forcedDatetime) : '') .
-			(!empty($this->token_auth) ? '&token_auth=' . urlencode($this->token_auth) : '') .
+			((!empty($this->token_auth) && !$this->doBulkRequests) ? '&token_auth=' . urlencode($this->token_auth) : '') .
 	        
 			// These parameters are set by the JS, but optional when using API
 	        (!empty($this->plugins) ? $this->plugins : '') . 
@@ -861,6 +1064,7 @@ class PiwikTracker
 	        // URL parameters
 	        '&url=' . urlencode($this->pageUrl) .
 			'&urlref=' . urlencode($this->urlReferrer) .
+		    ((!empty($this->pageCharset) && $this->pageCharset != self::DEFAULT_CHARSET_PARAMETER_VALUES) ? '&cs=' . $this->pageCharset : '') .
 	        
 	        // Attribution information, so that Goal conversions are attributed to the right referrer or campaign
 	        // Campaign name
@@ -871,6 +1075,13 @@ class PiwikTracker
     		(!empty($this->attributionInfo[2]) ? '&_refts=' . $this->attributionInfo[2] : '') .
     		// Referrer URL
     		(!empty($this->attributionInfo[3]) ? '&_ref=' . urlencode($this->attributionInfo[3]) : '') .
+    		
+    		// custom location info
+    		(!empty($this->country) ? '&country='.urlencode($this->country) : '') .
+    		(!empty($this->region) ? '&region='.urlencode($this->region) : '') .
+    		(!empty($this->city) ? '&city='.urlencode($this->city) : '') .
+    		(!empty($this->lat) ? '&lat='.urlencode($this->lat) : '') .
+    		(!empty($this->long) ? '&long='.urlencode($this->long) : '') .
 
     		// DEBUG 
 	        $this->DEBUG_APPEND_URL
