@@ -5,7 +5,7 @@
  *
  * @link http://dev.piwik.org/trac/browser/trunk/libs/UserAgentParser
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
- * @version $Id: UserAgentParser.php 6362 2012-05-29 05:17:56Z capedfuzz $
+ * @version $Id: UserAgentParser.php 7616 2012-12-14 21:36:03Z matt $
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -74,6 +74,7 @@ class UserAgentParser
 
 			// BlackBerry smartphones and tablets
 			'blackberry'					=> 'BB', // BlackBerry 6 and PlayBook adopted webkit
+			'bb10'							=> 'B2', // BlackBerry 10
 			'playbook'						=> 'BP',
 
 			'browsex'						=> 'BX',
@@ -157,6 +158,8 @@ class UserAgentParser
 			'nitro) opera'					=> 'OP',
 			'opera'							=> 'OP',
 
+			'rekonq'						=> 'RK',
+
 			// Safari
 			'safari'						=> 'SF',
 			'applewebkit'					=> 'SF',
@@ -172,7 +175,7 @@ class UserAgentParser
 			'ie'	 => array('IE'),
 			'gecko'  => array('NS', 'PX', 'FF', 'FB', 'CA', 'GA', 'KM', 'MO', 'SM', 'CO', 'FE', 'KP', 'KZ'),
 			'khtml'  => array('KO'),
-			'webkit' => array('SF', 'CH', 'OW', 'AR', 'EP', 'FL', 'WO', 'AB', 'IR', 'CS', 'FD', 'HA', 'MI', 'GE', 'DF', 'BB', 'BP', 'TI', 'CF'),
+			'webkit' => array('SF', 'CH', 'OW', 'AR', 'EP', 'FL', 'WO', 'AB', 'IR', 'CS', 'FD', 'HA', 'MI', 'GE', 'DF', 'BB', 'BP', 'TI', 'CF', 'RK', 'B2'),
 			'opera'  => array('OP'),
 		);
 
@@ -212,6 +215,7 @@ class UserAgentParser
 	static protected $operatingSystems = array(
 			'Android'				=> 'AND',
 			'Maemo'					=> 'MAE',
+			'CrOS '                 => 'LIN',
 			'Linux'					=> 'LIN',
 
 			// workaround for vendors who changed the WinPhone 7 user agent
@@ -278,6 +282,7 @@ class UserAgentParser
 			'PalmOS'				=> 'POS',
 			'Palm OS'				=> 'POS',
 
+			'BB10'					=> 'BBX',
 			'BlackBerry'			=> 'BLB',
 			'RIM Tablet OS'			=> 'QNX',
 			'QNX'					=> 'QNX',
@@ -312,6 +317,7 @@ class UserAgentParser
 			'BEOS'					=> 'BEO',
 			'Amiga'					=> 'AMI',
 			'AmigaOS'				=> 'AMI',
+
 		);
 	
 	// os family
@@ -451,6 +457,9 @@ class UserAgentParser
 			else if(strpos($userAgent, 'RIM Tablet OS') !== false) {
 				$info['id'] = 'BP';
 			}
+			else if(strpos($userAgent, 'BB10') !== false) {
+				$info['id'] = 'B2';
+			}
 
 			// Version/X.Y.Z override
 			if(preg_match_all("/(version)[\/\sa-z(]*([0-9]+)([\.0-9a-z]+)?/i", $userAgent, $newResults))
@@ -542,6 +551,7 @@ class UserAgentParser
 		self::$browserIdToName['AW'] = 'Amiga AWeb';
 		self::$browserIdToName['BB'] = 'BlackBerry';
 		self::$browserIdToName['BP'] = 'PlayBook';
+		self::$browserIdToName['B2'] = 'BlackBerry';
 		self::$browserIdToName['BX'] = 'BrowseX';
 		self::$browserIdToName['CF'] = 'Chrome Frame';
 		self::$browserIdToName['CO'] = 'CometBird';
