@@ -76,6 +76,7 @@ class Archiving
 	protected $processPeriodsMaximumEverySeconds = 3600;
 	
 	protected $websiteDayHasFinishedSinceLastRun = array();
+	protected $idSitesInvalidatedOldReports = array();
 	protected $piwikUrl = false;
 	protected $token_auth = false;
 	protected $visits = 0;
@@ -89,7 +90,9 @@ class Archiving
 	 * It will be overwritten by the number of days since last archiving ran until completion.
 	 */
 	const DEFAULT_DATE_LAST = 52;
-	
+	// Since weeks are not used in yearly archives, we make sure that all possible weeks are processed
+	const DEFAULT_DATE_LAST_WEEKS = 520;
+
 	protected $timeLastCompleted = false;
 	protected $requestPrepend = '&trigger=archivephp';
 	protected $errors = array();
@@ -107,12 +110,12 @@ class Archiving
 		
 		$this->logSection("INIT");
 		$this->log("Querying Piwik API at: {$this->piwikUrl}");		
-		$this->log("Running as Super User: " . $this->login);
+		$this->log("Running Piwik ". Piwik_Version::VERSION ." as Super User: " . $this->login);
 		
 		$this->acceptInvalidSSLCertificate = $this->isParameterSet("accept-invalid-ssl-certificate");
 		
 		// Test the specified piwik URL is valid
-		$response = $this->request("?module=API&method=API.getDefaultMetricTranslations&format=php");
+		$response = $this->request("?module=API&method=API.getDefaultMetricTranslations&format=original&serialize=1");
 		$responseUnserialized = @unserialize($response);
 		if($response === false
 			|| !is_array($responseUnserialized))
@@ -154,6 +157,10 @@ class Archiving
 		if(empty($lastTimestampWebsiteProcessed))
 		{
 			$dateLast = self::DEFAULT_DATE_LAST;
+			if($period == 'week')
+			{
+				$dateLast = self::DEFAULT_DATE_LAST_WEEKS;
+			}
 		}
 		else
 		{
@@ -222,11 +229,12 @@ class Archiving
 				// 2) OR always if script never executed for this website before
 		    	$shouldArchivePeriods = true;
 		    }
-		    
+
+
 		    // (*) If the website is archived because it is a new day in its timezone
 		    // We make sure all periods are archived, even if there is 0 visit today
-		    if(!$shouldArchivePeriods
-		    	&& in_array($idsite, $this->websiteDayHasFinishedSinceLastRun))
+			$dayHasEndedMustReprocess = in_array($idsite, $this->websiteDayHasFinishedSinceLastRun);
+		    if($dayHasEndedMustReprocess)
 		    {
 		    	$shouldArchivePeriods = true;
 		    }
@@ -238,12 +246,12 @@ class Archiving
 		    {
 		    	$shouldArchivePeriods = true;
 		    }
-		    
+
 		    // Test if we should process this website at all
-		    
 		    $elapsedSinceLastArchiving = time() - $lastTimestampWebsiteProcessedDay;
-		    if(!$shouldArchivePeriods
-		    	&& $elapsedSinceLastArchiving < $this->todayArchiveTimeToLive) 
+		    if(    !$websiteIsOldDataInvalidate // Invalidate old website forces the archiving for this site
+			    && !$dayHasEndedMustReprocess   // Also reprocess when day has ended since last run
+			    && $elapsedSinceLastArchiving < $this->todayArchiveTimeToLive)
 		    {
 		    	$this->log("Skipped website id $idsite, already processed today's report in recent run, "
 					.Piwik::getPrettyTimeFromSeconds($elapsedSinceLastArchiving, true, $isHtml = false)
@@ -260,10 +268,10 @@ class Archiving
 		    $url = $this->getVisitsRequestUrl($idsite, "day",
 			    				// when some data was purged from this website
 			    				// we make sure we query all previous days/weeks/months
-		    				$websiteIsOldDataInvalidate
+		    				($websiteIsOldDataInvalidate
 								// when --force-all-websites option, 
 								// also forces to archive last52 days to be safe
-							|| $this->shouldArchiveAllWebsites 
+							|| $this->shouldArchiveAllWebsites)
 								? false 
 								: $lastTimestampWebsiteProcessedDay
 			);
@@ -321,11 +329,10 @@ class Archiving
 					Piwik_SetOption( $this->lastRunKey($idsite, "periods"), time() );
 					
 					// Remove this website from the list of websites to be invalidated
-					// since it now just been re-processing the reports, job is done!
-					if( in_array($idsite, $this->idSitesInvalidatedOldReports ) )
+					// since it's now just been re-processing the reports, job is done!
+					if( $websiteIsOldDataInvalidate )
 					{
 						$websiteIdsInvalidated = Piwik_CoreAdminHome_API::getWebsiteIdsToInvalidate();
-						
 						if(count($websiteIdsInvalidated))
 						{
 							$found = array_search($idsite, $websiteIdsInvalidated);
@@ -338,21 +345,18 @@ class Archiving
 						}
 					}
 				}
-				$archivedPeriodsArchivesWebsite++;
-			}
-			else
-			{
-				$skippedPeriodsArchivesWebsite++;
 			}
+			$archivedPeriodsArchivesWebsite++;
+
 			$requestsWebsite = $this->requests - $requestsBefore;
-			
 			$debug = $this->shouldArchiveAllWebsites ? ", last days = $visitsAllDays visits" : "";
 			Piwik::log("Archived website id = $idsite, today = $visitsToday visits"
-							.$debug.", $requestsWebsite API requests, "
-							. $timerWebsite->__toString() 
-							." [" . ($websitesWithVisitsSinceLastRun+$skipped) . "/" 
-							. count($this->websites) 
-							. " done]" );
+				.$debug.", $requestsWebsite API requests, "
+				. $timerWebsite->__toString()
+				." [" . ($websitesWithVisitsSinceLastRun+$skipped) . "/"
+				. count($this->websites)
+				. " done]" );
+
 		}
 		
 		$this->log("Done archiving!");
@@ -394,7 +398,7 @@ class Archiving
 		$this->log($tasksOutput);
 		$this->log("done");
 	}
-	
+
 	/**
 	 * @return bool True on success, false if some request failed
 	 */
@@ -408,14 +412,7 @@ class Archiving
 	    // already processed above for "day"
 	    if($period != "day")
 	    {
-			$ch = curl_init($url);
-			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
-			
-			if($this->acceptInvalidSSLCertificate)
-			{
-				curl_setopt ($ch, CURLOPT_SSL_VERIFYHOST, false); 
-				curl_setopt ($ch, CURLOPT_SSL_VERIFYPEER, false); 
-			}
+		    $ch = $this->getNewCurlHandle($url);
 			
 			curl_multi_add_handle($mh, $ch);
 			$aCurl[$url] = $ch;
@@ -424,8 +421,8 @@ class Archiving
 	    $urlNoSegment = $url;
 	    foreach ($this->segments as $segment) {
 	    	$segmentUrl = $url.'&segment='.urlencode($segment);
-			$ch = curl_init($segmentUrl);
-			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
+		    $ch = $this->getNewCurlHandle($segmentUrl);
+
 			curl_multi_add_handle($mh, $ch);
 			$aCurl[$segmentUrl] = $ch;
 			$this->requests++;
@@ -440,10 +437,10 @@ class Archiving
 	    $visitsAllDaysInPeriod = false;
         foreach($aCurl as $url => $ch){
         	$content = curl_multi_getcontent($ch);
-        	$sucessResponse = $this->checkResponse($content, $url);
-            $success = $sucessResponse && $success;
+        	$successResponse = $this->checkResponse($content, $url);
+            $success = $successResponse && $success;
             if($url == $urlNoSegment
-            	&& $sucessResponse)
+            	&& $successResponse)
             {
             	$stats = unserialize($content);
             	if(!is_array($stats))
@@ -464,8 +461,22 @@ class Archiving
                     . (!empty($timerWebsite) ? $timerWebsite->__toString() : $timer->__toString()));
 	    return $success;
 	}
-	
-	
+
+	private function getNewCurlHandle($url)
+	{
+		$ch = curl_init($url);
+		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
+
+		if ($this->acceptInvalidSSLCertificate) {
+			curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
+			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
+		}
+		curl_setopt($ch, CURLOPT_USERAGENT, Piwik_Http::getUserAgent());
+		Piwik_Http::configCurlCertificate($ch);
+		return $ch;
+	}
+
+
 	/**
 	 * Logs a section in the output
 	 */
@@ -483,7 +494,7 @@ class Archiving
 		// How to test the error handling code?
 		// - Generate some hits since last archive.php run
 		// - Start the script, in the middle, shutdown apache, then restore
-		// Some errors should be logged and script should succesfully finish and then report the errors and trigger a PHP error
+		// Some errors should be logged and script should successfully finish and then report the errors and trigger a PHP error
 		if(!empty($this->errors))
 		{
 			$this->logSection("SUMMARY OF ERRORS");
@@ -499,7 +510,7 @@ class Archiving
 		}
 		else
 		{
-			// No error -> Logs the succesful script execution until completion
+			// No error -> Logs the successful script execution until completion
 			Piwik_SetOption(self::OPTION_ARCHIVING_FINISHED_TS, time());
 		}
 	}
@@ -547,10 +558,10 @@ class Archiving
 	
 	public function logFatalError($m, $backtrace = true)
 	{
-		$this->log("ERROR: $m");
+		$this->logError($m);
 		$fe = fopen('php://stderr', 'w');
 	    fwrite($fe, "Error in the last Piwik archive.php run: \n" . $m 
-	            . ($backtrace ? "\n\n Here is the full output of the script:\n\n" . $this->output : '') 
+	            . ($backtrace ? "\n\n Here is the full errors output:\n\n" . $this->output : '') 
 	    );
 		trigger_error($m, E_USER_ERROR);
 		exit;
@@ -558,7 +569,16 @@ class Archiving
 	
 	private function logNetworkError($url, $response)
 	{
-		$this->logError("Got invalid response from API request: $url. Response was '$response'");
+		$message = "Got invalid response from API request: $url. ";
+		if(empty($response))
+		{
+			$message .= "The response was empty. This usually means a server error. This solution to this error is generally to increase the value of 'memory_limit' in your php.ini file. Please check your Web server Error Log file for more details.";
+		}
+		else
+		{
+			$message .= "Response was '$response'";
+		}
+		$this->logError($message);
 		return false;
 	}
 	
@@ -604,7 +624,7 @@ class Archiving
 			if($token_auth != $this->token_auth
 				|| strlen($token_auth) != 32)
 			{
-				die('<b>You must specify the Super User token_auth as a parameter to this script, eg. <code>&token_auth=XYZ</code> if you wish to run this script through the browser. </b><br>
+				die('<b>You must specify the Super User token_auth as a parameter to this script, eg. <code>?token_auth=XYZ</code> if you wish to run this script through the browser. </b><br>
 					However it is recommended to run it <a href="http://piwik.org/docs/setup-auto-archiving/">via cron in the command line</a>, since it can take a long time to run.<br/>
 					In a shell, execute for example the following to trigger archiving on the local Piwik server:<br/>
 					<code>$ /path/to/php /path/to/piwik/misc/cron/archive.php --url=http://your-website.org/path/to/piwik/</code>');
@@ -741,13 +761,13 @@ class Archiving
 			{
 				$processedDateInTz = Piwik_Date::factory((int)$timestampActiveTraffic, $timezone);
 				$currentDateInTz = Piwik_Date::factory('now', $timezone);
-				
+
 				if($processedDateInTz->toString() != $currentDateInTz->toString() )
 				{
 					$timezoneToProcess[] = $timezone;
 				}
 			}
-			
+
 			$websiteDayHasFinishedSinceLastRun = Piwik_SitesManager_API::getInstance()->getSitesIdFromTimezones($timezoneToProcess);
 			$websiteDayHasFinishedSinceLastRun = array_diff($websiteDayHasFinishedSinceLastRun, $this->websites);
 			$this->websiteDayHasFinishedSinceLastRun = $websiteDayHasFinishedSinceLastRun;
@@ -758,8 +778,6 @@ class Archiving
 				
 				$this->websites = array_merge($this->websites, $websiteDayHasFinishedSinceLastRun);
 			}
-
-			
 		}
 	}
 
