@@ -5,7 +5,7 @@
 #
 # @link http://piwik.org
 # @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
-# @version $Id: import_logs.py 6433 2012-06-01 10:33:17Z Cyril $
+# @version $Id: import_logs.py 7731 2013-01-04 04:30:42Z capedfuzz $
 #
 # For more info see: http://piwik.org/log-analytics/
 
@@ -64,7 +64,6 @@ DOWNLOAD_EXTENSIONS = (
 EXCLUDED_USER_AGENTS = (
     'adsbot-google',
     'ask jeeves',
-    'baiduspider+(',
     'bot-',
     'bot/',
     'ccooter/',
@@ -74,10 +73,11 @@ EXCLUDED_USER_AGENTS = (
     'googlebot',
     'ia_archiver',
     'java/',
+    'libwww',
     'mediapartners-google',
     'msnbot',
     'robot',
-    'sosospider+',
+    'spider',
     'surveybot',
     'twiceler',
     'voilabot',
@@ -186,7 +186,10 @@ class Configuration(object):
     class Error(Exception):
         pass
 
-    def __init__(self):
+    def _create_parser(self):
+        """
+        Initialize and return the OptionParser instance.
+        """
         option_parser = optparse.OptionParser(
             usage='Usage: %prog [options] log_file [ log_file [...] ]',
             description="Import HTTP access logs to Piwik. "
@@ -212,7 +215,12 @@ class Configuration(object):
         option_parser.add_option(
             '--show-progress', dest='show_progress',
             action='store_true', default=os.isatty(sys.stdout.fileno()),
-            help="Print a progress report every second"
+            help="Print a progress report X seconds (default: 1, use --show-progress-delay to override)"
+        )
+        option_parser.add_option(
+            '--show-progress-delay', dest='show_progress_delay',
+            type='int', default=1,
+            help="Change the default progress delay"
         )
         option_parser.add_option(
             '--add-sites-new-hosts', dest='add_sites_new_hosts',
@@ -316,13 +324,18 @@ class Configuration(object):
             '--log-format-name', dest='log_format_name', default=None,
             help=("Access log format to detect (supported are: %s). "
                   "When not specified, the log format will be autodetected by trying all supported log formats."
-                  % ', '.join(sorted(FORMATS.iterkeys()))
-        ))
+                  % ', '.join(sorted(FORMATS.iterkeys())))
+        )
         option_parser.add_option(
             '--log-format-regex', dest='log_format_regex', default=None,
             help="Access log regular expression. For an example of a supported Regex, see the source code of this file. "
                  "Overrides --log-format-name"
         )
+        option_parser.add_option(
+            '--log-hostname', dest='log_hostname', default=None,
+            help="Force this hostname for a log format that doesn't incldude it. All hits "
+            "will seem to came to this host"
+        )
         option_parser.add_option(
             '--skip', dest='skip', default=0, type='int',
             help="Skip the n first lines to start parsing/importing data at a given line for the specified log file",
@@ -333,6 +346,10 @@ class Configuration(object):
             "It should be set to the number of CPU cores in your server. "
             "You can also experiment with higher values which may increase performance until a certain point",
         )
+        option_parser.add_option(
+            '--recorder-max-payload-size', dest='recorder_max_payload_size', default=200, type='int',
+            help="Maximum number of log entries to record in one tracking request (default: %default). "
+        )
         option_parser.add_option(
             '--output', dest='output',
             help="Redirect output (stdout and stderr) to the specified file"
@@ -341,8 +358,27 @@ class Configuration(object):
             '--encoding', dest='encoding', default='utf8',
             help="Log files encoding (default: %default)"
         )
+        option_parser.add_option(
+            '--disable-bulk-tracking', dest='use_bulk_tracking',
+            default=True, action='store_false',
+            help="Disables use of bulk tracking so recorders record one hit at a time."
+        )
+        option_parser.add_option(
+            '--debug-force-one-hit-every-Ns', dest='force_one_action_interval', default=False, type='float',
+            help="Debug option that will force each recorder to record one hit every N secs."
+        )
+        option_parser.add_option(
+            '--invalidate-dates', dest='invalidate_dates', default=None,
+            help="Invalidate reports for the specified dates (format: YYYY-MM-DD,YYYY-MM-DD,...). "
+                 "By default, all dates found in the logs will be invalidated.",
+        )
+        return option_parser
 
 
+    def _parse_args(self, option_parser):
+        """
+        Parse the command line args and create self.options and self.filenames.
+        """
         self.options, self.filenames = option_parser.parse_args(sys.argv[1:])
 
         if self.options.output:
@@ -399,6 +435,10 @@ class Configuration(object):
             self.options.recorders = 1
 
 
+    def __init__(self):
+        self._parse_args(self._create_parser())
+
+
     def _get_token_auth(self):
         """
         If the token auth is not specified in the options, get it from Piwik.
@@ -477,6 +517,10 @@ class Statistics(object):
         def increment(self):
             self.value = self.counter.next()
 
+        def advance(self, n):
+            for i in range(n):
+                self.increment()
+
         def __str__(self):
             return str(int(self.value))
 
@@ -638,13 +682,15 @@ Performance summary
         latest_total_recorded = 0
         while not self.monitor_stop:
             current_total = stats.count_lines_recorded.value
-            print '%d lines parsed, %d lines recorded, %d records/sec' % (
+            time_elapsed = time.time() - self.time_start
+            print '%d lines parsed, %d lines recorded, %d records/sec (avg), %d records/sec (current)' % (
                 stats.count_lines_parsed.value,
                 current_total,
-                current_total - latest_total_recorded,
+                current_total / time_elapsed if time_elapsed != 0 else 0,
+                (current_total - latest_total_recorded) / config.options.show_progress_delay,
             )
             latest_total_recorded = current_total
-            time.sleep(1)
+            time.sleep(config.options.show_progress_delay)
 
     def start_monitor(self):
         t = threading.Thread(target=self._monitor)
@@ -665,7 +711,7 @@ class Piwik(object):
         pass
 
     @staticmethod
-    def _call(path, args, headers=None, url=None):
+    def _call(path, args, headers=None, url=None, data=None):
         """
         Make a request to the Piwik site. It is up to the caller to format
         arguments, to embed authentication, etc.
@@ -673,9 +719,14 @@ class Piwik(object):
         if url is None:
             url = config.options.piwik_url
         headers = headers or {}
-        # If Content-Type isn't defined, PHP do not parse the request's body.
-        headers['Content-type'] = 'application/x-www-form-urlencoded'
-        data = urllib.urlencode(args)
+
+        if data is None:
+            # If Content-Type isn't defined, PHP do not parse the request's body.
+            headers['Content-type'] = 'application/x-www-form-urlencoded'
+            data = urllib.urlencode(args)
+        elif not isinstance(data, basestring) and headers['Content-type'] == 'application/json':
+            data = json.dumps(data)
+
         request = urllib2.Request(url + path, data, headers)
         response = urllib2.urlopen(request)
         result = response.read()
@@ -723,7 +774,8 @@ class Piwik(object):
             raise urllib2.URLError('Piwik returned an invalid response: ' + res[:300])
 
 
-    def _call_wrapper(self, func, expected_response, *args, **kwargs):
+    @staticmethod
+    def _call_wrapper(func, expected_response, on_failure, *args, **kwargs):
         """
         Try to make requests to Piwik at most PIWIK_FAILURE_MAX_RETRY times.
         """
@@ -732,8 +784,14 @@ class Piwik(object):
             try:
                 response = func(*args, **kwargs)
                 if expected_response is not None and response != expected_response:
-                    raise urllib2.URLError("didn't receive the expected response. Response was %s "
-                    % ((response[:200] + '..') if len(response) > 200 else response))
+                    if on_failure is not None:
+                        error_message = on_failure(response, kwargs.get('data'))
+                    else:
+                        truncate_after = 200
+                        truncated_response = (response[:truncate_after] + '..') if len(response) > truncate_after else response
+                        error_message = "didn't receive the expected response. Response was %s " % truncated_response
+
+                    raise urllib2.URLError(error_message)
                 return response
             except (urllib2.URLError, httplib.HTTPException, ValueError), e:
                 logging.debug('Error when connecting to Piwik: %s', e)
@@ -750,12 +808,14 @@ class Piwik(object):
                 else:
                     time.sleep(PIWIK_DELAY_AFTER_FAILURE)
 
-    def call(self, path, args, expected_content=None, headers=None):
-        return self._call_wrapper(self._call, expected_content, path, args, headers)
-
-    def call_api(self, method, **kwargs):
-        return self._call_wrapper(self._call_api, None, method, **kwargs)
+    @classmethod
+    def call(cls, path, args, expected_content=None, headers=None, data=None, on_failure=None):
+        return cls._call_wrapper(cls._call, expected_content, on_failure, path, args, headers,
+                                    data=data)
 
+    @classmethod
+    def call_api(cls, method, **kwargs):
+        return cls._call_wrapper(cls._call_api, None, None, method, **kwargs)
 
 
 ##
@@ -778,6 +838,8 @@ class StaticResolver(object):
         try:
             site = sites[0]
         except (IndexError, KeyError):
+            logging.debug('response for SitesManager.getSiteFromId: %s', str(sites))
+            
             fatal_error(
                 "cannot get the main URL of this site: invalid site ID: %s" % site_id
             )
@@ -800,19 +862,28 @@ class DynamicResolver(object):
     Use Piwik API to determine the site ID.
     """
 
+    _add_site_lock = threading.Lock()
+
     def __init__(self):
         self._cache = {}
 
-    def _resolve(self, hit):
+    def _get_site_id_from_hit_host(self, hit):
         main_url = 'http://' + hit.host
-        res = piwik.call_api(
+        return piwik.call_api(
             'SitesManager.getSitesIdFromSiteUrl',
             url=main_url,
         )
-        if res:
-            # The site already exists.
-            site_id = res[0]['idsite']
-        else:
+
+    def _add_site(self, hit):
+        main_url = 'http://' + hit.host
+        DynamicResolver._add_site_lock.acquire()
+
+        try:
+            # After we obtain the lock, make sure the site hasn't already been created.
+            res = self._get_site_id_from_hit_host(hit)
+            if res:
+                return res[0]['idsite']
+
             # The site doesn't exist.
             logging.debug('No Piwik site found for the hostname: %s', hit.host)
             if config.options.site_id_fallback is not None:
@@ -832,13 +903,25 @@ class DynamicResolver(object):
                     logging.error("Couldn't create a Piwik site for host %s: %s",
                         hit.host, result.get('message'),
                     )
+                    return None
                 else:
                     site_id = result['value']
                     stats.piwik_sites_created.append((hit.host, site_id))
+                    return site_id
             else:
                 # The site doesn't exist, we don't want to create new sites and
                 # there's no default site ID. We thus have to ignore this hit.
-                site_id = None
+                return None
+        finally:
+            DynamicResolver._add_site_lock.release()
+
+    def _resolve(self, hit):
+        res = self._get_site_id_from_hit_host(hit)
+        if res:
+            # The site already exists.
+            site_id = res[0]['idsite']
+        else:
+            site_id = self._add_site(hit)
         if site_id is not None:
             stats.piwik_sites.add(site_id)
         return site_id
@@ -860,7 +943,7 @@ class DynamicResolver(object):
 
 
     def check_format(self, format):
-        if 'host' not in format.regex.groupindex:
+        if 'host' not in format.regex.groupindex and not config.options.log_hostname:
             fatal_error(
                 "the selected log format doesn't include the hostname: you must "
                 "specify the Piwik site ID with the --idsite argument"
@@ -878,49 +961,76 @@ class Recorder(object):
     recorders = []
 
     def __init__(self):
-        self.queue = Queue.Queue(maxsize=10000)
+        self.queue = Queue.Queue(maxsize=2)
 
-    @staticmethod
-    def launch(recorder_count):
+        # if bulk tracking disabled, make sure we can store hits outside of the Queue
+        if not config.options.use_bulk_tracking:
+            self.unrecorded_hits = []
+
+    @classmethod
+    def launch(cls, recorder_count):
         """
         Launch a bunch of Recorder objects in a separate thread.
         """
         for i in xrange(recorder_count):
             recorder = Recorder()
-            Recorder.recorders.append(recorder)
-            t = threading.Thread(target=recorder._run)
+            cls.recorders.append(recorder)
+
+            run = recorder._run_bulk if config.options.use_bulk_tracking else recorder._run_single
+            t = threading.Thread(target=run)
+
             t.daemon = True
             t.start()
             logging.debug('Launched recorder')
 
-    @staticmethod
-    def add_hit(hit):
+    @classmethod
+    def add_hits(cls, all_hits):
         """
-        Add a hit in one of the recorders queue.
+        Add a set of hits to the recorders queue.
         """
-        # Get a queue so that one client IP will always use the same queue.
-        recorders = Recorder.recorders
-        queue = recorders[abs(hash(hit.ip)) % len(recorders)].queue
-        queue.put(hit)
+        # Organize hits so that one client IP will always use the same queue.
+        # We have to do this so visits from the same IP will be added in the right order.
+        hits_by_client = [[] for r in cls.recorders]
+        for hit in all_hits:
+            hits_by_client[abs(hash(hit.ip)) % len(cls.recorders)].append(hit)
 
-    @staticmethod
-    def wait_empty():
+        for i, recorder in enumerate(cls.recorders):
+            recorder.queue.put(hits_by_client[i])
+
+    @classmethod
+    def wait_empty(cls):
         """
         Wait until all recorders have an empty queue.
         """
-        for recorder in Recorder.recorders:
+        for recorder in cls.recorders:
             recorder._wait_empty()
 
-
-    def _run(self):
+    def _run_bulk(self):
         while True:
-            hit = self.queue.get()
-            try:
-                self._record_hit(hit)
-            except Piwik.Error, e:
-                fatal_error(e, hit.filename, hit.lineno)
+            hits = self.queue.get()
+            if len(hits) > 0:
+                try:
+                    self._record_hits(hits)
+                except Piwik.Error, e:
+                    fatal_error(e, hits[0].filename, hits[0].lineno) # approximate location of error
             self.queue.task_done()
 
+    def _run_single(self):
+        while True:
+            if config.options.force_one_action_interval != False:
+                time.sleep(config.options.force_one_action_interval)
+
+            if len(self.unrecorded_hits) > 0:
+                hit = self.unrecorded_hits.pop(0)
+
+                try:
+                    self._record_hits([hit])
+                except Piwik.Error, e:
+                    fatal_error(e, hit.filename, hit.lineno)
+            else:
+                self.unrecorded_hits = self.queue.get()
+                self.queue.task_done()
+
     def _wait_empty(self):
         """
         Wait until the queue is empty.
@@ -938,9 +1048,9 @@ class Recorder(object):
         date, time = date.isoformat(sep=' ').split()
         return '%s %s' % (date, time.replace('-', ':'))
 
-    def _record_hit(self, hit):
+    def _get_hit_args(self, hit):
         """
-        Insert the hit into Piwik.
+        Returns the args used in tracking a hit, without the token_auth.
         """
         site_id, main_url = resolver.resolve(hit)
         if site_id is None:
@@ -964,8 +1074,10 @@ class Recorder(object):
             'cdt': self.date_to_piwik(hit.date),
             'idsite': site_id,
             'dp': '0' if config.options.reverse_dns else '1',
-            'token_auth': config.options.piwik_token_auth,
+            'ua': hit.user_agent.encode('utf8'),
         }
+        args.update(hit.args)
+
         if hit.is_download:
             args['download'] = args['url']
         if hit.is_robot:
@@ -980,28 +1092,64 @@ class Recorder(object):
                 urllib.quote(args['url'], ''),
                 ("/From = %s" % urllib.quote(args['urlref'], '') if args['urlref'] != ''  else '')
             )
+        return args
+
+    def _record_hits(self, hits):
+        """
+        Inserts several hits into Piwik.
+        """
+        data = {
+            'token_auth': config.options.piwik_token_auth,
+            'requests': [self._get_hit_args(hit) for hit in hits]
+        }
 
         if not config.options.dry_run:
             piwik.call(
-                '/piwik.php', args,
+                '/piwik.php', args={},
                 expected_content=PIWIK_EXPECTED_IMAGE,
-                headers={'User-Agent' : hit.user_agent.encode('utf8')},
+                headers={'Content-type': 'application/json'},
+                data=data,
+                on_failure=self._on_tracking_failure
             )
-        stats.count_lines_recorded.increment()
+        stats.count_lines_recorded.advance(len(hits))
 
+    def _on_tracking_failure(self, response, data):
+        """
+        Removes the successfully tracked hits from the request payload so
+        they are not logged twice.
+        """
+        try:
+            response = json.loads(response)
+        except:
+            # the response should be in JSON, but in case it can't be parsed just try another attempt
+            logging.debug("cannot parse tracker response, should be valid JSON")
+            return response
+
+        # remove the successfully tracked hits from payload
+        succeeded = response['succeeded']
+        data['requests'] = data['requests'][succeeded:]
+
+        return response['error']
 
     @staticmethod
     def invalidate_reports():
         if config.options.dry_run or not stats.dates_recorded:
             return
 
-        dates = [date.strftime('%Y-%m-%d') for date in stats.dates_recorded]
-        print 'Purging Piwik archives for dates: ' + ' '.join(dates)
-        result = piwik.call_api(
-            'CoreAdminHome.invalidateArchivedReports',
-            dates=','.join(dates),
-            idSites=','.join(str(site_id) for site_id in stats.piwik_sites),
-        )
+        if config.options.invalidate_dates is not None:
+            dates = [date for date in config.options.invalidate_dates.split(',') if date]
+        else:
+            dates = [date.strftime('%Y-%m-%d') for date in stats.dates_recorded]
+        if dates:
+            print 'Purging Piwik archives for dates: ' + ' '.join(dates)
+            result = piwik.call_api(
+                'CoreAdminHome.invalidateArchivedReports',
+                dates=','.join(dates),
+                idSites=','.join(str(site_id) for site_id in stats.piwik_sites),
+            )
+            print('To re-process these reports with your new update data, execute the '
+                  'piwik/misc/cron/archive.php script, or see: http://piwik.org/setup-auto-archiving/ '
+                  'for more info.')
 
 
 
@@ -1022,6 +1170,12 @@ class Parser(object):
     a Queue.
     """
 
+    def __init__(self):
+        self.check_methods = [method for name, method
+                              in inspect.getmembers(self, predicate=inspect.ismethod)
+                              if name.startswith('check_')]
+
+
     ## All check_* methods are called for each hit and must return True if the
     ## hit can be imported, False otherwise.
 
@@ -1040,21 +1194,21 @@ class Parser(object):
         return result
 
     def check_static(self, hit):
-        for extension in STATIC_EXTENSIONS:
-            if hit.path.lower().endswith(extension):
-                if config.options.enable_static:
-                    hit.is_download = True
-                    return True
-                else:
-                    stats.count_lines_static.increment()
-                    return False
+        extension = hit.path.rsplit('.')[-1].lower()
+        if extension in STATIC_EXTENSIONS:
+            if config.options.enable_static:
+                hit.is_download = True
+                return True
+            else:
+                stats.count_lines_static.increment()
+                return False
         return True
 
     def check_download(self, hit):
-        for extension in DOWNLOAD_EXTENSIONS:
-            if hit.path.lower().endswith(extension):
-                stats.count_lines_downloads.increment()
-                hit.is_download = True
+        extension = hit.path.rsplit('.')[-1].lower()
+        if extension in DOWNLOAD_EXTENSIONS:
+            stats.count_lines_downloads.increment()
+            hit.is_download = True
         return True
 
     def check_user_agent(self, hit):
@@ -1070,7 +1224,7 @@ class Parser(object):
         return True
 
     def check_http_error(self, hit):
-        if hit.status.startswith('4') or hit.status.startswith('5'):
+        if hit.status[0] in ('4', '5'):
             if config.options.enable_http_errors:
                 hit.is_error = True
                 return True
@@ -1080,7 +1234,7 @@ class Parser(object):
         return True
 
     def check_http_redirect(self, hit):
-        if hit.status.startswith('3') and hit.status != '304':
+        if hit.status[0] == '3' and hit.status != '304':
             if config.options.enable_http_redirects:
                 hit.is_redirect = True
                 return True
@@ -1141,6 +1295,12 @@ class Parser(object):
             # The format was explicitely specified.
             format = config.format
         else:
+            # If the file is empty, don't bother.
+            data = file.read(100)
+            if len(data.strip()) == 0:
+                return
+            file.seek(0)
+
             format = self.detect_format(file)
             if format is None:
                 return fatal_error(
@@ -1150,6 +1310,7 @@ class Parser(object):
         # Make sure the format is compatible with the resolver.
         resolver.check_format(format)
 
+        hits = []
         for lineno, line in enumerate(file):
             try:
                 line = line.decode(config.options.encoding)
@@ -1175,6 +1336,7 @@ class Parser(object):
                 is_robot=False,
                 is_error=False,
                 is_redirect=False,
+                args={},
             )
 
             try:
@@ -1183,26 +1345,6 @@ class Parser(object):
             except IndexError:
                 hit.path, _, hit.query_string = hit.full_path.partition(config.options.query_string_delimiter)
 
-            # Parse date
-            date_string = match.group('date')
-            try:
-                hit.date = datetime.datetime.strptime(date_string, format.date_format)
-            except ValueError:
-                invalid_line(line, 'invalid date')
-                continue
-
-            # Parse timezone and substract its value from the date
-            try:
-                timezone = float(match.group('timezone'))
-            except IndexError:
-                timezone = 0
-            except ValueError:
-                invalid_line(line, 'invalid timezone')
-                continue
-
-            if timezone:
-                hit.date -= datetime.timedelta(hours=timezone/100)
-
             try:
                 hit.referrer = match.group('referrer')
             except IndexError:
@@ -1221,16 +1363,53 @@ class Parser(object):
             except (ValueError, IndexError):
                 # Some lines or formats don't have a length (e.g. 304 redirects, IIS logs)
                 hit.length = 0
-            try:
-                hit.host = match.group('host')
-            except IndexError:
-                # Some formats have no host.
-                pass
+
+            if config.options.log_hostname:
+                hit.host = config.options.log_hostname
+            else:
+                try:
+                    hit.host = match.group('host').lower().strip('.')
+                except IndexError:
+                    # Some formats have no host.
+                    pass
 
             # Check if the hit must be excluded.
-            check_methods = inspect.getmembers(self, predicate=inspect.ismethod)
-            if all((method(hit) for name, method in check_methods if name.startswith('check_'))):
-                Recorder.add_hit(hit)
+            if not all((method(hit) for method in self.check_methods)):
+                continue
+
+            # Parse date.
+            # We parse it after calling check_methods as it's quite CPU hungry, and
+            # we want to avoid that cost for excluded hits.
+            date_string = match.group('date')
+            try:
+                hit.date = datetime.datetime.strptime(date_string, format.date_format)
+            except ValueError:
+                invalid_line(line, 'invalid date')
+                continue
+
+            # Parse timezone and substract its value from the date
+            try:
+                timezone = float(match.group('timezone'))
+            except IndexError:
+                timezone = 0
+            except ValueError:
+                invalid_line(line, 'invalid timezone')
+                continue
+
+            if timezone:
+                hit.date -= datetime.timedelta(hours=timezone/100)
+
+            # Check if the hit must be excluded.
+            if all((method(hit) for method in self.check_methods)):
+                hits.append(hit)
+
+                if len(hits) >= config.options.recorder_max_payload_size * len(Recorder.recorders):
+                    Recorder.add_hits(hits)
+                    hits = []
+
+        # add last chunk of hits
+        if len(hits) > 0:
+            Recorder.add_hits(hits)
 
 
 
@@ -1239,11 +1418,11 @@ def main():
     """
     Start the importing process.
     """
+    stats.set_time_start()
+
     if config.options.show_progress:
         stats.start_monitor()
 
-    stats.set_time_start()
-
     recorders = Recorder.launch(config.options.recorders)
 
     try:
