@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 6028 2012-03-10 03:47:35Z vipsoft $
+ * @version $Id: Controller.php 7314 2012-10-26 02:00:20Z matt $
  * 
  * @category Piwik_Plugins
  * @package Piwik_CoreAdminHome
@@ -54,6 +54,13 @@ class Piwik_CoreAdminHome_Controller extends Piwik_Controller_Admin
 			$directoryWritable = is_writable(PIWIK_DOCUMENT_ROOT.'/themes/');
 			$logoFilesWriteable = is_writeable(PIWIK_DOCUMENT_ROOT.'/themes/logo.png') && is_writeable(PIWIK_DOCUMENT_ROOT.'/themes/logo-header.png');
 			$view->logosWriteable = ($logoFilesWriteable || $directoryWritable) && ini_get('file_uploads') == 1;
+			
+			$trustedHosts = array();
+			if (isset(Piwik_Config::getInstance()->General['trusted_hosts']))
+			{
+				$trustedHosts = Piwik_Config::getInstance()->General['trusted_hosts'];
+			}
+			$view->trustedHosts = $trustedHosts;
 		}
 		
 		$view->language = Piwik_LanguagesManager::getLanguageCodeForCurrentUser();
@@ -87,8 +94,17 @@ class Piwik_CoreAdminHome_Controller extends Piwik_Controller_Admin
 			Piwik_Config::getInstance()->mail = $mail;
 			
 			// update branding settings
-			Piwik_Config::getInstance()->branding['use_custom_logo'] = Piwik_Common::getRequestVar('useCustomLogo', '0');
-
+			$branding = Piwik_Config::getInstance()->branding;
+			$branding['use_custom_logo'] = Piwik_Common::getRequestVar('useCustomLogo', '0');
+			Piwik_Config::getInstance()->branding = $branding;
+			
+			// update trusted host settings
+			$trustedHosts = Piwik_Common::getRequestVar('trustedHosts', false, 'json');
+			if ($trustedHosts !== false)
+			{
+				Piwik_Url::saveTrustedHostnameInConfig($trustedHosts);
+			}
+			
 			Piwik_Config::getInstance()->forceSave();
 			
 			$toReturn = $response->getResponse();
