@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: CoreAdminHome.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: CoreAdminHome.php 7747 2013-01-13 11:12:13Z matt $
  * 
  * @category Piwik_Plugins
  * @package Piwik_CoreAdminHome
@@ -32,6 +32,7 @@ class Piwik_CoreAdminHome extends Piwik_Plugin
 			'AssetManager.getCssFiles' => 'getCssFiles',
 			'AssetManager.getJsFiles' => 'getJsFiles',
 			'AdminMenu.add' => 'addMenu',
+			'TopMenu.add' => 'addTopMenu',
 			'TaskScheduler.getScheduledTasks' => 'getScheduledTasks',
 		);
 	}
@@ -43,6 +44,14 @@ class Piwik_CoreAdminHome extends Piwik_Plugin
 	{
 		$tasks = &$notification->getNotificationObject();
 		
+		// general data purge on older archive tables, executed daily
+		$priority = Piwik_ScheduledTask::HIGH_PRIORITY;
+		$purgeArchiveTablesTask = new Piwik_ScheduledTask ( $this,
+															'purgeOutdatedArchives',
+															new Piwik_ScheduledTime_Daily(),
+															$priority );
+		$tasks[] = $purgeArchiveTablesTask;
+							
 		// lowest priority since tables should be optimized after they are modified
 		$priority = Piwik_ScheduledTask::LOWEST_PRIORITY;
 		$optimizeArchiveTableTask = new Piwik_ScheduledTask ( $this, 
@@ -63,6 +72,7 @@ class Piwik_CoreAdminHome extends Piwik_Plugin
 		$cssFiles[] = "plugins/CoreAdminHome/templates/menu.css";	
 		$cssFiles[] = "themes/default/common.css";
 		$cssFiles[] = "plugins/CoreAdminHome/templates/styles.css";
+		$cssFiles[] = "plugins/CoreHome/templates/donate.css";
 	}
 
 	/**
@@ -76,9 +86,11 @@ class Piwik_CoreAdminHome extends Piwik_Plugin
 		$jsFiles[] = "libs/jquery/jquery-ui.js";
 		$jsFiles[] = "libs/javascript/sprintf.js";
 		$jsFiles[] = "themes/default/common.js";
+		$jsFiles[] = "themes/default/ajaxHelper.js";
 		$jsFiles[] = "libs/jquery/jquery.history.js";
 		$jsFiles[] = "plugins/CoreHome/templates/broadcast.js";
 		$jsFiles[] = "plugins/CoreAdminHome/templates/generalSettings.js";
+		$jsFiles[] = "plugins/CoreHome/templates/donate.js";
 	}
 	
 	function addMenu()
@@ -89,19 +101,32 @@ class Piwik_CoreAdminHome extends Piwik_Plugin
 							$order = 6);
 	}
 	
-	function optimizeArchiveTable()
+	function addTopMenu()
 	{
-		$tablesPiwik = Piwik::getTablesInstalled();
-		$archiveTables = array_filter ($tablesPiwik, array("Piwik_CoreAdminHome", "isArchiveTable"));
-		if(empty($archiveTables))
+		$donateLinkTitle = Piwik_Translate('CoreHome_OnlyForAdmin');
+		Piwik_AddTopMenu('General_Donate',
+							'<a href="http://piwik.org/donate/" target="_blank" title="'.$donateLinkTitle.'">'
+								.Piwik_Translate('General_Donate').'</a> |',
+							Piwik::isUserIsSuperUser(),
+							$order = 21,
+							$isHTML = true);
+	}
+
+	function purgeOutdatedArchives()
+	{
+		$archiveTables = Piwik::getTablesArchivesInstalled();
+		foreach($archiveTables as $table)
 		{
-			return;
+			if(strpos($table, 'numeric') !== false)
+			{
+				Piwik_ArchiveProcessing_Period::doPurgeOutdatedArchives($table);
+			}
 		}
-		Piwik_OptimizeTables($archiveTables);
 	}
 	
-	private function isArchiveTable ( $tableName )
+	function optimizeArchiveTable()
 	{
-		return preg_match ( '/'.Piwik_Common::prefixTable('archive_').'/', $tableName ) > 0;
+		$archiveTables = Piwik::getTablesArchivesInstalled();
+		Piwik_OptimizeTables($archiveTables);
 	}
 }
