@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Dashboard.php 6253 2012-05-07 19:28:09Z SteveG $
+ * @version $Id: Dashboard.php 7533 2012-11-22 22:36:18Z SteveG $
  * 
  * @category Piwik_Plugins
  * @package Piwik_Dashboard
@@ -43,9 +43,7 @@ class Piwik_Dashboard extends Piwik_Plugin
 		$pos = 0;
 		$nameless = 1;
 		foreach ($dashboards AS &$dashboard) {
-			if (!empty($dashboard['name'])) {
-				$dashboard['name'] = Piwik_Common::unsanitizeInputValue($dashboard['name']);
-			} else {
+			if (empty($dashboard['name'])) {
 				$dashboard['name'] = Piwik_Translate('Dashboard_DashboardOf', $login);
 				if($nameless > 1) {
 					$dashboard['name'] .= " ($nameless)";
@@ -62,6 +60,7 @@ class Piwik_Dashboard extends Piwik_Plugin
 				$dashboard['layout'] = Piwik_Common::json_decode($layout);
 				$nameless++;
 			}
+			$dashboard['name'] = Piwik_Common::unsanitizeInputValue($dashboard['name']);
 			$pos++;
 		}
 		return $dashboards;
@@ -89,7 +88,19 @@ class Piwik_Dashboard extends Piwik_Plugin
 
 	public function addTopMenu()
 	{
-		Piwik_AddTopMenu('General_Dashboard', array('module' => 'CoreHome', 'action' => 'index'), true, 1);
+		$tooltip = false;
+		try
+		{
+			$idSite = Piwik_Common::getRequestVar('idSite');
+			$tooltip = Piwik_Translate('Dashboard_TopLinkTooltip', Piwik_Site::getNameFor($idSite));
+		}
+		catch (Exception $ex)
+		{
+			// if no idSite parameter, show no tooltip
+		}
+		
+		$urlParams = array('module' => 'CoreHome', 'action' => 'index');
+		Piwik_AddTopMenu('General_Dashboard', $urlParams, true, 1, $isHTML = false, $tooltip);
 	}
 
 	/**
