@@ -4,13 +4,18 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: API.php 3270 2010-10-28 18:21:55Z vipsoft $
+ * @version $Id: API.php 7627 2012-12-15 01:32:38Z capedfuzz $
  * 
  * @category Piwik_Plugins
  * @package Piwik_ExampleUI
  */
 
 /**
+ * ExampleUI API is also an example API useful if you are developing a Piwik plugin.
+ * 
+ * The functions listed in this API are returning the data used in the Controller to draw graphs and 
+ * display tables. See also the ExampleAPI plugin for an introduction to Piwik APIs.
+ * 
  * @package Piwik_ExampleUI
  */
 class Piwik_ExampleUI_API 
@@ -42,8 +47,8 @@ class Piwik_ExampleUI_API
 		// to keep things simple, we generate the data
 		foreach($period->getSubperiods() as $subPeriod)
 		{
-			$server1 = rand(50,90);
-			$server2 = rand(40, 110);
+			$server1 = mt_rand(50,90);
+			$server2 = mt_rand(40, 110);
 			$value = array('server1' => $server1, 'server2' => $server2);
 			$temperatures[$subPeriod->getLocalizedShortString()] = $value;
 		}
