@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 6077 2012-03-20 22:19:40Z matt $
+ * @version $Id: Controller.php 7474 2012-11-14 21:31:35Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_Goals
@@ -108,7 +108,6 @@ class Piwik_Goals_Controller extends Piwik_Controller
 			$columns['quantity'] = Piwik_Translate('Goals_LeftInCart', Piwik_Translate('General_Quantity'));
 			$columns['avg_quantity'] = Piwik_Translate('Goals_LeftInCart', Piwik_Translate('General_AverageQuantity'));
 			unset($columns['orders']);
-			unset($columns['nb_visits']);
 			unset($columns['conversion_rate']);
 			$_GET['abandonedCarts'] = 1;
 		}
@@ -156,7 +155,7 @@ class Piwik_Goals_Controller extends Piwik_Controller
 	public function getEcommerceLog($fetch = false)
 	{
 		$saveGET = $_GET;
-		$_GET['filterEcommerce'] = 1;
+		$_GET['filterEcommerce'] = Piwik_Common::getRequestVar('filterEcommerce', 1, 'int');
 		$_GET['widget'] = 1;
 		$_GET['segment'] = 'visitEcommerceStatus!=none';
 		$output = Piwik_FrontController::getInstance()->dispatch('Live', 'getVisitorLog', array($fetch));
@@ -195,7 +194,7 @@ class Piwik_Goals_Controller extends Piwik_Controller
 				$name = 'cart_'.$name;
 				$view->$name = $value;
 			}
-		}		
+		}
 		$view->idGoal = $idGoal;
 		$view->goalName = $goalDefinition['name'];
 		$view->goalAllowMultipleConversionsPerVisit = $goalDefinition['allow_multiple'];
