@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Goals.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: Goals.php 7560 2012-11-30 00:19:43Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_Goals
@@ -159,6 +159,7 @@ class Piwik_Goals extends Piwik_Plugin
 				'module' => 'Goals',
 				'action' => 'getVisitsUntilConversion',
 				'dimension' => Piwik_Translate('Goals_VisitsUntilConv'),
+				'constantRowsCount' => true,
 				'parameters' => array(),
 				'metrics' => $conversionReportMetrics,
 				'order' => 5
@@ -171,6 +172,7 @@ class Piwik_Goals extends Piwik_Plugin
 				'module' => 'Goals',
 				'action' => 'getDaysToConversion',
 				'dimension' => Piwik_Translate('Goals_DaysToConv'),
+				'constantRowsCount' => true,
 				'parameters' => array(),
 				'metrics' => $conversionReportMetrics,
 				'order' => 10
@@ -199,6 +201,7 @@ class Piwik_Goals extends Piwik_Plugin
 					'module' => 'Goals',
 					'action' => 'getVisitsUntilConversion',
 					'dimension' => Piwik_Translate('Goals_VisitsUntilConv'),
+					'constantRowsCount' => true,
 					'parameters' => array('idGoal' => $goal['idgoal']),
 					'metrics' => $conversionReportMetrics,
 					'order' => 51 + $goal['idgoal'] * 3
@@ -211,6 +214,7 @@ class Piwik_Goals extends Piwik_Plugin
 					'module' => 'Goals',
 					'action' => 'getDaysToConversion',
 					'dimension' => Piwik_Translate('Goals_DaysToConv'),
+					'constantRowsCount' => true,
 					'parameters' => array('idGoal' => $goal['idgoal']),
 					'metrics' => $conversionReportMetrics,
 					'order' => 52 + $goal['idgoal'] * 3
@@ -248,6 +252,7 @@ class Piwik_Goals extends Piwik_Plugin
 					'module' => 'Goals',
 					'action' => 'getVisitsUntilConversion',
 					'dimension' => Piwik_Translate('Goals_VisitsUntilConv'),
+					'constantRowsCount' => true,
 					'metrics' => $conversionReportMetrics,
 					'parameters' => array('idGoal' => Piwik_Archive::LABEL_ECOMMERCE_ORDER),
 					'order' => 11
@@ -258,6 +263,7 @@ class Piwik_Goals extends Piwik_Plugin
 					'module' => 'Goals',
 					'action' => 'getDaysToConversion',
 					'dimension' => Piwik_Translate('Goals_DaysToConv'),
+					'constantRowsCount' => true,
 					'metrics' => $conversionReportMetrics,
 					'parameters' => array('idGoal' => Piwik_Archive::LABEL_ECOMMERCE_ORDER),
 					'order' => 12
@@ -288,6 +294,7 @@ class Piwik_Goals extends Piwik_Plugin
 					'module' => 'Goals',
 					'action' => 'getVisitsUntilConversion',
 					'dimension' => Piwik_Translate('Goals_VisitsUntilConv'),
+					'constantRowsCount' => true,
 					'metrics' => $conversionReportMetrics,
 					'parameters' => array('idGoal' => Piwik_Archive::LABEL_ECOMMERCE_CART),
 					'order' => 20
@@ -298,6 +305,7 @@ class Piwik_Goals extends Piwik_Plugin
 					'module' => 'Goals',
 					'action' => 'getDaysToConversion',
 					'dimension' => Piwik_Translate('Goals_DaysToConv'),
+					'constantRowsCount' => true,
 					'metrics' => $conversionReportMetrics,
 					'parameters' => array('idGoal' => Piwik_Archive::LABEL_ECOMMERCE_CART),
 					'order' => 25
@@ -802,7 +810,11 @@ class Piwik_Goals extends Piwik_Plugin
 						continue;
 					}
 					// Product Name/Category not defined"
-					$label = Piwik_CustomVariables::LABEL_CUSTOM_VALUE_NOT_DEFINED;
+					if(class_exists('Piwik_CustomVariables')) {
+						$label = Piwik_CustomVariables::LABEL_CUSTOM_VALUE_NOT_DEFINED;
+					} else {
+						$label = "Value not defined";
+					}
 				}
 				// For carts, idorder = 0. To count abandoned carts, we must count visits with an abandoned cart
 				if($ecommerceType == Piwik_Tracker_GoalManager::IDGOAL_CART)
