@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Evolution.php 6112 2012-03-25 10:04:17Z JulienM $
+ * @version $Id: Evolution.php 7026 2012-09-20 06:36:09Z JulienM $
  *
  * @category Piwik_Plugins
  * @package Piwik_ImageGraph_StaticGraph
@@ -22,9 +22,10 @@ class Piwik_ImageGraph_StaticGraph_Evolution extends Piwik_ImageGraph_StaticGrap
 	{
 		$this->initGridChart(
 			$displayVerticalGridLines = true,
-			$drawCircles = true,
+			$bulletType = LEGEND_FAMILY_LINE,
 			$horizontalGraph = false,
-			$showTicks = true
+			$showTicks = true,
+			$verticalLegend = true
 		);
 
 		$this->pImage->drawLineChart();
