@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Exception.php 6112 2012-03-25 10:04:17Z JulienM $
+ * @version $Id: Exception.php 7303 2012-10-24 12:03:32Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_ImageGraph_StaticGraph
@@ -31,29 +31,45 @@ class Piwik_ImageGraph_StaticGraph_Exception extends Piwik_ImageGraph_StaticGrap
 		return array();
 	}
 
+
+	public function setWidth($width)
+	{
+		if(empty($width)) {
+			$width = 450;
+		}
+		parent::setWidth($width);
+	}
+
+	public function setHeight($height)
+	{
+		if(empty($height)) {
+			$height = 300;
+		}
+		parent::setHeight($height);
+	}
+
 	public function renderGraph()
 	{
 		$this->pData = new pData();
 
 		$message = $this->exception->getMessage();
-		$messageWidthHeight = $this->getTextWidthHeight($message, false);
-		$messageHeight = $messageWidthHeight[self::HEIGHT_KEY];
+		list($textWidth, $textHeight) = $this->getTextWidthHeight($message);
 
 		if($this->width == null)
 		{
-			$this->width = $messageWidthHeight[self::WIDTH_KEY] + self::MESSAGE_RIGHT_MARGIN;
+			$this->width = $textWidth + self::MESSAGE_RIGHT_MARGIN;
 		}
 
 		if($this->height == null)
 		{
-			$this->height = $messageHeight;
+			$this->height = $textHeight;
 		}
 
 		$this->initpImage();
 
 		$this->pImage->drawText(
 			0,
-			$messageHeight,
+			$textHeight,
 			$message
 		);
 	}
