@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 6371 2012-05-29 09:13:39Z capedfuzz $
+ * @version $Id: Controller.php 7690 2012-12-23 03:36:20Z capedfuzz $
  *
  * @category Piwik_Plugins
  * @package Piwik_Installation
@@ -15,7 +15,7 @@
  *
  * @package Piwik_Installation
  */
-class Piwik_Installation_Controller extends Piwik_Controller
+class Piwik_Installation_Controller extends Piwik_Controller_Admin
 {
 	// public so plugins can add/delete installation steps
 	public $steps = array(
@@ -101,32 +101,17 @@ class Piwik_Installation_Controller extends Piwik_Controller
 						__FUNCTION__
 					);
 		$this->skipThisStep( __FUNCTION__ );
-
-		$view->infos = self::getSystemInformation();
+		
+		$view->duringInstall = true;
+		
+		$this->setupSystemCheckView($view);
 		$this->session->general_infos = $view->infos['general_infos'];
 		
-		$view->helpMessages = array(
-			'zlib'            => 'Installation_SystemCheckZlibHelp',
-			'SPL'             => 'Installation_SystemCheckSplHelp',
-			'iconv'           => 'Installation_SystemCheckIconvHelp',
-			'Reflection'	  => 'Required extension that is built in PHP, see http://www.php.net/manual/en/book.reflection.php',
-			'json'            => 'Installation_SystemCheckWarnJsonHelp',
-			'libxml'          => 'Installation_SystemCheckWarnLibXmlHelp',
-			'dom'             => 'Installation_SystemCheckWarnDomHelp',
-			'SimpleXML'       => 'Installation_SystemCheckWarnSimpleXMLHelp',
-			'set_time_limit'  => 'Installation_SystemCheckTimeLimitHelp',
-			'mail'            => 'Installation_SystemCheckMailHelp',
-			'parse_ini_file'  => 'Installation_SystemCheckParseIniFileHelp',
-			'glob'            => 'Installation_SystemCheckGlobHelp',
-			'debug_backtrace' => 'Installation_SystemCheckDebugBacktraceHelp',
-			'create_function' => 'Installation_SystemCheckCreateFunctionHelp',
-			'eval'            => 'Installation_SystemCheckEvalHelp',
-			'gzcompress'      => 'Installation_SystemCheckGzcompressHelp',
-			'gzuncompress'    => 'Installation_SystemCheckGzuncompressHelp',
-			'pack'            => 'Installation_SystemCheckPackHelp',
-		);
-
-		$view->problemWithSomeDirectories = (false !== array_search(false, $view->infos['directories']));
+		// make sure DB sessions are used if the filesystem is NFS
+		if ($view->infos['is_nfs'])
+		{
+			$this->session->general_infos['session_save_handler'] = 'dbtable';
+		}
 
 		$view->showNextStep = !$view->problemWithSomeDirectories
 							&& $view->infos['phpVersion_ok']
@@ -167,7 +152,7 @@ class Piwik_Installation_Controller extends Piwik_Controller
 
 		$form = new Piwik_Installation_FormDatabaseSetup();
 
-		if($form->validate())
+		if ($form->validate())
 		{
 			try
 			{
@@ -450,18 +435,19 @@ class Piwik_Installation_Controller extends Piwik_Controller
 			$this->session->firstWebsiteSetupSuccessMessage = true;
 		}
 		$siteName = $this->session->site_name;
+		$siteName = Piwik_Common::sanitizeInputValue( urldecode($siteName) );
 		$idSite = $this->session->site_idSite;
 
 		// Load the Tracking code and help text from the SitesManager 
 		$viewTrackingHelp = new Piwik_View('SitesManager/templates/DisplayJavascriptCode.tpl');
-		$viewTrackingHelp->displaySiteName = urldecode($siteName);
+		$viewTrackingHelp->displaySiteName = $siteName;
 		$viewTrackingHelp->jsTag = Piwik::getJavascriptCode($idSite, Piwik_Url::getCurrentUrlWithoutFileName());
 		$viewTrackingHelp->idSite = $idSite;		
 		$viewTrackingHelp->piwikUrl = Piwik_Url::getCurrentUrlWithoutFileName();		
 
 		// Assign the html output to a smarty variable
 		$view->trackingHelp = $viewTrackingHelp->render();
-		$view->displaySiteName = urldecode($siteName);
+		$view->displaySiteName = $siteName;
 		
 		$view->showNextStep = true;
 
@@ -497,6 +483,32 @@ class Piwik_Installation_Controller extends Piwik_Controller
 		$this->session->unsetAll();
 	}
 
+	/**
+	 * This controller action renders an admin tab that runs the installation
+	 * system check, so people can see if there are any issues w/ their running
+	 * Piwik installation.
+	 * 
+	 * This admin tab is only viewable by the super user.
+	 */
+	public function systemCheckPage()
+	{
+		Piwik::checkUserIsSuperUser();
+		
+		$view = Piwik_View::factory('systemCheckPage');
+		$this->setBasicVariablesView($view);
+		$view->menu = Piwik_GetAdminMenu();
+		
+		$view->duringInstall = false;
+		
+		$this->setupSystemCheckView($view);
+		
+		$infos = $view->infos;
+		$infos['extra'] = self::performAdminPageOnlySystemCheck();
+		$view->infos = $infos;
+		
+		echo $view->render();
+	}
+	
 	/**
 	 * Instantiate access and log objects
 	 */
@@ -848,7 +860,7 @@ class Piwik_Installation_Controller extends Piwik_Controller
 		$infos['protocol'] = Piwik_ProxyHeaders::getProtocolInformation();
 		if(!Piwik::isHttps() && $infos['protocol'] !== null)
 		{
-			$infos['general_infos']['secure_protocol'] = '1';
+			$infos['general_infos']['assume_secure_protocol'] = '1';
 		}
 		if(count($headers = Piwik_ProxyHeaders::getProxyClientHeaders()) > 0)
 		{
@@ -858,6 +870,35 @@ class Piwik_Installation_Controller extends Piwik_Controller
 		{
 			$infos['general_infos']['proxy_host_headers'] = $headers;
 		}
+		
+		// check if filesystem is NFS, if it is file based sessions won't work properly
+		$infos['is_nfs'] = Piwik::checkIfFileSystemIsNFS();
+		
+		// determine whether there are any errors/warnings from the checks done above
+		$infos['has_errors'] = false;
+		$infos['has_warnings'] = false;
+		if (in_array(0, $infos['directories']) // if a directory is not writable
+			|| !$infos['phpVersion_ok']
+			|| !empty($infos['missing_extensions'])
+			|| empty($infos['adapters'])
+			|| !empty($infos['missing_functions']))
+		{
+			$infos['has_errors'] = true;
+		}
+		
+		if (!$infos['can_auto_update']
+			|| !empty($infos['missing_desired_extensions'])
+			|| !$infos['gd_ok']
+			|| !$infos['multibyte_ok']
+			|| !$infos['registerGlobals_ok']
+			|| !$infos['memory_ok']
+			|| !empty($infos['integrityErrorMessages'])
+			|| !$infos['timezone'] // if timezone support isn't available
+			|| $infos['tracker_status'] != 0
+			|| $infos['is_nfs'])
+		{
+			$infos['has_warnings'] = true;
+		}
 
 		return $infos;
 	}
@@ -894,4 +935,80 @@ class Piwik_Installation_Controller extends Piwik_Controller
 		}
 		return $exists;
 	}
+	
+	/**
+	 * Utility function, sets up a view that will display system check info.
+	 * 
+	 * @param Piwik_View $view
+	 */
+	private function setupSystemCheckView( $view )
+	{
+		$view->infos = self::getSystemInformation();
+		
+		$view->helpMessages = array(
+			'zlib'            => 'Installation_SystemCheckZlibHelp',
+			'SPL'             => 'Installation_SystemCheckSplHelp',
+			'iconv'           => 'Installation_SystemCheckIconvHelp',
+			'Reflection'	  => 'Required extension that is built in PHP, see http://www.php.net/manual/en/book.reflection.php',
+			'json'            => 'Installation_SystemCheckWarnJsonHelp',
+			'libxml'          => 'Installation_SystemCheckWarnLibXmlHelp',
+			'dom'             => 'Installation_SystemCheckWarnDomHelp',
+			'SimpleXML'       => 'Installation_SystemCheckWarnSimpleXMLHelp',
+			'set_time_limit'  => 'Installation_SystemCheckTimeLimitHelp',
+			'mail'            => 'Installation_SystemCheckMailHelp',
+			'parse_ini_file'  => 'Installation_SystemCheckParseIniFileHelp',
+			'glob'            => 'Installation_SystemCheckGlobHelp',
+			'debug_backtrace' => 'Installation_SystemCheckDebugBacktraceHelp',
+			'create_function' => 'Installation_SystemCheckCreateFunctionHelp',
+			'eval'            => 'Installation_SystemCheckEvalHelp',
+			'gzcompress'      => 'Installation_SystemCheckGzcompressHelp',
+			'gzuncompress'    => 'Installation_SystemCheckGzuncompressHelp',
+			'pack'            => 'Installation_SystemCheckPackHelp',
+		);
+
+		$view->problemWithSomeDirectories = (false !== array_search(false, $view->infos['directories']));
+	}
+	
+	/**
+	 * Performs extra system checks for the 'System Check' admin page. These
+	 * checks are not performed during Installation.
+	 * 
+	 * The following checks are performed:
+	 *  - Check for whether LOAD DATA INFILE can be used. The result of the check
+	 *    is stored in $result['load_data_infile_available']. The error message is
+	 *    stored in $result['load_data_infile_error'].
+	 * 
+	 * @return array
+	 */
+	public static function performAdminPageOnlySystemCheck()
+	{
+		$result = array();
+		
+		// check if LOAD DATA INFILE works
+		$optionTable = Piwik_Common::prefixTable('option');
+		$testOptionNames = array('test_system_check1', 'test_system_check2');
+		
+		$result['load_data_infile_available'] = false;
+		try
+		{
+			$result['load_data_infile_available'] = Piwik::tableInsertBatch(
+				$optionTable,
+				array('option_name', 'option_value'),
+				array(
+					array($testOptionNames[0], '1'),
+					array($testOptionNames[1], '2'),
+				),
+				$throwException = true
+			);
+		}
+		catch (Exception $ex)
+		{
+			$result['load_data_infile_error'] = str_replace("\n","<br/>", $ex->getMessage());
+		}
+		
+		// delete the temporary rows that were created
+		Piwik_Exec("DELETE FROM $optionTable WHERE option_name IN ('".implode("','", $testOptionNames)."')");
+		
+		return $result;
+	}
 }
