@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Installation.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: Installation.php 7676 2012-12-21 00:51:43Z capedfuzz $
  * 
  * @category Piwik_Plugins
  * @package Piwik_Installation
@@ -35,6 +35,8 @@ class Piwik_Installation extends Piwik_Plugin
 		$hooks = array(
 			'FrontController.NoConfigurationFile' => 'dispatch',
 			'FrontController.badConfigurationFile' => 'dispatch',
+            'AdminMenu.add' => 'addMenu',
+            'AssetManager.getCssFiles' => 'getCss',
 		);
 		return $hooks;
 	}
@@ -81,4 +83,25 @@ class Piwik_Installation extends Piwik_Plugin
 
 		exit;
 	}	
+
+	/**
+	 * Adds the 'System Check' admin page if the user is the super user.
+	 */
+	public function addMenu()
+	{
+		Piwik_AddAdminMenu('Installation_SystemCheck',
+						   array('module' => 'Installation', 'action' => 'systemCheckPage'),
+						   $addIf = Piwik::isUserIsSuperUser(),
+						   $order = 15);
+    }
+    
+    /**
+     * Adds CSS files to list of CSS files for asset manager.
+     */
+    public function getCss( $notification )
+    {
+        $cssFiles = &$notification->getNotificationObject();
+
+        $cssFiles[] = "plugins/Installation/templates/systemCheckPage.css";
+    }
 }
