@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: API.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: API.php 7607 2012-12-13 09:38:03Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_Live
@@ -112,8 +112,8 @@ class Piwik_Live_API
 	 * You can define any number of filters: none, one, many or all parameters can be defined
 	 *
 	 * @param int $idSite Site ID
-	 * @param bool|string $period (optional) Period to restrict to when looking at the logs
-	 * @param bool|string $date (optional) Date to restrict to
+	 * @param bool|string $period Period to restrict to when looking at the logs
+	 * @param bool|string $date Date to restrict to
 	 * @param bool|int $segment (optional) Number of visits rows to return
 	 * @param bool|int $filter_limit (optional)
 	 * @param bool|int $maxIdVisit (optional) Maximum idvisit to restrict the query to (useful when paginating)
@@ -121,7 +121,7 @@ class Piwik_Live_API
 	 *
 	 * @return Piwik_DataTable
 	 */
-	public function getLastVisitsDetails( $idSite, $period = false, $date = false, $segment = false, $filter_limit = false, $maxIdVisit = false, $minTimestamp = false )
+	public function getLastVisitsDetails( $idSite, $period, $date, $segment = false, $filter_limit = false, $maxIdVisit = false, $minTimestamp = false )
 	{
 		if(empty($filter_limit)) 
 		{
@@ -136,6 +136,7 @@ class Piwik_Live_API
 	/**
 	 * @deprecated
 	 */
+	
 	public function getLastVisits( $idSite, $filter_limit = 10, $minTimestamp = false )
 	{
 		return $this->getLastVisitsDetails($idSite, $period = false, $date = false, $segment = false, $filter_limit, $maxIdVisit = false, $minTimestamp );
@@ -183,15 +184,17 @@ class Piwik_Live_API
 			// eg. Downloads, Outlinks. For these, idaction_name is set to 0
 			$sql = "
 				SELECT
-					log_action.type as type,
+					COALESCE(log_action.type,log_action_title.type) AS type,
 					log_action.name AS url,
+					log_action.url_prefix,
 					log_action_title.name AS pageTitle,
 					log_action.idaction AS pageIdAction,
 					log_link_visit_action.idlink_va AS pageId,
-					log_link_visit_action.server_time as serverTimePretty
+					log_link_visit_action.server_time as serverTimePretty,
+					log_link_visit_action.time_spent_ref_action as timeSpentRef
 					$sqlCustomVariables
 				FROM " .Piwik_Common::prefixTable('log_link_visit_action')." AS log_link_visit_action
-					INNER JOIN " .Piwik_Common::prefixTable('log_action')." AS log_action
+					LEFT JOIN " .Piwik_Common::prefixTable('log_action')." AS log_action
 					ON  log_link_visit_action.idaction_url = log_action.idaction
 					LEFT JOIN " .Piwik_Common::prefixTable('log_action')." AS log_action_title
 					ON  log_link_visit_action.idaction_name = log_action_title.idaction
@@ -199,16 +202,18 @@ class Piwik_Live_API
 				 ";
 			$actionDetails = Piwik_FetchAll($sql, array($idvisit));
 			
-			foreach($actionDetails as &$actionDetail)
+			foreach($actionDetails as $actionIdx => &$actionDetail)
 			{
+				$actionDetail =& $actionDetails[$actionIdx];
 				$customVariablesPage = array();
 				for($i = 1; $i <= Piwik_Tracker::MAX_CUSTOM_VARIABLES; $i++)
 				{
-					if(!empty($actionDetail['custom_var_k'.$i])
-						&& !empty($actionDetail['custom_var_v'.$i]))
+					if(!empty($actionDetail['custom_var_k'.$i]))
 					{
+						$cvarKey = $actionDetail['custom_var_k'.$i];
+						$cvarKey = $this->getCustomVariablePrettyKey($cvarKey);
 						$customVariablesPage[$i] = array(
-							'customVariableName'.$i => $actionDetail['custom_var_k'.$i],
+							'customVariableName'.$i => $cvarKey,
 							'customVariableValue'.$i => $actionDetail['custom_var_v'.$i],
 						);
 					}
@@ -219,6 +224,17 @@ class Piwik_Live_API
 				{
 					$actionDetail['customVariables'] = $customVariablesPage;
 				}
+				// reconstruct url from prefix
+				$actionDetail['url'] = Piwik_Tracker_Action::reconstructNormalizedUrl($actionDetail['url'], $actionDetail['url_prefix']);
+				unset($actionDetail['url_prefix']);
+				// set the time spent for this action (which is the timeSpentRef of the next action)
+				if (isset($actionDetails[$actionIdx + 1]))
+				{
+					$actionDetail['timeSpent'] = $actionDetails[$actionIdx + 1]['timeSpentRef'];
+					$actionDetail['timeSpentPretty'] = Piwik::getPrettyTimeFromSeconds($actionDetail['timeSpent']);
+					
+				}
+				unset($actionDetails[$actionIdx]['timeSpentRef']); // not needed after timeSpent is added
 			}
 			
 			// If the visitor converted a goal, we shall select all Goals
@@ -343,6 +359,10 @@ class Piwik_Live_API
 						$details['type'] = 'outlink';
 						$details['icon'] = 'themes/default/images/link.gif';
 					break;
+					case Piwik_Tracker_Action::TYPE_SITE_SEARCH:
+						$details['type'] = 'search';
+						$details['icon'] = 'themes/default/images/search_ico.png';
+					break;
 					default:
 						$details['type'] = 'action';
 						$details['icon'] = null;
@@ -358,6 +378,18 @@ class Piwik_Live_API
 		return $table;
 	}
 
+	private function getCustomVariablePrettyKey($key)
+	{
+		$rename = array(
+			Piwik_Tracker_Action::CVAR_KEY_SEARCH_CATEGORY => Piwik_Translate('Actions_ColumnSearchCategory'),
+			Piwik_Tracker_Action::CVAR_KEY_SEARCH_COUNT => Piwik_Translate('Actions_ColumnSearchResultsCount'),
+		);
+		if(isset($rename[$key])) {
+			return $rename[$key];
+		}
+		return $key;
+	}
+
 	private function sortByServerTime($a, $b)
 	{
 		$ta = strtotime($a['serverTimePretty']);
@@ -509,6 +541,8 @@ class Piwik_Live_API
 		{
 			$toUnset[] = 'idvisitor';
 			$toUnset[] = 'location_ip';
+			$toUnset[] = 'location_latitude';
+			$toUnset[] = 'location_longitude';
 		}
 		foreach($toUnset as $keyName)
 		{
