@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Login.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: Login.php 7670 2012-12-19 22:13:38Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_Login
@@ -46,11 +46,12 @@ class Piwik_Login extends Piwik_Plugin
 	 */
 	function noAccess( $notification )
 	{
+		/* @var Exception  $exception */
 		$exception  = $notification->getNotificationObject();
 		$exceptionMessage = $exception->getMessage();
 
 		$controller = new Piwik_Login_Controller();
-		$controller->login($exceptionMessage);
+		$controller->login($exceptionMessage, Piwik::shouldLoggerLog() ? $exception->getTraceAsString() : '' );
 	}
 
 	/**
@@ -76,10 +77,13 @@ class Piwik_Login extends Piwik_Plugin
 	{
 		$auth = new Piwik_Login_Auth();
 		Zend_Registry::set('auth', $auth);
-
+		
+		$allowCookieAuthentication = $notification->getNotificationInfo();
+		
 		$action = Piwik::getAction();
-		if(Piwik::getModule() === 'API'
-			&& (empty($action) || $action == 'index'))
+		if (Piwik::getModule() === 'API'
+			&& (empty($action) || $action == 'index')
+			&& $allowCookieAuthentication !== true)
 		{
 			return;
 		}
@@ -138,5 +142,57 @@ class Piwik_Login extends Piwik_Plugin
 		$cookie->save();
 
 		@Piwik_Session::regenerateId();
+		
+		// remove password reset entry if it exists
+		self::removePasswordResetInfo($login);
+	}
+	
+	/**
+	 * Stores password reset info for a specific login.
+	 * 
+	 * @param string $login The user login for whom a password change was requested.
+	 * @param string $password The new password to set.
+	 */
+	public static function savePasswordResetInfo( $login, $password )
+	{
+		$optionName = self::getPasswordResetInfoOptionName($login);
+		$optionData = Piwik_UsersManager::getPasswordHash($password);
+		
+		Piwik_SetOption($optionName, $optionData);
+	}
+	
+	/**
+	 * Removes stored password reset info if it exists.
+	 * 
+	 * @param string $login The user login to check for.
+	 */
+	public static function removePasswordResetInfo( $login )
+	{
+		$optionName = self::getPasswordResetInfoOptionName($login);
+		Piwik_Option::getInstance()->delete($optionName);
+	}
+	
+	/**
+	 * Gets password hash stored in password reset info.
+	 * 
+	 * @param string $login The user login to check for.
+	 * @return string|false The hashed password or false if no reset info exists.
+	 */
+	public static function getPasswordToResetTo( $login )
+	{
+		$optionName = self::getPasswordResetInfoOptionName($login);
+		return Piwik_GetOption($optionName);
+	}
+	
+	/**
+	 * Gets the option name for the option that will store a user's password change
+	 * request.
+	 * 
+	 * @param string $login The user login for whom a password change was requested.
+	 * @return string
+	 */
+	public static function getPasswordResetInfoOptionName( $login )
+	{
+		return $login.'_reset_password_info';
 	}
 }
