@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Provider.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: Provider.php 7398 2012-11-07 22:17:51Z capedfuzz $
  *
  * @category Piwik_Plugins
  * @package Piwik_Provider
@@ -68,7 +68,7 @@ class Piwik_Provider extends Piwik_Plugin
 		$segments =& $notification->getNotificationObject();
 		$segments[] = array(
 		        'type' => 'dimension',
-		        'category' => 'Visit',
+		        'category' => 'Visit Location',
 		        'name' => Piwik_Translate('Provider_ColumnProvider'),
 		        'segment' => 'provider',
 				'acceptedValues' => 'comcast.net, proxad.net, etc.',
@@ -114,7 +114,6 @@ class Piwik_Provider extends Piwik_Plugin
 	
 	function postLoad()
 	{
-		Piwik_AddAction('template_headerUserCountry', array('Piwik_Provider','headerUserCountry'));
 		Piwik_AddAction('template_footerUserCountry', array('Piwik_Provider','footerUserCountry'));
 	}
 
@@ -163,6 +162,12 @@ class Piwik_Provider extends Piwik_Plugin
 	{
 		$visitorInfo =& $notification->getNotificationObject();
 		
+		// if provider info has already been set, abort
+		if (!empty($visitorInfo['location_provider']))
+		{
+			return;
+		}
+		
 		$ip = Piwik_IP::N2P($visitorInfo['location_ip']);
 		
 		// In case the IP was anonymized, we should not continue since the DNS reverse lookup will fail and this will slow down tracking
@@ -247,23 +252,13 @@ class Piwik_Provider extends Piwik_Plugin
 		return trim(strtolower(@Piwik_IP::getHostByAddr($ip)));
 	}
 
-	/**
-	 * @param Piwik_Event_Notification $notification  notification object
-	 */
-	static public function headerUserCountry($notification)
-	{
-		$out =& $notification->getNotificationObject();
-		$out = '<div id="leftcolumn">';
-	}
-
 	/**
 	 * @param Piwik_Event_Notification $notification  notification object
 	 */
 	static public function footerUserCountry($notification)
 	{
 		$out =& $notification->getNotificationObject();
-		$out = '</div>
-			<div id="rightcolumn">
+		$out = '<div>
 			<h2>'.Piwik_Translate('Provider_WidgetProviders').'</h2>';
 		$out .= Piwik_FrontController::getInstance()->fetchDispatch('Provider','getProvider');
 		$out .= '</div>';
