@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: functions.php 4181 2011-03-25 20:02:40Z vipsoft $
+ * @version $Id: functions.php 7628 2012-12-15 01:52:43Z capedfuzz $
  * 
  * @category Piwik_Plugins
  * @package Piwik_Provider
@@ -51,5 +51,14 @@ function Piwik_getHostnameUrl($in)
 		// link to "what does 'IP' mean?"
 		return "http://piwik.org/faq/general/#faq_52";
 	}
-	return "http://www.".$in."/";
+	
+	// if the name looks like it can be used in a URL, use it in one, otherwise link to startpage
+	if (preg_match("/^[a-zA-Z0-9_.]+$/", $in))
+	{
+		return "http://www.".$in."/";
+	}
+	else
+	{
+		return "https://startpage.com/do/search?q=".urlencode($in);
+	}
 }
