@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: Controller.php 7609 2012-12-13 10:49:29Z matt $
  * 
  * @category Piwik_Plugins
  * @package Piwik_Proxy
@@ -128,19 +128,24 @@ class Piwik_Proxy_Controller extends Piwik_Controller
 
 		// validate referrer
 		$referrer = Piwik_Url::getReferer();
-		if(!empty($referrer) && !Piwik_Url::isLocalUrl($referrer))
+		if(empty($referrer) || !Piwik_Url::isLocalUrl($referrer))
 		{
-			die('Invalid Referer detected - check that your browser sends the Referer header. <br/>The link you would have been redirected to is: '.$url);
+			die('Invalid Referer detected - check that your browser sends the Referer header.
+				<br/>The link you would have been redirected to is: '. $url);
 		}
 
 		// mask visits to *.piwik.org
-		if(self::isPiwikUrl($url))
+		if (!self::isPiwikUrl($url))
 		{
-			echo
-'<html><head>
-<meta http-equiv="refresh" content="0;url=' . $url . '" />
-</head></html>';
+			Piwik::checkUserHasSomeViewAccess();
 		}
+		if(!Piwik_Common::isLookLikeUrl($url))
+		{
+			die('Please check the &url= parameter: it should to be a valid URL');
+		}
+		@header('Content-Type: text/html; charset=utf-8');
+		echo '<html><head><meta http-equiv="refresh" content="0;url=' . $url . '" /></head></html>';
+		
 		exit;
 	}
 
@@ -162,6 +167,12 @@ class Piwik_Proxy_Controller extends Piwik_Controller
 		{
 			return true;
 		}
+		
+		// Allow clockworksms domain
+		if(strpos($url, 'http://www.clockworksms.com/') === 0)
+		{
+			return true;
+		}
 
 		return false;
 	}
