@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: API.php 5683 2012-01-18 17:01:19Z vipsoft $
+ * @version $Id: API.php 7458 2012-11-12 23:50:15Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_SEO
@@ -16,8 +16,8 @@
 require_once PIWIK_INCLUDE_PATH . '/plugins/Referers/functions.php';
 
 /**
- * The SEO API lets you access a list of SEO metrics for the specified URL: Google Pagerank, Yahoo back links, Yahoo Indexed pages,
- * Alexa Rank, and the age of the Domain name.
+ * The SEO API lets you access a list of SEO metrics for the specified URL: Google Pagerank, Goolge/Bing indexed pages
+ * Alexa Rank, age of the Domain name and count of DMOZ entries.
  * 
  * @package Piwik_SEO
  */
@@ -53,6 +53,16 @@ class Piwik_SEO_API
 				'logo' => Piwik_getSearchEngineLogoFromUrl('http://google.com'),
 				'id' => 'pagerank'
 			),
+            Piwik_Translate('SEO_Google_IndexedPages') => array(
+                'rank' => $rank->getIndexedPagesGoogle(),
+                'logo' => Piwik_getSearchEngineLogoFromUrl('http://google.com'),
+                'id' => 'google-index',
+            ),
+            Piwik_Translate('SEO_Bing_IndexedPages') => array(
+                'rank' => $rank->getIndexedPagesBing(),
+                'logo' => Piwik_getSearchEngineLogoFromUrl('http://bing.com'),
+                'id' => 'bing-index',
+			),
 			Piwik_Translate('SEO_AlexaRank') => array(
 				'rank' => $rank->getAlexaRank(),
 				'logo' => Piwik_getSearchEngineLogoFromUrl('http://alexa.com'),
@@ -61,9 +71,21 @@ class Piwik_SEO_API
 			Piwik_Translate('SEO_DomainAge') => array(
 				'rank' => $rank->getAge(),
 				'logo' => 'plugins/SEO/images/whois.png',
-				'id'   => 'domain-age'
+				'id'   => 'domain-age',
 			),
 		);
+
+		// Add DMOZ only if > 0 entries found
+		$dmozRank = array(
+			'rank' => $rank->getDmoz(),
+			'logo' => Piwik_getSearchEngineLogoFromUrl('http://dmoz.org'),
+			'id'   => 'dmoz',
+		);
+		if($dmozRank['rank'] > 0)
+		{
+			$data[Piwik_Translate('SEO_Dmoz')] = $dmozRank;
+		}
+
 		$dataTable = new Piwik_DataTable();
 		$dataTable->addRowsFromArrayWithIndexLabel($data);
 		return $dataTable;
