@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: RankChecker.php 5271 2011-10-08 15:17:18Z vipsoft $
+ * @version $Id: RankChecker.php 7757 2013-01-15 16:41:26Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_SEO
@@ -22,7 +22,6 @@
 class Piwik_SEO_RankChecker
 {
 	private $url;
-	private $results = array();
 
 	public function __construct($url)
 	{
@@ -62,7 +61,12 @@ class Piwik_SEO_RankChecker
 		}
 	}
 
-	public function getPageRank()
+    /**
+     * Returns the google page rank for the current url
+     *
+     * @return int
+     */
+    public function getPageRank()
 	{
 		$chwrite = $this->CheckHash($this->HashURL($this->url));
 
@@ -74,91 +78,161 @@ class Piwik_SEO_RankChecker
 		return $value;
 	}
 
-	public function getAlexaRank()
+    /**
+     * Returns the alexa traffic rank for the current url
+     *
+     * @return int
+     */
+    public function getAlexaRank()
 	{
-		$url = $this->url;
-		$xml = @simplexml_load_string($this->getPage('http://data.alexa.com/data?cli=10&url=' . $url));
+        $xml = @simplexml_load_string($this->getPage('http://data.alexa.com/data?cli=10&url=' . urlencode($this->url)));
 		return $xml ? $xml->SD->POPULARITY['TEXT'] : '';
 	}
 
+    /**
+     * Returns the number of Dmoz.org entries for the current url
+     *
+     * @return int
+     */
 	public function getDmoz()
 	{
-		$url = preg_replace('/^www\./', '', $this->url);
-		$url = "http://search.dmoz.org/cgi-bin/search?search=$url";
+        $url = 'http://www.dmoz.org/search?q=' . urlencode($this->url);
 		$data = $this->getPage($url);
-		if(preg_match('<center>No <b><a href="http://dmoz\.org/">Open Directory Project</a></b> results found</center>', $data))
-		{
-			$value = false;
+        preg_match('#Open Directory Sites[^\(]+\([0-9]-[0-9]+ of ([0-9]+)\)#', $data, $p);
+        if (!empty($p[1])) {
+            return (int) $p[1];
+        }
+        return 0;
+	}
+
+    /**
+     * Returns the number of pages google holds in it's index for the current url
+     *
+     * @return int
+     */
+    public function getIndexedPagesGoogle()
+	{
+        $url = 'http://www.google.com/search?hl=en&q=site%3A' . urlencode($this->url);
+		$data = $this->getPage($url);
+        if (preg_match('#about ([0-9\,]+) results#i', $data, $p)) {
+            return (int) str_replace(',', '', $p[1]);
 		}
-		else
-		{
-			$value = true;
+        return 0;
+	}
+
+    /**
+     * Returns the number of pages bing holds in it's index for the current url
+     *
+     * @return int
+     */
+    public function getIndexedPagesBing()
+	{
+        $url = 'http://www.bing.com/search?mkt=en-US&q=site%3A' . urlencode($this->url);
+		$data = $this->getPage($url);
+        if (preg_match('#([0-9\,]+) results#i', $data, $p)) {
+            return (int) str_replace(',', '', $p[1]);
 		}
-		return $value;
+        return 0;
 	}
 
-	public function getYahooDirectory()
-	{
-		$url = preg_replace('/^www\./', '', $this->url);
-		$url = "http://search.yahoo.com/search/dir?p=$url";
-		$data = $this->getPage($url);
-		if(preg_match('No Directory Search results were found\.', $data)) {
-			$value = false;
-		} else {
-			$value = true;
-		}
-		return $value;
-	}
+    /**
+     * Returns the domain age for the current url
+     *
+     * @return int
+     */
+    public function getAge()
+    {
+        $ageArchiveOrg = $this->_getAgeArchiveOrg();
+        $ageWhoIs = $this->_getAgeWhoIs();
+        $ageWhoisCom = $this->_getAgeWhoisCom();
 
-	public function getBacklinksGoogle()
-	{
-		$url = $this->url;
-		$url = 'http://www.google.com/search?q=link%3A'.urlencode($url);
-		$data = $this->getPage($url);
-		preg_match('/of about \<b\>([0-9\,]+)\<\/b\>/si', $data, $p);
-		$value = isset($p[1]) ? $this->toInt($p[1]) : 0;
-		return $value;
-	}
+        $ages = array();
 
-	public function getBacklinksYahoo()
-	{
-		$url = $this->url;
-		$url = 'http://siteexplorer.search.yahoo.com/search?p='.urlencode($url);
-		$data = $this->getPage($url);
-		preg_match('/Inlinks \(([0-9\,]+)\)/si', $data, $p);
-		$value = isset($p[1]) ? $this->toInt($p[1]) : 0;
-		return $value;
-	}
+        if($ageArchiveOrg > 0) {
+            $ages[] = $ageArchiveOrg;
+        }
 
-	public function getAge()
-	{
-		$url = preg_replace('/^www\./', '', $this->url);
-		$url = 'http://www.who.is/whois/'.urlencode($url);
-		$data = $this->getPage($url);
-		preg_match('#(?:Creation Date|Created On):\s*([a-z0-9/-]+)#si', $data, $p);
-		if(!isset($p[1]))
-		{
-			return null;
-		}
-		$value = time() - strtotime($p[1]);
-		$value = Piwik::getPrettyTimeFromSeconds($value);
-		return $value;
-	}
+        if($ageWhoIs > 0) {
+            $ages[] = $ageWhoIs;
+        }
 
-	public function getIndexedYahoo()
-	{
-		$url = $this->url;
-		$url = 'http://siteexplorer.search.yahoo.com/search?p='.urlencode($url);
-		$data = $this->getPage($url);
-		preg_match('/Pages \(([0-9,]{1,})\)/im', $data, $p);
-		$value = isset($p[1]) ? $this->toInt($p[1]) : 0;
-		return $value;
-	}
+        if($ageWhoisCom > 0) {
+            $ages[] = $ageWhoisCom;
+        }
 
-	private function toInt($string)
-	{
-		return preg_replace('#[^0-9]#si', '', $string);
-	}
+        if(count($ages) > 1) {
+            $maxAge = min($ages);
+        } else {
+            $maxAge = array_shift($ages);
+        }
+
+        if ($maxAge) {
+            return Piwik::getPrettyTimeFromSeconds(time() - $maxAge);
+        }
+        return false;
+    }
+
+    /**
+     * Returns the domain age archive.org lists for the current url
+     *
+     * @return int
+     */
+    protected function _getAgeArchiveOrg()
+    {
+        $url  = str_replace('www.', '', $this->url);
+        $data = @$this->getPage('http://wayback.archive.org/web/*/' . urlencode($url));
+        preg_match('#<a href=\"([^>]*)' . preg_quote($url) . '/\">([^<]*)<\/a>#', $data, $p);
+        if (!empty($p[2])) {
+            $value = strtotime($p[2]);
+            if ($value === false) {
+                return 0;
+            }
+            return $value;
+        }
+        return 0;
+    }
+
+    /**
+     * Returns the domain age who.is lists for the current url
+     *
+     * @return int
+     */
+    protected function _getAgeWhoIs()
+    {
+        $url  = preg_replace('/^www\./', '', $this->url);
+        $url  = 'http://www.who.is/whois/' . urlencode($url);
+        $data = $this->getPage($url);
+        preg_match('#(?:Creation Date|Created On)\.*:\s*([ \ta-z0-9\/\-:\.]+)#si', $data, $p);
+        if (!empty($p[1])) {
+            $value = strtotime(trim($p[1]));
+            if ($value === false) {
+                return 0;
+            }
+            return $value;
+        }
+        return 0;
+    }
+
+    /**
+     * Returns the domain age whois.com lists for the current url
+     *
+     * @return int
+     */
+    protected function _getAgeWhoisCom()
+    {
+        $url  = preg_replace('/^www\./', '', $this->url);
+        $url  = 'http://www.whois.com/whois/' . urlencode($url);
+        $data = $this->getPage($url);
+        preg_match('#(?:Creation Date|Created On):\s*([ \ta-z0-9\/\-:\.]+)#si', $data, $p);
+        if (!empty($p[1])) {
+            $value = strtotime(trim($p[1]));
+            if ($value === false) {
+                return 0;
+            }
+            return $value;
+        }
+        return 0;
+    }
 
 	/**
 	 * Convert numeric string to int
