@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: API.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: API.php 7535 2012-11-24 08:01:10Z capedfuzz $
  * 
  * @category Piwik_Plugins
  * @package Piwik_SitesManager
@@ -29,7 +29,8 @@
 class Piwik_SitesManager_API 
 {
 	static private $instance = null;
-	
+	const DEFAULT_SEARCH_KEYWORD_PARAMETERS = 'q,query,s,search,searchword,k,keyword';
+
 	/**
 	 * @return Piwik_SitesManager_API
 	 */
@@ -46,7 +47,11 @@ class Piwik_SitesManager_API
 	const OPTION_DEFAULT_TIMEZONE = 'SitesManager_DefaultTimezone';
 	const OPTION_DEFAULT_CURRENCY = 'SitesManager_DefaultCurrency';
 	const OPTION_EXCLUDED_QUERY_PARAMETERS_GLOBAL = 'SitesManager_ExcludedQueryParameters';
-	
+	const OPTION_SEARCH_KEYWORD_QUERY_PARAMETERS_GLOBAL = 'SitesManager_SearchKeywordParameters';
+	const OPTION_SEARCH_CATEGORY_QUERY_PARAMETERS_GLOBAL = 'SitesManager_SearchCategoryParameters';
+	const OPTION_EXCLUDED_USER_AGENTS_GLOBAL = 'SitesManager_ExcludedUserAgentsGlobal';
+	const OPTION_SITE_SPECIFIC_USER_AGENT_EXCLUDE_ENABLE = 'SitesManager_EnableSiteSpecificUserAgentExclude';
+
 	/**
 	 * Returns the javascript tag for the given idSite.
 	 * This tag must be included on every page to be tracked by Piwik
@@ -435,7 +440,10 @@ class Piwik_SitesManager_API
 	 * @param array|string The URLs array must contain at least one URL called the 'main_url' ; 
 	 * 						if several URLs are provided in the array, they will be recorded 
 	 * 						as Alias URLs for this website.
-	 * @param int Is Ecommerce Reporting enabled for this website? 
+	 * @param int Is Ecommerce Reporting enabled for this website?
+	 * @param int $sitesearch Whether site search is enabled, 0 or 1
+	 * @param string $searchKeywordParameters Comma separated list of search keyword parameter names
+	 * @param string $searchCategoryParameters Comma separated list of search category parameter names
 	 * @param string Comma separated list of IPs to exclude from the reports (allows wildcards)
 	 * @param string Timezone string, eg. 'Europe/London'
 	 * @param string Currency, eg. 'EUR'
@@ -445,7 +453,19 @@ class Piwik_SitesManager_API
 	 * 
 	 * @return int the website ID created
 	 */
-	public function addSite( $siteName, $urls, $ecommerce = null, $excludedIps = null, $excludedQueryParameters = null, $timezone = null, $currency = null, $group = null, $startDate = null )
+	public function addSite( $siteName,
+							   $urls,
+							   $ecommerce = null,
+							   $siteSearch = null,
+							   $searchKeywordParameters = null,
+							   $searchCategoryParameters = null,
+							   $excludedIps = null,
+							   $excludedQueryParameters = null,
+							   $timezone = null,
+							   $currency = null,
+							   $group = null,
+							   $startDate = null,
+							   $excludedUserAgents = null )
 	{
 		Piwik::checkUserIsSuperUser();
 		
@@ -453,8 +473,10 @@ class Piwik_SitesManager_API
 		$urls = $this->cleanParameterUrls($urls);
 		$this->checkUrls($urls);
 		$this->checkAtLeastOneUrl($urls);
+		$siteSearch = $this->checkSiteSearch($siteSearch);
+		list($searchKeywordParameters, $searchCategoryParameters ) = $this->checkSiteSearchParameters($searchKeywordParameters, $searchCategoryParameters);
+
 		$timezone = trim($timezone);
-		
 		if(empty($timezone))
 		{
 			$timezone = $this->getDefaultTimezone();
@@ -478,10 +500,14 @@ class Piwik_SitesManager_API
 		);
 	
 		$bind['excluded_ips'] = $this->checkAndReturnExcludedIps($excludedIps);
-		$bind['excluded_parameters'] = $this->checkAndReturnExcludedQueryParameters($excludedQueryParameters);
+		$bind['excluded_parameters'] = $this->checkAndReturnCommaSeparatedStringList($excludedQueryParameters);
+		$bind['excluded_user_agents'] = $this->checkAndReturnCommaSeparatedStringList($excludedUserAgents);
 		$bind['timezone'] = $timezone;
 		$bind['currency'] = $currency;
 		$bind['ecommerce'] = (int)$ecommerce;
+		$bind['sitesearch'] = $siteSearch;
+		$bind['sitesearch_keyword_parameters'] = $searchKeywordParameters;
+		$bind['sitesearch_category_parameters'] = $searchCategoryParameters;
 		$bind['ts_created'] = !is_null($startDate) 
 									? Piwik_Date::factory($startDate)->getDatetime()
 									: Piwik_Date::now()->getDatetime();
@@ -678,7 +704,50 @@ class Piwik_SitesManager_API
 		Piwik_Common::deleteTrackerCache();
 		return true;
 	}
-	
+
+
+	/**
+	 * Sets Site Search keyword/category parameter names, to be used on websites which have not specified these values
+	 * Expects Comma separated list of query params names
+	 *
+	 * @param string
+	 * @param string
+	 * @return bool
+	 */
+	public function setGlobalSearchParameters($searchKeywordParameters, $searchCategoryParameters)
+	{
+		Piwik::checkUserIsSuperUser();
+		Piwik_SetOption(self::OPTION_SEARCH_KEYWORD_QUERY_PARAMETERS_GLOBAL, $searchKeywordParameters);
+		Piwik_SetOption(self::OPTION_SEARCH_CATEGORY_QUERY_PARAMETERS_GLOBAL, $searchCategoryParameters);
+		Piwik_Common::deleteTrackerCache();
+		return true;
+	}
+
+	/**
+	 * @return string Comma separated list of URL parameters
+	 */
+	public function getSearchKeywordParametersGlobal()
+	{
+		Piwik::checkUserHasSomeAdminAccess();
+		$names = Piwik_GetOption(self::OPTION_SEARCH_KEYWORD_QUERY_PARAMETERS_GLOBAL);
+		if($names === false) {
+			$names = self::DEFAULT_SEARCH_KEYWORD_PARAMETERS;
+		}
+		if(empty($names)) {
+			$names = '';
+		}
+		return $names;
+	}
+
+	/**
+	 * @return string Comma separated list of URL parameters
+	 */
+	public function getSearchCategoryParametersGlobal()
+	{
+		Piwik::checkUserHasSomeAdminAccess();
+		return Piwik_GetOption(self::OPTION_SEARCH_CATEGORY_QUERY_PARAMETERS_GLOBAL);
+	}
+
 	/**
 	 * Returns the list of URL query parameters that are excluded from all websites 
 	 * 
@@ -686,10 +755,71 @@ class Piwik_SitesManager_API
 	 */
 	public function getExcludedQueryParametersGlobal()
 	{
-		Piwik::checkUserHasSomeAdminAccess();
+		Piwik::checkUserHasSomeViewAccess();
 		return Piwik_GetOption(self::OPTION_EXCLUDED_QUERY_PARAMETERS_GLOBAL);
 	}
 	
+	/**
+	 * Returns the list of user agent substrings to look for when excluding visits for
+	 * all websites. If a visitor's user agent string contains one of these substrings,
+	 * their visits will not be included.
+	 * 
+	 * @return string Comma separated list of strings.
+	 */
+	public function getExcludedUserAgentsGlobal()
+	{
+		Piwik::checkUserHasSomeAdminAccess();
+		return Piwik_GetOption(self::OPTION_EXCLUDED_USER_AGENTS_GLOBAL);
+	}
+	
+	/**
+	 * Sets list of user agent substrings to look for when excluding visits. For more info,
+	 * @see getExcludedUserAgentsGlobal.
+	 * 
+	 * @param string $excludedUserAgents Comma separated list of strings. Each element is trimmed,
+	 *                                   and empty strings are removed.
+	 */
+	public function setGlobalExcludedUserAgents( $excludedUserAgents )
+	{
+		Piwik::checkUserIsSuperUser();
+		
+		// update option
+		$excludedUserAgents = $this->checkAndReturnCommaSeparatedStringList($excludedUserAgents);
+		Piwik_SetOption(self::OPTION_EXCLUDED_USER_AGENTS_GLOBAL, $excludedUserAgents);
+		
+		// make sure tracker cache will reflect change
+		Piwik_Common::deleteTrackerCache();
+	}
+	
+	/**
+	 * Returns true if site-specific user agent exclusion has been enabled. If it hasn't,
+	 * only the global user agent substrings (see @setGlobalExcludedUserAgents) will be used.
+	 * 
+	 * @return bool
+	 */
+	public function isSiteSpecificUserAgentExcludeEnabled()
+	{
+		Piwik::checkUserHasSomeAdminAccess();
+		return (bool)Piwik_GetOption(self::OPTION_SITE_SPECIFIC_USER_AGENT_EXCLUDE_ENABLE);
+	}
+	
+	/**
+	 * Sets whether it should be allowed to exclude different user agents for different
+	 * websites.
+	 * 
+	 * @param bool $enabled
+	 */
+	public function setSiteSpecificUserAgentExcludeEnabled( $enabled )
+	{
+		Piwik::checkUserIsSuperUser();
+		
+		// update option
+		Piwik_SetOption(self::OPTION_SITE_SPECIFIC_USER_AGENT_EXCLUDE_ENABLE, $enabled);
+		
+		// make sure tracker cache will reflect change
+		Piwik_Common::deleteTrackerCache();
+	}
+	
 	/**
 	 * Sets list of URL query parameters to be excluded on all websites.
 	 * Will also apply to websites created in the future.
@@ -700,7 +830,7 @@ class Piwik_SitesManager_API
 	public function setGlobalExcludedQueryParameters($excludedQueryParameters)
 	{
 		Piwik::checkUserIsSuperUser();
-		$excludedQueryParameters = $this->checkAndReturnExcludedQueryParameters($excludedQueryParameters);
+		$excludedQueryParameters = $this->checkAndReturnCommaSeparatedStringList($excludedQueryParameters);
 		Piwik_SetOption(self::OPTION_EXCLUDED_QUERY_PARAMETERS_GLOBAL, $excludedQueryParameters);
 		Piwik_Common::deleteTrackerCache();
 		return true;
@@ -785,7 +915,10 @@ class Piwik_SitesManager_API
 	 * @param int $idSite website ID defining the website to edit
 	 * @param string $siteName website name
 	 * @param string|array $urls the website URLs
-	 * @param null $ecommerce
+	 * @param int $ecommerce Whether Ecommerce is enabled, 0 or 1
+	 * @param int $sitesearch Whether site search is enabled, 0 or 1
+	 * @param string $searchKeywordParameters Comma separated list of search keyword parameter names
+	 * @param string $searchCategoryParameters Comma separated list of search category parameter names
 	 * @param string $excludedIps Comma separated list of IPs to exclude from being tracked (allows wildcards)
 	 * @param null $excludedQueryParameters
 	 * @param string $timezone Timezone
@@ -796,7 +929,20 @@ class Piwik_SitesManager_API
 	 * @throws Exception
 	 * @return bool true on success
 	 */
-	public function updateSite( $idSite, $siteName, $urls = null, $ecommerce = null, $excludedIps = null, $excludedQueryParameters = null, $timezone = null, $currency = null, $group = null, $startDate = null)
+	public function updateSite( $idSite,
+	                            $siteName,
+	                            $urls = null,
+	                            $ecommerce = null,
+	                            $siteSearch = null,
+	                            $searchKeywordParameters = null,
+	                            $searchCategoryParameters = null,
+	                            $excludedIps = null,
+	                            $excludedQueryParameters = null,
+	                            $timezone = null,
+	                            $currency = null,
+	                            $group = null,
+	                            $startDate = null,
+	                            $excludedUserAgents = null)
 	{
 		Piwik::checkUserHasAdminAccess($idSite);
 
@@ -807,7 +953,7 @@ class Piwik_SitesManager_API
 		}
 
 		$this->checkName($siteName);
-		
+
 		// Build the SQL UPDATE based on specified updates to perform
 		$bind = array();
 		if(!is_null($urls))
@@ -845,7 +991,14 @@ class Piwik_SitesManager_API
 			$bind['ts_created'] = Piwik_Date::factory($startDate)->getDatetime();
 		}
 		$bind['excluded_ips'] = $this->checkAndReturnExcludedIps($excludedIps);
-		$bind['excluded_parameters'] = $this->checkAndReturnExcludedQueryParameters($excludedQueryParameters);
+		$bind['excluded_parameters'] = $this->checkAndReturnCommaSeparatedStringList($excludedQueryParameters);
+		$bind['excluded_user_agents'] = $this->checkAndReturnCommaSeparatedStringList($excludedUserAgents);
+
+		$bind['sitesearch'] = $this->checkSiteSearch($siteSearch);
+		list($searchKeywordParameters, $searchCategoryParameters ) = $this->checkSiteSearchParameters($searchKeywordParameters, $searchCategoryParameters);
+		$bind['sitesearch_keyword_parameters'] = $searchKeywordParameters;
+		$bind['sitesearch_category_parameters'] = $searchCategoryParameters;
+
 		$bind['name'] = $siteName;
 		$db = Zend_Registry::get('db');
 		$db->update(Piwik_Common::prefixTable("site"), 
@@ -864,7 +1017,7 @@ class Piwik_SitesManager_API
 		Piwik_PostEvent('SitesManager.updateSite', $idSite);
 	}
 	
-	private function checkAndReturnExcludedQueryParameters($parameters)
+	private function checkAndReturnCommaSeparatedStringList($parameters)
 	{
 		$parameters = trim($parameters);
 		if(empty($parameters))
@@ -1082,6 +1235,29 @@ class Piwik_SitesManager_API
 		}
 	}
 
+
+	private function checkSiteSearch($siteSearch)
+	{
+		if($siteSearch === null) {
+			return "1";
+		}
+		return $siteSearch == 1 ? "1" : "0";
+	}
+
+	private function checkSiteSearchParameters($searchKeywordParameters, $searchCategoryParameters)
+	{
+		$searchKeywordParameters = trim($searchKeywordParameters);
+		$searchCategoryParameters = trim($searchCategoryParameters);
+		if(empty($searchKeywordParameters)) {
+			$searchKeywordParameters = '';
+		}
+		if(empty($searchCategoryParameters)) {
+			$searchCategoryParameters = '';
+		}
+
+		return array($searchKeywordParameters, $searchCategoryParameters);
+	}
+
 	/**
 	 * Check that the array of URLs are valid URLs
 	 * 
