@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: SitesManager.php 6243 2012-05-02 22:08:23Z SteveG $
+ * @version $Id: SitesManager.php 7745 2013-01-10 22:52:55Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_SitesManager
@@ -82,19 +82,41 @@ class Piwik_SitesManager extends Piwik_Plugin
 		// add the 'hosts' entry in the website array
 		$array =& $notification->getNotificationObject();
 		$array['hosts'] = $this->getTrackerHosts($idSite);
-		$array['excluded_ips'] = $this->getTrackerExcludedIps($idSite);
-		$array['excluded_parameters'] = $this->getTrackerExcludedQueryParameters($idSite);
+
+		$website = Piwik_SitesManager_API::getInstance()->getSiteFromId($idSite);
+		$array['excluded_ips'] = $this->getTrackerExcludedIps($website);
+		$array['excluded_parameters'] = self::getTrackerExcludedQueryParameters($website);
+		$array['excluded_user_agents'] = self::getExcludedUserAgents($website);
+		$array['sitesearch'] = $website['sitesearch'];
+		$array['sitesearch_keyword_parameters'] = $this->getTrackerSearchKeywordParameters($website);
+		$array['sitesearch_category_parameters'] = $this->getTrackerSearchCategoryParameters($website);
+	}
+
+	private function getTrackerSearchKeywordParameters($website)
+	{
+		$searchParameters = $website['sitesearch_keyword_parameters'];
+		if(empty($searchParameters)) {
+			$searchParameters = Piwik_SitesManager_API::getInstance()->getSearchKeywordParametersGlobal();
+		}
+		return explode(",", $searchParameters);
+	}
+
+	private function getTrackerSearchCategoryParameters($website)
+	{
+		$searchParameters = $website['sitesearch_category_parameters'];
+		if(empty($searchParameters)) {
+			$searchParameters = Piwik_SitesManager_API::getInstance()->getSearchCategoryParametersGlobal();
+		}
+		return explode(",", $searchParameters);
 	}
 
 	/**
 	 * Returns the array of excluded IPs to save in the config file
 	 *
-	 * @param int $idSite
 	 * @return array
 	 */
-	private function getTrackerExcludedIps($idSite)
+	private function getTrackerExcludedIps($website)
 	{
-		$website = Piwik_SitesManager_API::getInstance()->getSiteFromId($idSite);
 		$excludedIps = $website['excluded_ips'];
 		$globalExcludedIps = Piwik_SitesManager_API::getInstance()->getExcludedIpsGlobal();
 
@@ -111,21 +133,48 @@ class Piwik_SitesManager extends Piwik_Plugin
 		}
 		return $ipRanges;
 	}
+	
+	/**
+	 * Returns the array of excluded user agent substrings for a site. Filters out
+	 * any garbage data & trims each entry.
+	 * 
+	 * @param array $website The full set of information for a site.
+	 * @return array
+	 */
+	private static function getExcludedUserAgents( $website )
+	{
+		$excludedUserAgents = Piwik_SitesManager_API::getInstance()->getExcludedUserAgentsGlobal();
+		if (Piwik_SitesManager_API::getInstance()->isSiteSpecificUserAgentExcludeEnabled())
+		{
+			$excludedUserAgents .= ','.$website['excluded_user_agents'];
+		}
+		return self::filterBlankFromCommaSepList($excludedUserAgents);
+	}
 
 	/**
 	 * Returns the array of URL query parameters to exclude from URLs
 	 *
-	 * @param int $idSite
 	 * @return array
 	 */
-	private function getTrackerExcludedQueryParameters($idSite)
+	public static function getTrackerExcludedQueryParameters($website)
 	{
-		$website = Piwik_SitesManager_API::getInstance()->getSiteFromId($idSite);
 		$excludedQueryParameters = $website['excluded_parameters'];
 		$globalExcludedQueryParameters = Piwik_SitesManager_API::getInstance()->getExcludedQueryParametersGlobal();
 
 		$excludedQueryParameters .= ',' . $globalExcludedQueryParameters;
-		$parameters = explode(',', $excludedQueryParameters);
+		return self::filterBlankFromCommaSepList($excludedQueryParameters);
+	}
+	
+	/**
+	 * Trims each element of a comma-separated list of strings, removes empty elements and
+	 * returns the result (as an array).
+	 * 
+	 * @param string $parameters The unfiltered list.
+	 * @return array The filtered list of strings as an array.
+	 */
+	static private function filterBlankFromCommaSepList( $parameters )
+	{
+		$parameters = explode(',', $parameters);
 		$parameters = array_filter($parameters, 'strlen');
 		$parameters = array_unique($parameters);
 		return $parameters;
