@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 3565 2011-01-03 05:49:45Z matt $
+ * @version $Id: Controller.php 6266 2012-05-16 21:22:18Z SteveG $
  * 
  * @category Piwik_Plugins
  * @package Piwik_Widgetize
@@ -19,7 +19,7 @@ class Piwik_Widgetize_Controller extends Piwik_Controller
 	function index()
 	{
 		$view = Piwik_View::factory('index');
-		$view->availableWidgets = json_encode(Piwik_GetWidgetsList());
+		$view->availableWidgets = Piwik_Common::json_encode(Piwik_GetWidgetsList());
 		$this->setGeneralVariablesView($view);
 		echo $view->render();
 	}
@@ -65,8 +65,13 @@ class Piwik_Widgetize_Controller extends Piwik_Controller
 		$actionName = Piwik_Common::getRequestVar('actionToWidgetize');
 		$parameters = array ( $fetch = true );
 		$outputDataTable = Piwik_FrontController::getInstance()->fetchDispatch( $controllerName, $actionName, $parameters);
-		$view = Piwik_View::factory('iframe');
+		if($controllerName == 'Dashboard' && $actionName == 'index') {
+			$view = Piwik_View::factory('empty');
+		} else {
+			$view = Piwik_View::factory('iframe');
+		}
 		$this->setGeneralVariablesView($view);
+		$view->setXFrameOptions('allow');
 		$view->content = $outputDataTable;
 		echo $view->render();
 	}
